{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Домашнее задание 6\n",
    "**Выполнил: Ким Адамейко, группа мАДБМ16**"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\n",
      "                         MODELLER 9.19, 2017/07/19, r11078\n",
      "\n",
      "     PROTEIN STRUCTURE MODELLING BY SATISFACTION OF SPATIAL RESTRAINTS\n",
      "\n",
      "\n",
      "                     Copyright(c) 1989-2017 Andrej Sali\n",
      "                            All Rights Reserved\n",
      "\n",
      "                             Written by A. Sali\n",
      "                               with help from\n",
      "              B. Webb, M.S. Madhusudhan, M-Y. Shen, G.Q. Dong,\n",
      "          M.A. Marti-Renom, N. Eswar, F. Alber, M. Topf, B. Oliva,\n",
      "             A. Fiser, R. Sanchez, B. Yerkovich, A. Badretdinov,\n",
      "                     F. Melo, J.P. Overington, E. Feyfant\n",
      "                 University of California, San Francisco, USA\n",
      "                    Rockefeller University, New York, USA\n",
      "                      Harvard University, Cambridge, USA\n",
      "                   Imperial Cancer Research Fund, London, UK\n",
      "              Birkbeck College, University of London, London, UK\n",
      "\n",
      "\n",
      "Kind, OS, HostName, Kernel, Processor: 4, Linux shadbox 3.2.0-29-generic x86_64\n",
      "Date and time of compilation         : 2017/07/19 14:40:43\n",
      "MODELLER executable type             : x86_64-intel8\n",
      "Job starting time (YY/MM/DD HH:MM:SS): 2017/12/29 05:44:41\n",
      "\n"
     ]
    }
   ],
   "source": [
    "import sys \n",
    "import modeller \n",
    "import _modeller\n",
    "import modeller.automodel \n",
    "\n",
    "env = modeller.environ()\n",
    "env.io.hetatm = True\n",
    "modeller.log.none()   # отключаем обширный вывод лога\n",
    "\n",
    "import pubchempy as pcp\n",
    "import py3Dmol\n",
    "\n",
    "from rdkit import Chem\n",
    "from rdkit.Chem import AllChem\n",
    "from rdkit.Chem.Draw import IPythonConsole \n",
    "from __future__ import print_function, division\n",
    "\n",
    "from IPython.display import display,Image, Markdown\n",
    "\n",
    "def show_compound_3d(smiles, view, grid=(0, 0), style={'stick': {}}):\n",
    "    m2d = Chem.MolFromSmiles(smiles)\n",
    "    m3d = Chem.AddHs(m2d)\n",
    "    Chem.AllChem.EmbedMolecule(m3d)\n",
    "    AllChem.MMFFOptimizeMolecule(m3d,maxIters=500,nonBondedThresh=200 )\n",
    "    mb = Chem.MolToMolBlock(m3d)\n",
    "    view.addModel(mb,'sdf', viewer=grid)\n",
    "    view.setStyle({'model':0},style, viewer=grid)\n",
    "    view.zoomTo(viewer=grid)\n",
    "    return view"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "uniprot_id = 'P00702'\n",
    "# Скачаем PDB-файл белка-лизоцима и FASTA-последовательность тестового белка, который будем выравнивать \n",
    "! wget -nv -nc http://www.pdb.org/pdb/files/1lmp.pdb\n",
    "! wget -nv -nc http://www.uniprot.org/uniprot/{uniprot_id}.fasta\n",
    "! wget -nv -nc http://www.ebirds.ru/images/large/84.jpg"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Будем работать с лизоцимом *Phasianus colchicus colchicus*, обыкновенного фазана ([cтраница в Uniprot](http://www.uniprot.org/uniprot/P00702)).\n",
    "![](84.jpg)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\r\n",
      ">P1;without_ligand\r\n",
      "sequence::     : :     : :::-1.00:-1.00\r\n",
      "MRSLLILVLCFLPLAAPGKVYGRCELAAAMKRMGLDNYRGYSLGNWVCAAKFESNFNTGATNRNTDGSTDYGILQ\r\n",
      "INSRWWCNDGRTPGSKNLCHIPCSALLSSDITASVNCAKKIVSDGNGMNAWVAWRKHCKGTDVNVWIRGCRL---*\r\n",
      "\r\n",
      ">P1;1lmp\r\n",
      "structureX:1lmp.pdb:   1 :A:+132 :A:MOL_ID  1; MOLECULE  LYSOZYME; CHAIN  A; SYNONYM  MUCOPEPTIDE N-ACETYLMURAMYLHYDROLASE; EC  3.2.1.17:MOL_ID  1; ORGANISM_SCIENTIFIC  ONCORHYNCHUS MYKISS; ORGANISM_COMMON  RAINBOW TROUT; ORGANISM_TAXID  8022; ORGAN  KIDNEY: 2.00: 0.16\r\n",
      "------------------KVYDRCELARALKASGMDGYAGNSLPNWVCLSKWESSYNTQATNRNTDGSTDYGIFQ\r\n",
      "INSRYWCDDGRTPGAKNVCGIRCSQLLTDDLTVAIRCAKRVVLDPNGIGAWVAWRLHCQNQDLRSYVAGCGV...*\r\n"
     ]
    }
   ],
   "source": [
    "alignm=modeller.alignment(env)                                      # Создадим объект-выравнивание\n",
    "alignm.append(file = uniprot_id + '.fasta',                         # добавим последовательность и структуру\n",
    "              align_codes='all',alignment_format='FASTA')\n",
    "mdl = modeller.model(env, file='1lmp.pdb', \n",
    "                     model_segment=('FIRST:'+'A', 'LAST:'+'A'))     # создадим модель\n",
    "alignm.append_model(mdl, atom_files='1lmp.pdb', align_codes='1lmp') # и добавим в выравнивание\n",
    "alignm[0].code = 'without_ligand'\n",
    "\n",
    "alignm.salign()\n",
    "alignm.write(file='all_in_one.ali', alignment_format='PIR')\n",
    "! cat 'all_in_one.ali'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "without_ligand 1lmp\n",
      "The following 1 residues contain 6-membered rings with poor geometries\n",
      "after transfer from templates. Rebuilding rings from internal coordinates:\n",
      "   <Residue 52 (type PHE)>\n",
      "0 atoms in HETATM/BLK residues constrained\n",
      "to protein atoms within 2.30 angstroms\n",
      "and protein CA atoms within 10.00 angstroms\n",
      "0 atoms in residues without defined topology\n",
      "constrained to be rigid bodies\n",
      "\n",
      ">> Summary of successfully produced models:\n",
      "Filename                          molpdf\n",
      "----------------------------------------\n",
      "without_ligand.B99990001.pdb      730.58990\n",
      "without_ligand.B99990002.pdb      764.55945\n",
      "\n"
     ]
    }
   ],
   "source": [
    "s = alignm[0]\n",
    "pdb = alignm[1]\n",
    "\n",
    "print(s.code, pdb.code)\n",
    "\n",
    "## Создаем объект automodel\n",
    "a = modeller.automodel.automodel(env, alnfile='all_in_one.ali', knowns= pdb.code , sequence = s.code )\n",
    "\n",
    "a.name='mod' + s.code\n",
    "a.starting_model = 1\n",
    "a.ending_model   = 2\n",
    "a.make()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Выведем выровненный белок слева, исходный справа:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div id=\"3dmolviewer_151451551001\"  style=\"position: relative; width: 900px; height: 400px\">\n",
       "<script>\n",
       "if(typeof $3Dmolpromise === 'undefined') $3Dmolpromise = $.when($.getScript('https://3dmol.csb.pitt.edu/build/3Dmol.js'))\n",
       "var viewer_151451551001 = null;\n",
       "$3Dmolpromise.done(function() {\n",
       "var viewergrid_151451551001 = null;\n",
       "viewergrid_151451551001 = $3Dmol.createViewerGrid($(\"#3dmolviewer_151451551001\"),{rows: 1, cols: 2, control_all: true},{backgroundColor:\"white\"});\n",
       "viewer_151451551001 = viewergrid_151451551001[0][0];\n",
       "\tviewergrid_151451551001[0][0].addModel(\"EXPDTA    THEORETICAL MODEL, MODELLER 9.19 2017/12/29 05:44:59\\nREMARK   6 MODELLER OBJECTIVE FUNCTION:       730.5899\\nREMARK   6 MODELLER BEST TEMPLATE % SEQ ID:  60.606\\nREMARK   6 SEQUENCE: without_ligand\\nREMARK   6 ALIGNMENT: all_in_one.ali\\nREMARK   6 TEMPLATE: 1lmp 1:A - 129:A MODELS 19: - 147: AT 60.6%\\nSSBOND   1 CYS     24    CYS    145                          1555   1555  2.04\\nSSBOND   2 CYS     48    CYS    133                          1555   1555  2.03\\nSSBOND   3 CYS     82    CYS     98                          1555   1555  2.04\\nSSBOND   4 CYS     94    CYS    112                          1555   1555  2.04\\nATOM      1  N   MET     1      65.022  43.126  35.990  1.00 99.23           N\\nATOM      2  CA  MET     1      65.634  42.444  34.830  1.00 99.23           C\\nATOM      3  CB  MET     1      66.774  41.523  35.296  1.00 99.23           C\\nATOM      4  CG  MET     1      67.995  42.267  35.841  1.00 99.23           C\\nATOM      5  SD  MET     1      68.991  43.104  34.572  1.00 99.23           S\\nATOM      6  CE  MET     1      69.717  41.578  33.905  1.00 99.23           C\\nATOM      7  C   MET     1      64.624  41.603  34.127  1.00 99.23           C\\nATOM      8  O   MET     1      63.629  42.099  33.602  1.00 99.23           O\\nATOM      9  N   ARG     2      64.878  40.283  34.106  1.00211.52           N\\nATOM     10  CA  ARG     2      64.002  39.358  33.460  1.00211.52           C\\nATOM     11  CB  ARG     2      64.637  37.973  33.230  1.00211.52           C\\nATOM     12  CG  ARG     2      65.848  37.989  32.295  1.00211.52           C\\nATOM     13  CD  ARG     2      66.485  36.612  32.084  1.00211.52           C\\nATOM     14  NE  ARG     2      65.690  35.903  31.043  1.00211.52           N\\nATOM     15  CZ  ARG     2      66.007  34.620  30.701  1.00211.52           C\\nATOM     16  NH1 ARG     2      67.031  33.976  31.334  1.00211.52           N\\nATOM     17  NH2 ARG     2      65.295  33.979  29.729  1.00211.52           N\\nATOM     18  C   ARG     2      62.818  39.169  34.350  1.00211.52           C\\nATOM     19  O   ARG     2      62.872  39.440  35.549  1.00211.52           O\\nATOM     20  N   SER     3      61.697  38.717  33.758  1.00124.99           N\\nATOM     21  CA  SER     3      60.498  38.469  34.504  1.00124.99           C\\nATOM     22  CB  SER     3      59.241  38.335  33.627  1.00124.99           C\\nATOM     23  OG  SER     3      59.378  37.240  32.735  1.00124.99           O\\nATOM     24  C   SER     3      60.702  37.189  35.247  1.00124.99           C\\nATOM     25  O   SER     3      61.796  36.630  35.234  1.00124.99           O\\nATOM     26  N   LEU     4      59.658  36.711  35.953  1.00301.25           N\\nATOM     27  CA  LEU     4      59.791  35.515  36.737  1.00301.25           C\\nATOM     28  CB  LEU     4      58.612  35.258  37.695  1.00301.25           C\\nATOM     29  CG  LEU     4      58.730  33.940  38.493  1.00301.25           C\\nATOM     30  CD1 LEU     4      59.955  33.952  39.420  1.00301.25           C\\nATOM     31  CD2 LEU     4      57.422  33.613  39.235  1.00301.25           C\\nATOM     32  C   LEU     4      59.885  34.325  35.844  1.00301.25           C\\nATOM     33  O   LEU     4      59.243  34.257  34.796  1.00301.25           O\\nATOM     34  N   LEU     5      60.730  33.359  36.256  1.00264.62           N\\nATOM     35  CA  LEU     5      60.867  32.119  35.556  1.00264.62           C\\nATOM     36  CB  LEU     5      62.271  31.869  34.972  1.00264.62           C\\nATOM     37  CG  LEU     5      62.684  32.848  33.854  1.00264.62           C\\nATOM     38  CD1 LEU     5      62.895  34.268  34.393  1.00264.62           C\\nATOM     39  CD2 LEU     5      63.900  32.327  33.071  1.00264.62           C\\nATOM     40  C   LEU     5      60.628  31.043  36.564  1.00264.62           C\\nATOM     41  O   LEU     5      60.879  31.230  37.754  1.00264.62           O\\nATOM     42  N   ILE     6      60.100  29.890  36.118  1.00126.59           N\\nATOM     43  CA  ILE     6      59.892  28.796  37.021  1.00126.59           C\\nATOM     44  CB  ILE     6      58.457  28.525  37.356  1.00126.59           C\\nATOM     45  CG1 ILE     6      58.376  27.553  38.542  1.00126.59           C\\nATOM     46  CG2 ILE     6      57.758  28.015  36.085  1.00126.59           C\\nATOM     47  CD1 ILE     6      56.974  27.435  39.139  1.00126.59           C\\nATOM     48  C   ILE     6      60.395  27.571  36.336  1.00126.59           C\\nATOM     49  O   ILE     6      60.598  27.571  35.123  1.00126.59           O\\nATOM     50  N   LEU     7      60.630  26.489  37.106  1.00260.46           N\\nATOM     51  CA  LEU     7      61.051  25.279  36.467  1.00260.46           C\\nATOM     52  CB  LEU     7      61.311  24.124  37.463  1.00260.46           C\\nATOM     53  CG  LEU     7      61.781  22.789  36.841  1.00260.46           C\\nATOM     54  CD1 LEU     7      60.677  22.113  36.010  1.00260.46           C\\nATOM     55  CD2 LEU     7      63.092  22.967  36.064  1.00260.46           C\\nATOM     56  C   LEU     7      59.907  24.922  35.575  1.00260.46           C\\nATOM     57  O   LEU     7      58.746  24.990  35.978  1.00260.46           O\\nATOM     58  N   VAL     8      60.204  24.546  34.318  1.00 80.16           N\\nATOM     59  CA  VAL     8      59.125  24.311  33.407  1.00 80.16           C\\nATOM     60  CB  VAL     8      59.378  24.861  32.033  1.00 80.16           C\\nATOM     61  CG1 VAL     8      58.183  24.513  31.130  1.00 80.16           C\\nATOM     62  CG2 VAL     8      59.645  26.371  32.160  1.00 80.16           C\\nATOM     63  C   VAL     8      58.909  22.844  33.261  1.00 80.16           C\\nATOM     64  O   VAL     8      59.853  22.061  33.164  1.00 80.16           O\\nATOM     65  N   LEU     9      57.624  22.443  33.275  1.00290.74           N\\nATOM     66  CA  LEU     9      57.268  21.074  33.070  1.00290.74           C\\nATOM     67  CB  LEU     9      56.532  20.459  34.274  1.00290.74           C\\nATOM     68  CG  LEU     9      56.295  18.943  34.164  1.00290.74           C\\nATOM     69  CD1 LEU     9      57.623  18.172  34.098  1.00290.74           C\\nATOM     70  CD2 LEU     9      55.393  18.451  35.307  1.00290.74           C\\nATOM     71  C   LEU     9      56.357  21.090  31.882  1.00290.74           C\\nATOM     72  O   LEU     9      55.553  22.008  31.725  1.00290.74           O\\nATOM     73  N   CYS    10      56.486  20.087  30.991  1.00126.52           N\\nATOM     74  CA  CYS    10      55.708  20.065  29.784  1.00126.52           C\\nATOM     75  CB  CYS    10      56.396  19.323  28.623  1.00126.52           C\\nATOM     76  SG  CYS    10      56.681  17.564  28.978  1.00126.52           S\\nATOM     77  C   CYS    10      54.383  19.420  30.048  1.00126.52           C\\nATOM     78  O   CYS    10      54.155  18.837  31.106  1.00126.52           O\\nATOM     79  N   PHE    11      53.459  19.541  29.072  1.00220.10           N\\nATOM     80  CA  PHE    11      52.140  18.989  29.187  1.00220.10           C\\nATOM     81  CB  PHE    11      51.025  20.040  29.038  1.00220.10           C\\nATOM     82  CG  PHE    11      51.068  20.978  30.195  1.00220.10           C\\nATOM     83  CD1 PHE    11      51.990  21.998  30.248  1.00220.10           C\\nATOM     84  CD2 PHE    11      50.160  20.848  31.219  1.00220.10           C\\nATOM     85  CE1 PHE    11      52.012  22.863  31.320  1.00220.10           C\\nATOM     86  CE2 PHE    11      50.175  21.707  32.292  1.00220.10           C\\nATOM     87  CZ  PHE    11      51.106  22.717  32.344  1.00220.10           C\\nATOM     88  C   PHE    11      51.943  18.047  28.042  1.00220.10           C\\nATOM     89  O   PHE    11      52.538  18.222  26.980  1.00220.10           O\\nATOM     90  N   LEU    12      51.119  16.995  28.244  1.00249.65           N\\nATOM     91  CA  LEU    12      50.812  16.104  27.161  1.00249.65           C\\nATOM     92  CB  LEU    12      51.393  14.689  27.370  1.00249.65           C\\nATOM     93  CG  LEU    12      51.285  13.753  26.149  1.00249.65           C\\nATOM     94  CD1 LEU    12      49.828  13.435  25.775  1.00249.65           C\\nATOM     95  CD2 LEU    12      52.109  14.293  24.970  1.00249.65           C\\nATOM     96  C   LEU    12      49.315  15.994  27.139  1.00249.65           C\\nATOM     97  O   LEU    12      48.732  15.096  27.746  1.00249.65           O\\nATOM     98  N   PRO    13      48.682  16.912  26.465  1.00104.38           N\\nATOM     99  CA  PRO    13      47.240  16.892  26.416  1.00104.38           C\\nATOM    100  CD  PRO    13      49.196  18.272  26.486  1.00104.38           C\\nATOM    101  CB  PRO    13      46.792  18.355  26.404  1.00104.38           C\\nATOM    102  CG  PRO    13      48.042  19.142  25.977  1.00104.38           C\\nATOM    103  C   PRO    13      46.664  16.118  25.270  1.00104.38           C\\nATOM    104  O   PRO    13      47.374  15.848  24.303  1.00104.38           O\\nATOM    105  N   LEU    14      45.372  15.744  25.377  1.00240.05           N\\nATOM    106  CA  LEU    14      44.653  15.171  24.277  1.00240.05           C\\nATOM    107  CB  LEU    14      43.999  13.804  24.557  1.00240.05           C\\nATOM    108  CG  LEU    14      44.987  12.639  24.736  1.00240.05           C\\nATOM    109  CD1 LEU    14      45.865  12.836  25.983  1.00240.05           C\\nATOM    110  CD2 LEU    14      44.256  11.287  24.722  1.00240.05           C\\nATOM    111  C   LEU    14      43.531  16.124  24.035  1.00240.05           C\\nATOM    112  O   LEU    14      42.710  16.356  24.920  1.00240.05           O\\nATOM    113  N   ALA    15      43.468  16.731  22.837  1.00277.75           N\\nATOM    114  CA  ALA    15      42.397  17.653  22.600  1.00277.75           C\\nATOM    115  CB  ALA    15      42.568  19.003  23.319  1.00277.75           C\\nATOM    116  C   ALA    15      42.366  17.935  21.139  1.00277.75           C\\nATOM    117  O   ALA    15      43.279  17.562  20.404  1.00277.75           O\\nATOM    118  N   ALA    16      41.286  18.590  20.675  1.00216.33           N\\nATOM    119  CA  ALA    16      41.206  18.924  19.289  1.00216.33           C\\nATOM    120  CB  ALA    16      39.848  19.510  18.864  1.00216.33           C\\nATOM    121  C   ALA    16      42.256  19.952  19.038  1.00216.33           C\\nATOM    122  O   ALA    16      42.687  20.677  19.932  1.00216.33           O\\nATOM    123  N   PRO    17      42.702  19.980  17.819  1.00 88.31           N\\nATOM    124  CA  PRO    17      43.727  20.902  17.419  1.00 88.31           C\\nATOM    125  CD  PRO    17      42.696  18.783  17.001  1.00 88.31           C\\nATOM    126  CB  PRO    17      44.335  20.333  16.136  1.00 88.31           C\\nATOM    127  CG  PRO    17      43.358  19.231  15.691  1.00 88.31           C\\nATOM    128  C   PRO    17      43.148  22.265  17.258  1.00 88.31           C\\nATOM    129  O   PRO    17      41.925  22.391  17.232  1.00 88.31           O\\nATOM    130  N   GLY    18      44.013  23.293  17.154  1.00 65.04           N\\nATOM    131  CA  GLY    18      43.523  24.625  17.000  1.00 65.04           C\\nATOM    132  C   GLY    18      42.667  24.600  15.786  1.00 65.04           C\\nATOM    133  O   GLY    18      42.968  23.920  14.805  1.00 65.04           O\\nATOM    134  N   LYS    19      41.556  25.351  15.829  1.00174.78           N\\nATOM    135  CA  LYS    19      40.642  25.299  14.734  1.00174.78           C\\nATOM    136  CB  LYS    19      39.184  25.147  15.205  1.00174.78           C\\nATOM    137  CG  LYS    19      38.146  25.095  14.085  1.00174.78           C\\nATOM    138  CD  LYS    19      36.737  24.777  14.595  1.00174.78           C\\nATOM    139  CE  LYS    19      35.674  24.718  13.496  1.00174.78           C\\nATOM    140  NZ  LYS    19      34.347  24.440  14.093  1.00174.78           N\\nATOM    141  C   LYS    19      40.717  26.585  13.990  1.00174.78           C\\nATOM    142  O   LYS    19      40.631  27.660  14.581  1.00174.78           O\\nATOM    143  N   VAL    20      40.901  26.502  12.658  1.00137.15           N\\nATOM    144  CA  VAL    20      40.847  27.703  11.886  1.00137.15           C\\nATOM    145  CB  VAL    20      41.918  27.821  10.840  1.00137.15           C\\nATOM    146  CG1 VAL    20      43.269  27.986  11.552  1.00137.15           C\\nATOM    147  CG2 VAL    20      41.872  26.582   9.940  1.00137.15           C\\nATOM    148  C   VAL    20      39.496  27.690  11.248  1.00137.15           C\\nATOM    149  O   VAL    20      39.180  26.826  10.433  1.00137.15           O\\nATOM    150  N   TYR    21      38.665  28.671  11.639  1.00 92.95           N\\nATOM    151  CA  TYR    21      37.302  28.763  11.211  1.00 92.95           C\\nATOM    152  CB  TYR    21      36.424  29.683  12.074  1.00 92.95           C\\nATOM    153  CG  TYR    21      36.102  29.088  13.395  1.00 92.95           C\\nATOM    154  CD1 TYR    21      37.012  29.095  14.427  1.00 92.95           C\\nATOM    155  CD2 TYR    21      34.852  28.550  13.601  1.00 92.95           C\\nATOM    156  CE1 TYR    21      36.683  28.552  15.647  1.00 92.95           C\\nATOM    157  CE2 TYR    21      34.518  28.009  14.815  1.00 92.95           C\\nATOM    158  CZ  TYR    21      35.435  28.009  15.836  1.00 92.95           C\\nATOM    159  OH  TYR    21      35.082  27.454  17.082  1.00 92.95           O\\nATOM    160  C   TYR    21      37.205  29.390   9.863  1.00 92.95           C\\nATOM    161  O   TYR    21      37.982  30.276   9.507  1.00 92.95           O\\nATOM    162  N   GLY    22      36.241  28.890   9.064  1.00 27.88           N\\nATOM    163  CA  GLY    22      35.903  29.528   7.830  1.00 27.88           C\\nATOM    164  C   GLY    22      35.067  30.697   8.247  1.00 27.88           C\\nATOM    165  O   GLY    22      34.465  30.687   9.320  1.00 27.88           O\\nATOM    166  N   ARG    23      34.981  31.729   7.390  1.00133.90           N\\nATOM    167  CA  ARG    23      34.295  32.943   7.739  1.00133.90           C\\nATOM    168  CB  ARG    23      34.377  33.965   6.595  1.00133.90           C\\nATOM    169  CG  ARG    23      33.680  35.301   6.855  1.00133.90           C\\nATOM    170  CD  ARG    23      34.019  36.343   5.787  1.00133.90           C\\nATOM    171  NE  ARG    23      33.912  35.672   4.460  1.00133.90           N\\nATOM    172  CZ  ARG    23      32.734  35.690   3.773  1.00133.90           C\\nATOM    173  NH1 ARG    23      31.662  36.375   4.267  1.00133.90           N\\nATOM    174  NH2 ARG    23      32.632  35.034   2.580  1.00133.90           N\\nATOM    175  C   ARG    23      32.849  32.694   8.047  1.00133.90           C\\nATOM    176  O   ARG    23      32.353  33.151   9.077  1.00133.90           O\\nATOM    177  N   CYS    24      32.128  31.975   7.165  1.00 47.49           N\\nATOM    178  CA  CYS    24      30.728  31.744   7.394  1.00 47.49           C\\nATOM    179  CB  CYS    24      29.960  31.278   6.146  1.00 47.49           C\\nATOM    180  SG  CYS    24      29.805  32.647   4.961  1.00 47.49           S\\nATOM    181  C   CYS    24      30.530  30.784   8.525  1.00 47.49           C\\nATOM    182  O   CYS    24      29.544  30.883   9.252  1.00 47.49           O\\nATOM    183  N   GLU    25      31.453  29.819   8.697  1.00 38.67           N\\nATOM    184  CA  GLU    25      31.315  28.855   9.752  1.00 38.67           C\\nATOM    185  CB  GLU    25      32.479  27.851   9.800  1.00 38.67           C\\nATOM    186  CG  GLU    25      32.339  26.829  10.928  1.00 38.67           C\\nATOM    187  CD  GLU    25      33.572  25.937  10.921  1.00 38.67           C\\nATOM    188  OE1 GLU    25      34.695  26.470  10.719  1.00 38.67           O\\nATOM    189  OE2 GLU    25      33.404  24.705  11.121  1.00 38.67           O\\nATOM    190  C   GLU    25      31.330  29.586  11.056  1.00 38.67           C\\nATOM    191  O   GLU    25      30.566  29.275  11.970  1.00 38.67           O\\nATOM    192  N   LEU    26      32.230  30.579  11.160  1.00117.75           N\\nATOM    193  CA  LEU    26      32.387  31.378  12.342  1.00117.75           C\\nATOM    194  CB  LEU    26      33.507  32.424  12.169  1.00117.75           C\\nATOM    195  CG  LEU    26      33.998  33.130  13.450  1.00117.75           C\\nATOM    196  CD1 LEU    26      32.871  33.775  14.260  1.00117.75           C\\nATOM    197  CD2 LEU    26      34.865  32.192  14.290  1.00117.75           C\\nATOM    198  C   LEU    26      31.113  32.149  12.539  1.00117.75           C\\nATOM    199  O   LEU    26      30.580  32.229  13.645  1.00117.75           O\\nATOM    200  N   ALA    27      30.570  32.708  11.440  1.00 36.49           N\\nATOM    201  CA  ALA    27      29.399  33.535  11.521  1.00 36.49           C\\nATOM    202  CB  ALA    27      28.938  34.043  10.145  1.00 36.49           C\\nATOM    203  C   ALA    27      28.274  32.734  12.103  1.00 36.49           C\\nATOM    204  O   ALA    27      27.540  33.225  12.959  1.00 36.49           O\\nATOM    205  N   ALA    28      28.112  31.472  11.661  1.00 29.34           N\\nATOM    206  CA  ALA    28      27.033  30.649  12.134  1.00 29.34           C\\nATOM    207  CB  ALA    28      26.969  29.288  11.417  1.00 29.34           C\\nATOM    208  C   ALA    28      27.174  30.379  13.606  1.00 29.34           C\\nATOM    209  O   ALA    28      26.197  30.459  14.349  1.00 29.34           O\\nATOM    210  N   ALA    29      28.397  30.058  14.073  1.00 33.78           N\\nATOM    211  CA  ALA    29      28.619  29.720  15.453  1.00 33.78           C\\nATOM    212  CB  ALA    29      30.072  29.302  15.736  1.00 33.78           C\\nATOM    213  C   ALA    29      28.313  30.898  16.331  1.00 33.78           C\\nATOM    214  O   ALA    29      27.748  30.736  17.411  1.00 33.78           O\\nATOM    215  N   MET    30      28.715  32.114  15.911  1.00 98.95           N\\nATOM    216  CA  MET    30      28.481  33.299  16.694  1.00 98.95           C\\nATOM    217  CB  MET    30      29.172  34.544  16.113  1.00 98.95           C\\nATOM    218  CG  MET    30      30.695  34.476  16.224  1.00 98.95           C\\nATOM    219  SD  MET    30      31.328  34.564  17.927  1.00 98.95           S\\nATOM    220  CE  MET    30      33.078  34.434  17.463  1.00 98.95           C\\nATOM    221  C   MET    30      27.013  33.591  16.778  1.00 98.95           C\\nATOM    222  O   MET    30      26.504  33.968  17.834  1.00 98.95           O\\nATOM    223  N   LYS    31      26.292  33.427  15.654  1.00 95.69           N\\nATOM    224  CA  LYS    31      24.889  33.727  15.609  1.00 95.69           C\\nATOM    225  CB  LYS    31      24.305  33.505  14.205  1.00 95.69           C\\nATOM    226  CG  LYS    31      22.870  33.997  14.010  1.00 95.69           C\\nATOM    227  CD  LYS    31      22.735  35.520  14.018  1.00 95.69           C\\nATOM    228  CE  LYS    31      21.374  36.008  13.520  1.00 95.69           C\\nATOM    229  NZ  LYS    31      21.281  35.817  12.056  1.00 95.69           N\\nATOM    230  C   LYS    31      24.175  32.814  16.561  1.00 95.69           C\\nATOM    231  O   LYS    31      23.299  33.241  17.311  1.00 95.69           O\\nATOM    232  N   ARG    32      24.558  31.524  16.569  1.00131.18           N\\nATOM    233  CA  ARG    32      23.936  30.536  17.407  1.00131.18           C\\nATOM    234  CB  ARG    32      24.480  29.119  17.151  1.00131.18           C\\nATOM    235  CG  ARG    32      23.843  28.046  18.037  1.00131.18           C\\nATOM    236  CD  ARG    32      24.272  26.623  17.675  1.00131.18           C\\nATOM    237  NE  ARG    32      25.754  26.627  17.525  1.00131.18           N\\nATOM    238  CZ  ARG    32      26.384  25.534  17.006  1.00131.18           C\\nATOM    239  NH1 ARG    32      25.664  24.420  16.688  1.00131.18           N\\nATOM    240  NH2 ARG    32      27.733  25.560  16.795  1.00131.18           N\\nATOM    241  C   ARG    32      24.177  30.875  18.850  1.00131.18           C\\nATOM    242  O   ARG    32      23.313  30.655  19.698  1.00131.18           O\\nATOM    243  N   MET    33      25.376  31.412  19.147  1.00163.62           N\\nATOM    244  CA  MET    33      25.865  31.768  20.453  1.00163.62           C\\nATOM    245  CB  MET    33      27.382  32.018  20.489  1.00163.62           C\\nATOM    246  CG  MET    33      28.185  30.715  20.448  1.00163.62           C\\nATOM    247  SD  MET    33      27.965  29.691  21.939  1.00163.62           S\\nATOM    248  CE  MET    33      29.065  28.348  21.407  1.00163.62           C\\nATOM    249  C   MET    33      25.153  32.947  21.052  1.00163.62           C\\nATOM    250  O   MET    33      25.249  33.156  22.262  1.00163.62           O\\nATOM    251  N   GLY    34      24.500  33.799  20.234  1.00 33.21           N\\nATOM    252  CA  GLY    34      23.778  34.919  20.786  1.00 33.21           C\\nATOM    253  C   GLY    34      24.590  36.171  20.652  1.00 33.21           C\\nATOM    254  O   GLY    34      24.273  37.191  21.262  1.00 33.21           O\\nATOM    255  N   LEU    35      25.672  36.114  19.855  1.00100.12           N\\nATOM    256  CA  LEU    35      26.538  37.235  19.614  1.00100.12           C\\nATOM    257  CB  LEU    35      27.843  36.857  18.890  1.00100.12           C\\nATOM    258  CG  LEU    35      28.850  36.108  19.784  1.00100.12           C\\nATOM    259  CD1 LEU    35      29.438  37.042  20.853  1.00100.12           C\\nATOM    260  CD2 LEU    35      28.232  34.837  20.385  1.00100.12           C\\nATOM    261  C   LEU    35      25.859  38.308  18.816  1.00100.12           C\\nATOM    262  O   LEU    35      26.223  39.477  18.924  1.00100.12           O\\nATOM    263  N   ASP    36      24.896  37.957  17.944  1.00 62.96           N\\nATOM    264  CA  ASP    36      24.292  38.989  17.149  1.00 62.96           C\\nATOM    265  CB  ASP    36      23.298  38.451  16.103  1.00 62.96           C\\nATOM    266  CG  ASP    36      23.021  39.547  15.079  1.00 62.96           C\\nATOM    267  OD1 ASP    36      23.594  40.659  15.226  1.00 62.96           O\\nATOM    268  OD2 ASP    36      22.235  39.284  14.131  1.00 62.96           O\\nATOM    269  C   ASP    36      23.555  39.924  18.063  1.00 62.96           C\\nATOM    270  O   ASP    36      22.627  39.529  18.766  1.00 62.96           O\\nATOM    271  N   ASN    37      23.952  41.214  18.038  1.00 95.47           N\\nATOM    272  CA  ASN    37      23.359  42.279  18.803  1.00 95.47           C\\nATOM    273  CB  ASN    37      21.832  42.332  18.616  1.00 95.47           C\\nATOM    274  CG  ASN    37      21.319  43.702  19.041  1.00 95.47           C\\nATOM    275  OD1 ASN    37      22.064  44.537  19.551  1.00 95.47           O\\nATOM    276  ND2 ASN    37      20.002  43.948  18.810  1.00 95.47           N\\nATOM    277  C   ASN    37      23.663  42.171  20.276  1.00 95.47           C\\nATOM    278  O   ASN    37      22.948  42.737  21.100  1.00 95.47           O\\nATOM    279  N   TYR    38      24.761  41.494  20.667  1.00 58.14           N\\nATOM    280  CA  TYR    38      25.076  41.418  22.069  1.00 58.14           C\\nATOM    281  CB  TYR    38      26.130  40.338  22.387  1.00 58.14           C\\nATOM    282  CG  TYR    38      26.219  40.184  23.867  1.00 58.14           C\\nATOM    283  CD1 TYR    38      25.345  39.352  24.529  1.00 58.14           C\\nATOM    284  CD2 TYR    38      27.170  40.865  24.592  1.00 58.14           C\\nATOM    285  CE1 TYR    38      25.415  39.200  25.894  1.00 58.14           C\\nATOM    286  CE2 TYR    38      27.245  40.717  25.957  1.00 58.14           C\\nATOM    287  CZ  TYR    38      26.368  39.884  26.610  1.00 58.14           C\\nATOM    288  OH  TYR    38      26.448  39.735  28.011  1.00 58.14           O\\nATOM    289  C   TYR    38      25.641  42.755  22.441  1.00 58.14           C\\nATOM    290  O   TYR    38      26.563  43.246  21.795  1.00 58.14           O\\nATOM    291  N   ARG    39      25.071  43.377  23.493  1.00148.67           N\\nATOM    292  CA  ARG    39      25.412  44.685  23.985  1.00148.67           C\\nATOM    293  CB  ARG    39      26.815  44.870  24.596  1.00148.67           C\\nATOM    294  CG  ARG    39      27.958  44.755  23.593  1.00148.67           C\\nATOM    295  CD  ARG    39      29.241  45.444  24.048  1.00148.67           C\\nATOM    296  NE  ARG    39      28.986  46.911  24.093  1.00148.67           N\\nATOM    297  CZ  ARG    39      28.516  47.486  25.239  1.00148.67           C\\nATOM    298  NH1 ARG    39      28.260  46.715  26.337  1.00148.67           N\\nATOM    299  NH2 ARG    39      28.301  48.834  25.287  1.00148.67           N\\nATOM    300  C   ARG    39      25.318  45.653  22.851  1.00148.67           C\\nATOM    301  O   ARG    39      26.027  46.659  22.830  1.00148.67           O\\nATOM    302  N   GLY    40      24.434  45.372  21.875  1.00 26.50           N\\nATOM    303  CA  GLY    40      24.203  46.295  20.800  1.00 26.50           C\\nATOM    304  C   GLY    40      25.201  46.142  19.693  1.00 26.50           C\\nATOM    305  O   GLY    40      25.318  47.034  18.854  1.00 26.50           O\\nATOM    306  N   TYR    41      25.953  45.027  19.631  1.00120.28           N\\nATOM    307  CA  TYR    41      26.869  44.951  18.532  1.00120.28           C\\nATOM    308  CB  TYR    41      28.335  44.840  18.961  1.00120.28           C\\nATOM    309  CG  TYR    41      28.650  46.201  19.490  1.00120.28           C\\nATOM    310  CD1 TYR    41      28.377  46.542  20.796  1.00120.28           C\\nATOM    311  CD2 TYR    41      29.202  47.147  18.657  1.00120.28           C\\nATOM    312  CE1 TYR    41      28.663  47.803  21.271  1.00120.28           C\\nATOM    313  CE2 TYR    41      29.490  48.406  19.125  1.00120.28           C\\nATOM    314  CZ  TYR    41      29.221  48.737  20.432  1.00120.28           C\\nATOM    315  OH  TYR    41      29.517  50.032  20.912  1.00120.28           O\\nATOM    316  C   TYR    41      26.479  43.831  17.627  1.00120.28           C\\nATOM    317  O   TYR    41      26.423  42.666  18.018  1.00120.28           O\\nATOM    318  N   SER    42      26.220  44.193  16.355  1.00 45.11           N\\nATOM    319  CA  SER    42      25.746  43.283  15.359  1.00 45.11           C\\nATOM    320  CB  SER    42      25.326  43.985  14.056  1.00 45.11           C\\nATOM    321  OG  SER    42      26.444  44.625  13.461  1.00 45.11           O\\nATOM    322  C   SER    42      26.825  42.297  15.043  1.00 45.11           C\\nATOM    323  O   SER    42      28.001  42.510  15.337  1.00 45.11           O\\nATOM    324  N   LEU    43      26.415  41.197  14.385  1.00 62.81           N\\nATOM    325  CA  LEU    43      27.226  40.049  14.102  1.00 62.81           C\\nATOM    326  CB  LEU    43      26.424  38.957  13.374  1.00 62.81           C\\nATOM    327  CG  LEU    43      27.223  37.676  13.096  1.00 62.81           C\\nATOM    328  CD1 LEU    43      27.686  37.023  14.407  1.00 62.81           C\\nATOM    329  CD2 LEU    43      26.428  36.711  12.204  1.00 62.81           C\\nATOM    330  C   LEU    43      28.420  40.417  13.264  1.00 62.81           C\\nATOM    331  O   LEU    43      29.519  39.916  13.501  1.00 62.81           O\\nATOM    332  N   GLY    44      28.251  41.323  12.285  1.00 38.48           N\\nATOM    333  CA  GLY    44      29.321  41.681  11.394  1.00 38.48           C\\nATOM    334  C   GLY    44      30.483  42.238  12.167  1.00 38.48           C\\nATOM    335  O   GLY    44      31.633  42.064  11.766  1.00 38.48           O\\nATOM    336  N   ASN    45      30.223  42.963  13.271  1.00 46.59           N\\nATOM    337  CA  ASN    45      31.293  43.547  14.035  1.00 46.59           C\\nATOM    338  CB  ASN    45      30.792  44.382  15.226  1.00 46.59           C\\nATOM    339  CG  ASN    45      30.214  45.682  14.680  1.00 46.59           C\\nATOM    340  OD1 ASN    45      30.941  46.543  14.186  1.00 46.59           O\\nATOM    341  ND2 ASN    45      28.865  45.829  14.765  1.00 46.59           N\\nATOM    342  C   ASN    45      32.183  42.465  14.574  1.00 46.59           C\\nATOM    343  O   ASN    45      33.408  42.582  14.550  1.00 46.59           O\\nATOM    344  N   TRP    46      31.568  41.383  15.082  1.00 73.75           N\\nATOM    345  CA  TRP    46      32.247  40.273  15.696  1.00 73.75           C\\nATOM    346  CB  TRP    46      31.258  39.312  16.379  1.00 73.75           C\\nATOM    347  CG  TRP    46      30.474  39.985  17.488  1.00 73.75           C\\nATOM    348  CD2 TRP    46      30.997  40.268  18.796  1.00 73.75           C\\nATOM    349  CD1 TRP    46      29.200  40.470  17.471  1.00 73.75           C\\nATOM    350  NE1 TRP    46      28.895  41.037  18.685  1.00 73.75           N\\nATOM    351  CE2 TRP    46      29.993  40.919  19.512  1.00 73.75           C\\nATOM    352  CE3 TRP    46      32.217  40.007  19.352  1.00 73.75           C\\nATOM    353  CZ2 TRP    46      30.194  41.325  20.801  1.00 73.75           C\\nATOM    354  CZ3 TRP    46      32.413  40.413  20.654  1.00 73.75           C\\nATOM    355  CH2 TRP    46      31.422  41.059  21.366  1.00 73.75           C\\nATOM    356  C   TRP    46      33.062  39.509  14.688  1.00 73.75           C\\nATOM    357  O   TRP    46      34.163  39.053  14.996  1.00 73.75           O\\nATOM    358  N   VAL    47      32.525  39.300  13.468  1.00 46.08           N\\nATOM    359  CA  VAL    47      33.243  38.587  12.444  1.00 46.08           C\\nATOM    360  CB  VAL    47      32.411  38.325  11.222  1.00 46.08           C\\nATOM    361  CG1 VAL    47      33.290  37.601  10.189  1.00 46.08           C\\nATOM    362  CG2 VAL    47      31.160  37.531  11.633  1.00 46.08           C\\nATOM    363  C   VAL    47      34.435  39.402  12.021  1.00 46.08           C\\nATOM    364  O   VAL    47      35.527  38.867  11.834  1.00 46.08           O\\nATOM    365  N   CYS    48      34.253  40.731  11.871  1.00 49.04           N\\nATOM    366  CA  CYS    48      35.296  41.614  11.419  1.00 49.04           C\\nATOM    367  CB  CYS    48      34.802  43.072  11.325  1.00 49.04           C\\nATOM    368  SG  CYS    48      36.142  44.259  11.021  1.00 49.04           S\\nATOM    369  C   CYS    48      36.457  41.590  12.369  1.00 49.04           C\\nATOM    370  O   CYS    48      37.608  41.462  11.954  1.00 49.04           O\\nATOM    371  N   ALA    49      36.187  41.707  13.680  1.00 39.46           N\\nATOM    372  CA  ALA    49      37.244  41.757  14.656  1.00 39.46           C\\nATOM    373  CB  ALA    49      36.727  41.998  16.084  1.00 39.46           C\\nATOM    374  C   ALA    49      38.004  40.465  14.669  1.00 39.46           C\\nATOM    375  O   ALA    49      39.224  40.457  14.830  1.00 39.46           O\\nATOM    376  N   ALA    50      37.298  39.329  14.525  1.00 36.86           N\\nATOM    377  CA  ALA    50      37.928  38.036  14.573  1.00 36.86           C\\nATOM    378  CB  ALA    50      36.916  36.886  14.445  1.00 36.86           C\\nATOM    379  C   ALA    50      38.898  37.914  13.435  1.00 36.86           C\\nATOM    380  O   ALA    50      40.001  37.393  13.603  1.00 36.86           O\\nATOM    381  N   LYS    51      38.507  38.389  12.237  1.00127.27           N\\nATOM    382  CA  LYS    51      39.344  38.278  11.077  1.00127.27           C\\nATOM    383  CB  LYS    51      38.666  38.841   9.816  1.00127.27           C\\nATOM    384  CG  LYS    51      39.526  38.744   8.556  1.00127.27           C\\nATOM    385  CD  LYS    51      39.701  37.328   8.019  1.00127.27           C\\nATOM    386  CE  LYS    51      38.744  37.003   6.868  1.00127.27           C\\nATOM    387  NZ  LYS    51      39.195  37.676   5.628  1.00127.27           N\\nATOM    388  C   LYS    51      40.620  39.047  11.263  1.00127.27           C\\nATOM    389  O   LYS    51      41.706  38.525  11.014  1.00127.27           O\\nATOM    390  N   PHE    52      40.524  40.320  11.693  1.00101.02           N\\nATOM    391  CA  PHE    52      41.700  41.139  11.819  1.00101.02           C\\nATOM    392  CB  PHE    52      41.405  42.638  12.012  1.00101.02           C\\nATOM    393  CG  PHE    52      42.698  43.339  11.761  1.00101.02           C\\nATOM    394  CD1 PHE    52      43.126  43.548  10.470  1.00101.02           C\\nATOM    395  CD2 PHE    52      43.482  43.783  12.802  1.00101.02           C\\nATOM    396  CE1 PHE    52      44.316  44.188  10.218  1.00101.02           C\\nATOM    397  CE2 PHE    52      44.674  44.425  12.557  1.00101.02           C\\nATOM    398  CZ  PHE    52      45.091  44.629  11.262  1.00101.02           C\\nATOM    399  C   PHE    52      42.561  40.687  12.960  1.00101.02           C\\nATOM    400  O   PHE    52      43.786  40.713  12.856  1.00101.02           O\\nATOM    401  N   GLU    53      41.940  40.315  14.097  1.00100.96           N\\nATOM    402  CA  GLU    53      42.667  39.927  15.279  1.00100.96           C\\nATOM    403  CB  GLU    53      41.772  39.816  16.525  1.00100.96           C\\nATOM    404  CG  GLU    53      41.295  41.170  17.060  1.00100.96           C\\nATOM    405  CD  GLU    53      42.490  41.893  17.671  1.00100.96           C\\nATOM    406  OE1 GLU    53      43.621  41.342  17.581  1.00100.96           O\\nATOM    407  OE2 GLU    53      42.292  43.002  18.234  1.00100.96           O\\nATOM    408  C   GLU    53      43.398  38.619  15.140  1.00100.96           C\\nATOM    409  O   GLU    53      44.564  38.533  15.523  1.00100.96           O\\nATOM    410  N   SER    54      42.763  37.556  14.598  1.00106.32           N\\nATOM    411  CA  SER    54      43.466  36.299  14.627  1.00106.32           C\\nATOM    412  CB  SER    54      42.928  35.359  15.717  1.00106.32           C\\nATOM    413  OG  SER    54      41.590  34.988  15.421  1.00106.32           O\\nATOM    414  C   SER    54      43.339  35.546  13.338  1.00106.32           C\\nATOM    415  O   SER    54      43.820  34.417  13.249  1.00106.32           O\\nATOM    416  N   ASN    55      42.739  36.131  12.290  1.00 63.11           N\\nATOM    417  CA  ASN    55      42.588  35.400  11.060  1.00 63.11           C\\nATOM    418  CB  ASN    55      43.922  35.031  10.392  1.00 63.11           C\\nATOM    419  CG  ASN    55      44.490  36.309   9.797  1.00 63.11           C\\nATOM    420  OD1 ASN    55      43.749  37.154   9.296  1.00 63.11           O\\nATOM    421  ND2 ASN    55      45.840  36.461   9.854  1.00 63.11           N\\nATOM    422  C   ASN    55      41.813  34.145  11.321  1.00 63.11           C\\nATOM    423  O   ASN    55      42.020  33.120  10.672  1.00 63.11           O\\nATOM    424  N   PHE    56      40.865  34.226  12.269  1.00 91.78           N\\nATOM    425  CA  PHE    56      39.959  33.167  12.609  1.00 91.78           C\\nATOM    426  CB  PHE    56      39.115  32.687  11.416  1.00 91.78           C\\nATOM    427  CG  PHE    56      38.261  33.817  10.958  1.00 91.78           C\\nATOM    428  CD1 PHE    56      37.147  34.195  11.670  1.00 91.78           C\\nATOM    429  CD2 PHE    56      38.567  34.488   9.797  1.00 91.78           C\\nATOM    430  CE1 PHE    56      36.359  35.235  11.238  1.00 91.78           C\\nATOM    431  CE2 PHE    56      37.783  35.528   9.359  1.00 91.78           C\\nATOM    432  CZ  PHE    56      36.677  35.903  10.081  1.00 91.78           C\\nATOM    433  C   PHE    56      40.638  31.951  13.168  1.00 91.78           C\\nATOM    434  O   PHE    56      40.067  30.862  13.100  1.00 91.78           O\\nATOM    435  N   ASN    57      41.846  32.051  13.759  1.00127.83           N\\nATOM    436  CA  ASN    57      42.290  30.804  14.311  1.00127.83           C\\nATOM    437  CB  ASN    57      43.658  30.275  13.831  1.00127.83           C\\nATOM    438  CG  ASN    57      44.807  30.978  14.517  1.00127.83           C\\nATOM    439  OD1 ASN    57      45.471  30.388  15.365  1.00127.83           O\\nATOM    440  ND2 ASN    57      45.071  32.255  14.144  1.00127.83           N\\nATOM    441  C   ASN    57      42.266  30.919  15.801  1.00127.83           C\\nATOM    442  O   ASN    57      42.725  31.899  16.387  1.00127.83           O\\nATOM    443  N   THR    58      41.682  29.893  16.444  1.00128.94           N\\nATOM    444  CA  THR    58      41.492  29.835  17.866  1.00128.94           C\\nATOM    445  CB  THR    58      40.578  28.725  18.283  1.00128.94           C\\nATOM    446  OG1 THR    58      40.437  28.727  19.693  1.00128.94           O\\nATOM    447  CG2 THR    58      41.118  27.385  17.771  1.00128.94           C\\nATOM    448  C   THR    58      42.807  29.711  18.582  1.00128.94           C\\nATOM    449  O   THR    58      42.917  30.083  19.748  1.00128.94           O\\nATOM    450  N   GLY    59      43.803  29.117  17.908  1.00 73.07           N\\nATOM    451  CA  GLY    59      45.141  28.847  18.361  1.00 73.07           C\\nATOM    452  C   GLY    59      46.004  30.070  18.521  1.00 73.07           C\\nATOM    453  O   GLY    59      47.047  29.996  19.170  1.00 73.07           O\\nATOM    454  N   ALA    60      45.664  31.189  17.852  1.00 57.13           N\\nATOM    455  CA  ALA    60      46.539  32.331  17.791  1.00 57.13           C\\nATOM    456  CB  ALA    60      45.960  33.505  16.986  1.00 57.13           C\\nATOM    457  C   ALA    60      46.930  32.861  19.139  1.00 57.13           C\\nATOM    458  O   ALA    60      46.120  32.977  20.058  1.00 57.13           O\\nATOM    459  N   THR    61      48.232  33.200  19.276  1.00113.38           N\\nATOM    460  CA  THR    61      48.740  33.758  20.496  1.00113.38           C\\nATOM    461  CB  THR    61      49.470  32.734  21.312  1.00113.38           C\\nATOM    462  OG1 THR    61      48.644  31.600  21.529  1.00113.38           O\\nATOM    463  CG2 THR    61      49.809  33.349  22.669  1.00113.38           C\\nATOM    464  C   THR    61      49.721  34.825  20.102  1.00113.38           C\\nATOM    465  O   THR    61      50.436  34.670  19.113  1.00113.38           O\\nATOM    466  N   ASN    62      49.764  35.957  20.840  1.00 64.27           N\\nATOM    467  CA  ASN    62      50.715  36.990  20.525  1.00 64.27           C\\nATOM    468  CB  ASN    62      50.129  38.113  19.650  1.00 64.27           C\\nATOM    469  CG  ASN    62      51.271  39.005  19.179  1.00 64.27           C\\nATOM    470  OD1 ASN    62      52.160  38.572  18.446  1.00 64.27           O\\nATOM    471  ND2 ASN    62      51.244  40.294  19.613  1.00 64.27           N\\nATOM    472  C   ASN    62      51.169  37.606  21.816  1.00 64.27           C\\nATOM    473  O   ASN    62      50.357  37.993  22.655  1.00 64.27           O\\nATOM    474  N   ARG    63      52.498  37.715  22.010  1.00134.31           N\\nATOM    475  CA  ARG    63      53.015  38.283  23.221  1.00134.31           C\\nATOM    476  CB  ARG    63      54.399  37.773  23.635  1.00134.31           C\\nATOM    477  CG  ARG    63      54.322  36.424  24.326  1.00134.31           C\\nATOM    478  CD  ARG    63      55.573  36.067  25.117  1.00134.31           C\\nATOM    479  NE  ARG    63      55.226  34.841  25.885  1.00134.31           N\\nATOM    480  CZ  ARG    63      56.033  34.383  26.885  1.00134.31           C\\nATOM    481  NH1 ARG    63      57.215  35.007  27.164  1.00134.31           N\\nATOM    482  NH2 ARG    63      55.642  33.297  27.613  1.00134.31           N\\nATOM    483  C   ARG    63      53.141  39.760  23.090  1.00134.31           C\\nATOM    484  O   ARG    63      53.314  40.300  21.998  1.00134.31           O\\nATOM    485  N   ASN    64      53.060  40.454  24.240  1.00 70.89           N\\nATOM    486  CA  ASN    64      53.208  41.877  24.229  1.00 70.89           C\\nATOM    487  CB  ASN    64      51.992  42.626  24.800  1.00 70.89           C\\nATOM    488  CG  ASN    64      50.844  42.450  23.813  1.00 70.89           C\\nATOM    489  OD1 ASN    64      49.797  41.898  24.148  1.00 70.89           O\\nATOM    490  ND2 ASN    64      51.046  42.934  22.558  1.00 70.89           N\\nATOM    491  C   ASN    64      54.411  42.211  25.056  1.00 70.89           C\\nATOM    492  O   ASN    64      54.961  41.359  25.755  1.00 70.89           O\\nATOM    493  N   THR    65      54.853  43.481  24.955  1.00 95.63           N\\nATOM    494  CA  THR    65      56.015  44.014  25.614  1.00 95.63           C\\nATOM    495  CB  THR    65      56.279  45.441  25.241  1.00 95.63           C\\nATOM    496  OG1 THR    65      56.448  45.556  23.837  1.00 95.63           O\\nATOM    497  CG2 THR    65      57.553  45.906  25.963  1.00 95.63           C\\nATOM    498  C   THR    65      55.799  43.994  27.093  1.00 95.63           C\\nATOM    499  O   THR    65      56.732  43.761  27.860  1.00 95.63           O\\nATOM    500  N   ASP    66      54.550  44.256  27.520  1.00 78.06           N\\nATOM    501  CA  ASP    66      54.178  44.348  28.903  1.00 78.06           C\\nATOM    502  CB  ASP    66      52.758  44.900  29.138  1.00 78.06           C\\nATOM    503  CG  ASP    66      51.722  43.939  28.580  1.00 78.06           C\\nATOM    504  OD1 ASP    66      52.008  43.280  27.545  1.00 78.06           O\\nATOM    505  OD2 ASP    66      50.623  43.849  29.189  1.00 78.06           O\\nATOM    506  C   ASP    66      54.298  43.007  29.570  1.00 78.06           C\\nATOM    507  O   ASP    66      54.287  42.923  30.797  1.00 78.06           O\\nATOM    508  N   GLY    67      54.359  41.907  28.797  1.00 30.12           N\\nATOM    509  CA  GLY    67      54.509  40.630  29.433  1.00 30.12           C\\nATOM    510  C   GLY    67      53.214  39.901  29.322  1.00 30.12           C\\nATOM    511  O   GLY    67      53.109  38.737  29.705  1.00 30.12           O\\nATOM    512  N   SER    68      52.181  40.588  28.808  1.00 46.07           N\\nATOM    513  CA  SER    68      50.911  39.958  28.621  1.00 46.07           C\\nATOM    514  CB  SER    68      49.726  40.931  28.677  1.00 46.07           C\\nATOM    515  OG  SER    68      49.794  41.832  27.581  1.00 46.07           O\\nATOM    516  C   SER    68      50.884  39.306  27.274  1.00 46.07           C\\nATOM    517  O   SER    68      51.732  39.564  26.418  1.00 46.07           O\\nATOM    518  N   THR    69      49.892  38.414  27.073  1.00 58.44           N\\nATOM    519  CA  THR    69      49.735  37.743  25.815  1.00 58.44           C\\nATOM    520  CB  THR    69      50.136  36.299  25.865  1.00 58.44           C\\nATOM    521  OG1 THR    69      51.491  36.187  26.267  1.00 58.44           O\\nATOM    522  CG2 THR    69      49.958  35.683  24.470  1.00 58.44           C\\nATOM    523  C   THR    69      48.281  37.800  25.442  1.00 58.44           C\\nATOM    524  O   THR    69      47.409  37.872  26.308  1.00 58.44           O\\nATOM    525  N   ASP    70      48.003  37.783  24.121  1.00 60.90           N\\nATOM    526  CA  ASP    70      46.674  37.826  23.559  1.00 60.90           C\\nATOM    527  CB  ASP    70      46.593  38.704  22.298  1.00 60.90           C\\nATOM    528  CG  ASP    70      46.881  40.146  22.702  1.00 60.90           C\\nATOM    529  OD1 ASP    70      46.431  40.550  23.808  1.00 60.90           O\\nATOM    530  OD2 ASP    70      47.561  40.859  21.917  1.00 60.90           O\\nATOM    531  C   ASP    70      46.338  36.419  23.155  1.00 60.90           C\\nATOM    532  O   ASP    70      47.173  35.746  22.549  1.00 60.90           O\\nATOM    533  N   TYR    71      45.112  35.933  23.480  1.00 84.65           N\\nATOM    534  CA  TYR    71      44.812  34.549  23.209  1.00 84.65           C\\nATOM    535  CB  TYR    71      44.629  33.695  24.483  1.00 84.65           C\\nATOM    536  CG  TYR    71      45.887  33.631  25.289  1.00 84.65           C\\nATOM    537  CD1 TYR    71      46.197  34.629  26.187  1.00 84.65           C\\nATOM    538  CD2 TYR    71      46.752  32.567  25.163  1.00 84.65           C\\nATOM    539  CE1 TYR    71      47.347  34.574  26.938  1.00 84.65           C\\nATOM    540  CE2 TYR    71      47.905  32.505  25.911  1.00 84.65           C\\nATOM    541  CZ  TYR    71      48.204  33.508  26.802  1.00 84.65           C\\nATOM    542  OH  TYR    71      49.384  33.449  27.573  1.00 84.65           O\\nATOM    543  C   TYR    71      43.525  34.353  22.454  1.00 84.65           C\\nATOM    544  O   TYR    71      42.500  34.973  22.736  1.00 84.65           O\\nATOM    545  N   GLY    72      43.571  33.428  21.471  1.00 41.64           N\\nATOM    546  CA  GLY    72      42.404  32.942  20.790  1.00 41.64           C\\nATOM    547  C   GLY    72      41.981  33.777  19.631  1.00 41.64           C\\nATOM    548  O   GLY    72      42.678  34.672  19.159  1.00 41.64           O\\nATOM    549  N   ILE    73      40.763  33.460  19.153  1.00 78.27           N\\nATOM    550  CA  ILE    73      40.176  34.058  17.993  1.00 78.27           C\\nATOM    551  CB  ILE    73      38.879  33.391  17.629  1.00 78.27           C\\nATOM    552  CG1 ILE    73      38.506  33.698  16.176  1.00 78.27           C\\nATOM    553  CG2 ILE    73      37.801  33.802  18.644  1.00 78.27           C\\nATOM    554  CD1 ILE    73      37.405  32.775  15.665  1.00 78.27           C\\nATOM    555  C   ILE    73      39.960  35.534  18.224  1.00 78.27           C\\nATOM    556  O   ILE    73      40.108  36.336  17.306  1.00 78.27           O\\nATOM    557  N   LEU    74      39.514  35.899  19.443  1.00107.14           N\\nATOM    558  CA  LEU    74      39.243  37.206  19.991  1.00107.14           C\\nATOM    559  CB  LEU    74      38.343  37.119  21.232  1.00107.14           C\\nATOM    560  CG  LEU    74      36.992  36.449  20.931  1.00107.14           C\\nATOM    561  CD1 LEU    74      36.109  36.375  22.183  1.00107.14           C\\nATOM    562  CD2 LEU    74      36.295  37.128  19.744  1.00107.14           C\\nATOM    563  C   LEU    74      40.494  37.920  20.426  1.00107.14           C\\nATOM    564  O   LEU    74      40.454  39.110  20.730  1.00107.14           O\\nATOM    565  N   GLN    75      41.610  37.192  20.605  1.00 75.30           N\\nATOM    566  CA  GLN    75      42.835  37.791  21.071  1.00 75.30           C\\nATOM    567  CB  GLN    75      43.443  38.791  20.071  1.00 75.30           C\\nATOM    568  CG  GLN    75      43.951  38.140  18.783  1.00 75.30           C\\nATOM    569  CD  GLN    75      45.317  37.531  19.068  1.00 75.30           C\\nATOM    570  OE1 GLN    75      46.282  38.245  19.339  1.00 75.30           O\\nATOM    571  NE2 GLN    75      45.406  36.175  19.000  1.00 75.30           N\\nATOM    572  C   GLN    75      42.600  38.514  22.369  1.00 75.30           C\\nATOM    573  O   GLN    75      42.928  39.692  22.506  1.00 75.30           O\\nATOM    574  N   ILE    76      42.027  37.809  23.367  1.00 78.35           N\\nATOM    575  CA  ILE    76      41.764  38.376  24.667  1.00 78.35           C\\nATOM    576  CB  ILE    76      40.750  37.578  25.434  1.00 78.35           C\\nATOM    577  CG1 ILE    76      39.401  37.635  24.690  1.00 78.35           C\\nATOM    578  CG2 ILE    76      40.690  38.102  26.878  1.00 78.35           C\\nATOM    579  CD1 ILE    76      38.377  36.604  25.162  1.00 78.35           C\\nATOM    580  C   ILE    76      43.054  38.461  25.453  1.00 78.35           C\\nATOM    581  O   ILE    76      43.835  37.512  25.500  1.00 78.35           O\\nATOM    582  N   ASN    77      43.310  39.631  26.086  1.00 72.24           N\\nATOM    583  CA  ASN    77      44.547  39.921  26.782  1.00 72.24           C\\nATOM    584  CB  ASN    77      44.849  41.430  26.843  1.00 72.24           C\\nATOM    585  CG  ASN    77      46.280  41.626  27.321  1.00 72.24           C\\nATOM    586  OD1 ASN    77      46.528  41.881  28.499  1.00 72.24           O\\nATOM    587  ND2 ASN    77      47.252  41.496  26.379  1.00 72.24           N\\nATOM    588  C   ASN    77      44.568  39.374  28.189  1.00 72.24           C\\nATOM    589  O   ASN    77      43.581  39.440  28.922  1.00 72.24           O\\nATOM    590  N   SER    78      45.745  38.832  28.586  1.00 70.39           N\\nATOM    591  CA  SER    78      46.010  38.194  29.852  1.00 70.39           C\\nATOM    592  CB  SER    78      47.279  37.328  29.818  1.00 70.39           C\\nATOM    593  OG  SER    78      48.408  38.133  29.517  1.00 70.39           O\\nATOM    594  C   SER    78      46.149  39.155  30.998  1.00 70.39           C\\nATOM    595  O   SER    78      46.105  38.735  32.153  1.00 70.39           O\\nATOM    596  N   ARG    79      46.398  40.453  30.752  1.00113.44           N\\nATOM    597  CA  ARG    79      46.511  41.308  31.902  1.00113.44           C\\nATOM    598  CB  ARG    79      46.902  42.760  31.576  1.00113.44           C\\nATOM    599  CG  ARG    79      48.404  43.028  31.490  1.00113.44           C\\nATOM    600  CD  ARG    79      48.712  44.527  31.482  1.00113.44           C\\nATOM    601  NE  ARG    79      50.174  44.707  31.700  1.00113.44           N\\nATOM    602  CZ  ARG    79      50.659  44.825  32.971  1.00113.44           C\\nATOM    603  NH1 ARG    79      49.810  44.730  34.036  1.00113.44           N\\nATOM    604  NH2 ARG    79      51.990  45.044  33.179  1.00113.44           N\\nATOM    605  C   ARG    79      45.205  41.385  32.644  1.00113.44           C\\nATOM    606  O   ARG    79      45.179  41.292  33.870  1.00113.44           O\\nATOM    607  N   TRP    80      44.107  41.698  31.925  1.00133.01           N\\nATOM    608  CA  TRP    80      42.790  41.832  32.498  1.00133.01           C\\nATOM    609  CB  TRP    80      41.944  42.834  31.692  1.00133.01           C\\nATOM    610  CG  TRP    80      42.458  44.253  31.760  1.00133.01           C\\nATOM    611  CD2 TRP    80      42.044  45.313  30.882  1.00133.01           C\\nATOM    612  CD1 TRP    80      43.380  44.793  32.609  1.00133.01           C\\nATOM    613  NE1 TRP    80      43.563  46.125  32.322  1.00133.01           N\\nATOM    614  CE2 TRP    80      42.747  46.458  31.260  1.00133.01           C\\nATOM    615  CE3 TRP    80      41.153  45.331  29.845  1.00133.01           C\\nATOM    616  CZ2 TRP    80      42.567  47.643  30.606  1.00133.01           C\\nATOM    617  CZ3 TRP    80      40.975  46.531  29.190  1.00133.01           C\\nATOM    618  CH2 TRP    80      41.668  47.665  29.563  1.00133.01           C\\nATOM    619  C   TRP    80      41.946  40.580  32.628  1.00133.01           C\\nATOM    620  O   TRP    80      41.354  40.310  33.671  1.00133.01           O\\nATOM    621  N   TRP    81      41.790  39.863  31.496  1.00142.58           N\\nATOM    622  CA  TRP    81      40.797  38.830  31.302  1.00142.58           C\\nATOM    623  CB  TRP    81      40.381  38.785  29.830  1.00142.58           C\\nATOM    624  CG  TRP    81      39.878  40.139  29.397  1.00142.58           C\\nATOM    625  CD2 TRP    81      38.792  40.822  30.040  1.00142.58           C\\nATOM    626  CD1 TRP    81      40.356  40.986  28.441  1.00142.58           C\\nATOM    627  NE1 TRP    81      39.627  42.151  28.441  1.00142.58           N\\nATOM    628  CE2 TRP    81      38.665  42.066  29.424  1.00142.58           C\\nATOM    629  CE3 TRP    81      37.977  40.448  31.070  1.00142.58           C\\nATOM    630  CZ2 TRP    81      37.712  42.958  29.827  1.00142.58           C\\nATOM    631  CZ3 TRP    81      37.011  41.348  31.467  1.00142.58           C\\nATOM    632  CH2 TRP    81      36.880  42.580  30.858  1.00142.58           C\\nATOM    633  C   TRP    81      41.018  37.416  31.783  1.00142.58           C\\nATOM    634  O   TRP    81      40.076  36.803  32.286  1.00142.58           O\\nATOM    635  N   CYS    82      42.217  36.823  31.590  1.00 59.67           N\\nATOM    636  CA  CYS    82      42.393  35.422  31.900  1.00 59.67           C\\nATOM    637  CB  CYS    82      42.435  34.526  30.642  1.00 59.67           C\\nATOM    638  SG  CYS    82      43.735  35.016  29.461  1.00 59.67           S\\nATOM    639  C   CYS    82      43.695  35.231  32.607  1.00 59.67           C\\nATOM    640  O   CYS    82      44.518  36.142  32.646  1.00 59.67           O\\nATOM    641  N   ASN    83      43.916  34.024  33.181  1.00 78.60           N\\nATOM    642  CA  ASN    83      45.124  33.774  33.924  1.00 78.60           C\\nATOM    643  CB  ASN    83      44.844  33.110  35.279  1.00 78.60           C\\nATOM    644  CG  ASN    83      46.178  32.818  35.945  1.00 78.60           C\\nATOM    645  OD1 ASN    83      47.007  33.706  36.138  1.00 78.60           O\\nATOM    646  ND2 ASN    83      46.395  31.522  36.294  1.00 78.60           N\\nATOM    647  C   ASN    83      46.031  32.841  33.171  1.00 78.60           C\\nATOM    648  O   ASN    83      45.707  31.671  32.985  1.00 78.60           O\\nATOM    649  N   ASP    84      47.146  33.377  32.623  1.00117.18           N\\nATOM    650  CA  ASP    84      48.210  32.640  31.988  1.00117.18           C\\nATOM    651  CB  ASP    84      48.825  33.348  30.757  1.00117.18           C\\nATOM    652  CG  ASP    84      49.384  34.722  31.088  1.00117.18           C\\nATOM    653  OD1 ASP    84      49.441  35.090  32.292  1.00117.18           O\\nATOM    654  OD2 ASP    84      49.759  35.431  30.115  1.00117.18           O\\nATOM    655  C   ASP    84      49.265  32.202  32.969  1.00117.18           C\\nATOM    656  O   ASP    84      50.052  31.307  32.673  1.00117.18           O\\nATOM    657  N   GLY    85      49.373  32.890  34.124  1.00 56.50           N\\nATOM    658  CA  GLY    85      50.289  32.542  35.179  1.00 56.50           C\\nATOM    659  C   GLY    85      51.548  33.358  35.082  1.00 56.50           C\\nATOM    660  O   GLY    85      52.233  33.559  36.085  1.00 56.50           O\\nATOM    661  N   ARG    86      51.923  33.750  33.848  1.00179.62           N\\nATOM    662  CA  ARG    86      53.100  34.522  33.540  1.00179.62           C\\nATOM    663  CB  ARG    86      53.749  34.156  32.198  1.00179.62           C\\nATOM    664  CG  ARG    86      52.930  34.517  30.967  1.00179.62           C\\nATOM    665  CD  ARG    86      53.639  34.099  29.682  1.00179.62           C\\nATOM    666  NE  ARG    86      53.245  35.065  28.624  1.00179.62           N\\nATOM    667  CZ  ARG    86      53.966  36.219  28.507  1.00179.62           C\\nATOM    668  NH1 ARG    86      54.972  36.481  29.391  1.00179.62           N\\nATOM    669  NH2 ARG    86      53.700  37.107  27.507  1.00179.62           N\\nATOM    670  C   ARG    86      52.913  36.024  33.592  1.00179.62           C\\nATOM    671  O   ARG    86      53.898  36.757  33.516  1.00179.62           O\\nATOM    672  N   THR    87      51.673  36.560  33.612  1.00156.15           N\\nATOM    673  CA  THR    87      51.574  38.000  33.492  1.00156.15           C\\nATOM    674  CB  THR    87      50.410  38.493  32.685  1.00156.15           C\\nATOM    675  OG1 THR    87      49.191  37.983  33.202  1.00156.15           O\\nATOM    676  CG2 THR    87      50.603  38.082  31.228  1.00156.15           C\\nATOM    677  C   THR    87      51.468  38.696  34.803  1.00156.15           C\\nATOM    678  O   THR    87      50.685  38.350  35.686  1.00156.15           O\\nATOM    679  N   PRO    88      52.287  39.712  34.908  1.00 88.04           N\\nATOM    680  CA  PRO    88      52.303  40.543  36.076  1.00 88.04           C\\nATOM    681  CD  PRO    88      53.552  39.753  34.194  1.00 88.04           C\\nATOM    682  CB  PRO    88      53.652  41.270  36.071  1.00 88.04           C\\nATOM    683  CG  PRO    88      54.193  41.076  34.644  1.00 88.04           C\\nATOM    684  C   PRO    88      51.122  41.461  36.110  1.00 88.04           C\\nATOM    685  O   PRO    88      50.779  42.034  35.076  1.00 88.04           O\\nATOM    686  N   GLY    89      50.515  41.628  37.303  1.00 37.70           N\\nATOM    687  CA  GLY    89      49.425  42.542  37.514  1.00 37.70           C\\nATOM    688  C   GLY    89      48.172  42.059  36.849  1.00 37.70           C\\nATOM    689  O   GLY    89      47.350  42.877  36.438  1.00 37.70           O\\nATOM    690  N   SER    90      47.982  40.730  36.726  1.00 59.87           N\\nATOM    691  CA  SER    90      46.817  40.213  36.048  1.00 59.87           C\\nATOM    692  CB  SER    90      47.010  38.783  35.511  1.00 59.87           C\\nATOM    693  OG  SER    90      47.237  37.888  36.589  1.00 59.87           O\\nATOM    694  C   SER    90      45.606  40.203  36.944  1.00 59.87           C\\nATOM    695  O   SER    90      45.684  39.842  38.118  1.00 59.87           O\\nATOM    696  N   LYS    91      44.469  40.691  36.389  1.00155.40           N\\nATOM    697  CA  LYS    91      43.145  40.770  36.968  1.00155.40           C\\nATOM    698  CB  LYS    91      42.311  41.865  36.285  1.00155.40           C\\nATOM    699  CG  LYS    91      42.901  43.263  36.465  1.00155.40           C\\nATOM    700  CD  LYS    91      42.992  43.690  37.929  1.00155.40           C\\nATOM    701  CE  LYS    91      43.639  45.058  38.124  1.00155.40           C\\nATOM    702  NZ  LYS    91      45.078  44.992  37.788  1.00155.40           N\\nATOM    703  C   LYS    91      42.335  39.483  36.928  1.00155.40           C\\nATOM    704  O   LYS    91      41.682  39.126  37.907  1.00155.40           O\\nATOM    705  N   ASN    92      42.338  38.752  35.788  1.00 67.36           N\\nATOM    706  CA  ASN    92      41.559  37.543  35.597  1.00 67.36           C\\nATOM    707  CB  ASN    92      42.038  36.374  36.477  1.00 67.36           C\\nATOM    708  CG  ASN    92      41.378  35.099  35.971  1.00 67.36           C\\nATOM    709  OD1 ASN    92      40.602  35.123  35.017  1.00 67.36           O\\nATOM    710  ND2 ASN    92      41.693  33.952  36.629  1.00 67.36           N\\nATOM    711  C   ASN    92      40.083  37.741  35.863  1.00 67.36           C\\nATOM    712  O   ASN    92      39.492  37.024  36.671  1.00 67.36           O\\nATOM    713  N   LEU    93      39.441  38.717  35.182  1.00105.82           N\\nATOM    714  CA  LEU    93      38.032  38.988  35.344  1.00105.82           C\\nATOM    715  CB  LEU    93      37.551  40.287  34.672  1.00105.82           C\\nATOM    716  CG  LEU    93      38.020  41.559  35.401  1.00105.82           C\\nATOM    717  CD1 LEU    93      39.539  41.716  35.316  1.00105.82           C\\nATOM    718  CD2 LEU    93      37.276  42.808  34.905  1.00105.82           C\\nATOM    719  C   LEU    93      37.158  37.871  34.837  1.00105.82           C\\nATOM    720  O   LEU    93      36.122  37.579  35.431  1.00105.82           O\\nATOM    721  N   CYS    94      37.522  37.235  33.707  1.00 67.33           N\\nATOM    722  CA  CYS    94      36.734  36.169  33.143  1.00 67.33           C\\nATOM    723  CB  CYS    94      37.116  35.805  31.691  1.00 67.33           C\\nATOM    724  SG  CYS    94      36.582  37.123  30.548  1.00 67.33           S\\nATOM    725  C   CYS    94      36.818  34.975  34.045  1.00 67.33           C\\nATOM    726  O   CYS    94      35.990  34.068  33.968  1.00 67.33           O\\nATOM    727  N   HIS    95      37.844  34.956  34.919  1.00122.48           N\\nATOM    728  CA  HIS    95      38.076  33.911  35.877  1.00122.48           C\\nATOM    729  ND1 HIS    95      38.084  33.515  39.148  1.00122.48           N\\nATOM    730  CG  HIS    95      37.352  32.984  38.110  1.00122.48           C\\nATOM    731  CB  HIS    95      36.941  33.769  36.903  1.00122.48           C\\nATOM    732  NE2 HIS    95      37.706  31.387  39.663  1.00122.48           N\\nATOM    733  CD2 HIS    95      37.130  31.683  38.440  1.00122.48           C\\nATOM    734  CE1 HIS    95      38.269  32.518  40.049  1.00122.48           C\\nATOM    735  C   HIS    95      38.274  32.608  35.175  1.00122.48           C\\nATOM    736  O   HIS    95      37.661  31.598  35.519  1.00122.48           O\\nATOM    737  N   ILE    96      39.151  32.611  34.152  1.00 63.58           N\\nATOM    738  CA  ILE    96      39.446  31.422  33.408  1.00 63.58           C\\nATOM    739  CB  ILE    96      38.735  31.379  32.088  1.00 63.58           C\\nATOM    740  CG1 ILE    96      39.159  32.580  31.228  1.00 63.58           C\\nATOM    741  CG2 ILE    96      37.222  31.299  32.348  1.00 63.58           C\\nATOM    742  CD1 ILE    96      38.661  32.503  29.786  1.00 63.58           C\\nATOM    743  C   ILE    96      40.912  31.378  33.119  1.00 63.58           C\\nATOM    744  O   ILE    96      41.632  32.365  33.274  1.00 63.58           O\\nATOM    745  N   PRO    97      41.368  30.194  32.788  1.00106.60           N\\nATOM    746  CA  PRO    97      42.725  30.046  32.333  1.00106.60           C\\nATOM    747  CD  PRO    97      40.922  29.029  33.537  1.00106.60           C\\nATOM    748  CB  PRO    97      43.084  28.575  32.530  1.00106.60           C\\nATOM    749  CG  PRO    97      42.163  28.131  33.681  1.00106.60           C\\nATOM    750  C   PRO    97      42.737  30.485  30.900  1.00106.60           C\\nATOM    751  O   PRO    97      41.745  30.258  30.210  1.00106.60           O\\nATOM    752  N   CYS    98      43.846  31.077  30.420  1.00 56.95           N\\nATOM    753  CA  CYS    98      43.939  31.590  29.080  1.00 56.95           C\\nATOM    754  CB  CYS    98      45.223  32.405  28.851  1.00 56.95           C\\nATOM    755  SG  CYS    98      45.340  33.860  29.942  1.00 56.95           S\\nATOM    756  C   CYS    98      43.891  30.454  28.092  1.00 56.95           C\\nATOM    757  O   CYS    98      43.465  30.627  26.949  1.00 56.95           O\\nATOM    758  N   SER    99      44.338  29.258  28.519  1.00 86.03           N\\nATOM    759  CA  SER    99      44.441  28.083  27.693  1.00 86.03           C\\nATOM    760  CB  SER    99      44.951  26.875  28.492  1.00 86.03           C\\nATOM    761  OG  SER    99      46.178  27.205  29.124  1.00 86.03           O\\nATOM    762  C   SER    99      43.088  27.712  27.157  1.00 86.03           C\\nATOM    763  O   SER    99      42.975  27.164  26.061  1.00 86.03           O\\nATOM    764  N   ALA   100      42.028  28.013  27.926  1.00 57.83           N\\nATOM    765  CA  ALA   100      40.661  27.711  27.593  1.00 57.83           C\\nATOM    766  CB  ALA   100      39.671  28.121  28.698  1.00 57.83           C\\nATOM    767  C   ALA   100      40.270  28.441  26.339  1.00 57.83           C\\nATOM    768  O   ALA   100      39.359  28.022  25.628  1.00 57.83           O\\nATOM    769  N   LEU   101      40.890  29.608  26.096  1.00 95.56           N\\nATOM    770  CA  LEU   101      40.648  30.475  24.970  1.00 95.56           C\\nATOM    771  CB  LEU   101      41.316  31.845  25.153  1.00 95.56           C\\nATOM    772  CG  LEU   101      40.761  32.602  26.375  1.00 95.56           C\\nATOM    773  CD1 LEU   101      41.444  33.967  26.546  1.00 95.56           C\\nATOM    774  CD2 LEU   101      39.224  32.709  26.314  1.00 95.56           C\\nATOM    775  C   LEU   101      41.130  29.888  23.658  1.00 95.56           C\\nATOM    776  O   LEU   101      40.785  30.406  22.596  1.00 95.56           O\\nATOM    777  N   LEU   102      42.081  28.933  23.699  1.00110.84           N\\nATOM    778  CA  LEU   102      42.675  28.294  22.546  1.00110.84           C\\nATOM    779  CB  LEU   102      44.117  27.834  22.813  1.00110.84           C\\nATOM    780  CG  LEU   102      45.048  29.044  23.058  1.00110.84           C\\nATOM    781  CD1 LEU   102      46.520  28.622  23.177  1.00110.84           C\\nATOM    782  CD2 LEU   102      44.833  30.142  22.002  1.00110.84           C\\nATOM    783  C   LEU   102      41.881  27.180  21.902  1.00110.84           C\\nATOM    784  O   LEU   102      42.184  26.787  20.777  1.00110.84           O\\nATOM    785  N   SER   103      40.909  26.573  22.608  1.00 50.17           N\\nATOM    786  CA  SER   103      40.233  25.397  22.115  1.00 50.17           C\\nATOM    787  CB  SER   103      39.353  24.736  23.187  1.00 50.17           C\\nATOM    788  OG  SER   103      38.332  25.634  23.591  1.00 50.17           O\\nATOM    789  C   SER   103      39.380  25.663  20.907  1.00 50.17           C\\nATOM    790  O   SER   103      38.999  26.794  20.609  1.00 50.17           O\\nATOM    791  N   SER   104      39.083  24.581  20.153  1.00 33.14           N\\nATOM    792  CA  SER   104      38.269  24.667  18.976  1.00 33.14           C\\nATOM    793  CB  SER   104      38.146  23.326  18.237  1.00 33.14           C\\nATOM    794  OG  SER   104      39.412  22.946  17.717  1.00 33.14           O\\nATOM    795  C   SER   104      36.903  25.080  19.413  1.00 33.14           C\\nATOM    796  O   SER   104      36.218  25.816  18.707  1.00 33.14           O\\nATOM    797  N   ASP   105      36.474  24.592  20.594  1.00 74.54           N\\nATOM    798  CA  ASP   105      35.196  24.937  21.151  1.00 74.54           C\\nATOM    799  CB  ASP   105      34.873  24.112  22.412  1.00 74.54           C\\nATOM    800  CG  ASP   105      33.427  24.337  22.821  1.00 74.54           C\\nATOM    801  OD1 ASP   105      33.037  25.514  23.016  1.00 74.54           O\\nATOM    802  OD2 ASP   105      32.693  23.326  22.965  1.00 74.54           O\\nATOM    803  C   ASP   105      35.252  26.387  21.548  1.00 74.54           C\\nATOM    804  O   ASP   105      36.127  26.805  22.303  1.00 74.54           O\\nATOM    805  N   ILE   106      34.315  27.182  20.997  1.00135.54           N\\nATOM    806  CA  ILE   106      34.135  28.604  21.162  1.00135.54           C\\nATOM    807  CB  ILE   106      33.277  29.216  20.098  1.00135.54           C\\nATOM    808  CG1 ILE   106      33.472  30.742  20.089  1.00135.54           C\\nATOM    809  CG2 ILE   106      31.824  28.771  20.333  1.00135.54           C\\nATOM    810  CD1 ILE   106      32.861  31.432  18.869  1.00135.54           C\\nATOM    811  C   ILE   106      33.538  29.010  22.486  1.00135.54           C\\nATOM    812  O   ILE   106      33.655  30.164  22.892  1.00135.54           O\\nATOM    813  N   THR   107      32.813  28.112  23.170  1.00 70.63           N\\nATOM    814  CA  THR   107      31.987  28.462  24.296  1.00 70.63           C\\nATOM    815  CB  THR   107      31.468  27.245  25.002  1.00 70.63           C\\nATOM    816  OG1 THR   107      30.731  26.437  24.096  1.00 70.63           O\\nATOM    817  CG2 THR   107      30.566  27.694  26.169  1.00 70.63           C\\nATOM    818  C   THR   107      32.684  29.308  25.327  1.00 70.63           C\\nATOM    819  O   THR   107      32.132  30.330  25.731  1.00 70.63           O\\nATOM    820  N   ALA   108      33.880  28.932  25.812  1.00 40.58           N\\nATOM    821  CA  ALA   108      34.527  29.721  26.830  1.00 40.58           C\\nATOM    822  CB  ALA   108      35.819  29.069  27.356  1.00 40.58           C\\nATOM    823  C   ALA   108      34.892  31.077  26.298  1.00 40.58           C\\nATOM    824  O   ALA   108      34.698  32.084  26.978  1.00 40.58           O\\nATOM    825  N   SER   109      35.423  31.134  25.060  1.00 74.60           N\\nATOM    826  CA  SER   109      35.886  32.363  24.481  1.00 74.60           C\\nATOM    827  CB  SER   109      36.505  32.170  23.086  1.00 74.60           C\\nATOM    828  OG  SER   109      36.944  33.419  22.573  1.00 74.60           O\\nATOM    829  C   SER   109      34.726  33.301  24.334  1.00 74.60           C\\nATOM    830  O   SER   109      34.845  34.490  24.629  1.00 74.60           O\\nATOM    831  N   VAL   110      33.566  32.789  23.872  1.00 95.43           N\\nATOM    832  CA  VAL   110      32.428  33.643  23.671  1.00 95.43           C\\nATOM    833  CB  VAL   110      31.251  32.969  23.021  1.00 95.43           C\\nATOM    834  CG1 VAL   110      31.665  32.500  21.617  1.00 95.43           C\\nATOM    835  CG2 VAL   110      30.729  31.847  23.931  1.00 95.43           C\\nATOM    836  C   VAL   110      31.968  34.195  24.983  1.00 95.43           C\\nATOM    837  O   VAL   110      31.637  35.375  25.077  1.00 95.43           O\\nATOM    838  N   ASN   111      31.940  33.363  26.040  1.00 32.22           N\\nATOM    839  CA  ASN   111      31.456  33.828  27.306  1.00 32.22           C\\nATOM    840  CB  ASN   111      31.496  32.740  28.391  1.00 32.22           C\\nATOM    841  CG  ASN   111      30.480  31.672  28.024  1.00 32.22           C\\nATOM    842  OD1 ASN   111      29.366  31.979  27.604  1.00 32.22           O\\nATOM    843  ND2 ASN   111      30.872  30.380  28.183  1.00 32.22           N\\nATOM    844  C   ASN   111      32.330  34.955  27.772  1.00 32.22           C\\nATOM    845  O   ASN   111      31.837  35.964  28.271  1.00 32.22           O\\nATOM    846  N   CYS   112      33.661  34.812  27.637  1.00 48.13           N\\nATOM    847  CA  CYS   112      34.566  35.828  28.100  1.00 48.13           C\\nATOM    848  CB  CYS   112      36.035  35.355  28.087  1.00 48.13           C\\nATOM    849  SG  CYS   112      37.238  36.576  28.699  1.00 48.13           S\\nATOM    850  C   CYS   112      34.405  37.079  27.272  1.00 48.13           C\\nATOM    851  O   CYS   112      34.395  38.182  27.813  1.00 48.13           O\\nATOM    852  N   ALA   113      34.244  36.949  25.937  1.00 44.02           N\\nATOM    853  CA  ALA   113      34.095  38.099  25.071  1.00 44.02           C\\nATOM    854  CB  ALA   113      33.905  37.717  23.597  1.00 44.02           C\\nATOM    855  C   ALA   113      32.867  38.867  25.476  1.00 44.02           C\\nATOM    856  O   ALA   113      32.849  40.097  25.440  1.00 44.02           O\\nATOM    857  N   LYS   114      31.788  38.158  25.855  1.00 65.25           N\\nATOM    858  CA  LYS   114      30.583  38.825  26.256  1.00 65.25           C\\nATOM    859  CB  LYS   114      29.424  37.861  26.560  1.00 65.25           C\\nATOM    860  CG  LYS   114      28.825  37.256  25.285  1.00 65.25           C\\nATOM    861  CD  LYS   114      27.851  36.102  25.522  1.00 65.25           C\\nATOM    862  CE  LYS   114      27.276  35.530  24.227  1.00 65.25           C\\nATOM    863  NZ  LYS   114      28.303  34.725  23.533  1.00 65.25           N\\nATOM    864  C   LYS   114      30.867  39.637  27.482  1.00 65.25           C\\nATOM    865  O   LYS   114      30.315  40.723  27.647  1.00 65.25           O\\nATOM    866  N   LYS   115      31.718  39.114  28.388  1.00118.09           N\\nATOM    867  CA  LYS   115      32.057  39.817  29.596  1.00118.09           C\\nATOM    868  CB  LYS   115      32.914  38.963  30.557  1.00118.09           C\\nATOM    869  CG  LYS   115      33.156  39.588  31.940  1.00118.09           C\\nATOM    870  CD  LYS   115      34.027  40.848  31.931  1.00118.09           C\\nATOM    871  CE  LYS   115      34.236  41.470  33.311  1.00118.09           C\\nATOM    872  NZ  LYS   115      33.013  42.184  33.731  1.00118.09           N\\nATOM    873  C   LYS   115      32.826  41.066  29.258  1.00118.09           C\\nATOM    874  O   LYS   115      32.547  42.136  29.798  1.00118.09           O\\nATOM    875  N   ILE   116      33.795  40.978  28.321  1.00150.45           N\\nATOM    876  CA  ILE   116      34.651  42.097  28.028  1.00150.45           C\\nATOM    877  CB  ILE   116      35.749  41.773  27.048  1.00150.45           C\\nATOM    878  CG1 ILE   116      35.249  41.519  25.616  1.00150.45           C\\nATOM    879  CG2 ILE   116      36.507  40.583  27.649  1.00150.45           C\\nATOM    880  CD1 ILE   116      34.998  42.809  24.835  1.00150.45           C\\nATOM    881  C   ILE   116      33.846  43.254  27.509  1.00150.45           C\\nATOM    882  O   ILE   116      34.090  44.396  27.891  1.00150.45           O\\nATOM    883  N   VAL   117      32.849  42.983  26.644  1.00 67.00           N\\nATOM    884  CA  VAL   117      32.060  43.984  25.975  1.00 67.00           C\\nATOM    885  CB  VAL   117      31.195  43.412  24.885  1.00 67.00           C\\nATOM    886  CG1 VAL   117      32.127  42.822  23.815  1.00 67.00           C\\nATOM    887  CG2 VAL   117      30.202  42.398  25.475  1.00 67.00           C\\nATOM    888  C   VAL   117      31.223  44.764  26.944  1.00 67.00           C\\nATOM    889  O   VAL   117      30.802  45.878  26.638  1.00 67.00           O\\nATOM    890  N   SER   118      30.910  44.186  28.117  1.00 79.85           N\\nATOM    891  CA  SER   118      30.092  44.823  29.117  1.00 79.85           C\\nATOM    892  CB  SER   118      29.765  43.887  30.294  1.00 79.85           C\\nATOM    893  OG  SER   118      28.986  42.786  29.848  1.00 79.85           O\\nATOM    894  C   SER   118      30.782  46.028  29.692  1.00 79.85           C\\nATOM    895  O   SER   118      30.120  46.913  30.233  1.00 79.85           O\\nATOM    896  N   ASP   119      32.124  46.107  29.598  1.00 38.33           N\\nATOM    897  CA  ASP   119      32.819  47.234  30.158  1.00 38.33           C\\nATOM    898  CB  ASP   119      34.351  47.117  30.093  1.00 38.33           C\\nATOM    899  CG  ASP   119      34.779  46.022  31.057  1.00 38.33           C\\nATOM    900  OD1 ASP   119      33.883  45.420  31.706  1.00 38.33           O\\nATOM    901  OD2 ASP   119      36.011  45.776  31.162  1.00 38.33           O\\nATOM    902  C   ASP   119      32.428  48.451  29.376  1.00 38.33           C\\nATOM    903  O   ASP   119      31.843  48.354  28.299  1.00 38.33           O\\nATOM    904  N   GLY   120      32.770  49.640  29.915  1.00 28.35           N\\nATOM    905  CA  GLY   120      32.358  50.902  29.363  1.00 28.35           C\\nATOM    906  C   GLY   120      32.845  51.068  27.955  1.00 28.35           C\\nATOM    907  O   GLY   120      32.121  51.595  27.112  1.00 28.35           O\\nATOM    908  N   ASN   121      34.087  50.641  27.665  1.00 48.80           N\\nATOM    909  CA  ASN   121      34.667  50.803  26.358  1.00 48.80           C\\nATOM    910  CB  ASN   121      36.158  50.442  26.307  1.00 48.80           C\\nATOM    911  CG  ASN   121      36.895  51.600  26.965  1.00 48.80           C\\nATOM    912  OD1 ASN   121      36.767  52.748  26.542  1.00 48.80           O\\nATOM    913  ND2 ASN   121      37.679  51.297  28.035  1.00 48.80           N\\nATOM    914  C   ASN   121      33.923  49.984  25.350  1.00 48.80           C\\nATOM    915  O   ASN   121      33.902  50.315  24.164  1.00 48.80           O\\nATOM    916  N   GLY   122      33.328  48.859  25.780  1.00 28.82           N\\nATOM    917  CA  GLY   122      32.563  48.076  24.853  1.00 28.82           C\\nATOM    918  C   GLY   122      33.505  47.398  23.907  1.00 28.82           C\\nATOM    919  O   GLY   122      34.576  46.930  24.288  1.00 28.82           O\\nATOM    920  N   MET   123      33.115  47.360  22.621  1.00 74.66           N\\nATOM    921  CA  MET   123      33.841  46.702  21.569  1.00 74.66           C\\nATOM    922  CB  MET   123      33.075  46.591  20.242  1.00 74.66           C\\nATOM    923  CG  MET   123      31.958  45.548  20.303  1.00 74.66           C\\nATOM    924  SD  MET   123      31.385  44.984  18.674  1.00 74.66           S\\nATOM    925  CE  MET   123      32.919  44.113  18.241  1.00 74.66           C\\nATOM    926  C   MET   123      35.149  47.386  21.322  1.00 74.66           C\\nATOM    927  O   MET   123      36.037  46.817  20.688  1.00 74.66           O\\nATOM    928  N   ASN   124      35.269  48.646  21.775  1.00 61.09           N\\nATOM    929  CA  ASN   124      36.441  49.468  21.617  1.00 61.09           C\\nATOM    930  CB  ASN   124      36.296  50.850  22.275  1.00 61.09           C\\nATOM    931  CG  ASN   124      35.244  51.623  21.499  1.00 61.09           C\\nATOM    932  OD1 ASN   124      35.294  51.706  20.272  1.00 61.09           O\\nATOM    933  ND2 ASN   124      34.248  52.189  22.232  1.00 61.09           N\\nATOM    934  C   ASN   124      37.606  48.790  22.276  1.00 61.09           C\\nATOM    935  O   ASN   124      38.757  49.167  22.067  1.00 61.09           O\\nATOM    936  N   ALA   125      37.339  47.797  23.136  1.00 53.55           N\\nATOM    937  CA  ALA   125      38.382  47.098  23.828  1.00 53.55           C\\nATOM    938  CB  ALA   125      37.856  45.975  24.738  1.00 53.55           C\\nATOM    939  C   ALA   125      39.317  46.473  22.828  1.00 53.55           C\\nATOM    940  O   ALA   125      40.507  46.316  23.102  1.00 53.55           O\\nATOM    941  N   TRP   126      38.813  46.050  21.653  1.00 90.68           N\\nATOM    942  CA  TRP   126      39.717  45.430  20.719  1.00 90.68           C\\nATOM    943  CB  TRP   126      39.101  44.304  19.877  1.00 90.68           C\\nATOM    944  CG  TRP   126      38.835  43.036  20.646  1.00 90.68           C\\nATOM    945  CD2 TRP   126      37.549  42.655  21.153  1.00 90.68           C\\nATOM    946  CD1 TRP   126      39.691  42.023  20.960  1.00 90.68           C\\nATOM    947  NE1 TRP   126      39.018  41.036  21.633  1.00 90.68           N\\nATOM    948  CE2 TRP   126      37.699  41.406  21.755  1.00 90.68           C\\nATOM    949  CE3 TRP   126      36.340  43.292  21.115  1.00 90.68           C\\nATOM    950  CZ2 TRP   126      36.640  40.767  22.329  1.00 90.68           C\\nATOM    951  CZ3 TRP   126      35.272  42.646  21.697  1.00 90.68           C\\nATOM    952  CH2 TRP   126      35.422  41.407  22.288  1.00 90.68           C\\nATOM    953  C   TRP   126      40.293  46.430  19.762  1.00 90.68           C\\nATOM    954  O   TRP   126      39.583  47.170  19.084  1.00 90.68           O\\nATOM    955  N   VAL   127      41.638  46.429  19.663  1.00 95.40           N\\nATOM    956  CA  VAL   127      42.363  47.342  18.828  1.00 95.40           C\\nATOM    957  CB  VAL   127      43.853  47.207  18.969  1.00 95.40           C\\nATOM    958  CG1 VAL   127      44.292  45.823  18.465  1.00 95.40           C\\nATOM    959  CG2 VAL   127      44.508  48.376  18.219  1.00 95.40           C\\nATOM    960  C   VAL   127      42.004  47.124  17.386  1.00 95.40           C\\nATOM    961  O   VAL   127      41.807  48.085  16.644  1.00 95.40           O\\nATOM    962  N   ALA   128      41.887  45.853  16.953  1.00 36.42           N\\nATOM    963  CA  ALA   128      41.613  45.535  15.579  1.00 36.42           C\\nATOM    964  CB  ALA   128      41.553  44.022  15.312  1.00 36.42           C\\nATOM    965  C   ALA   128      40.291  46.107  15.181  1.00 36.42           C\\nATOM    966  O   ALA   128      40.137  46.585  14.059  1.00 36.42           O\\nATOM    967  N   TRP   129      39.293  46.054  16.081  1.00 50.43           N\\nATOM    968  CA  TRP   129      37.985  46.557  15.768  1.00 50.43           C\\nATOM    969  CB  TRP   129      36.987  46.332  16.916  1.00 50.43           C\\nATOM    970  CG  TRP   129      35.592  46.834  16.632  1.00 50.43           C\\nATOM    971  CD2 TRP   129      35.151  48.175  16.901  1.00 50.43           C\\nATOM    972  CD1 TRP   129      34.522  46.177  16.097  1.00 50.43           C\\nATOM    973  NE1 TRP   129      33.442  47.024  16.015  1.00 50.43           N\\nATOM    974  CE2 TRP   129      33.815  48.258  16.506  1.00 50.43           C\\nATOM    975  CE3 TRP   129      35.805  49.249  17.434  1.00 50.43           C\\nATOM    976  CZ2 TRP   129      33.111  49.422  16.637  1.00 50.43           C\\nATOM    977  CZ3 TRP   129      35.092  50.420  17.564  1.00 50.43           C\\nATOM    978  CH2 TRP   129      33.772  50.505  17.173  1.00 50.43           C\\nATOM    979  C   TRP   129      38.072  48.031  15.519  1.00 50.43           C\\nATOM    980  O   TRP   129      37.536  48.545  14.537  1.00 50.43           O\\nATOM    981  N   ARG   130      38.771  48.765  16.400  1.00140.84           N\\nATOM    982  CA  ARG   130      38.801  50.183  16.224  1.00140.84           C\\nATOM    983  CB  ARG   130      39.497  50.935  17.376  1.00140.84           C\\nATOM    984  CG  ARG   130      40.958  50.572  17.652  1.00140.84           C\\nATOM    985  CD  ARG   130      41.433  51.172  18.980  1.00140.84           C\\nATOM    986  NE  ARG   130      42.904  50.984  19.107  1.00140.84           N\\nATOM    987  CZ  ARG   130      43.488  51.122  20.333  1.00140.84           C\\nATOM    988  NH1 ARG   130      42.710  51.323  21.436  1.00140.84           N\\nATOM    989  NH2 ARG   130      44.847  51.059  20.457  1.00140.84           N\\nATOM    990  C   ARG   130      39.458  50.506  14.923  1.00140.84           C\\nATOM    991  O   ARG   130      38.993  51.382  14.194  1.00140.84           O\\nATOM    992  N   LYS   131      40.567  49.819  14.592  1.00 61.27           N\\nATOM    993  CA  LYS   131      41.238  50.163  13.375  1.00 61.27           C\\nATOM    994  CB  LYS   131      42.612  49.486  13.251  1.00 61.27           C\\nATOM    995  CG  LYS   131      43.413  49.953  12.035  1.00 61.27           C\\nATOM    996  CD  LYS   131      44.887  49.548  12.085  1.00 61.27           C\\nATOM    997  CE  LYS   131      45.687  49.993  10.859  1.00 61.27           C\\nATOM    998  NZ  LYS   131      47.095  49.565  10.994  1.00 61.27           N\\nATOM    999  C   LYS   131      40.449  49.808  12.144  1.00 61.27           C\\nATOM   1000  O   LYS   131      40.102  50.686  11.357  1.00 61.27           O\\nATOM   1001  N   HIS   132      40.179  48.501  11.927  1.00111.52           N\\nATOM   1002  CA  HIS   132      39.531  48.047  10.723  1.00111.52           C\\nATOM   1003  ND1 HIS   132      42.571  46.799  10.467  1.00111.52           N\\nATOM   1004  CG  HIS   132      41.415  46.836   9.720  1.00111.52           C\\nATOM   1005  CB  HIS   132      40.036  46.672  10.274  1.00111.52           C\\nATOM   1006  NE2 HIS   132      43.176  47.268   8.379  1.00111.52           N\\nATOM   1007  CD2 HIS   132      41.804  47.121   8.448  1.00111.52           C\\nATOM   1008  CE1 HIS   132      43.594  47.066   9.615  1.00111.52           C\\nATOM   1009  C   HIS   132      38.026  48.074  10.669  1.00111.52           C\\nATOM   1010  O   HIS   132      37.456  48.277   9.603  1.00111.52           O\\nATOM   1011  N   CYS   133      37.334  47.729  11.765  1.00 89.73           N\\nATOM   1012  CA  CYS   133      35.899  47.593  11.751  1.00 89.73           C\\nATOM   1013  CB  CYS   133      35.440  46.616  12.846  1.00 89.73           C\\nATOM   1014  SG  CYS   133      36.443  45.094  12.849  1.00 89.73           S\\nATOM   1015  C   CYS   133      35.116  48.860  11.906  1.00 89.73           C\\nATOM   1016  O   CYS   133      34.086  49.048  11.260  1.00 89.73           O\\nATOM   1017  N   LYS   134      35.587  49.755  12.789  1.00 60.11           N\\nATOM   1018  CA  LYS   134      34.864  50.929  13.194  1.00 60.11           C\\nATOM   1019  CB  LYS   134      35.703  51.775  14.171  1.00 60.11           C\\nATOM   1020  CG  LYS   134      35.004  52.970  14.821  1.00 60.11           C\\nATOM   1021  CD  LYS   134      35.856  53.580  15.939  1.00 60.11           C\\nATOM   1022  CE  LYS   134      35.306  54.883  16.516  1.00 60.11           C\\nATOM   1023  NZ  LYS   134      36.205  55.367  17.588  1.00 60.11           N\\nATOM   1024  C   LYS   134      34.527  51.793  12.015  1.00 60.11           C\\nATOM   1025  O   LYS   134      35.388  52.129  11.205  1.00 60.11           O\\nATOM   1026  N   GLY   135      33.228  52.154  11.896  1.00 29.26           N\\nATOM   1027  CA  GLY   135      32.750  53.082  10.909  1.00 29.26           C\\nATOM   1028  C   GLY   135      32.882  52.524   9.526  1.00 29.26           C\\nATOM   1029  O   GLY   135      32.882  53.284   8.559  1.00 29.26           O\\nATOM   1030  N   THR   136      32.999  51.191   9.373  1.00102.52           N\\nATOM   1031  CA  THR   136      33.170  50.670   8.046  1.00102.52           C\\nATOM   1032  CB  THR   136      34.324  49.722   7.904  1.00102.52           C\\nATOM   1033  OG1 THR   136      34.587  49.483   6.531  1.00102.52           O\\nATOM   1034  CG2 THR   136      33.965  48.399   8.596  1.00102.52           C\\nATOM   1035  C   THR   136      31.940  49.933   7.621  1.00102.52           C\\nATOM   1036  O   THR   136      30.997  49.765   8.394  1.00102.52           O\\nATOM   1037  N   ASP   137      31.929  49.486   6.346  1.00 55.35           N\\nATOM   1038  CA  ASP   137      30.833  48.723   5.826  1.00 55.35           C\\nATOM   1039  CB  ASP   137      30.643  48.858   4.306  1.00 55.35           C\\nATOM   1040  CG  ASP   137      29.278  48.276   3.969  1.00 55.35           C\\nATOM   1041  OD1 ASP   137      28.467  48.097   4.916  1.00 55.35           O\\nATOM   1042  OD2 ASP   137      29.025  48.007   2.766  1.00 55.35           O\\nATOM   1043  C   ASP   137      31.143  47.283   6.118  1.00 55.35           C\\nATOM   1044  O   ASP   137      32.056  46.698   5.537  1.00 55.35           O\\nATOM   1045  N   VAL   138      30.390  46.722   7.083  1.00 78.03           N\\nATOM   1046  CA  VAL   138      30.455  45.399   7.646  1.00 78.03           C\\nATOM   1047  CB  VAL   138      29.698  45.331   8.942  1.00 78.03           C\\nATOM   1048  CG1 VAL   138      29.788  43.907   9.515  1.00 78.03           C\\nATOM   1049  CG2 VAL   138      30.257  46.409   9.885  1.00 78.03           C\\nATOM   1050  C   VAL   138      29.898  44.324   6.748  1.00 78.03           C\\nATOM   1051  O   VAL   138      30.213  43.147   6.918  1.00 78.03           O\\nATOM   1052  N   ASN   139      29.053  44.692   5.769  1.00 91.71           N\\nATOM   1053  CA  ASN   139      28.252  43.771   5.003  1.00 91.71           C\\nATOM   1054  CB  ASN   139      27.529  44.469   3.834  1.00 91.71           C\\nATOM   1055  CG  ASN   139      26.474  43.539   3.253  1.00 91.71           C\\nATOM   1056  OD1 ASN   139      26.766  42.410   2.866  1.00 91.71           O\\nATOM   1057  ND2 ASN   139      25.206  44.025   3.179  1.00 91.71           N\\nATOM   1058  C   ASN   139      29.069  42.647   4.431  1.00 91.71           C\\nATOM   1059  O   ASN   139      28.604  41.510   4.370  1.00 91.71           O\\nATOM   1060  N   VAL   140      30.312  42.909   4.004  1.00101.59           N\\nATOM   1061  CA  VAL   140      31.113  41.891   3.383  1.00101.59           C\\nATOM   1062  CB  VAL   140      32.463  42.399   2.979  1.00101.59           C\\nATOM   1063  CG1 VAL   140      32.271  43.509   1.931  1.00101.59           C\\nATOM   1064  CG2 VAL   140      33.202  42.858   4.248  1.00101.59           C\\nATOM   1065  C   VAL   140      31.339  40.726   4.314  1.00101.59           C\\nATOM   1066  O   VAL   140      31.403  39.582   3.865  1.00101.59           O\\nATOM   1067  N   TRP   141      31.480  40.965   5.634  1.00123.75           N\\nATOM   1068  CA  TRP   141      31.817  39.894   6.539  1.00123.75           C\\nATOM   1069  CB  TRP   141      32.121  40.348   7.978  1.00123.75           C\\nATOM   1070  CG  TRP   141      33.513  40.911   8.127  1.00123.75           C\\nATOM   1071  CD2 TRP   141      33.873  42.291   7.959  1.00123.75           C\\nATOM   1072  CD1 TRP   141      34.665  40.245   8.428  1.00123.75           C\\nATOM   1073  NE1 TRP   141      35.723  41.121   8.453  1.00123.75           N\\nATOM   1074  CE2 TRP   141      35.250  42.384   8.166  1.00123.75           C\\nATOM   1075  CE3 TRP   141      33.122  43.388   7.652  1.00123.75           C\\nATOM   1076  CZ2 TRP   141      35.898  43.582   8.071  1.00123.75           C\\nATOM   1077  CZ3 TRP   141      33.777  44.596   7.562  1.00123.75           C\\nATOM   1078  CH2 TRP   141      35.139  44.691   7.767  1.00123.75           C\\nATOM   1079  C   TRP   141      30.789  38.794   6.592  1.00123.75           C\\nATOM   1080  O   TRP   141      31.173  37.637   6.755  1.00123.75           O\\nATOM   1081  N   ILE   142      29.479  39.123   6.599  1.00138.84           N\\nATOM   1082  CA  ILE   142      28.379  38.179   6.580  1.00138.84           C\\nATOM   1083  CB  ILE   142      27.102  38.687   7.199  1.00138.84           C\\nATOM   1084  CG1 ILE   142      26.576  39.956   6.518  1.00138.84           C\\nATOM   1085  CG2 ILE   142      27.375  38.862   8.702  1.00138.84           C\\nATOM   1086  CD1 ILE   142      27.431  41.187   6.818  1.00138.84           C\\nATOM   1087  C   ILE   142      28.071  37.600   5.222  1.00138.84           C\\nATOM   1088  O   ILE   142      27.521  36.506   5.131  1.00138.84           O\\nATOM   1089  N   ARG   143      28.340  38.346   4.135  1.00182.47           N\\nATOM   1090  CA  ARG   143      27.955  38.003   2.786  1.00182.47           C\\nATOM   1091  CB  ARG   143      28.801  38.746   1.737  1.00182.47           C\\nATOM   1092  CG  ARG   143      28.495  38.343   0.294  1.00182.47           C\\nATOM   1093  CD  ARG   143      27.276  39.048  -0.295  1.00182.47           C\\nATOM   1094  NE  ARG   143      27.793  40.202  -1.079  1.00182.47           N\\nATOM   1095  CZ  ARG   143      27.028  41.317  -1.256  1.00182.47           C\\nATOM   1096  NH1 ARG   143      25.790  41.394  -0.685  1.00182.47           N\\nATOM   1097  NH2 ARG   143      27.510  42.354  -2.000  1.00182.47           N\\nATOM   1098  C   ARG   143      28.128  36.543   2.471  1.00182.47           C\\nATOM   1099  O   ARG   143      29.213  35.982   2.612  1.00182.47           O\\nATOM   1100  N   GLY   144      27.016  35.904   2.029  1.00 28.96           N\\nATOM   1101  CA  GLY   144      26.990  34.554   1.525  1.00 28.96           C\\nATOM   1102  C   GLY   144      26.797  33.549   2.620  1.00 28.96           C\\nATOM   1103  O   GLY   144      26.601  32.364   2.355  1.00 28.96           O\\nATOM   1104  N   CYS   145      26.858  33.986   3.883  1.00 59.69           N\\nATOM   1105  CA  CYS   145      26.755  33.096   5.004  1.00 59.69           C\\nATOM   1106  CB  CYS   145      27.294  33.731   6.293  1.00 59.69           C\\nATOM   1107  SG  CYS   145      29.048  34.169   6.085  1.00 59.69           S\\nATOM   1108  C   CYS   145      25.355  32.594   5.192  1.00 59.69           C\\nATOM   1109  O   CYS   145      25.148  31.528   5.773  1.00 59.69           O\\nATOM   1110  N   ARG   146      24.358  33.364   4.716  1.00117.37           N\\nATOM   1111  CA  ARG   146      22.969  33.018   4.837  1.00117.37           C\\nATOM   1112  CB  ARG   146      22.602  31.637   4.261  1.00117.37           C\\nATOM   1113  CG  ARG   146      22.680  31.550   2.738  1.00117.37           C\\nATOM   1114  CD  ARG   146      21.749  30.490   2.139  1.00117.37           C\\nATOM   1115  NE  ARG   146      22.197  29.149   2.608  1.00117.37           N\\nATOM   1116  CZ  ARG   146      21.400  28.060   2.397  1.00117.37           C\\nATOM   1117  NH1 ARG   146      20.175  28.210   1.814  1.00117.37           N\\nATOM   1118  NH2 ARG   146      21.832  26.818   2.761  1.00117.37           N\\nATOM   1119  C   ARG   146      22.537  33.027   6.265  1.00117.37           C\\nATOM   1120  O   ARG   146      21.687  32.230   6.658  1.00117.37           O\\nATOM   1121  N   LEU   147      23.105  33.930   7.085  1.00 70.16           N\\nATOM   1122  CA  LEU   147      22.630  34.043   8.431  1.00 70.16           C\\nATOM   1123  CB  LEU   147      23.715  34.456   9.441  1.00 70.16           C\\nATOM   1124  CG  LEU   147      24.732  33.335   9.723  1.00 70.16           C\\nATOM   1125  CD1 LEU   147      24.068  32.155  10.456  1.00 70.16           C\\nATOM   1126  CD2 LEU   147      25.455  32.897   8.443  1.00 70.16           C\\nATOM   1127  C   LEU   147      21.564  35.129   8.391  1.00 70.16           C\\nATOM   1128  O   LEU   147      21.524  35.982   9.315  1.00 70.16           O\\nATOM   1129  OXT LEU   147      20.766  35.116   7.416  1.00 70.16           O\\nTER    1130      LEU   147\\nCONECT  180 1107\\nCONECT  368 1014\\nCONECT  638  755\\nCONECT  724  849\\nEND\\n\",\"pdb\");\n",
       "\tviewergrid_151451551001[0][0].setStyle({\"cartoon\": {\"color\": \"spectrum\"}});\n",
       "\tviewergrid_151451551001[0][0].zoomTo();\n",
       "\tviewergrid_151451551001[0][0].zoom(1.25);\n",
       "\tviewergrid_151451551001[0][1].addModel(\"HEADER    HYDROLASE (O-GLYCOSYL)                  25-OCT-94   1LMP              \\nTITLE     THE CRYSTAL STRUCTURES OF THREE COMPLEXES BETWEEN                     \\nTITLE    2 CHITOOLIGOSACCHARIDES AND LYSOZYME FROM THE RAINBOW TROUT            \\nCOMPND    MOL_ID: 1;                                                            \\nCOMPND   2 MOLECULE: LYSOZYME;                                                  \\nCOMPND   3 CHAIN: A;                                                            \\nCOMPND   4 SYNONYM: MUCOPEPTIDE N-ACETYLMURAMYLHYDROLASE;                       \\nCOMPND   5 EC: 3.2.1.17                                                         \\nSOURCE    MOL_ID: 1;                                                            \\nSOURCE   2 ORGANISM_SCIENTIFIC: ONCORHYNCHUS MYKISS;                            \\nSOURCE   3 ORGANISM_COMMON: RAINBOW TROUT;                                      \\nSOURCE   4 ORGANISM_TAXID: 8022;                                                \\nSOURCE   5 ORGAN: KIDNEY                                                        \\nKEYWDS    HYDROLASE (O-GLYCOSYL)                                                \\nEXPDTA    X-RAY DIFFRACTION                                                     \\nAUTHOR    S.KARLSEN,E.HOUGH                                                     \\nREVDAT   3   13-JUL-11 1LMP    1       VERSN                                    \\nREVDAT   2   24-FEB-09 1LMP    1       VERSN                                    \\nREVDAT   1   01-JAN-96 1LMP    0                                                \\nJRNL        AUTH   S.KARLSEN,E.HOUGH                                            \\nJRNL        TITL   CRYSTAL STRUCTURES OF THREE COMPLEXES BETWEEN                \\nJRNL        TITL 2 CHITO-OLIGOSACCHARIDES AND LYSOZYME FROM THE RAINBOW TROUT.  \\nJRNL        TITL 3 HOW DISTORTED IS THE NAG SUGAR IN SITE D?                    \\nJRNL        REF    ACTA CRYSTALLOGR.,SECT.D      V.  51   962 1995              \\nJRNL        REFN                   ISSN 0907-4449                               \\nJRNL        PMID   15299765                                                     \\nJRNL        DOI    10.1107/S0907444995005105                                    \\nREMARK   1                                                                      \\nREMARK   1 REFERENCE 1                                                          \\nREMARK   1  AUTH   S.KARLSEN,B.E.ELIASSEN,L.KR.HANSEN,R.L.LARSEN,B.W.RIISE,     \\nREMARK   1  AUTH 2 A.O.SMALAAS,E.HOUGH,B.GRINDE                                 \\nREMARK   1  TITL   THE REFINED CRYSTAL STRUCTURE OF LYSOZYME FROM RAINBOW TROUT \\nREMARK   1  TITL 2 (ONCORHYNCHUS MYKISS)                                        \\nREMARK   1  REF    TO BE PUBLISHED                                              \\nREMARK   1  REFN                                                                \\nREMARK   1 REFERENCE 2                                                          \\nREMARK   1  AUTH   B.GRINDE,J.JOLLES,P.JOLLES                                   \\nREMARK   1  TITL   PURIFICATION AND CHARACTERIZATION OF TWO LYSOZYMES FROM      \\nREMARK   1  TITL 2 RAINBOW TROUT (SALMO GAIRDNERI)                              \\nREMARK   1  REF    EUR.J.BIOCHEM.                V. 173   269 1988              \\nREMARK   1  REFN                   ISSN 0014-2956                               \\nREMARK   2                                                                      \\nREMARK   2 RESOLUTION.    2.00 ANGSTROMS.                                       \\nREMARK   3                                                                      \\nREMARK   3 REFINEMENT.                                                          \\nREMARK   3   PROGRAM     : PROLSQ                                               \\nREMARK   3   AUTHORS     : KONNERT,HENDRICKSON                                  \\nREMARK   3                                                                      \\nREMARK   3  DATA USED IN REFINEMENT.                                            \\nREMARK   3   RESOLUTION RANGE HIGH (ANGSTROMS) : 2.00                           \\nREMARK   3   RESOLUTION RANGE LOW  (ANGSTROMS) : 8.00                           \\nREMARK   3   DATA CUTOFF            (SIGMA(F)) : 3.000                          \\nREMARK   3   COMPLETENESS FOR RANGE        (%) : NULL                           \\nREMARK   3   NUMBER OF REFLECTIONS             : 12175                          \\nREMARK   3                                                                      \\nREMARK   3  FIT TO DATA USED IN REFINEMENT.                                     \\nREMARK   3   CROSS-VALIDATION METHOD          : NULL                            \\nREMARK   3   FREE R VALUE TEST SET SELECTION  : NULL                            \\nREMARK   3   R VALUE     (WORKING + TEST SET) : 0.159                           \\nREMARK   3   R VALUE            (WORKING SET) : NULL                            \\nREMARK   3   FREE R VALUE                     : NULL                            \\nREMARK   3   FREE R VALUE TEST SET SIZE   (%) : NULL                            \\nREMARK   3   FREE R VALUE TEST SET COUNT      : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  FIT/AGREEMENT OF MODEL WITH ALL DATA.                               \\nREMARK   3   R VALUE   (WORKING + TEST SET, NO CUTOFF) : NULL                   \\nREMARK   3   R VALUE          (WORKING SET, NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE                  (NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE TEST SET SIZE (%, NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE TEST SET COUNT   (NO CUTOFF) : NULL                   \\nREMARK   3   TOTAL NUMBER OF REFLECTIONS   (NO CUTOFF) : NULL                   \\nREMARK   3                                                                      \\nREMARK   3  NUMBER OF NON-HYDROGEN ATOMS USED IN REFINEMENT.                    \\nREMARK   3   PROTEIN ATOMS            : 999                                     \\nREMARK   3   NUCLEIC ACID ATOMS       : 0                                       \\nREMARK   3   HETEROGEN ATOMS          : 43                                      \\nREMARK   3   SOLVENT ATOMS            : 117                                     \\nREMARK   3                                                                      \\nREMARK   3  B VALUES.                                                           \\nREMARK   3   FROM WILSON PLOT           (A**2) : NULL                           \\nREMARK   3   MEAN B VALUE      (OVERALL, A**2) : NULL                           \\nREMARK   3   OVERALL ANISOTROPIC B VALUE.                                       \\nREMARK   3    B11 (A**2) : NULL                                                 \\nREMARK   3    B22 (A**2) : NULL                                                 \\nREMARK   3    B33 (A**2) : NULL                                                 \\nREMARK   3    B12 (A**2) : NULL                                                 \\nREMARK   3    B13 (A**2) : NULL                                                 \\nREMARK   3    B23 (A**2) : NULL                                                 \\nREMARK   3                                                                      \\nREMARK   3  ESTIMATED COORDINATE ERROR.                                         \\nREMARK   3   ESD FROM LUZZATI PLOT        (A) : NULL                            \\nREMARK   3   ESD FROM SIGMAA              (A) : NULL                            \\nREMARK   3   LOW RESOLUTION CUTOFF        (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  RMS DEVIATIONS FROM IDEAL VALUES.                                   \\nREMARK   3   DISTANCE RESTRAINTS.                    RMS    SIGMA               \\nREMARK   3    BOND LENGTH                     (A) : 0.013 ; 0.020               \\nREMARK   3    ANGLE DISTANCE                  (A) : 0.047 ; 0.040               \\nREMARK   3    INTRAPLANAR 1-4 DISTANCE        (A) : 0.075 ; 0.050               \\nREMARK   3    H-BOND OR METAL COORDINATION    (A) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3   PLANE RESTRAINT                  (A) : 0.013 ; 0.020               \\nREMARK   3   CHIRAL-CENTER RESTRAINT       (A**3) : 0.037 ; 0.060               \\nREMARK   3                                                                      \\nREMARK   3   NON-BONDED CONTACT RESTRAINTS.                                     \\nREMARK   3    SINGLE TORSION                  (A) : 0.183 ; 0.030               \\nREMARK   3    MULTIPLE TORSION                (A) : 0.185 ; 0.300               \\nREMARK   3    H-BOND (X...Y)                  (A) : NULL  ; NULL                \\nREMARK   3    H-BOND (X-H...Y)                (A) : 0.235 ; 0.300               \\nREMARK   3                                                                      \\nREMARK   3   CONFORMATIONAL TORSION ANGLE RESTRAINTS.                           \\nREMARK   3    SPECIFIED                 (DEGREES) : NULL  ; NULL                \\nREMARK   3    PLANAR                    (DEGREES) : 5.200 ; 3.000               \\nREMARK   3    STAGGERED                 (DEGREES) : 18.200; 15.000              \\nREMARK   3    TRANSVERSE                (DEGREES) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL FACTOR RESTRAINTS.    RMS    SIGMA                \\nREMARK   3   MAIN-CHAIN BOND               (A**2) : NULL  ; NULL                \\nREMARK   3   MAIN-CHAIN ANGLE              (A**2) : NULL  ; NULL                \\nREMARK   3   SIDE-CHAIN BOND               (A**2) : NULL  ; NULL                \\nREMARK   3   SIDE-CHAIN ANGLE              (A**2) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3  OTHER REFINEMENT REMARKS: NULL                                      \\nREMARK   4                                                                      \\nREMARK   4 1LMP COMPLIES WITH FORMAT V. 3.30, 13-JUL-11                         \\nREMARK 100                                                                      \\nREMARK 100 THIS ENTRY HAS BEEN PROCESSED BY BNL.                                \\nREMARK 200                                                                      \\nREMARK 200 EXPERIMENTAL DETAILS                                                 \\nREMARK 200  EXPERIMENT TYPE                : X-RAY DIFFRACTION                  \\nREMARK 200  DATE OF DATA COLLECTION        : AUG-93                             \\nREMARK 200  TEMPERATURE           (KELVIN) : NULL                               \\nREMARK 200  PH                             : NULL                               \\nREMARK 200  NUMBER OF CRYSTALS USED        : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  SYNCHROTRON              (Y/N) : N                                  \\nREMARK 200  RADIATION SOURCE               : NULL                               \\nREMARK 200  BEAMLINE                       : NULL                               \\nREMARK 200  X-RAY GENERATOR MODEL          : NULL                               \\nREMARK 200  MONOCHROMATIC OR LAUE    (M/L) : M                                  \\nREMARK 200  WAVELENGTH OR RANGE        (A) : 1.5418                             \\nREMARK 200  MONOCHROMATOR                  : NULL                               \\nREMARK 200  OPTICS                         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  DETECTOR TYPE                  : AREA DETECTOR                      \\nREMARK 200  DETECTOR MANUFACTURER          : ENRAF-NONIUS FAST                  \\nREMARK 200  INTENSITY-INTEGRATION SOFTWARE : MADNES                             \\nREMARK 200  DATA SCALING SOFTWARE          : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  NUMBER OF UNIQUE REFLECTIONS   : 12175                              \\nREMARK 200  RESOLUTION RANGE HIGH      (A) : NULL                               \\nREMARK 200  RESOLUTION RANGE LOW       (A) : NULL                               \\nREMARK 200  REJECTION CRITERIA  (SIGMA(I)) : 3.000                              \\nREMARK 200                                                                      \\nREMARK 200 OVERALL.                                                             \\nREMARK 200  COMPLETENESS FOR RANGE     (%) : 96.9                               \\nREMARK 200  DATA REDUNDANCY                : NULL                               \\nREMARK 200  R MERGE                    (I) : 0.03300                            \\nREMARK 200  R SYM                      (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR THE DATA SET  : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 IN THE HIGHEST RESOLUTION SHELL.                                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE HIGH (A) : NULL                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE LOW  (A) : NULL                     \\nREMARK 200  COMPLETENESS FOR SHELL     (%) : NULL                               \\nREMARK 200  DATA REDUNDANCY IN SHELL       : NULL                               \\nREMARK 200  R MERGE FOR SHELL          (I) : NULL                               \\nREMARK 200  R SYM FOR SHELL            (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR SHELL         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 DIFFRACTION PROTOCOL: NULL                                           \\nREMARK 200 METHOD USED TO DETERMINE THE STRUCTURE: NULL                         \\nREMARK 200 SOFTWARE USED: NULL                                                  \\nREMARK 200 STARTING MODEL: NULL                                                 \\nREMARK 200                                                                      \\nREMARK 200 REMARK: NULL                                                         \\nREMARK 280                                                                      \\nREMARK 280 CRYSTAL                                                              \\nREMARK 280 SOLVENT CONTENT, VS   (%): 61.55                                     \\nREMARK 280 MATTHEWS COEFFICIENT, VM (ANGSTROMS**3/DA): 3.20                     \\nREMARK 280                                                                      \\nREMARK 280 CRYSTALLIZATION CONDITIONS: NULL                                     \\nREMARK 285                                                                      \\nREMARK 285 THE ENTRY COORDINATES                                                \\nREMARK 285 ARE NOT PRESENTED IN THE STANDARD CRYSTAL FRAME.                     \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY                                            \\nREMARK 290 SYMMETRY OPERATORS FOR SPACE GROUP: P 31 2 1                         \\nREMARK 290                                                                      \\nREMARK 290      SYMOP   SYMMETRY                                                \\nREMARK 290     NNNMMM   OPERATOR                                                \\nREMARK 290       1555   X,Y,Z                                                   \\nREMARK 290       2555   -Y,X-Y,Z+1/3                                            \\nREMARK 290       3555   -X+Y,-X,Z+2/3                                           \\nREMARK 290       4555   Y,X,-Z                                                  \\nREMARK 290       5555   X-Y,-Y,-Z+2/3                                           \\nREMARK 290       6555   -X,-X+Y,-Z+1/3                                          \\nREMARK 290                                                                      \\nREMARK 290     WHERE NNN -> OPERATOR NUMBER                                     \\nREMARK 290           MMM -> TRANSLATION VECTOR                                  \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY TRANSFORMATIONS                            \\nREMARK 290 THE FOLLOWING TRANSFORMATIONS OPERATE ON THE ATOM/HETATM             \\nREMARK 290 RECORDS IN THIS ENTRY TO PRODUCE CRYSTALLOGRAPHICALLY                \\nREMARK 290 RELATED MOLECULES.                                                   \\nREMARK 290   SMTRY1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 290   SMTRY1   2 -0.500000 -0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   2  0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   2  0.000000  0.000000  1.000000       18.09627            \\nREMARK 290   SMTRY1   3 -0.500000  0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   3 -0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   3  0.000000  0.000000  1.000000       36.19254            \\nREMARK 290   SMTRY1   4  0.500000  0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   4  0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   4  0.000000  0.000000 -1.000000        0.00000            \\nREMARK 290   SMTRY1   5  0.500000 -0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   5 -0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   5  0.000000  0.000000 -1.000000       36.19254            \\nREMARK 290   SMTRY1   6 -1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   6  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   6  0.000000  0.000000 -1.000000       18.09627            \\nREMARK 290                                                                      \\nREMARK 290 REMARK: NULL                                                         \\nREMARK 300                                                                      \\nREMARK 300 BIOMOLECULE: 1                                                       \\nREMARK 300 SEE REMARK 350 FOR THE AUTHOR PROVIDED AND/OR PROGRAM                \\nREMARK 300 GENERATED ASSEMBLY INFORMATION FOR THE STRUCTURE IN                  \\nREMARK 300 THIS ENTRY. THE REMARK MAY ALSO PROVIDE INFORMATION ON               \\nREMARK 300 BURIED SURFACE AREA.                                                 \\nREMARK 350                                                                      \\nREMARK 350 COORDINATES FOR A COMPLETE MULTIMER REPRESENTING THE KNOWN           \\nREMARK 350 BIOLOGICALLY SIGNIFICANT OLIGOMERIZATION STATE OF THE                \\nREMARK 350 MOLECULE CAN BE GENERATED BY APPLYING BIOMT TRANSFORMATIONS          \\nREMARK 350 GIVEN BELOW.  BOTH NON-CRYSTALLOGRAPHIC AND                          \\nREMARK 350 CRYSTALLOGRAPHIC OPERATIONS ARE GIVEN.                               \\nREMARK 350                                                                      \\nREMARK 350 BIOMOLECULE: 1                                                       \\nREMARK 350 AUTHOR DETERMINED BIOLOGICAL UNIT: MONOMERIC                         \\nREMARK 350 APPLY THE FOLLOWING TO CHAINS: A                                     \\nREMARK 350   BIOMT1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 350   BIOMT2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 350   BIOMT3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS IN SAME ASYMMETRIC UNIT                     \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS ARE IN CLOSE CONTACT.                            \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI           DISTANCE          \\nREMARK 500   O5   NAG A   131     O4   NDG A   132              2.11            \\nREMARK 500   C1   NAG A   131     C4   NDG A   132              2.14            \\nREMARK 500   OE1  GLU A    35     O    HOH A   244              2.14            \\nREMARK 500   NH1  ARG A    45     NH2  ARG A    68              2.19            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS                                             \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS THAT ARE RELATED BY CRYSTALLOGRAPHIC             \\nREMARK 500 SYMMETRY ARE IN CLOSE CONTACT.  AN ATOM LOCATED WITHIN 0.15          \\nREMARK 500 ANGSTROMS OF A SYMMETRY RELATED ATOM IS ASSUMED TO BE ON A           \\nREMARK 500 SPECIAL POSITION AND IS, THEREFORE, LISTED IN REMARK 375             \\nREMARK 500 INSTEAD OF REMARK 500.  ATOMS WITH NON-BLANK ALTERNATE               \\nREMARK 500 LOCATION INDICATORS ARE NOT INCLUDED IN THE CALCULATIONS.            \\nREMARK 500                                                                      \\nREMARK 500 DISTANCE CUTOFF:                                                     \\nREMARK 500 2.2 ANGSTROMS FOR CONTACTS NOT INVOLVING HYDROGEN ATOMS              \\nREMARK 500 1.6 ANGSTROMS FOR CONTACTS INVOLVING HYDROGEN ATOMS                  \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI  SSYMOP   DISTANCE          \\nREMARK 500   O    HOH A   143     O    HOH A   143     4556     1.47            \\nREMARK 500   O    HOH A   170     O    HOH A   170     4556     1.51            \\nREMARK 500   O    SER A    81     O    HOH A   170     4556     2.01            \\nREMARK 500   O    HOH A   175     O    HOH A   235     4556     2.17            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: COVALENT BOND ANGLES                                       \\nREMARK 500                                                                      \\nREMARK 500 THE STEREOCHEMICAL PARAMETERS OF THE FOLLOWING RESIDUES              \\nREMARK 500 HAVE VALUES WHICH DEVIATE FROM EXPECTED VALUES BY MORE               \\nREMARK 500 THAN 6*RMSD (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN               \\nREMARK 500 IDENTIFIER; SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                 \\nREMARK 500                                                                      \\nREMARK 500 STANDARD TABLE:                                                      \\nREMARK 500 FORMAT: (10X,I3,1X,A3,1X,A1,I4,A1,3(1X,A4,2X),12X,F5.1)              \\nREMARK 500                                                                      \\nREMARK 500 EXPECTED VALUES PROTEIN: ENGH AND HUBER, 1999                        \\nREMARK 500 EXPECTED VALUES NUCLEIC ACID: CLOWNEY ET AL 1996                     \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI ATM1   ATM2   ATM3                                     \\nREMARK 500    ASP A   4   CB  -  CG  -  OD1 ANGL. DEV. =  -6.3 DEGREES          \\nREMARK 500    ASP A   4   CB  -  CG  -  OD2 ANGL. DEV. =   5.7 DEGREES          \\nREMARK 500    ARG A   5   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.1 DEGREES          \\nREMARK 500    ASP A  18   CB  -  CG  -  OD1 ANGL. DEV. =   6.0 DEGREES          \\nREMARK 500    ARG A  45   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.4 DEGREES          \\nREMARK 500    ASP A  48   CB  -  CG  -  OD1 ANGL. DEV. =   6.5 DEGREES          \\nREMARK 500    ASP A  48   CB  -  CG  -  OD2 ANGL. DEV. =  -5.9 DEGREES          \\nREMARK 500    ARG A  61   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.5 DEGREES          \\nREMARK 500    TYR A  62   CB  -  CG  -  CD2 ANGL. DEV. =  -4.7 DEGREES          \\nREMARK 500    ASP A  86   CB  -  CG  -  OD1 ANGL. DEV. =   9.2 DEGREES          \\nREMARK 500    ARG A  93   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.3 DEGREES          \\nREMARK 500    ARG A  97   NE  -  CZ  -  NH1 ANGL. DEV. =   5.1 DEGREES          \\nREMARK 500    ARG A  97   NE  -  CZ  -  NH2 ANGL. DEV. =  -4.6 DEGREES          \\nREMARK 500    ARG A 121   CD  -  NE  -  CZ  ANGL. DEV. =  10.2 DEGREES          \\nREMARK 500    ARG A 121   NE  -  CZ  -  NH1 ANGL. DEV. =   5.9 DEGREES          \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: PLANAR GROUPS                                              \\nREMARK 500                                                                      \\nREMARK 500 PLANAR GROUPS IN THE FOLLOWING RESIDUES HAVE A TOTAL                 \\nREMARK 500 RMS DISTANCE OF ALL ATOMS FROM THE BEST-FIT PLANE                    \\nREMARK 500 BY MORE THAN AN EXPECTED VALUE OF 6*RMSD, WITH AN                    \\nREMARK 500 RMSD 0.02 ANGSTROMS, OR AT LEAST ONE ATOM HAS                        \\nREMARK 500 AN RMSD GREATER THAN THIS VALUE                                      \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        RMS     TYPE                                    \\nREMARK 500    ARG A  10         0.11    SIDE CHAIN                              \\nREMARK 500    ARG A  45         0.09    SIDE CHAIN                              \\nREMARK 500    ARG A  61         0.17    SIDE CHAIN                              \\nREMARK 500    ARG A  79         0.13    SIDE CHAIN                              \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 525                                                                      \\nREMARK 525 SOLVENT                                                              \\nREMARK 525                                                                      \\nREMARK 525 THE SOLVENT MOLECULES HAVE CHAIN IDENTIFIERS THAT                    \\nREMARK 525 INDICATE THE POLYMER CHAIN WITH WHICH THEY ARE MOST                  \\nREMARK 525 CLOSELY ASSOCIATED. THE REMARK LISTS ALL THE SOLVENT                 \\nREMARK 525 MOLECULES WHICH ARE MORE THAN 5A AWAY FROM THE                       \\nREMARK 525 NEAREST POLYMER CHAIN (M = MODEL NUMBER;                             \\nREMARK 525 RES=RESIDUE NAME; C=CHAIN IDENTIFIER; SSEQ=SEQUENCE                  \\nREMARK 525 NUMBER; I=INSERTION CODE):                                           \\nREMARK 525                                                                      \\nREMARK 525  M RES CSSEQI                                                        \\nREMARK 525    HOH A 214        DISTANCE =  8.17 ANGSTROMS                       \\nREMARK 800                                                                      \\nREMARK 800 SITE                                                                 \\nREMARK 800 SITE_IDENTIFIER: AC1                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NAG A 130                 \\nREMARK 800                                                                      \\nREMARK 800 SITE_IDENTIFIER: AC2                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NAG A 131                 \\nREMARK 800                                                                      \\nREMARK 800 SITE_IDENTIFIER: AC3                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NDG A 132                 \\nDBREF  1LMP A    1   129  UNP    P11941   LYC2_ONCMY      16    144             \\nSEQADV 1LMP ASP A   86  UNP  P11941    ALA   101 CONFLICT                       \\nSEQRES   1 A  129  LYS VAL TYR ASP ARG CYS GLU LEU ALA ARG ALA LEU LYS          \\nSEQRES   2 A  129  ALA SER GLY MET ASP GLY TYR ALA GLY ASN SER LEU PRO          \\nSEQRES   3 A  129  ASN TRP VAL CYS LEU SER LYS TRP GLU SER SER TYR ASN          \\nSEQRES   4 A  129  THR GLN ALA THR ASN ARG ASN THR ASP GLY SER THR ASP          \\nSEQRES   5 A  129  TYR GLY ILE PHE GLN ILE ASN SER ARG TYR TRP CYS ASP          \\nSEQRES   6 A  129  ASP GLY ARG THR PRO GLY ALA LYS ASN VAL CYS GLY ILE          \\nSEQRES   7 A  129  ARG CYS SER GLN LEU LEU THR ASP ASP LEU THR VAL ALA          \\nSEQRES   8 A  129  ILE ARG CYS ALA LYS ARG VAL VAL LEU ASP PRO ASN GLY          \\nSEQRES   9 A  129  ILE GLY ALA TRP VAL ALA TRP ARG LEU HIS CYS GLN ASN          \\nSEQRES  10 A  129  GLN ASP LEU ARG SER TYR VAL ALA GLY CYS GLY VAL              \\nHET    NAG  A 130      14                                                       \\nHET    NAG  A 131      14                                                       \\nHET    NDG  A 132      15                                                       \\nHETNAM     NAG N-ACETYL-D-GLUCOSAMINE                                           \\nHETNAM     NDG 2-(ACETYLAMINO)-2-DEOXY-A-D-GLUCOPYRANOSE                        \\nFORMUL   2  NAG    2(C8 H15 N O6)                                               \\nFORMUL   2  NDG    C8 H15 N O6                                                  \\nFORMUL   3  HOH   *117(H2 O)                                                    \\nHELIX    1   1 ARG A    5  ALA A   14  1                                  10    \\nHELIX    2   2 TYR A   20  GLY A   22  5                                   3    \\nHELIX    3   3 LEU A   25  SER A   36  1                                  12    \\nHELIX    4   4 CYS A   80  LEU A   83  5                                   4    \\nHELIX    5   5 THR A   89  LEU A  100  1                                  12    \\nHELIX    6   6 GLY A  104  ALA A  107  5                                   4    \\nHELIX    7   7 VAL A  109  HIS A  114  1                                   6    \\nHELIX    8   8 ARG A  121  VAL A  124  1                                   4    \\nSHEET    1   A 2 THR A  43  ARG A  45  0                                        \\nSHEET    2   A 2 THR A  51  TYR A  53 -1  N  ASP A  52   O  ASN A  44           \\nSSBOND   1 CYS A    6    CYS A  127                          1555   1555  2.00  \\nSSBOND   2 CYS A   30    CYS A  115                          1555   1555  2.01  \\nSSBOND   3 CYS A   64    CYS A   80                          1555   1555  2.03  \\nSSBOND   4 CYS A   76    CYS A   94                          1555   1555  2.02  \\nLINK         C1  NAG A 130                 O4  NAG A 131     1555   1555  1.39  \\nLINK         C1  NAG A 131                 O4  NDG A 132     1555   1555  1.41  \\nSITE     1 AC1  7 TRP A  63  ASP A 101  ASN A 103  NAG A 131                    \\nSITE     2 AC1  7 HOH A 152  HOH A 242  HOH A 245                               \\nSITE     1 AC2  9 ILE A  58  ASN A  59  TYR A  62  TRP A  63                    \\nSITE     2 AC2  9 ALA A 107  TRP A 108  NAG A 130  NDG A 132                    \\nSITE     3 AC2  9 HOH A 151                                                     \\nSITE     1 AC3 11 GLU A  35  ASN A  46  ASP A  52  GLN A  57                    \\nSITE     2 AC3 11 ASN A  59  TRP A 108  VAL A 109  NAG A 131                    \\nSITE     3 AC3 11 HOH A 149  HOH A 244  HOH A 249                               \\nCRYST1   76.420   76.420   54.290  90.00  90.00 120.00 P 31 2 1      6          \\nORIGX1      1.000000  0.000000  0.000000        0.00000                         \\nORIGX2      0.000000  1.000000  0.000000        0.00000                         \\nORIGX3      0.000000  0.000000  1.000000        0.00000                         \\nSCALE1      0.015110  0.000000  0.000000        0.00000                         \\nSCALE2      0.007555  0.013086  0.000000        0.00000                         \\nSCALE3      0.000000  0.000000  0.018420        0.00000                         \\nATOM      1  N   LYS A   1      40.347  23.372  17.250  1.00 18.46           N  \\nATOM      2  CA  LYS A   1      40.073  23.407  15.807  1.00 15.65           C  \\nATOM      3  C   LYS A   1      40.596  24.629  15.115  1.00 17.93           C  \\nATOM      4  O   LYS A   1      40.458  25.714  15.693  1.00 14.83           O  \\nATOM      5  CB  LYS A   1      38.560  23.401  15.582  1.00 15.31           C  \\nATOM      6  CG  LYS A   1      38.032  23.710  14.177  1.00 19.38           C  \\nATOM      7  CD  LYS A   1      36.559  23.377  14.207  1.00 23.13           C  \\nATOM      8  CE  LYS A   1      35.670  23.601  13.032  1.00 26.45           C  \\nATOM      9  NZ  LYS A   1      36.120  22.779  11.894  1.00 23.20           N  \\nATOM     10  N   VAL A   2      41.125  24.494  13.923  1.00 15.30           N  \\nATOM     11  CA  VAL A   2      41.608  25.678  13.176  1.00 20.02           C  \\nATOM     12  C   VAL A   2      40.514  25.924  12.118  1.00 23.84           C  \\nATOM     13  O   VAL A   2      40.414  25.137  11.181  1.00 24.49           O  \\nATOM     14  CB  VAL A   2      43.013  25.575  12.573  1.00 20.68           C  \\nATOM     15  CG1 VAL A   2      43.281  26.867  11.826  1.00 19.15           C  \\nATOM     16  CG2 VAL A   2      44.049  25.168  13.622  1.00 10.67           C  \\nATOM     17  N   TYR A   3      39.710  26.949  12.315  1.00 23.36           N  \\nATOM     18  CA  TYR A   3      38.638  27.323  11.400  1.00 14.17           C  \\nATOM     19  C   TYR A   3      39.186  27.965  10.134  1.00 16.95           C  \\nATOM     20  O   TYR A   3      40.165  28.702  10.075  1.00 19.73           O  \\nATOM     21  CB  TYR A   3      37.632  28.347  11.995  1.00 12.31           C  \\nATOM     22  CG  TYR A   3      36.652  27.714  12.936  1.00 14.11           C  \\nATOM     23  CD1 TYR A   3      36.982  27.245  14.192  1.00 13.59           C  \\nATOM     24  CD2 TYR A   3      35.318  27.563  12.512  1.00 19.65           C  \\nATOM     25  CE1 TYR A   3      36.048  26.639  15.053  1.00 14.59           C  \\nATOM     26  CE2 TYR A   3      34.351  26.957  13.318  1.00 18.45           C  \\nATOM     27  CZ  TYR A   3      34.741  26.508  14.586  1.00 21.46           C  \\nATOM     28  OH  TYR A   3      33.842  25.916  15.417  1.00 22.23           O  \\nATOM     29  N   ASP A   4      38.472  27.746   9.078  1.00 20.20           N  \\nATOM     30  CA  ASP A   4      38.563  28.275   7.732  1.00 22.68           C  \\nATOM     31  C   ASP A   4      37.913  29.655   7.877  1.00 13.41           C  \\nATOM     32  O   ASP A   4      36.886  29.708   8.609  1.00 14.78           O  \\nATOM     33  CB  ASP A   4      37.881  27.335   6.714  1.00 22.82           C  \\nATOM     34  CG  ASP A   4      37.437  28.107   5.488  1.00 24.29           C  \\nATOM     35  OD1 ASP A   4      38.372  28.271   4.674  1.00 44.94           O  \\nATOM     36  OD2 ASP A   4      36.299  28.575   5.338  1.00 40.03           O  \\nATOM     37  N   ARG A   5      38.371  30.656   7.186  1.00 16.12           N  \\nATOM     38  CA  ARG A   5      37.790  31.993   7.264  1.00 22.57           C  \\nATOM     39  C   ARG A   5      36.286  32.052   7.017  1.00 27.39           C  \\nATOM     40  O   ARG A   5      35.604  32.681   7.857  1.00 18.92           O  \\nATOM     41  CB  ARG A   5      38.476  32.885   6.251  1.00 14.57           C  \\nATOM     42  CG  ARG A   5      37.915  34.299   6.177  1.00 21.83           C  \\nATOM     43  CD  ARG A   5      38.776  35.072   5.208  1.00 20.58           C  \\nATOM     44  NE  ARG A   5      38.632  34.614   3.827  1.00 26.09           N  \\nATOM     45  CZ  ARG A   5      37.680  34.895   2.939  1.00 24.62           C  \\nATOM     46  NH1 ARG A   5      36.677  35.715   3.197  1.00 22.32           N  \\nATOM     47  NH2 ARG A   5      37.762  34.300   1.752  1.00 23.40           N  \\nATOM     48  N   CYS A   6      35.764  31.444   5.964  1.00 22.68           N  \\nATOM     49  CA  CYS A   6      34.313  31.485   5.674  1.00 17.04           C  \\nATOM     50  C   CYS A   6      33.558  30.617   6.652  1.00 14.60           C  \\nATOM     51  O   CYS A   6      32.428  30.993   6.976  1.00 17.85           O  \\nATOM     52  CB  CYS A   6      34.031  31.115   4.209  1.00 20.63           C  \\nATOM     53  SG  CYS A   6      34.518  32.471   3.120  1.00 19.40           S  \\nATOM     54  N   GLU A   7      34.140  29.516   7.066  1.00 14.34           N  \\nATOM     55  CA  GLU A   7      33.509  28.647   8.067  1.00 15.91           C  \\nATOM     56  C   GLU A   7      33.279  29.378   9.374  1.00 13.36           C  \\nATOM     57  O   GLU A   7      32.186  29.245   9.998  1.00 13.77           O  \\nATOM     58  CB  GLU A   7      34.393  27.429   8.264  1.00 17.03           C  \\nATOM     59  CG  GLU A   7      33.909  26.462   9.310  1.00 14.95           C  \\nATOM     60  CD  GLU A   7      34.938  25.403   9.582  1.00 27.28           C  \\nATOM     61  OE1 GLU A   7      36.114  25.543   9.367  1.00 21.35           O  \\nATOM     62  OE2 GLU A   7      34.447  24.376  10.043  1.00 23.54           O  \\nATOM     63  N   LEU A   8      34.309  30.157   9.740  1.00 11.86           N  \\nATOM     64  CA  LEU A   8      34.180  31.000  10.946  1.00 11.28           C  \\nATOM     65  C   LEU A   8      33.104  32.053  10.689  1.00 12.97           C  \\nATOM     66  O   LEU A   8      32.245  32.277  11.530  1.00 16.68           O  \\nATOM     67  CB  LEU A   8      35.499  31.652  11.332  1.00 13.19           C  \\nATOM     68  CG  LEU A   8      35.466  32.531  12.586  1.00 19.14           C  \\nATOM     69  CD1 LEU A   8      35.149  31.692  13.809  1.00 17.13           C  \\nATOM     70  CD2 LEU A   8      36.834  33.255  12.661  1.00 15.84           C  \\nATOM     71  N   ALA A   9      33.162  32.719   9.530  1.00 14.21           N  \\nATOM     72  CA  ALA A   9      32.170  33.765   9.183  1.00 15.32           C  \\nATOM     73  C   ALA A   9      30.762  33.199   9.309  1.00 20.76           C  \\nATOM     74  O   ALA A   9      29.881  33.864   9.910  1.00 20.35           O  \\nATOM     75  CB  ALA A   9      32.493  34.365   7.812  1.00 12.21           C  \\nATOM     76  N   ARG A  10      30.481  32.006   8.808  1.00 13.12           N  \\nATOM     77  CA  ARG A  10      29.153  31.416   8.949  1.00  8.69           C  \\nATOM     78  C   ARG A  10      28.763  31.138  10.381  1.00 14.66           C  \\nATOM     79  O   ARG A  10      27.599  31.407  10.743  1.00 16.18           O  \\nATOM     80  CB  ARG A  10      29.136  30.134   8.077  1.00 11.95           C  \\nATOM     81  CG  ARG A  10      29.355  30.655   6.636  1.00 23.45           C  \\nATOM     82  CD  ARG A  10      28.976  29.728   5.541  1.00 44.55           C  \\nATOM     83  NE  ARG A  10      29.278  28.340   5.882  1.00 38.82           N  \\nATOM     84  CZ  ARG A  10      30.456  27.778   5.573  1.00 57.87           C  \\nATOM     85  NH1 ARG A  10      31.203  28.272   4.585  1.00 24.69           N  \\nATOM     86  NH2 ARG A  10      30.906  26.699   6.234  1.00 35.62           N  \\nATOM     87  N   ALA A  11      29.625  30.549  11.195  1.00 20.04           N  \\nATOM     88  CA  ALA A  11      29.349  30.250  12.599  1.00 15.30           C  \\nATOM     89  C   ALA A  11      29.102  31.554  13.370  1.00 20.91           C  \\nATOM     90  O   ALA A  11      28.197  31.569  14.233  1.00 16.15           O  \\nATOM     91  CB  ALA A  11      30.477  29.420  13.211  1.00 11.27           C  \\nATOM     92  N   LEU A  12      29.803  32.645  13.105  1.00 14.33           N  \\nATOM     93  CA  LEU A  12      29.576  33.923  13.793  1.00 17.22           C  \\nATOM     94  C   LEU A  12      28.223  34.539  13.409  1.00 12.82           C  \\nATOM     95  O   LEU A  12      27.460  35.053  14.245  1.00 17.90           O  \\nATOM     96  CB  LEU A  12      30.795  34.867  13.521  1.00  9.99           C  \\nATOM     97  CG  LEU A  12      32.162  34.437  14.075  1.00 19.97           C  \\nATOM     98  CD1 LEU A  12      33.254  35.426  13.707  1.00 19.86           C  \\nATOM     99  CD2 LEU A  12      31.992  34.260  15.594  1.00 16.73           C  \\nATOM    100  N   LYS A  13      27.986  34.515  12.104  1.00 13.83           N  \\nATOM    101  CA  LYS A  13      26.714  35.051  11.569  1.00 16.29           C  \\nATOM    102  C   LYS A  13      25.539  34.276  12.189  1.00 22.44           C  \\nATOM    103  O   LYS A  13      24.552  34.865  12.661  1.00 16.93           O  \\nATOM    104  CB  LYS A  13      26.691  35.014  10.060  1.00 23.15           C  \\nATOM    105  CG  LYS A  13      25.395  35.325   9.332  1.00 22.03           C  \\nATOM    106  CD  LYS A  13      24.829  36.685   9.661  1.00 36.34           C  \\nATOM    107  CE  LYS A  13      24.096  37.439   8.572  1.00 34.01           C  \\nATOM    108  NZ  LYS A  13      24.575  37.038   7.221  1.00 65.12           N  \\nATOM    109  N   ALA A  14      25.589  32.966  12.237  1.00 18.73           N  \\nATOM    110  CA  ALA A  14      24.597  32.046  12.784  1.00 23.65           C  \\nATOM    111  C   ALA A  14      24.386  32.312  14.258  1.00 17.69           C  \\nATOM    112  O   ALA A  14      23.274  32.069  14.748  1.00 23.46           O  \\nATOM    113  CB  ALA A  14      24.985  30.567  12.620  1.00 16.71           C  \\nATOM    114  N   SER A  15      25.385  32.787  14.978  1.00 18.66           N  \\nATOM    115  CA  SER A  15      25.349  33.048  16.428  1.00 19.35           C  \\nATOM    116  C   SER A  15      24.997  34.465  16.862  1.00 17.79           C  \\nATOM    117  O   SER A  15      25.132  34.714  18.068  1.00 25.00           O  \\nATOM    118  CB  SER A  15      26.716  32.737  17.060  1.00 24.47           C  \\nATOM    119  OG  SER A  15      26.830  31.324  17.030  1.00 37.07           O  \\nATOM    120  N   GLY A  16      24.613  35.294  15.937  1.00 19.45           N  \\nATOM    121  CA  GLY A  16      24.171  36.645  16.139  1.00 16.50           C  \\nATOM    122  C   GLY A  16      25.245  37.689  16.334  1.00 21.68           C  \\nATOM    123  O   GLY A  16      24.886  38.768  16.869  1.00 20.53           O  \\nATOM    124  N   MET A  17      26.450  37.345  15.882  1.00 21.90           N  \\nATOM    125  CA  MET A  17      27.580  38.317  16.009  1.00 13.23           C  \\nATOM    126  C   MET A  17      27.510  39.430  14.969  1.00 19.76           C  \\nATOM    127  O   MET A  17      28.146  40.472  15.200  1.00 21.08           O  \\nATOM    128  CB  MET A  17      28.972  37.683  15.921  1.00 10.50           C  \\nATOM    129  CG  MET A  17      29.098  36.642  17.044  1.00 17.31           C  \\nATOM    130  SD  MET A  17      29.255  37.555  18.582  1.00 30.13           S  \\nATOM    131  CE  MET A  17      31.007  37.771  18.782  1.00 29.67           C  \\nATOM    132  N   ASP A  18      26.786  39.296  13.862  1.00 22.04           N  \\nATOM    133  CA  ASP A  18      26.760  40.394  12.862  1.00 16.68           C  \\nATOM    134  C   ASP A  18      25.941  41.570  13.408  1.00 29.72           C  \\nATOM    135  O   ASP A  18      24.712  41.514  13.401  1.00 25.38           O  \\nATOM    136  CB  ASP A  18      26.312  39.826  11.519  1.00 18.74           C  \\nATOM    137  CG  ASP A  18      26.467  40.887  10.442  1.00 34.76           C  \\nATOM    138  OD1 ASP A  18      27.194  41.890  10.546  1.00 22.73           O  \\nATOM    139  OD2 ASP A  18      25.792  40.715   9.412  1.00 31.88           O  \\nATOM    140  N   GLY A  19      26.590  42.624  13.893  1.00 23.44           N  \\nATOM    141  CA  GLY A  19      25.904  43.794  14.434  1.00 20.18           C  \\nATOM    142  C   GLY A  19      25.820  43.776  15.950  1.00 19.60           C  \\nATOM    143  O   GLY A  19      25.195  44.714  16.480  1.00 26.69           O  \\nATOM    144  N   TYR A  20      26.417  42.782  16.613  1.00 16.96           N  \\nATOM    145  CA  TYR A  20      26.321  42.705  18.081  1.00 17.33           C  \\nATOM    146  C   TYR A  20      26.986  43.947  18.676  1.00 18.43           C  \\nATOM    147  O   TYR A  20      28.163  44.178  18.374  1.00 18.22           O  \\nATOM    148  CB  TYR A  20      26.917  41.397  18.650  1.00 12.58           C  \\nATOM    149  CG  TYR A  20      26.408  41.254  20.086  1.00 13.24           C  \\nATOM    150  CD1 TYR A  20      25.175  40.690  20.346  1.00 17.66           C  \\nATOM    151  CD2 TYR A  20      27.166  41.730  21.170  1.00 16.33           C  \\nATOM    152  CE1 TYR A  20      24.699  40.597  21.650  1.00 20.69           C  \\nATOM    153  CE2 TYR A  20      26.689  41.649  22.478  1.00 20.26           C  \\nATOM    154  CZ  TYR A  20      25.438  41.069  22.717  1.00 21.29           C  \\nATOM    155  OH  TYR A  20      24.950  40.954  23.982  1.00 27.09           O  \\nATOM    156  N   ALA A  21      26.261  44.702  19.474  1.00 21.02           N  \\nATOM    157  CA  ALA A  21      26.686  45.950  20.117  1.00 14.59           C  \\nATOM    158  C   ALA A  21      27.240  46.930  19.061  1.00 26.05           C  \\nATOM    159  O   ALA A  21      28.153  47.748  19.282  1.00 24.30           O  \\nATOM    160  CB  ALA A  21      27.671  45.637  21.231  1.00 20.86           C  \\nATOM    161  N   GLY A  22      26.662  46.842  17.862  1.00 19.35           N  \\nATOM    162  CA  GLY A  22      27.020  47.645  16.696  1.00 16.32           C  \\nATOM    163  C   GLY A  22      28.259  47.255  15.918  1.00 29.12           C  \\nATOM    164  O   GLY A  22      28.809  48.084  15.157  1.00 23.30           O  \\nATOM    165  N   ASN A  23      28.805  46.071  16.049  1.00 19.67           N  \\nATOM    166  CA  ASN A  23      30.014  45.558  15.400  1.00 19.85           C  \\nATOM    167  C   ASN A  23      29.665  44.587  14.284  1.00 18.50           C  \\nATOM    168  O   ASN A  23      29.251  43.444  14.598  1.00 20.81           O  \\nATOM    169  CB  ASN A  23      30.919  44.867  16.436  1.00 18.98           C  \\nATOM    170  CG  ASN A  23      31.326  45.880  17.500  1.00 23.62           C  \\nATOM    171  OD1 ASN A  23      30.956  45.831  18.674  1.00 24.10           O  \\nATOM    172  ND2 ASN A  23      32.050  46.845  17.011  1.00 18.56           N  \\nATOM    173  N   SER A  24      29.790  45.013  13.061  1.00 19.76           N  \\nATOM    174  CA  SER A  24      29.472  44.173  11.893  1.00 22.86           C  \\nATOM    175  C   SER A  24      30.412  42.971  11.865  1.00 17.74           C  \\nATOM    176  O   SER A  24      31.519  43.050  12.384  1.00 16.59           O  \\nATOM    177  CB  SER A  24      29.529  44.986  10.611  1.00 22.63           C  \\nATOM    178  OG  SER A  24      30.868  45.404  10.339  1.00 23.48           O  \\nATOM    179  N   LEU A  25      29.958  41.916  11.207  1.00 15.58           N  \\nATOM    180  CA  LEU A  25      30.677  40.656  11.075  1.00 15.40           C  \\nATOM    181  C   LEU A  25      32.137  40.746  10.685  1.00 15.36           C  \\nATOM    182  O   LEU A  25      32.948  40.026  11.316  1.00 15.67           O  \\nATOM    183  CB  LEU A  25      29.835  39.766  10.074  1.00 14.88           C  \\nATOM    184  CG  LEU A  25      30.298  38.309   9.963  1.00 18.70           C  \\nATOM    185  CD1 LEU A  25      30.115  37.578  11.292  1.00 15.67           C  \\nATOM    186  CD2 LEU A  25      29.516  37.603   8.847  1.00 17.13           C  \\nATOM    187  N   PRO A  26      32.489  41.532   9.691  1.00 21.37           N  \\nATOM    188  CA  PRO A  26      33.891  41.644   9.273  1.00 18.87           C  \\nATOM    189  C   PRO A  26      34.825  42.072  10.421  1.00 20.05           C  \\nATOM    190  O   PRO A  26      36.000  41.701  10.366  1.00 14.84           O  \\nATOM    191  CB  PRO A  26      33.918  42.587   8.067  1.00 22.73           C  \\nATOM    192  CG  PRO A  26      32.491  42.624   7.630  1.00 18.42           C  \\nATOM    193  CD  PRO A  26      31.637  42.406   8.871  1.00 16.61           C  \\nATOM    194  N   ASN A  27      34.361  42.789  11.425  1.00 17.22           N  \\nATOM    195  CA  ASN A  27      35.113  43.225  12.608  1.00 13.27           C  \\nATOM    196  C   ASN A  27      35.612  42.017  13.377  1.00 10.15           C  \\nATOM    197  O   ASN A  27      36.783  41.915  13.704  1.00 15.05           O  \\nATOM    198  CB  ASN A  27      34.267  44.154  13.516  1.00 13.80           C  \\nATOM    199  CG  ASN A  27      34.292  45.508  12.799  1.00 24.88           C  \\nATOM    200  OD1 ASN A  27      35.341  46.185  12.812  1.00 20.38           O  \\nATOM    201  ND2 ASN A  27      33.233  45.890  12.133  1.00 23.80           N  \\nATOM    202  N   TRP A  28      34.645  41.134  13.583  1.00 15.92           N  \\nATOM    203  CA  TRP A  28      34.826  39.856  14.319  1.00 13.94           C  \\nATOM    204  C   TRP A  28      35.707  38.864  13.572  1.00 15.40           C  \\nATOM    205  O   TRP A  28      36.507  38.214  14.259  1.00 14.86           O  \\nATOM    206  CB  TRP A  28      33.508  39.191  14.642  1.00 13.16           C  \\nATOM    207  CG  TRP A  28      32.568  40.049  15.428  1.00 16.33           C  \\nATOM    208  CD1 TRP A  28      31.427  40.678  15.018  1.00 14.77           C  \\nATOM    209  CD2 TRP A  28      32.716  40.356  16.822  1.00 17.90           C  \\nATOM    210  NE1 TRP A  28      30.871  41.370  16.063  1.00 19.67           N  \\nATOM    211  CE2 TRP A  28      31.627  41.183  17.179  1.00 23.79           C  \\nATOM    212  CE3 TRP A  28      33.694  40.011  17.775  1.00 16.35           C  \\nATOM    213  CZ2 TRP A  28      31.470  41.668  18.474  1.00 29.57           C  \\nATOM    214  CZ3 TRP A  28      33.534  40.490  19.078  1.00 18.00           C  \\nATOM    215  CH2 TRP A  28      32.440  41.298  19.402  1.00 15.42           C  \\nATOM    216  N   VAL A  29      35.602  38.711  12.277  1.00 18.40           N  \\nATOM    217  CA  VAL A  29      36.473  37.823  11.484  1.00 13.46           C  \\nATOM    218  C   VAL A  29      37.892  38.414  11.474  1.00 14.97           C  \\nATOM    219  O   VAL A  29      38.875  37.687  11.679  1.00 15.39           O  \\nATOM    220  CB  VAL A  29      35.959  37.565  10.059  1.00 13.48           C  \\nATOM    221  CG1 VAL A  29      36.933  36.695   9.265  1.00 12.84           C  \\nATOM    222  CG2 VAL A  29      34.572  36.988  10.064  1.00 14.46           C  \\nATOM    223  N   CYS A  30      38.046  39.718  11.277  1.00 16.14           N  \\nATOM    224  CA  CYS A  30      39.377  40.376  11.292  1.00 13.89           C  \\nATOM    225  C   CYS A  30      40.085  40.184  12.622  1.00 15.23           C  \\nATOM    226  O   CYS A  30      41.288  39.832  12.651  1.00 16.41           O  \\nATOM    227  CB  CYS A  30      39.242  41.866  10.918  1.00 13.86           C  \\nATOM    228  SG  CYS A  30      40.795  42.784  10.937  1.00 20.39           S  \\nATOM    229  N   LEU A  31      39.402  40.417  13.749  1.00 12.96           N  \\nATOM    230  CA  LEU A  31      40.128  40.282  15.041  1.00 21.55           C  \\nATOM    231  C   LEU A  31      40.475  38.819  15.310  1.00 13.97           C  \\nATOM    232  O   LEU A  31      41.505  38.618  15.958  1.00 17.80           O  \\nATOM    233  CB  LEU A  31      39.304  40.947  16.124  1.00 21.46           C  \\nATOM    234  CG  LEU A  31      38.278  40.339  17.013  1.00 22.89           C  \\nATOM    235  CD1 LEU A  31      38.722  39.323  18.065  1.00 18.01           C  \\nATOM    236  CD2 LEU A  31      37.651  41.536  17.793  1.00 21.95           C  \\nATOM    237  N   SER A  32      39.636  37.868  14.912  1.00 15.12           N  \\nATOM    238  CA  SER A  32      39.915  36.429  15.124  1.00 17.16           C  \\nATOM    239  C   SER A  32      41.193  36.016  14.356  1.00 17.69           C  \\nATOM    240  O   SER A  32      42.112  35.329  14.817  1.00 17.21           O  \\nATOM    241  CB  SER A  32      38.757  35.529  14.716  1.00 12.42           C  \\nATOM    242  OG  SER A  32      37.600  35.769  15.445  1.00 16.87           O  \\nATOM    243  N   LYS A  33      41.291  36.470  13.102  1.00 14.38           N  \\nATOM    244  CA  LYS A  33      42.453  36.248  12.248  1.00 14.46           C  \\nATOM    245  C   LYS A  33      43.766  36.775  12.869  1.00 20.46           C  \\nATOM    246  O   LYS A  33      44.753  36.017  12.934  1.00 17.19           O  \\nATOM    247  CB  LYS A  33      42.260  36.887  10.867  1.00 18.49           C  \\nATOM    248  CG  LYS A  33      43.344  36.335   9.919  1.00 24.81           C  \\nATOM    249  CD  LYS A  33      44.289  37.439   9.529  1.00 33.05           C  \\nATOM    250  CE  LYS A  33      45.099  36.975   8.318  1.00 57.02           C  \\nATOM    251  NZ  LYS A  33      46.537  37.178   8.664  1.00 45.77           N  \\nATOM    252  N   TRP A  34      43.782  38.025  13.337  1.00 14.53           N  \\nATOM    253  CA  TRP A  34      44.982  38.645  13.905  1.00 13.49           C  \\nATOM    254  C   TRP A  34      45.275  38.153  15.305  1.00 22.95           C  \\nATOM    255  O   TRP A  34      46.476  38.084  15.608  1.00 30.70           O  \\nATOM    256  CB  TRP A  34      44.866  40.177  13.897  1.00 16.57           C  \\nATOM    257  CG  TRP A  34      44.824  40.583  12.464  1.00 13.87           C  \\nATOM    258  CD1 TRP A  34      43.807  40.959  11.633  1.00 17.30           C  \\nATOM    259  CD2 TRP A  34      46.006  40.573  11.652  1.00 19.89           C  \\nATOM    260  NE1 TRP A  34      44.279  41.210  10.370  1.00 23.40           N  \\nATOM    261  CE2 TRP A  34      45.618  40.988  10.350  1.00 18.07           C  \\nATOM    262  CE3 TRP A  34      47.355  40.296  11.938  1.00 26.52           C  \\nATOM    263  CZ2 TRP A  34      46.583  41.111   9.356  1.00 37.31           C  \\nATOM    264  CZ3 TRP A  34      48.282  40.404  10.924  1.00 40.23           C  \\nATOM    265  CH2 TRP A  34      47.903  40.805   9.651  1.00 34.72           C  \\nATOM    266  N   GLU A  35      44.254  37.863  16.083  1.00 17.64           N  \\nATOM    267  CA  GLU A  35      44.448  37.386  17.454  1.00 18.73           C  \\nATOM    268  C   GLU A  35      44.900  35.935  17.527  1.00 18.86           C  \\nATOM    269  O   GLU A  35      45.832  35.632  18.288  1.00 17.23           O  \\nATOM    270  CB  GLU A  35      43.166  37.507  18.299  1.00 13.16           C  \\nATOM    271  CG  GLU A  35      42.684  38.876  18.761  1.00 15.09           C  \\nATOM    272  CD  GLU A  35      43.588  39.517  19.796  1.00 22.23           C  \\nATOM    273  OE1 GLU A  35      44.603  39.018  20.255  1.00 20.04           O  \\nATOM    274  OE2 GLU A  35      43.200  40.623  20.176  1.00 20.77           O  \\nATOM    275  N   SER A  36      44.294  35.013  16.812  1.00 17.58           N  \\nATOM    276  CA  SER A  36      44.642  33.607  16.930  1.00 17.66           C  \\nATOM    277  C   SER A  36      44.899  32.835  15.659  1.00 19.50           C  \\nATOM    278  O   SER A  36      45.165  31.628  15.792  1.00 18.49           O  \\nATOM    279  CB  SER A  36      43.423  32.949  17.624  1.00 15.60           C  \\nATOM    280  OG  SER A  36      42.374  33.081  16.675  1.00 13.21           O  \\nATOM    281  N   SER A  37      44.785  33.468  14.515  1.00 16.77           N  \\nATOM    282  CA  SER A  37      44.898  32.801  13.212  1.00 15.41           C  \\nATOM    283  C   SER A  37      43.795  31.755  13.111  1.00 20.35           C  \\nATOM    284  O   SER A  37      44.009  30.659  12.572  1.00 18.87           O  \\nATOM    285  CB  SER A  37      46.230  32.113  12.958  1.00 32.23           C  \\nATOM    286  OG  SER A  37      47.257  32.995  13.284  1.00 29.24           O  \\nATOM    287  N   TYR A  38      42.663  32.076  13.724  1.00 17.05           N  \\nATOM    288  CA  TYR A  38      41.504  31.191  13.727  1.00 18.35           C  \\nATOM    289  C   TYR A  38      41.620  29.864  14.475  1.00 18.07           C  \\nATOM    290  O   TYR A  38      40.879  28.907  14.193  1.00 12.36           O  \\nATOM    291  CB  TYR A  38      41.182  30.857  12.263  1.00 16.26           C  \\nATOM    292  CG  TYR A  38      40.986  32.038  11.360  1.00 15.65           C  \\nATOM    293  CD1 TYR A  38      40.052  33.024  11.624  1.00 23.28           C  \\nATOM    294  CD2 TYR A  38      41.761  32.157  10.202  1.00 19.32           C  \\nATOM    295  CE1 TYR A  38      39.872  34.117  10.769  1.00 14.60           C  \\nATOM    296  CE2 TYR A  38      41.556  33.211   9.318  1.00 24.47           C  \\nATOM    297  CZ  TYR A  38      40.616  34.187   9.599  1.00 22.07           C  \\nATOM    298  OH  TYR A  38      40.411  35.217   8.725  1.00 24.28           O  \\nATOM    299  N   ASN A  39      42.532  29.801  15.413  1.00 15.97           N  \\nATOM    300  CA  ASN A  39      42.740  28.550  16.162  1.00 13.21           C  \\nATOM    301  C   ASN A  39      42.063  28.674  17.523  1.00 14.83           C  \\nATOM    302  O   ASN A  39      42.483  29.550  18.309  1.00 14.96           O  \\nATOM    303  CB  ASN A  39      44.261  28.256  16.158  1.00 15.35           C  \\nATOM    304  CG  ASN A  39      44.628  26.954  16.890  1.00 12.41           C  \\nATOM    305  OD1 ASN A  39      43.892  26.058  17.247  1.00 18.02           O  \\nATOM    306  ND2 ASN A  39      45.929  26.806  17.158  1.00 15.84           N  \\nATOM    307  N   THR A  40      41.074  27.844  17.810  1.00 14.00           N  \\nATOM    308  CA  THR A  40      40.384  27.810  19.108  1.00 18.17           C  \\nATOM    309  C   THR A  40      41.318  27.410  20.244  1.00 15.60           C  \\nATOM    310  O   THR A  40      41.082  27.776  21.398  1.00 15.54           O  \\nATOM    311  CB  THR A  40      39.113  26.863  19.084  1.00 17.38           C  \\nATOM    312  OG1 THR A  40      39.595  25.495  18.994  1.00 13.72           O  \\nATOM    313  CG2 THR A  40      38.161  27.266  17.955  1.00 12.13           C  \\nATOM    314  N   GLN A  41      42.425  26.721  19.985  1.00 17.45           N  \\nATOM    315  CA  GLN A  41      43.386  26.265  20.968  1.00 13.17           C  \\nATOM    316  C   GLN A  41      44.540  27.213  21.234  1.00 22.87           C  \\nATOM    317  O   GLN A  41      45.482  26.823  21.961  1.00 24.42           O  \\nATOM    318  CB  GLN A  41      44.010  24.905  20.541  1.00 12.53           C  \\nATOM    319  CG  GLN A  41      42.898  23.865  20.441  1.00 17.23           C  \\nATOM    320  CD  GLN A  41      43.367  22.421  20.495  1.00 13.61           C  \\nATOM    321  OE1 GLN A  41      43.458  21.752  19.461  1.00 22.26           O  \\nATOM    322  NE2 GLN A  41      43.696  22.001  21.710  1.00 16.79           N  \\nATOM    323  N   ALA A  42      44.487  28.381  20.640  1.00 14.34           N  \\nATOM    324  CA  ALA A  42      45.597  29.312  20.879  1.00 18.27           C  \\nATOM    325  C   ALA A  42      45.657  29.805  22.325  1.00 22.28           C  \\nATOM    326  O   ALA A  42      44.649  30.163  22.947  1.00 15.13           O  \\nATOM    327  CB  ALA A  42      45.490  30.492  19.914  1.00 17.94           C  \\nATOM    328  N   THR A  43      46.872  29.867  22.870  1.00 17.78           N  \\nATOM    329  CA  THR A  43      47.132  30.407  24.214  1.00 26.75           C  \\nATOM    330  C   THR A  43      48.398  31.281  24.131  1.00 22.42           C  \\nATOM    331  O   THR A  43      49.319  31.066  23.358  1.00 23.75           O  \\nATOM    332  CB  THR A  43      47.229  29.363  25.388  1.00 25.09           C  \\nATOM    333  OG1 THR A  43      48.343  28.493  25.035  1.00 21.09           O  \\nATOM    334  CG2 THR A  43      45.931  28.597  25.626  1.00 11.74           C  \\nATOM    335  N   ASN A  44      48.417  32.336  24.899  1.00 15.73           N  \\nATOM    336  CA  ASN A  44      49.524  33.298  24.959  1.00 17.41           C  \\nATOM    337  C   ASN A  44      49.635  33.837  26.382  1.00 22.79           C  \\nATOM    338  O   ASN A  44      48.708  34.479  26.902  1.00 19.97           O  \\nATOM    339  CB  ASN A  44      49.320  34.372  23.887  1.00 23.51           C  \\nATOM    340  CG  ASN A  44      50.396  35.452  23.938  1.00 47.13           C  \\nATOM    341  OD1 ASN A  44      51.524  35.245  23.437  1.00 53.30           O  \\nATOM    342  ND2 ASN A  44      50.077  36.597  24.559  1.00 46.80           N  \\nATOM    343  N   ARG A  45      50.748  33.557  27.024  1.00 18.97           N  \\nATOM    344  CA  ARG A  45      50.983  34.022  28.397  1.00 15.52           C  \\nATOM    345  C   ARG A  45      51.507  35.442  28.411  1.00 26.35           C  \\nATOM    346  O   ARG A  45      52.357  35.790  27.568  1.00 28.65           O  \\nATOM    347  CB  ARG A  45      51.958  33.079  29.109  1.00 24.05           C  \\nATOM    348  CG  ARG A  45      52.139  33.583  30.535  1.00 43.45           C  \\nATOM    349  CD  ARG A  45      51.436  32.875  31.615  1.00 34.96           C  \\nATOM    350  NE  ARG A  45      52.263  31.752  32.079  1.00 73.13           N  \\nATOM    351  CZ  ARG A  45      52.319  30.619  31.355  1.00 79.93           C  \\nATOM    352  NH1 ARG A  45      51.394  30.364  30.416  1.00 58.80           N  \\nATOM    353  NH2 ARG A  45      53.327  29.787  31.613  1.00 53.52           N  \\nATOM    354  N   ASN A  46      51.039  36.257  29.335  1.00 28.72           N  \\nATOM    355  CA  ASN A  46      51.522  37.653  29.431  1.00 31.17           C  \\nATOM    356  C   ASN A  46      52.478  37.797  30.621  1.00 34.85           C  \\nATOM    357  O   ASN A  46      52.546  36.929  31.508  1.00 30.02           O  \\nATOM    358  CB  ASN A  46      50.344  38.607  29.500  1.00 20.09           C  \\nATOM    359  CG  ASN A  46      49.591  38.619  28.175  1.00 23.38           C  \\nATOM    360  OD1 ASN A  46      48.408  38.263  28.170  1.00 36.10           O  \\nATOM    361  ND2 ASN A  46      50.177  38.963  27.043  1.00 33.99           N  \\nATOM    362  N   THR A  47      53.164  38.919  30.590  1.00 36.86           N  \\nATOM    363  CA  THR A  47      54.153  39.356  31.579  1.00 37.27           C  \\nATOM    364  C   THR A  47      53.601  39.489  32.991  1.00 33.48           C  \\nATOM    365  O   THR A  47      54.243  39.229  34.004  1.00 46.09           O  \\nATOM    366  CB  THR A  47      54.804  40.756  31.230  1.00 52.01           C  \\nATOM    367  OG1 THR A  47      53.721  41.711  31.514  1.00 69.50           O  \\nATOM    368  CG2 THR A  47      55.362  40.834  29.816  1.00 39.44           C  \\nATOM    369  N   ASP A  48      52.360  39.919  33.004  1.00 29.16           N  \\nATOM    370  CA  ASP A  48      51.535  40.122  34.209  1.00 29.86           C  \\nATOM    371  C   ASP A  48      50.944  38.851  34.842  1.00 32.96           C  \\nATOM    372  O   ASP A  48      50.176  38.986  35.837  1.00 34.15           O  \\nATOM    373  CB  ASP A  48      50.436  41.146  33.837  1.00 26.05           C  \\nATOM    374  CG  ASP A  48      49.319  40.537  33.009  1.00 47.30           C  \\nATOM    375  OD1 ASP A  48      49.355  39.402  32.489  1.00 32.41           O  \\nATOM    376  OD2 ASP A  48      48.322  41.290  32.925  1.00 58.64           O  \\nATOM    377  N   GLY A  49      51.226  37.670  34.308  1.00 22.78           N  \\nATOM    378  CA  GLY A  49      50.720  36.424  34.892  1.00 30.15           C  \\nATOM    379  C   GLY A  49      49.424  35.938  34.256  1.00 20.20           C  \\nATOM    380  O   GLY A  49      49.012  34.791  34.547  1.00 25.53           O  \\nATOM    381  N   SER A  50      48.861  36.800  33.431  1.00 21.62           N  \\nATOM    382  CA  SER A  50      47.602  36.385  32.763  1.00 21.86           C  \\nATOM    383  C   SER A  50      47.954  35.684  31.436  1.00 19.00           C  \\nATOM    384  O   SER A  50      49.070  35.702  30.931  1.00 19.44           O  \\nATOM    385  CB  SER A  50      46.643  37.538  32.551  1.00 14.68           C  \\nATOM    386  OG  SER A  50      47.225  38.400  31.584  1.00 18.76           O  \\nATOM    387  N   THR A  51      46.914  35.020  30.926  1.00 19.33           N  \\nATOM    388  CA  THR A  51      46.971  34.274  29.669  1.00 16.55           C  \\nATOM    389  C   THR A  51      45.771  34.623  28.807  1.00 16.93           C  \\nATOM    390  O   THR A  51      44.697  34.813  29.414  1.00 15.79           O  \\nATOM    391  CB  THR A  51      47.110  32.719  29.952  1.00 18.65           C  \\nATOM    392  OG1 THR A  51      48.310  32.615  30.799  1.00 22.61           O  \\nATOM    393  CG2 THR A  51      47.191  31.792  28.724  1.00 11.90           C  \\nATOM    394  N   ASP A  52      45.988  34.678  27.502  1.00 17.35           N  \\nATOM    395  CA  ASP A  52      44.945  34.918  26.490  1.00 20.57           C  \\nATOM    396  C   ASP A  52      44.541  33.540  25.940  1.00 17.31           C  \\nATOM    397  O   ASP A  52      45.384  32.712  25.653  1.00 18.51           O  \\nATOM    398  CB  ASP A  52      45.354  35.888  25.391  1.00 17.67           C  \\nATOM    399  CG  ASP A  52      45.777  37.237  25.989  1.00 25.71           C  \\nATOM    400  OD1 ASP A  52      45.196  37.738  26.966  1.00 21.10           O  \\nATOM    401  OD2 ASP A  52      46.720  37.793  25.423  1.00 25.65           O  \\nATOM    402  N   TYR A  53      43.221  33.325  25.829  1.00 12.97           N  \\nATOM    403  CA  TYR A  53      42.615  32.057  25.428  1.00 16.88           C  \\nATOM    404  C   TYR A  53      41.650  32.046  24.260  1.00 15.87           C  \\nATOM    405  O   TYR A  53      40.691  32.832  24.229  1.00 15.49           O  \\nATOM    406  CB  TYR A  53      41.788  31.462  26.620  1.00 13.26           C  \\nATOM    407  CG  TYR A  53      42.659  31.119  27.812  1.00 17.67           C  \\nATOM    408  CD1 TYR A  53      42.975  32.051  28.803  1.00 13.92           C  \\nATOM    409  CD2 TYR A  53      43.176  29.822  27.926  1.00 24.83           C  \\nATOM    410  CE1 TYR A  53      43.766  31.706  29.893  1.00 10.61           C  \\nATOM    411  CE2 TYR A  53      43.968  29.449  29.013  1.00 21.03           C  \\nATOM    412  CZ  TYR A  53      44.277  30.423  29.990  1.00 21.61           C  \\nATOM    413  OH  TYR A  53      45.084  30.097  31.042  1.00 17.14           O  \\nATOM    414  N   GLY A  54      41.899  31.077  23.380  1.00 11.91           N  \\nATOM    415  CA  GLY A  54      41.025  30.803  22.269  1.00 12.37           C  \\nATOM    416  C   GLY A  54      41.092  31.669  21.049  1.00 18.38           C  \\nATOM    417  O   GLY A  54      42.036  32.428  20.856  1.00 12.89           O  \\nATOM    418  N   ILE A  55      40.067  31.483  20.228  1.00 17.64           N  \\nATOM    419  CA  ILE A  55      39.973  32.201  18.939  1.00 14.29           C  \\nATOM    420  C   ILE A  55      39.994  33.722  19.101  1.00 21.77           C  \\nATOM    421  O   ILE A  55      40.509  34.406  18.225  1.00 18.01           O  \\nATOM    422  CB  ILE A  55      38.725  31.630  18.132  1.00 13.85           C  \\nATOM    423  CG1 ILE A  55      39.064  31.779  16.634  1.00 14.21           C  \\nATOM    424  CG2 ILE A  55      37.368  32.271  18.514  1.00 10.77           C  \\nATOM    425  CD1 ILE A  55      38.253  30.831  15.682  1.00 15.40           C  \\nATOM    426  N   PHE A  56      39.391  34.258  20.144  1.00 14.78           N  \\nATOM    427  CA  PHE A  56      39.284  35.685  20.475  1.00 18.37           C  \\nATOM    428  C   PHE A  56      40.338  36.136  21.500  1.00 21.80           C  \\nATOM    429  O   PHE A  56      40.342  37.310  21.917  1.00 19.12           O  \\nATOM    430  CB  PHE A  56      37.890  36.066  21.024  1.00 12.10           C  \\nATOM    431  CG  PHE A  56      36.745  35.656  20.148  1.00 22.21           C  \\nATOM    432  CD1 PHE A  56      36.714  36.045  18.795  1.00 24.31           C  \\nATOM    433  CD2 PHE A  56      35.737  34.878  20.687  1.00 15.11           C  \\nATOM    434  CE1 PHE A  56      35.628  35.649  17.987  1.00 22.11           C  \\nATOM    435  CE2 PHE A  56      34.648  34.473  19.891  1.00 18.01           C  \\nATOM    436  CZ  PHE A  56      34.606  34.852  18.558  1.00 15.95           C  \\nATOM    437  N   GLN A  57      41.185  35.198  21.917  1.00 12.00           N  \\nATOM    438  CA  GLN A  57      42.249  35.500  22.872  1.00 18.97           C  \\nATOM    439  C   GLN A  57      41.713  36.303  24.058  1.00 19.57           C  \\nATOM    440  O   GLN A  57      42.237  37.390  24.353  1.00 18.20           O  \\nATOM    441  CB  GLN A  57      43.430  36.212  22.161  1.00 13.60           C  \\nATOM    442  CG  GLN A  57      44.125  35.302  21.156  1.00  9.93           C  \\nATOM    443  CD  GLN A  57      45.008  34.347  21.916  1.00 15.19           C  \\nATOM    444  OE1 GLN A  57      46.023  34.727  22.432  1.00 15.17           O  \\nATOM    445  NE2 GLN A  57      44.558  33.107  22.033  1.00 17.43           N  \\nATOM    446  N   ILE A  58      40.686  35.751  24.700  1.00 13.37           N  \\nATOM    447  CA  ILE A  58      40.144  36.411  25.920  1.00 14.37           C  \\nATOM    448  C   ILE A  58      41.105  36.257  27.096  1.00 14.99           C  \\nATOM    449  O   ILE A  58      41.641  35.190  27.428  1.00 12.78           O  \\nATOM    450  CB  ILE A  58      38.691  35.875  26.119  1.00 19.24           C  \\nATOM    451  CG1 ILE A  58      37.841  36.509  24.972  1.00 22.89           C  \\nATOM    452  CG2 ILE A  58      38.183  36.134  27.563  1.00 13.90           C  \\nATOM    453  CD1 ILE A  58      36.476  35.836  24.753  1.00 23.01           C  \\nATOM    454  N   ASN A  59      41.363  37.350  27.818  1.00 17.25           N  \\nATOM    455  CA  ASN A  59      42.310  37.460  28.933  1.00 17.24           C  \\nATOM    456  C   ASN A  59      41.790  36.983  30.277  1.00 14.54           C  \\nATOM    457  O   ASN A  59      40.668  37.301  30.690  1.00 16.35           O  \\nATOM    458  CB  ASN A  59      42.757  38.929  28.982  1.00 22.14           C  \\nATOM    459  CG  ASN A  59      43.899  39.067  29.987  1.00 25.20           C  \\nATOM    460  OD1 ASN A  59      43.684  39.424  31.168  1.00 23.44           O  \\nATOM    461  ND2 ASN A  59      45.082  38.754  29.464  1.00 16.47           N  \\nATOM    462  N   SER A  60      42.639  36.226  30.992  1.00 15.55           N  \\nATOM    463  CA  SER A  60      42.308  35.610  32.294  1.00 16.24           C  \\nATOM    464  C   SER A  60      42.332  36.537  33.513  1.00 17.55           C  \\nATOM    465  O   SER A  60      41.913  36.094  34.591  1.00 18.30           O  \\nATOM    466  CB  SER A  60      43.243  34.442  32.609  1.00 12.14           C  \\nATOM    467  OG  SER A  60      44.609  34.782  32.675  1.00 15.60           O  \\nATOM    468  N   ARG A  61      42.804  37.766  33.334  1.00 25.85           N  \\nATOM    469  CA  ARG A  61      42.773  38.704  34.457  1.00 25.69           C  \\nATOM    470  C   ARG A  61      41.364  39.194  34.786  1.00 22.93           C  \\nATOM    471  O   ARG A  61      40.991  39.448  35.945  1.00 24.66           O  \\nATOM    472  CB  ARG A  61      43.632  39.927  34.174  1.00 27.65           C  \\nATOM    473  CG  ARG A  61      43.685  40.644  35.544  1.00 31.27           C  \\nATOM    474  CD  ARG A  61      45.128  41.010  35.711  1.00 49.54           C  \\nATOM    475  NE  ARG A  61      45.200  42.466  35.733  1.00 59.79           N  \\nATOM    476  CZ  ARG A  61      44.922  43.171  36.845  1.00 81.11           C  \\nATOM    477  NH1 ARG A  61      43.993  42.792  37.726  1.00 76.32           N  \\nATOM    478  NH2 ARG A  61      45.639  44.284  37.049  1.00 79.91           N  \\nATOM    479  N   TYR A  62      40.551  39.343  33.728  1.00 22.63           N  \\nATOM    480  CA  TYR A  62      39.170  39.797  33.914  1.00 24.66           C  \\nATOM    481  C   TYR A  62      38.033  38.870  33.554  1.00 18.51           C  \\nATOM    482  O   TYR A  62      36.947  38.969  34.188  1.00 19.76           O  \\nATOM    483  CB  TYR A  62      38.874  41.062  33.035  1.00 25.26           C  \\nATOM    484  CG  TYR A  62      39.816  42.174  33.438  1.00 34.67           C  \\nATOM    485  CD1 TYR A  62      39.602  43.023  34.517  1.00 40.78           C  \\nATOM    486  CD2 TYR A  62      40.986  42.306  32.675  1.00 32.42           C  \\nATOM    487  CE1 TYR A  62      40.548  44.005  34.851  1.00 40.18           C  \\nATOM    488  CE2 TYR A  62      41.923  43.288  33.008  1.00 46.53           C  \\nATOM    489  CZ  TYR A  62      41.706  44.146  34.093  1.00 41.63           C  \\nATOM    490  OH  TYR A  62      42.657  45.116  34.369  1.00 72.23           O  \\nATOM    491  N   TRP A  63      38.248  38.046  32.522  1.00 17.37           N  \\nATOM    492  CA  TRP A  63      37.065  37.302  32.025  1.00 14.97           C  \\nATOM    493  C   TRP A  63      36.910  35.852  32.362  1.00 17.83           C  \\nATOM    494  O   TRP A  63      35.720  35.480  32.312  1.00 13.57           O  \\nATOM    495  CB  TRP A  63      37.081  37.498  30.458  1.00 12.63           C  \\nATOM    496  CG  TRP A  63      37.269  38.942  30.049  1.00 18.40           C  \\nATOM    497  CD1 TRP A  63      38.348  39.582  29.515  1.00 14.00           C  \\nATOM    498  CD2 TRP A  63      36.232  39.937  30.189  1.00 13.65           C  \\nATOM    499  NE1 TRP A  63      38.047  40.907  29.322  1.00 14.56           N  \\nATOM    500  CE2 TRP A  63      36.760  41.150  29.724  1.00 14.69           C  \\nATOM    501  CE3 TRP A  63      34.919  39.912  30.687  1.00 21.13           C  \\nATOM    502  CZ2 TRP A  63      36.014  42.331  29.733  1.00 16.09           C  \\nATOM    503  CZ3 TRP A  63      34.187  41.080  30.677  1.00 20.95           C  \\nATOM    504  CH2 TRP A  63      34.714  42.280  30.200  1.00 13.33           C  \\nATOM    505  N   CYS A  64      37.937  35.078  32.614  1.00 17.33           N  \\nATOM    506  CA  CYS A  64      37.707  33.638  32.860  1.00 18.36           C  \\nATOM    507  C   CYS A  64      38.643  33.203  33.975  1.00 15.69           C  \\nATOM    508  O   CYS A  64      39.633  33.915  34.229  1.00 17.52           O  \\nATOM    509  CB  CYS A  64      37.893  32.873  31.548  1.00 12.23           C  \\nATOM    510  SG  CYS A  64      39.569  33.010  30.792  1.00 15.40           S  \\nATOM    511  N   ASP A  65      38.341  32.069  34.579  1.00 13.86           N  \\nATOM    512  CA  ASP A  65      39.238  31.570  35.641  1.00 16.52           C  \\nATOM    513  C   ASP A  65      40.240  30.537  35.161  1.00 14.55           C  \\nATOM    514  O   ASP A  65      39.777  29.498  34.636  1.00 16.81           O  \\nATOM    515  CB  ASP A  65      38.254  31.020  36.660  1.00 19.55           C  \\nATOM    516  CG  ASP A  65      39.056  30.332  37.771  1.00 39.16           C  \\nATOM    517  OD1 ASP A  65      40.143  30.861  38.120  1.00 33.03           O  \\nATOM    518  OD2 ASP A  65      38.561  29.290  38.227  1.00 43.60           O  \\nATOM    519  N   ASP A  66      41.533  30.714  35.237  1.00 14.68           N  \\nATOM    520  CA  ASP A  66      42.490  29.664  34.800  1.00 18.54           C  \\nATOM    521  C   ASP A  66      43.285  29.145  36.030  1.00 21.82           C  \\nATOM    522  O   ASP A  66      44.214  28.353  35.835  1.00 21.01           O  \\nATOM    523  CB  ASP A  66      43.401  30.105  33.688  1.00 14.01           C  \\nATOM    524  CG  ASP A  66      44.449  31.117  34.071  1.00 17.63           C  \\nATOM    525  OD1 ASP A  66      44.498  31.571  35.229  1.00 18.50           O  \\nATOM    526  OD2 ASP A  66      45.282  31.477  33.171  1.00 21.35           O  \\nATOM    527  N   GLY A  67      42.907  29.581  37.205  1.00 19.91           N  \\nATOM    528  CA  GLY A  67      43.476  29.240  38.466  1.00 17.84           C  \\nATOM    529  C   GLY A  67      44.897  29.629  38.766  1.00 21.63           C  \\nATOM    530  O   GLY A  67      45.424  29.194  39.811  1.00 25.31           O  \\nATOM    531  N   ARG A  68      45.535  30.429  37.955  1.00 18.98           N  \\nATOM    532  CA  ARG A  68      46.925  30.855  38.193  1.00 22.39           C  \\nATOM    533  C   ARG A  68      47.192  32.328  37.884  1.00 26.40           C  \\nATOM    534  O   ARG A  68      48.349  32.801  37.731  1.00 29.50           O  \\nATOM    535  CB  ARG A  68      47.869  29.967  37.371  1.00 22.87           C  \\nATOM    536  CG  ARG A  68      47.655  30.073  35.887  1.00 17.07           C  \\nATOM    537  CD  ARG A  68      48.873  29.623  35.179  1.00 20.83           C  \\nATOM    538  NE  ARG A  68      48.897  30.169  33.822  1.00 26.31           N  \\nATOM    539  CZ  ARG A  68      49.537  29.559  32.818  1.00 49.80           C  \\nATOM    540  NH1 ARG A  68      50.222  28.429  33.043  1.00 26.63           N  \\nATOM    541  NH2 ARG A  68      49.558  30.037  31.562  1.00 21.96           N  \\nATOM    542  N   THR A  69      46.054  33.050  37.795  1.00 20.06           N  \\nATOM    543  CA  THR A  69      46.161  34.474  37.509  1.00 22.37           C  \\nATOM    544  C   THR A  69      45.868  35.301  38.775  1.00 18.89           C  \\nATOM    545  O   THR A  69      44.771  35.215  39.315  1.00 29.15           O  \\nATOM    546  CB  THR A  69      45.249  35.044  36.349  1.00 23.00           C  \\nATOM    547  OG1 THR A  69      45.511  34.126  35.269  1.00 15.08           O  \\nATOM    548  CG2 THR A  69      45.528  36.493  35.957  1.00 17.64           C  \\nATOM    549  N   PRO A  70      46.898  36.088  39.096  1.00 38.62           N  \\nATOM    550  CA  PRO A  70      46.831  37.059  40.183  1.00 36.92           C  \\nATOM    551  C   PRO A  70      45.840  38.190  39.888  1.00 21.03           C  \\nATOM    552  O   PRO A  70      45.882  38.862  38.818  1.00 38.15           O  \\nATOM    553  CB  PRO A  70      48.274  37.535  40.368  1.00 57.26           C  \\nATOM    554  CG  PRO A  70      48.975  37.298  39.072  1.00 46.04           C  \\nATOM    555  CD  PRO A  70      48.194  36.179  38.389  1.00 40.03           C  \\nATOM    556  N   GLY A  71      44.909  38.379  40.818  1.00 26.51           N  \\nATOM    557  CA  GLY A  71      43.876  39.404  40.765  1.00 37.61           C  \\nATOM    558  C   GLY A  71      42.778  39.217  39.737  1.00 31.96           C  \\nATOM    559  O   GLY A  71      42.288  40.233  39.199  1.00 39.20           O  \\nATOM    560  N   ALA A  72      42.399  37.974  39.510  1.00 24.83           N  \\nATOM    561  CA  ALA A  72      41.412  37.624  38.506  1.00 31.81           C  \\nATOM    562  C   ALA A  72      39.993  37.827  39.010  1.00 38.51           C  \\nATOM    563  O   ALA A  72      39.705  37.478  40.154  1.00 34.08           O  \\nATOM    564  CB  ALA A  72      41.652  36.181  38.080  1.00 27.44           C  \\nATOM    565  N   LYS A  73      39.179  38.322  38.081  1.00 30.14           N  \\nATOM    566  CA  LYS A  73      37.767  38.604  38.376  1.00 26.24           C  \\nATOM    567  C   LYS A  73      36.761  37.683  37.705  1.00 35.69           C  \\nATOM    568  O   LYS A  73      35.587  37.673  38.192  1.00 39.50           O  \\nATOM    569  CB  LYS A  73      37.420  40.047  37.983  1.00 24.79           C  \\nATOM    570  CG  LYS A  73      38.539  41.039  38.297  1.00 41.30           C  \\nATOM    571  CD  LYS A  73      38.023  42.212  39.114  1.00 75.00           C  \\nATOM    572  CE  LYS A  73      37.966  41.868  40.590  1.00 73.38           C  \\nATOM    573  NZ  LYS A  73      39.251  42.194  41.268  1.00 70.15           N  \\nATOM    574  N   ASN A  74      37.123  36.933  36.700  1.00 15.91           N  \\nATOM    575  CA  ASN A  74      36.096  35.997  36.081  1.00 15.63           C  \\nATOM    576  C   ASN A  74      34.669  36.522  35.889  1.00 17.55           C  \\nATOM    577  O   ASN A  74      33.674  35.992  36.408  1.00 18.43           O  \\nATOM    578  CB  ASN A  74      36.032  34.686  36.882  1.00 15.16           C  \\nATOM    579  CG  ASN A  74      35.411  33.576  36.071  1.00 18.17           C  \\nATOM    580  OD1 ASN A  74      35.097  33.714  34.863  1.00 18.06           O  \\nATOM    581  ND2 ASN A  74      35.196  32.469  36.786  1.00 23.58           N  \\nATOM    582  N   VAL A  75      34.617  37.554  35.058  1.00 21.60           N  \\nATOM    583  CA  VAL A  75      33.335  38.206  34.703  1.00 16.52           C  \\nATOM    584  C   VAL A  75      32.495  37.284  33.829  1.00 20.44           C  \\nATOM    585  O   VAL A  75      31.256  37.300  33.983  1.00 22.78           O  \\nATOM    586  CB  VAL A  75      33.682  39.583  34.114  1.00 19.29           C  \\nATOM    587  CG1 VAL A  75      32.533  40.216  33.366  1.00 29.00           C  \\nATOM    588  CG2 VAL A  75      34.195  40.497  35.214  1.00 19.92           C  \\nATOM    589  N   CYS A  76      33.043  36.469  32.948  1.00 16.20           N  \\nATOM    590  CA  CYS A  76      32.196  35.576  32.138  1.00 12.00           C  \\nATOM    591  C   CYS A  76      31.777  34.398  32.995  1.00 14.64           C  \\nATOM    592  O   CYS A  76      30.896  33.677  32.505  1.00 17.41           O  \\nATOM    593  CB  CYS A  76      32.836  35.049  30.861  1.00  9.87           C  \\nATOM    594  SG  CYS A  76      33.054  36.453  29.681  1.00 18.35           S  \\nATOM    595  N   GLY A  77      32.384  34.226  34.141  1.00 18.64           N  \\nATOM    596  CA  GLY A  77      31.963  33.109  35.020  1.00 18.26           C  \\nATOM    597  C   GLY A  77      32.272  31.757  34.425  1.00 18.13           C  \\nATOM    598  O   GLY A  77      31.422  30.859  34.526  1.00 20.18           O  \\nATOM    599  N   ILE A  78      33.453  31.630  33.828  1.00 29.20           N  \\nATOM    600  CA  ILE A  78      33.811  30.366  33.191  1.00 21.25           C  \\nATOM    601  C   ILE A  78      35.254  30.000  33.522  1.00 16.76           C  \\nATOM    602  O   ILE A  78      36.001  30.853  34.021  1.00 21.81           O  \\nATOM    603  CB  ILE A  78      33.590  30.440  31.630  1.00 15.20           C  \\nATOM    604  CG1 ILE A  78      34.312  31.715  31.117  1.00 13.92           C  \\nATOM    605  CG2 ILE A  78      32.108  30.390  31.212  1.00 19.90           C  \\nATOM    606  CD1 ILE A  78      34.469  31.764  29.589  1.00 15.43           C  \\nATOM    607  N   ARG A  79      35.542  28.769  33.158  1.00 15.88           N  \\nATOM    608  CA  ARG A  79      36.917  28.266  33.255  1.00 18.00           C  \\nATOM    609  C   ARG A  79      37.542  28.693  31.914  1.00 20.50           C  \\nATOM    610  O   ARG A  79      36.773  28.503  30.932  1.00 13.97           O  \\nATOM    611  CB  ARG A  79      37.091  26.787  33.428  1.00 21.11           C  \\nATOM    612  CG  ARG A  79      36.322  26.223  34.632  1.00 21.94           C  \\nATOM    613  CD  ARG A  79      37.172  26.532  35.823  1.00 30.78           C  \\nATOM    614  NE  ARG A  79      37.012  25.419  36.771  1.00 60.65           N  \\nATOM    615  CZ  ARG A  79      37.388  25.475  38.058  1.00 74.21           C  \\nATOM    616  NH1 ARG A  79      38.366  26.302  38.455  1.00 62.60           N  \\nATOM    617  NH2 ARG A  79      36.769  24.690  38.963  1.00 50.54           N  \\nATOM    618  N   CYS A  80      38.783  29.157  31.857  1.00 15.00           N  \\nATOM    619  CA  CYS A  80      39.378  29.545  30.573  1.00  9.53           C  \\nATOM    620  C   CYS A  80      39.463  28.385  29.568  1.00 16.33           C  \\nATOM    621  O   CYS A  80      39.456  28.596  28.342  1.00 15.34           O  \\nATOM    622  CB  CYS A  80      40.728  30.146  30.863  1.00 10.23           C  \\nATOM    623  SG  CYS A  80      40.713  31.674  31.799  1.00 16.76           S  \\nATOM    624  N   SER A  81      39.562  27.174  30.060  1.00 17.11           N  \\nATOM    625  CA  SER A  81      39.583  25.909  29.298  1.00 27.76           C  \\nATOM    626  C   SER A  81      38.387  25.747  28.347  1.00 19.17           C  \\nATOM    627  O   SER A  81      38.523  25.158  27.244  1.00 15.68           O  \\nATOM    628  CB  SER A  81      39.699  24.773  30.307  1.00 18.26           C  \\nATOM    629  OG  SER A  81      38.622  24.665  31.223  1.00 18.96           O  \\nATOM    630  N   GLN A  82      37.208  26.275  28.715  1.00 12.61           N  \\nATOM    631  CA  GLN A  82      35.998  26.278  27.903  1.00 14.47           C  \\nATOM    632  C   GLN A  82      36.102  27.181  26.661  1.00 16.25           C  \\nATOM    633  O   GLN A  82      35.252  27.041  25.776  1.00 18.52           O  \\nATOM    634  CB  GLN A  82      34.781  26.744  28.685  1.00 18.12           C  \\nATOM    635  CG  GLN A  82      34.561  25.870  29.915  1.00 21.03           C  \\nATOM    636  CD  GLN A  82      33.345  26.329  30.701  1.00 33.40           C  \\nATOM    637  OE1 GLN A  82      33.426  26.905  31.784  1.00 30.92           O  \\nATOM    638  NE2 GLN A  82      32.176  26.062  30.130  1.00 28.66           N  \\nATOM    639  N   LEU A  83      37.105  28.053  26.662  1.00 12.53           N  \\nATOM    640  CA  LEU A  83      37.379  28.945  25.565  1.00 17.44           C  \\nATOM    641  C   LEU A  83      38.254  28.240  24.523  1.00 20.26           C  \\nATOM    642  O   LEU A  83      38.543  28.910  23.518  1.00 19.47           O  \\nATOM    643  CB  LEU A  83      38.055  30.259  26.051  1.00 11.30           C  \\nATOM    644  CG  LEU A  83      37.243  31.103  27.013  1.00 13.36           C  \\nATOM    645  CD1 LEU A  83      37.996  32.353  27.389  1.00 15.63           C  \\nATOM    646  CD2 LEU A  83      35.913  31.450  26.325  1.00 11.21           C  \\nATOM    647  N   LEU A  84      38.663  27.001  24.747  1.00 15.58           N  \\nATOM    648  CA  LEU A  84      39.562  26.348  23.785  1.00 18.37           C  \\nATOM    649  C   LEU A  84      38.919  25.231  22.972  1.00 19.62           C  \\nATOM    650  O   LEU A  84      39.648  24.560  22.241  1.00 19.93           O  \\nATOM    651  CB  LEU A  84      40.789  25.803  24.554  1.00 15.48           C  \\nATOM    652  CG  LEU A  84      41.555  26.832  25.368  1.00 25.14           C  \\nATOM    653  CD1 LEU A  84      42.662  26.144  26.151  1.00 28.13           C  \\nATOM    654  CD2 LEU A  84      42.223  27.893  24.491  1.00 15.35           C  \\nATOM    655  N   THR A  85      37.646  25.036  23.134  1.00 19.69           N  \\nATOM    656  CA  THR A  85      36.900  23.970  22.445  1.00 13.86           C  \\nATOM    657  C   THR A  85      36.622  24.308  20.984  1.00 26.75           C  \\nATOM    658  O   THR A  85      36.574  25.455  20.521  1.00 22.46           O  \\nATOM    659  CB  THR A  85      35.625  23.658  23.308  1.00 17.99           C  \\nATOM    660  OG1 THR A  85      34.770  24.841  23.283  1.00 17.16           O  \\nATOM    661  CG2 THR A  85      35.888  23.278  24.776  1.00 19.95           C  \\nATOM    662  N   ASP A  86      36.391  23.269  20.182  1.00 21.54           N  \\nATOM    663  CA  ASP A  86      36.108  23.434  18.730  1.00 19.67           C  \\nATOM    664  C   ASP A  86      34.776  24.154  18.624  1.00 14.42           C  \\nATOM    665  O   ASP A  86      34.551  24.958  17.728  1.00 19.13           O  \\nATOM    666  CB  ASP A  86      36.260  22.079  18.071  1.00 21.50           C  \\nATOM    667  CG  ASP A  86      37.582  21.332  18.252  1.00 76.88           C  \\nATOM    668  OD1 ASP A  86      38.708  21.823  18.550  1.00 34.80           O  \\nATOM    669  OD2 ASP A  86      37.562  20.083  18.057  1.00 37.31           O  \\nATOM    670  N   ASP A  87      33.868  23.857  19.522  1.00 19.06           N  \\nATOM    671  CA  ASP A  87      32.561  24.470  19.680  1.00 17.34           C  \\nATOM    672  C   ASP A  87      32.748  25.885  20.235  1.00 17.82           C  \\nATOM    673  O   ASP A  87      33.355  26.043  21.339  1.00 17.69           O  \\nATOM    674  CB  ASP A  87      31.723  23.637  20.624  1.00 15.32           C  \\nATOM    675  CG  ASP A  87      30.312  24.207  20.661  1.00 25.26           C  \\nATOM    676  OD1 ASP A  87      29.633  24.042  19.655  1.00 37.21           O  \\nATOM    677  OD2 ASP A  87      29.903  24.810  21.635  1.00 33.96           O  \\nATOM    678  N   LEU A  88      32.256  26.855  19.508  1.00 15.61           N  \\nATOM    679  CA  LEU A  88      32.434  28.292  19.817  1.00 18.42           C  \\nATOM    680  C   LEU A  88      31.381  28.887  20.781  1.00 23.52           C  \\nATOM    681  O   LEU A  88      31.463  30.055  21.162  1.00 17.99           O  \\nATOM    682  CB  LEU A  88      32.266  29.143  18.551  1.00 20.15           C  \\nATOM    683  CG  LEU A  88      33.485  29.171  17.624  1.00 35.63           C  \\nATOM    684  CD1 LEU A  88      33.834  27.798  17.053  1.00 20.00           C  \\nATOM    685  CD2 LEU A  88      33.280  30.084  16.405  1.00 20.00           C  \\nATOM    686  N   THR A  89      30.325  28.069  21.167  1.00 17.61           N  \\nATOM    687  CA  THR A  89      29.272  28.630  22.010  1.00 14.12           C  \\nATOM    688  C   THR A  89      29.705  29.458  23.218  1.00 17.75           C  \\nATOM    689  O   THR A  89      29.159  30.571  23.361  1.00 17.45           O  \\nATOM    690  CB  THR A  89      28.360  27.423  22.451  1.00 17.59           C  \\nATOM    691  OG1 THR A  89      27.923  26.853  21.185  1.00 24.55           O  \\nATOM    692  CG2 THR A  89      27.261  27.902  23.400  1.00 21.48           C  \\nATOM    693  N   VAL A  90      30.572  28.938  24.073  1.00 18.21           N  \\nATOM    694  CA  VAL A  90      30.980  29.610  25.294  1.00 17.12           C  \\nATOM    695  C   VAL A  90      31.868  30.804  24.926  1.00 16.76           C  \\nATOM    696  O   VAL A  90      31.675  31.846  25.567  1.00 17.90           O  \\nATOM    697  CB  VAL A  90      31.667  28.667  26.291  1.00 14.60           C  \\nATOM    698  CG1 VAL A  90      32.332  29.359  27.469  1.00 14.54           C  \\nATOM    699  CG2 VAL A  90      30.657  27.672  26.786  1.00 19.10           C  \\nATOM    700  N   ALA A  91      32.754  30.635  23.970  1.00 10.75           N  \\nATOM    701  CA  ALA A  91      33.638  31.742  23.543  1.00 12.26           C  \\nATOM    702  C   ALA A  91      32.780  32.897  23.050  1.00 16.95           C  \\nATOM    703  O   ALA A  91      33.063  34.036  23.432  1.00 16.20           O  \\nATOM    704  CB  ALA A  91      34.629  31.293  22.478  1.00  9.95           C  \\nATOM    705  N   ILE A  92      31.788  32.578  22.225  1.00 14.01           N  \\nATOM    706  CA  ILE A  92      30.906  33.642  21.685  1.00 20.50           C  \\nATOM    707  C   ILE A  92      30.134  34.337  22.823  1.00 17.47           C  \\nATOM    708  O   ILE A  92      30.034  35.575  22.837  1.00 15.67           O  \\nATOM    709  CB  ILE A  92      29.984  33.106  20.538  1.00 20.56           C  \\nATOM    710  CG1 ILE A  92      30.885  32.859  19.284  1.00 14.53           C  \\nATOM    711  CG2 ILE A  92      28.780  34.025  20.218  1.00 12.81           C  \\nATOM    712  CD1 ILE A  92      30.054  31.995  18.292  1.00 16.95           C  \\nATOM    713  N   ARG A  93      29.556  33.567  23.736  1.00 14.49           N  \\nATOM    714  CA  ARG A  93      28.794  34.168  24.828  1.00 18.76           C  \\nATOM    715  C   ARG A  93      29.711  35.064  25.649  1.00 17.16           C  \\nATOM    716  O   ARG A  93      29.324  36.166  26.049  1.00 16.42           O  \\nATOM    717  CB  ARG A  93      28.145  33.032  25.592  1.00 17.75           C  \\nATOM    718  CG  ARG A  93      27.242  33.508  26.716  1.00 35.41           C  \\nATOM    719  CD  ARG A  93      26.922  32.320  27.573  1.00 45.93           C  \\nATOM    720  NE  ARG A  93      26.362  31.336  26.645  1.00 46.10           N  \\nATOM    721  CZ  ARG A  93      26.471  30.022  26.817  1.00 76.63           C  \\nATOM    722  NH1 ARG A  93      27.322  29.481  27.685  1.00 54.12           N  \\nATOM    723  NH2 ARG A  93      25.670  29.245  26.082  1.00 62.87           N  \\nATOM    724  N   CYS A  94      30.946  34.683  25.880  1.00 15.49           N  \\nATOM    725  CA  CYS A  94      31.893  35.528  26.659  1.00 20.88           C  \\nATOM    726  C   CYS A  94      32.330  36.727  25.783  1.00 17.36           C  \\nATOM    727  O   CYS A  94      32.335  37.840  26.375  1.00 18.30           O  \\nATOM    728  CB  CYS A  94      33.016  34.662  27.256  1.00 13.87           C  \\nATOM    729  SG  CYS A  94      34.183  35.643  28.222  1.00 15.28           S  \\nATOM    730  N   ALA A  95      32.655  36.606  24.492  1.00 15.48           N  \\nATOM    731  CA  ALA A  95      33.016  37.783  23.675  1.00 17.66           C  \\nATOM    732  C   ALA A  95      31.865  38.798  23.642  1.00 20.76           C  \\nATOM    733  O   ALA A  95      32.019  40.020  23.619  1.00 14.72           O  \\nATOM    734  CB  ALA A  95      33.424  37.365  22.281  1.00 12.91           C  \\nATOM    735  N   LYS A  96      30.605  38.346  23.619  1.00 14.30           N  \\nATOM    736  CA  LYS A  96      29.419  39.206  23.666  1.00 17.13           C  \\nATOM    737  C   LYS A  96      29.428  40.003  24.986  1.00 17.20           C  \\nATOM    738  O   LYS A  96      29.018  41.183  24.985  1.00 17.01           O  \\nATOM    739  CB  LYS A  96      28.100  38.457  23.541  1.00  8.06           C  \\nATOM    740  CG  LYS A  96      27.947  38.011  22.097  1.00 18.44           C  \\nATOM    741  CD  LYS A  96      26.604  37.293  21.950  1.00 21.53           C  \\nATOM    742  CE  LYS A  96      26.380  36.802  20.523  1.00 24.84           C  \\nATOM    743  NZ  LYS A  96      25.188  35.905  20.535  1.00 20.54           N  \\nATOM    744  N   ARG A  97      29.825  39.369  26.083  1.00 13.83           N  \\nATOM    745  CA  ARG A  97      29.907  40.040  27.381  1.00 17.41           C  \\nATOM    746  C   ARG A  97      31.055  41.087  27.372  1.00 19.69           C  \\nATOM    747  O   ARG A  97      30.916  42.254  27.822  1.00 15.34           O  \\nATOM    748  CB  ARG A  97      30.080  39.057  28.530  1.00 16.69           C  \\nATOM    749  CG  ARG A  97      30.450  39.720  29.857  1.00 17.78           C  \\nATOM    750  CD  ARG A  97      29.401  40.677  30.301  1.00 25.17           C  \\nATOM    751  NE  ARG A  97      29.717  41.496  31.444  1.00 18.76           N  \\nATOM    752  CZ  ARG A  97      30.365  42.651  31.411  1.00 13.49           C  \\nATOM    753  NH1 ARG A  97      30.780  43.264  30.320  1.00 12.96           N  \\nATOM    754  NH2 ARG A  97      30.565  43.230  32.583  1.00 19.37           N  \\nATOM    755  N   VAL A  98      32.222  40.728  26.873  1.00 15.71           N  \\nATOM    756  CA  VAL A  98      33.373  41.606  26.768  1.00 18.30           C  \\nATOM    757  C   VAL A  98      32.986  42.889  26.004  1.00 17.21           C  \\nATOM    758  O   VAL A  98      33.398  43.946  26.547  1.00 17.38           O  \\nATOM    759  CB  VAL A  98      34.584  40.915  26.098  1.00 16.56           C  \\nATOM    760  CG1 VAL A  98      35.717  41.920  25.863  1.00 14.33           C  \\nATOM    761  CG2 VAL A  98      35.079  39.679  26.832  1.00 10.64           C  \\nATOM    762  N   VAL A  99      32.319  42.821  24.853  1.00 13.39           N  \\nATOM    763  CA  VAL A  99      32.018  44.020  24.083  1.00 14.82           C  \\nATOM    764  C   VAL A  99      31.002  45.000  24.714  1.00 17.40           C  \\nATOM    765  O   VAL A  99      30.894  46.131  24.187  1.00 17.99           O  \\nATOM    766  CB  VAL A  99      31.431  43.859  22.632  1.00 24.56           C  \\nATOM    767  CG1 VAL A  99      32.662  43.864  21.750  1.00 23.77           C  \\nATOM    768  CG2 VAL A  99      30.443  42.748  22.502  1.00 15.81           C  \\nATOM    769  N   LEU A 100      30.323  44.532  25.726  1.00 17.67           N  \\nATOM    770  CA  LEU A 100      29.349  45.395  26.404  1.00 21.97           C  \\nATOM    771  C   LEU A 100      30.083  46.361  27.342  1.00 20.83           C  \\nATOM    772  O   LEU A 100      29.358  47.280  27.727  1.00 26.62           O  \\nATOM    773  CB  LEU A 100      28.302  44.535  27.108  1.00 15.25           C  \\nATOM    774  CG  LEU A 100      27.471  43.650  26.219  1.00 17.44           C  \\nATOM    775  CD1 LEU A 100      26.531  42.842  27.118  1.00 31.28           C  \\nATOM    776  CD2 LEU A 100      26.686  44.489  25.222  1.00 17.72           C  \\nATOM    777  N   ASP A 101      31.333  46.128  27.694  1.00 13.05           N  \\nATOM    778  CA  ASP A 101      31.988  47.087  28.564  1.00 16.95           C  \\nATOM    779  C   ASP A 101      32.228  48.341  27.707  1.00 22.07           C  \\nATOM    780  O   ASP A 101      32.169  48.304  26.479  1.00 21.47           O  \\nATOM    781  CB  ASP A 101      33.282  46.590  29.213  1.00 18.53           C  \\nATOM    782  CG  ASP A 101      33.044  45.995  30.590  1.00 17.30           C  \\nATOM    783  OD1 ASP A 101      31.874  45.780  30.979  1.00 26.27           O  \\nATOM    784  OD2 ASP A 101      34.060  45.721  31.245  1.00 22.85           O  \\nATOM    785  N   PRO A 102      32.499  49.413  28.436  1.00 21.39           N  \\nATOM    786  CA  PRO A 102      32.779  50.736  27.892  1.00 25.90           C  \\nATOM    787  C   PRO A 102      33.700  50.814  26.694  1.00 18.82           C  \\nATOM    788  O   PRO A 102      33.318  51.517  25.731  1.00 24.76           O  \\nATOM    789  CB  PRO A 102      33.385  51.460  29.109  1.00 29.27           C  \\nATOM    790  CG  PRO A 102      32.486  50.920  30.212  1.00 24.89           C  \\nATOM    791  CD  PRO A 102      32.568  49.435  29.920  1.00 23.84           C  \\nATOM    792  N   ASN A 103      34.764  50.039  26.726  1.00 23.60           N  \\nATOM    793  CA  ASN A 103      35.755  50.081  25.634  1.00 19.04           C  \\nATOM    794  C   ASN A 103      35.274  49.362  24.350  1.00 26.12           C  \\nATOM    795  O   ASN A 103      35.910  49.450  23.294  1.00 20.00           O  \\nATOM    796  CB  ASN A 103      37.068  49.457  26.094  1.00 20.77           C  \\nATOM    797  CG  ASN A 103      37.877  50.402  26.984  1.00 33.46           C  \\nATOM    798  OD1 ASN A 103      37.473  51.549  27.186  1.00 30.23           O  \\nATOM    799  ND2 ASN A 103      39.001  49.990  27.538  1.00 20.00           N  \\nATOM    800  N   GLY A 104      34.127  48.626  24.412  1.00 17.55           N  \\nATOM    801  CA  GLY A 104      33.616  47.925  23.243  1.00 18.44           C  \\nATOM    802  C   GLY A 104      34.701  47.013  22.665  1.00 15.00           C  \\nATOM    803  O   GLY A 104      35.494  46.395  23.387  1.00 16.48           O  \\nATOM    804  N   ILE A 105      34.713  46.948  21.358  1.00 16.97           N  \\nATOM    805  CA  ILE A 105      35.646  46.062  20.629  1.00 21.90           C  \\nATOM    806  C   ILE A 105      37.087  46.525  20.745  1.00 16.33           C  \\nATOM    807  O   ILE A 105      37.959  45.712  20.373  1.00 17.78           O  \\nATOM    808  CB  ILE A 105      35.054  45.889  19.172  1.00 20.57           C  \\nATOM    809  CG1 ILE A 105      35.574  44.581  18.532  1.00 13.63           C  \\nATOM    810  CG2 ILE A 105      35.326  47.181  18.371  1.00 20.85           C  \\nATOM    811  CD1 ILE A 105      34.898  44.235  17.204  1.00 14.68           C  \\nATOM    812  N   GLY A 106      37.261  47.705  21.309  1.00 15.13           N  \\nATOM    813  CA  GLY A 106      38.620  48.245  21.517  1.00 12.14           C  \\nATOM    814  C   GLY A 106      39.312  47.460  22.610  1.00 19.51           C  \\nATOM    815  O   GLY A 106      40.470  47.686  22.916  1.00 19.10           O  \\nATOM    816  N   ALA A 107      38.652  46.513  23.251  1.00 17.59           N  \\nATOM    817  CA  ALA A 107      39.173  45.619  24.293  1.00 15.03           C  \\nATOM    818  C   ALA A 107      40.253  44.710  23.697  1.00 15.02           C  \\nATOM    819  O   ALA A 107      41.168  44.201  24.344  1.00 18.31           O  \\nATOM    820  CB  ALA A 107      38.120  44.734  24.928  1.00 18.12           C  \\nATOM    821  N   TRP A 108      40.102  44.455  22.407  1.00 16.04           N  \\nATOM    822  CA  TRP A 108      41.024  43.604  21.666  1.00 16.09           C  \\nATOM    823  C   TRP A 108      42.185  44.390  21.050  1.00 19.70           C  \\nATOM    824  O   TRP A 108      41.940  45.192  20.125  1.00 19.09           O  \\nATOM    825  CB  TRP A 108      40.250  42.838  20.565  1.00 17.83           C  \\nATOM    826  CG  TRP A 108      39.508  41.661  21.114  1.00 13.49           C  \\nATOM    827  CD1 TRP A 108      39.997  40.402  21.369  1.00 14.20           C  \\nATOM    828  CD2 TRP A 108      38.133  41.659  21.526  1.00 12.99           C  \\nATOM    829  NE1 TRP A 108      38.977  39.640  21.907  1.00 15.50           N  \\nATOM    830  CE2 TRP A 108      37.816  40.352  22.006  1.00 11.62           C  \\nATOM    831  CE3 TRP A 108      37.128  42.621  21.504  1.00 14.87           C  \\nATOM    832  CZ2 TRP A 108      36.552  39.982  22.465  1.00 12.52           C  \\nATOM    833  CZ3 TRP A 108      35.854  42.259  21.957  1.00 14.43           C  \\nATOM    834  CH2 TRP A 108      35.567  40.965  22.438  1.00 15.49           C  \\nATOM    835  N   VAL A 109      43.393  44.138  21.490  1.00 15.29           N  \\nATOM    836  CA  VAL A 109      44.564  44.819  20.925  1.00 21.54           C  \\nATOM    837  C   VAL A 109      44.623  44.610  19.404  1.00 23.06           C  \\nATOM    838  O   VAL A 109      44.864  45.605  18.677  1.00 19.01           O  \\nATOM    839  CB  VAL A 109      45.872  44.374  21.633  1.00 20.10           C  \\nATOM    840  CG1 VAL A 109      47.055  45.224  21.119  1.00 22.23           C  \\nATOM    841  CG2 VAL A 109      45.761  44.380  23.126  1.00 27.58           C  \\nATOM    842  N   ALA A 110      44.457  43.394  18.900  1.00 20.17           N  \\nATOM    843  CA  ALA A 110      44.567  43.107  17.463  1.00 19.37           C  \\nATOM    844  C   ALA A 110      43.513  43.877  16.682  1.00 17.18           C  \\nATOM    845  O   ALA A 110      43.932  44.231  15.553  1.00 18.73           O  \\nATOM    846  CB  ALA A 110      44.478  41.621  17.114  1.00 20.58           C  \\nATOM    847  N   TRP A 111      42.320  44.088  17.232  1.00 16.19           N  \\nATOM    848  CA  TRP A 111      41.333  44.872  16.460  1.00 12.35           C  \\nATOM    849  C   TRP A 111      41.857  46.331  16.297  1.00 19.29           C  \\nATOM    850  O   TRP A 111      41.792  46.927  15.207  1.00 18.58           O  \\nATOM    851  CB  TRP A 111      39.935  44.789  17.078  1.00 13.53           C  \\nATOM    852  CG  TRP A 111      38.914  45.576  16.308  1.00 14.55           C  \\nATOM    853  CD1 TRP A 111      38.112  45.145  15.268  1.00 14.98           C  \\nATOM    854  CD2 TRP A 111      38.592  46.964  16.537  1.00 15.96           C  \\nATOM    855  NE1 TRP A 111      37.324  46.174  14.853  1.00 14.19           N  \\nATOM    856  CE2 TRP A 111      37.604  47.304  15.588  1.00 20.11           C  \\nATOM    857  CE3 TRP A 111      39.073  47.910  17.449  1.00 16.50           C  \\nATOM    858  CZ2 TRP A 111      37.076  48.596  15.486  1.00 15.26           C  \\nATOM    859  CZ3 TRP A 111      38.523  49.182  17.375  1.00 18.55           C  \\nATOM    860  CH2 TRP A 111      37.544  49.508  16.436  1.00 18.44           C  \\nATOM    861  N   ARG A 112      42.300  46.939  17.385  1.00 16.92           N  \\nATOM    862  CA  ARG A 112      42.818  48.318  17.434  1.00 20.82           C  \\nATOM    863  C   ARG A 112      43.910  48.533  16.407  1.00 20.44           C  \\nATOM    864  O   ARG A 112      43.925  49.504  15.648  1.00 17.20           O  \\nATOM    865  CB  ARG A 112      43.357  48.710  18.841  1.00 12.95           C  \\nATOM    866  CG  ARG A 112      42.133  48.857  19.772  1.00 14.66           C  \\nATOM    867  CD  ARG A 112      42.330  49.813  20.906  1.00 18.96           C  \\nATOM    868  NE  ARG A 112      43.618  49.681  21.519  1.00 26.26           N  \\nATOM    869  CZ  ARG A 112      44.054  48.817  22.412  1.00 31.02           C  \\nATOM    870  NH1 ARG A 112      43.236  47.941  22.992  1.00 21.48           N  \\nATOM    871  NH2 ARG A 112      45.313  48.780  22.803  1.00 23.55           N  \\nATOM    872  N   LEU A 113      44.749  47.501  16.374  1.00 18.45           N  \\nATOM    873  CA  LEU A 113      45.939  47.519  15.550  1.00 25.99           C  \\nATOM    874  C   LEU A 113      45.681  47.231  14.056  1.00 31.44           C  \\nATOM    875  O   LEU A 113      46.098  48.003  13.184  1.00 23.75           O  \\nATOM    876  CB  LEU A 113      46.946  46.510  16.071  1.00 19.39           C  \\nATOM    877  CG  LEU A 113      48.346  47.099  16.060  1.00 47.96           C  \\nATOM    878  CD1 LEU A 113      48.435  48.440  16.796  1.00 20.00           C  \\nATOM    879  CD2 LEU A 113      49.385  46.195  16.705  1.00 20.00           C  \\nATOM    880  N   HIS A 114      45.093  46.098  13.698  1.00 22.13           N  \\nATOM    881  CA  HIS A 114      44.837  45.724  12.308  1.00 19.41           C  \\nATOM    882  C   HIS A 114      43.452  45.871  11.693  1.00 17.65           C  \\nATOM    883  O   HIS A 114      43.413  45.674  10.463  1.00 27.42           O  \\nATOM    884  CB  HIS A 114      45.136  44.209  12.140  1.00 15.20           C  \\nATOM    885  CG  HIS A 114      46.534  43.960  12.577  1.00 20.23           C  \\nATOM    886  ND1 HIS A 114      46.758  43.358  13.805  1.00 31.86           N  \\nATOM    887  CD2 HIS A 114      47.727  44.166  11.966  1.00 21.43           C  \\nATOM    888  CE1 HIS A 114      48.061  43.211  13.969  1.00 21.45           C  \\nATOM    889  NE2 HIS A 114      48.634  43.673  12.864  1.00 25.18           N  \\nATOM    890  N   CYS A 115      42.426  46.200  12.433  1.00 20.67           N  \\nATOM    891  CA  CYS A 115      41.107  46.283  11.869  1.00 19.68           C  \\nATOM    892  C   CYS A 115      40.453  47.636  11.967  1.00 15.99           C  \\nATOM    893  O   CYS A 115      39.652  47.912  11.049  1.00 21.86           O  \\nATOM    894  CB  CYS A 115      40.171  45.279  12.605  1.00 18.67           C  \\nATOM    895  SG  CYS A 115      40.931  43.617  12.760  1.00 19.60           S  \\nATOM    896  N   GLN A 116      40.704  48.332  13.061  1.00 15.01           N  \\nATOM    897  CA  GLN A 116      40.067  49.652  13.248  1.00 23.86           C  \\nATOM    898  C   GLN A 116      40.348  50.586  12.064  1.00 27.48           C  \\nATOM    899  O   GLN A 116      41.511  50.661  11.615  1.00 24.50           O  \\nATOM    900  CB  GLN A 116      40.582  50.271  14.524  1.00 13.47           C  \\nATOM    901  CG  GLN A 116      40.094  51.679  14.755  1.00 16.62           C  \\nATOM    902  CD  GLN A 116      40.350  52.150  16.168  1.00 22.39           C  \\nATOM    903  OE1 GLN A 116      39.545  52.906  16.707  1.00 29.30           O  \\nATOM    904  NE2 GLN A 116      41.443  51.741  16.817  1.00 16.00           N  \\nATOM    905  N   ASN A 117      39.326  51.255  11.551  1.00 28.23           N  \\nATOM    906  CA  ASN A 117      39.531  52.191  10.415  1.00 42.50           C  \\nATOM    907  C   ASN A 117      40.001  51.571   9.097  1.00 61.43           C  \\nATOM    908  O   ASN A 117      40.420  52.304   8.171  1.00 42.87           O  \\nATOM    909  CB  ASN A 117      40.541  53.291  10.825  1.00 33.32           C  \\nATOM    910  CG  ASN A 117      40.120  54.182  11.976  1.00 31.33           C  \\nATOM    911  OD1 ASN A 117      38.926  54.497  12.184  1.00 37.02           O  \\nATOM    912  ND2 ASN A 117      41.117  54.596  12.771  1.00 33.22           N  \\nATOM    913  N   GLN A 118      39.985  50.273   8.938  1.00 35.07           N  \\nATOM    914  CA  GLN A 118      40.392  49.535   7.749  1.00 29.48           C  \\nATOM    915  C   GLN A 118      39.224  49.101   6.861  1.00 33.01           C  \\nATOM    916  O   GLN A 118      38.065  49.114   7.297  1.00 27.85           O  \\nATOM    917  CB  GLN A 118      41.121  48.198   8.037  1.00 30.27           C  \\nATOM    918  CG  GLN A 118      42.384  48.563   8.815  1.00 36.63           C  \\nATOM    919  CD  GLN A 118      43.433  48.995   7.814  1.00 75.43           C  \\nATOM    920  OE1 GLN A 118      43.138  49.281   6.653  1.00 76.43           O  \\nATOM    921  NE2 GLN A 118      44.634  48.968   8.379  1.00 73.90           N  \\nATOM    922  N   ASP A 119      39.638  48.675   5.669  1.00 33.91           N  \\nATOM    923  CA  ASP A 119      38.556  48.161   4.772  1.00 39.09           C  \\nATOM    924  C   ASP A 119      38.547  46.656   5.106  1.00 21.68           C  \\nATOM    925  O   ASP A 119      39.526  45.900   4.908  1.00 31.47           O  \\nATOM    926  CB  ASP A 119      38.741  48.595   3.324  1.00 44.22           C  \\nATOM    927  CG  ASP A 119      37.453  48.269   2.550  1.00 81.11           C  \\nATOM    928  OD1 ASP A 119      36.477  49.055   2.549  1.00 69.69           O  \\nATOM    929  OD2 ASP A 119      37.407  47.179   1.952  1.00 71.31           O  \\nATOM    930  N   LEU A 120      37.431  46.230   5.692  1.00 30.47           N  \\nATOM    931  CA  LEU A 120      37.331  44.802   6.116  1.00 24.47           C  \\nATOM    932  C   LEU A 120      36.547  43.896   5.179  1.00 35.50           C  \\nATOM    933  O   LEU A 120      36.230  42.733   5.510  1.00 23.43           O  \\nATOM    934  CB  LEU A 120      36.761  44.902   7.537  1.00 19.87           C  \\nATOM    935  CG  LEU A 120      37.462  45.716   8.594  1.00 18.37           C  \\nATOM    936  CD1 LEU A 120      36.864  45.446   9.968  1.00 23.47           C  \\nATOM    937  CD2 LEU A 120      38.935  45.350   8.701  1.00 16.15           C  \\nATOM    938  N   ARG A 121      36.239  44.406   3.994  1.00 26.13           N  \\nATOM    939  CA  ARG A 121      35.463  43.694   2.969  1.00 43.70           C  \\nATOM    940  C   ARG A 121      36.054  42.321   2.669  1.00 36.20           C  \\nATOM    941  O   ARG A 121      35.344  41.307   2.522  1.00 31.75           O  \\nATOM    942  CB  ARG A 121      35.345  44.522   1.675  1.00 35.99           C  \\nATOM    943  CG  ARG A 121      33.936  45.100   1.507  1.00 63.53           C  \\nATOM    944  CD  ARG A 121      32.852  44.064   1.547  1.00 76.01           C  \\nATOM    945  NE  ARG A 121      31.605  44.323   0.849  1.00 81.11           N  \\nATOM    946  CZ  ARG A 121      31.249  44.324  -0.436  1.00 81.11           C  \\nATOM    947  NH1 ARG A 121      32.080  44.339  -1.486  1.00 76.93           N  \\nATOM    948  NH2 ARG A 121      29.937  44.310  -0.730  1.00 78.66           N  \\nATOM    949  N   SER A 122      37.368  42.334   2.567  1.00 19.19           N  \\nATOM    950  CA  SER A 122      38.094  41.110   2.292  1.00 22.31           C  \\nATOM    951  C   SER A 122      37.878  39.995   3.315  1.00 38.34           C  \\nATOM    952  O   SER A 122      38.062  38.817   2.910  1.00 25.91           O  \\nATOM    953  CB  SER A 122      39.584  41.424   2.244  1.00 33.09           C  \\nATOM    954  OG  SER A 122      39.929  42.127   3.430  1.00 60.31           O  \\nATOM    955  N   TYR A 123      37.575  40.310   4.563  1.00 33.97           N  \\nATOM    956  CA  TYR A 123      37.428  39.223   5.561  1.00 26.12           C  \\nATOM    957  C   TYR A 123      36.200  38.357   5.300  1.00 14.78           C  \\nATOM    958  O   TYR A 123      36.275  37.207   5.768  1.00 22.61           O  \\nATOM    959  CB  TYR A 123      37.444  39.773   7.013  1.00 17.69           C  \\nATOM    960  CG  TYR A 123      38.846  40.281   7.282  1.00 20.04           C  \\nATOM    961  CD1 TYR A 123      39.858  39.432   7.688  1.00 15.21           C  \\nATOM    962  CD2 TYR A 123      39.164  41.627   7.071  1.00 25.16           C  \\nATOM    963  CE1 TYR A 123      41.160  39.905   7.923  1.00 15.03           C  \\nATOM    964  CE2 TYR A 123      40.433  42.109   7.327  1.00 17.95           C  \\nATOM    965  CZ  TYR A 123      41.449  41.250   7.741  1.00 16.94           C  \\nATOM    966  OH  TYR A 123      42.737  41.675   7.993  1.00 19.62           O  \\nATOM    967  N   VAL A 124      35.192  38.853   4.629  1.00 18.45           N  \\nATOM    968  CA  VAL A 124      33.978  38.018   4.369  1.00 21.35           C  \\nATOM    969  C   VAL A 124      33.731  37.751   2.882  1.00 20.96           C  \\nATOM    970  O   VAL A 124      32.794  37.067   2.504  1.00 22.36           O  \\nATOM    971  CB  VAL A 124      32.799  38.683   5.078  1.00 23.47           C  \\nATOM    972  CG1 VAL A 124      33.059  38.598   6.571  1.00 26.40           C  \\nATOM    973  CG2 VAL A 124      32.560  40.101   4.601  1.00 30.60           C  \\nATOM    974  N   ALA A 125      34.618  38.214   2.027  1.00 25.88           N  \\nATOM    975  CA  ALA A 125      34.575  38.033   0.592  1.00 32.41           C  \\nATOM    976  C   ALA A 125      34.616  36.536   0.269  1.00 21.27           C  \\nATOM    977  O   ALA A 125      35.465  35.760   0.722  1.00 27.19           O  \\nATOM    978  CB  ALA A 125      35.733  38.705  -0.120  1.00 38.08           C  \\nATOM    979  N   GLY A 126      33.628  36.229  -0.558  1.00 29.73           N  \\nATOM    980  CA  GLY A 126      33.422  34.859  -1.048  1.00 16.76           C  \\nATOM    981  C   GLY A 126      32.706  33.952  -0.036  1.00 18.63           C  \\nATOM    982  O   GLY A 126      32.705  32.762  -0.383  1.00 24.95           O  \\nATOM    983  N   CYS A 127      32.195  34.442   1.085  1.00 23.65           N  \\nATOM    984  CA  CYS A 127      31.633  33.532   2.092  1.00 15.47           C  \\nATOM    985  C   CYS A 127      30.155  33.267   1.882  1.00 15.28           C  \\nATOM    986  O   CYS A 127      29.662  32.307   2.475  1.00 23.63           O  \\nATOM    987  CB  CYS A 127      31.942  34.102   3.494  1.00 19.93           C  \\nATOM    988  SG  CYS A 127      33.718  34.150   3.855  1.00 22.03           S  \\nATOM    989  N   GLY A 128      29.575  34.150   1.101  1.00 23.38           N  \\nATOM    990  CA  GLY A 128      28.150  34.117   0.760  1.00 18.57           C  \\nATOM    991  C   GLY A 128      27.265  34.369   1.962  1.00 22.84           C  \\nATOM    992  O   GLY A 128      26.203  33.765   2.081  1.00 28.45           O  \\nATOM    993  N   VAL A 129      27.607  35.188   2.912  1.00 25.27           N  \\nATOM    994  CA  VAL A 129      26.915  35.579   4.143  1.00 23.88           C  \\nATOM    995  C   VAL A 129      27.122  37.129   4.234  1.00 37.06           C  \\nATOM    996  O   VAL A 129      26.036  37.695   4.510  1.00 43.88           O  \\nATOM    997  CB  VAL A 129      27.347  34.847   5.420  1.00 30.64           C  \\nATOM    998  CG1 VAL A 129      27.275  33.331   5.355  1.00 34.41           C  \\nATOM    999  CG2 VAL A 129      28.771  35.215   5.868  1.00 30.19           C  \\nTER    1000      VAL A 129                                                      \\nHETATM 1001  C1  NAG A 130      40.573  45.941  30.725  1.00 16.35           C  \\nHETATM 1002  C2  NAG A 130      40.599  47.461  31.105  1.00 49.86           C  \\nHETATM 1003  C3  NAG A 130      39.697  47.780  32.309  1.00 29.37           C  \\nHETATM 1004  C4  NAG A 130      38.249  47.104  32.228  1.00 20.77           C  \\nHETATM 1005  C5  NAG A 130      38.436  45.626  31.880  1.00 22.06           C  \\nHETATM 1006  C6  NAG A 130      37.186  44.958  31.539  1.00 18.57           C  \\nHETATM 1007  C7  NAG A 130      42.034  48.701  30.178  1.00 25.62           C  \\nHETATM 1008  C8  NAG A 130      43.346  49.262  30.759  1.00 42.60           C  \\nHETATM 1009  N2  NAG A 130      41.695  47.858  31.171  1.00 42.79           N  \\nHETATM 1010  O3  NAG A 130      39.266  49.181  32.311  1.00 46.30           O  \\nHETATM 1011  O4  NAG A 130      37.469  47.416  33.391  1.00 26.43           O  \\nHETATM 1012  O5  NAG A 130      39.246  45.423  30.710  1.00 20.34           O  \\nHETATM 1013  O6  NAG A 130      36.383  45.653  30.651  1.00 21.58           O  \\nHETATM 1014  O7  NAG A 130      41.594  49.122  29.081  1.00 58.35           O  \\nHETATM 1015  C1  NAG A 131      43.023  42.938  27.078  1.00 24.56           C  \\nHETATM 1016  C2  NAG A 131      41.492  42.604  27.308  1.00 30.33           C  \\nHETATM 1017  C3  NAG A 131      40.822  43.798  27.982  1.00 13.79           C  \\nHETATM 1018  C4  NAG A 131      41.639  44.440  29.207  1.00 16.75           C  \\nHETATM 1019  C5  NAG A 131      43.116  44.565  28.850  1.00 32.65           C  \\nHETATM 1020  C6  NAG A 131      43.971  44.853  30.023  1.00 38.78           C  \\nHETATM 1021  C7  NAG A 131      40.423  40.786  26.468  1.00 12.52           C  \\nHETATM 1022  C8  NAG A 131      39.899  40.642  25.035  1.00 12.39           C  \\nHETATM 1023  N2  NAG A 131      40.892  42.050  26.534  1.00 17.85           N  \\nHETATM 1024  O3  NAG A 131      39.563  43.515  28.603  1.00 15.77           O  \\nHETATM 1025  O4  NAG A 131      41.024  45.731  29.426  1.00 17.85           O  \\nHETATM 1026  O5  NAG A 131      43.596  43.274  28.397  1.00 20.51           O  \\nHETATM 1027  O6  NAG A 131      43.753  44.063  31.167  1.00 56.49           O  \\nHETATM 1028  O7  NAG A 131      40.336  39.746  27.152  1.00 16.98           O  \\nHETATM 1029  C1  NDG A 132      46.881  40.478  24.981  1.00 29.15           C  \\nHETATM 1030  C2  NDG A 132      46.805  41.995  25.238  1.00 28.47           C  \\nHETATM 1031  C3  NDG A 132      45.696  42.310  26.245  1.00 33.80           C  \\nHETATM 1032  C4  NDG A 132      44.322  41.736  25.871  1.00 33.06           C  \\nHETATM 1033  C5  NDG A 132      44.299  40.337  25.216  1.00 33.05           C  \\nHETATM 1034  C6  NDG A 132      43.345  40.460  24.056  1.00 28.22           C  \\nHETATM 1035  C7  NDG A 132      48.758  43.117  26.079  1.00 34.25           C  \\nHETATM 1036  C8  NDG A 132      48.543  44.254  25.032  1.00 34.25           C  \\nHETATM 1037  O   NDG A 132      45.558  39.988  24.562  1.00 34.25           O  \\nHETATM 1038  O3  NDG A 132      45.624  43.701  26.666  1.00 32.94           O  \\nHETATM 1039  O4  NDG A 132      43.524  41.622  27.086  1.00 26.50           O  \\nHETATM 1040  O6  NDG A 132      43.599  41.602  23.184  1.00 25.99           O  \\nHETATM 1041  O7  NDG A 132      49.919  43.191  26.673  1.00 34.25           O  \\nHETATM 1042  N2  NDG A 132      47.855  42.106  26.370  1.00 34.25           N  \\nHETATM 1043  O1L NDG A 132      47.236  40.018  26.007  1.00 20.00           O  \\nHETATM 1044  O   HOH A 133      26.246  29.807  19.762  1.00 44.26           O  \\nHETATM 1045  O   HOH A 134      42.457  45.513   5.433  1.00 44.45           O  \\nHETATM 1046  O   HOH A 135      43.129  44.697   8.039  1.00 42.75           O  \\nHETATM 1047  O   HOH A 136      30.676  48.082  12.515  1.00 30.11           O  \\nHETATM 1048  O   HOH A 137      45.397  33.460   9.278  1.00 46.64           O  \\nHETATM 1049  O   HOH A 138      42.270  28.973   8.488  1.00 30.46           O  \\nHETATM 1050  O   HOH A 139      44.881  29.870  10.111  1.00 36.19           O  \\nHETATM 1051  O   HOH A 140      36.813  19.961  21.449  1.00 37.55           O  \\nHETATM 1052  O   HOH A 141      33.911  21.046  21.228  1.00 29.57           O  \\nHETATM 1053  O   HOH A 142      47.163  37.425  22.811  1.00 35.20           O  \\nHETATM 1054  O   HOH A 143      50.688  29.260  26.410  1.00 35.88           O  \\nHETATM 1055  O   HOH A 144      37.814  30.027  21.259  1.00 18.60           O  \\nHETATM 1056  O   HOH A 145      35.987  28.037  21.407  1.00 18.50           O  \\nHETATM 1057  O   HOH A 146      33.941  27.839  23.332  1.00 18.21           O  \\nHETATM 1058  O   HOH A 147      31.233  25.903  23.973  1.00 26.37           O  \\nHETATM 1059  O   HOH A 148      33.222  25.029  25.620  1.00 24.59           O  \\nHETATM 1060  O   HOH A 149      48.054  41.415  29.146  1.00 38.25           O  \\nHETATM 1061  O   HOH A 150      45.653  41.509  31.621  1.00 30.84           O  \\nHETATM 1062  O   HOH A 151      39.549  47.453  27.372  1.00 28.50           O  \\nHETATM 1063  O   HOH A 152      37.121  46.082  28.281  1.00 23.29           O  \\nHETATM 1064  O   HOH A 153      35.737  48.800  29.148  1.00 19.80           O  \\nHETATM 1065  O   HOH A 154      35.327  46.041  26.364  1.00 17.44           O  \\nHETATM 1066  O   HOH A 155      47.450  39.756  36.686  1.00 42.57           O  \\nHETATM 1067  O   HOH A 156      43.181  32.844  38.573  1.00 26.40           O  \\nHETATM 1068  O   HOH A 157      42.102  33.428  36.234  1.00 25.04           O  \\nHETATM 1069  O   HOH A 158      50.872  31.929  34.885  1.00 34.74           O  \\nHETATM 1070  O   HOH A 159      51.336  27.000  35.357  1.00 59.34           O  \\nHETATM 1071  O   HOH A 160      46.953  28.097  31.061  1.00 18.96           O  \\nHETATM 1072  O   HOH A 161      47.577  32.509  33.301  1.00 16.49           O  \\nHETATM 1073  O   HOH A 162      30.297  30.120   3.054  1.00 32.01           O  \\nHETATM 1074  O   HOH A 163      30.253  43.810   4.175  1.00 73.43           O  \\nHETATM 1075  O   HOH A 164      54.291  42.638  35.300  1.00 60.64           O  \\nHETATM 1076  O   HOH A 165      38.180  32.868  22.674  1.00 14.52           O  \\nHETATM 1077  O   HOH A 166      41.909  25.652  37.234  1.00 16.68           O  \\nHETATM 1078  O   HOH A 167      39.176  23.335  33.549  1.00 20.31           O  \\nHETATM 1079  O   HOH A 168      33.991  29.402  36.749  1.00 37.46           O  \\nHETATM 1080  O   HOH A 169      36.366  22.717  30.508  1.00 38.87           O  \\nHETATM 1081  O   HOH A 170      39.688  22.174  27.546  1.00 42.71           O  \\nHETATM 1082  O   HOH A 171      29.454  33.811  29.657  1.00 36.48           O  \\nHETATM 1083  O   HOH A 172      30.286  32.010  28.140  1.00 34.07           O  \\nHETATM 1084  O   HOH A 173      26.854  37.106  26.832  1.00 35.29           O  \\nHETATM 1085  O   HOH A 174      25.482  39.410  26.251  1.00 45.08           O  \\nHETATM 1086  O   HOH A 175      39.875  25.136  41.397  1.00 30.77           O  \\nHETATM 1087  O   HOH A 176      40.998  27.364  39.063  1.00 27.69           O  \\nHETATM 1088  O   HOH A 177      26.908  31.409  21.981  1.00 25.68           O  \\nHETATM 1089  O   HOH A 178      25.643  33.900  22.469  1.00 33.30           O  \\nHETATM 1090  O   HOH A 179      28.495  28.102  18.315  1.00 48.60           O  \\nHETATM 1091  O   HOH A 180      31.692  24.972  11.145  1.00 57.62           O  \\nHETATM 1092  O   HOH A 181      26.885  25.969   5.922  1.00 31.19           O  \\nHETATM 1093  O   HOH A 182      28.060  29.349  15.898  1.00 45.01           O  \\nHETATM 1094  O   HOH A 183      30.711  26.321  17.129  1.00 32.36           O  \\nHETATM 1095  O   HOH A 184      28.775  30.503  29.497  1.00 42.21           O  \\nHETATM 1096  O   HOH A 185      29.237  27.866  30.561  1.00 45.76           O  \\nHETATM 1097  O   HOH A 186      32.165  48.286  20.008  1.00 26.08           O  \\nHETATM 1098  O   HOH A 187      27.507  50.974  28.469  1.00 31.43           O  \\nHETATM 1099  O   HOH A 188      29.852  48.567  21.547  1.00 37.20           O  \\nHETATM 1100  O   HOH A 189      29.179  50.481  26.452  1.00 61.06           O  \\nHETATM 1101  O   HOH A 190      40.900  50.004  24.515  1.00 51.70           O  \\nHETATM 1102  O   HOH A 191      36.829  51.179  12.906  1.00 43.76           O  \\nHETATM 1103  O   HOH A 192      36.534  48.596  11.404  1.00 41.14           O  \\nHETATM 1104  O   HOH A 193      39.856  57.612  14.660  1.00 59.55           O  \\nHETATM 1105  O   HOH A 194      38.704  51.290  20.772  1.00 37.82           O  \\nHETATM 1106  O   HOH A 195      48.941  50.913  11.287  1.00 51.27           O  \\nHETATM 1107  O   HOH A 196      41.365  54.071   6.463  1.00 43.07           O  \\nHETATM 1108  O   HOH A 197      30.534  36.988  -1.181  1.00 49.70           O  \\nHETATM 1109  O   HOH A 198      28.760  32.799  -2.317  1.00 45.69           O  \\nHETATM 1110  O   HOH A 199      30.545  31.312  -1.471  1.00 52.26           O  \\nHETATM 1111  O   HOH A 200      35.181  29.738   1.305  1.00 70.41           O  \\nHETATM 1112  O   HOH A 201      41.204  32.816   2.283  1.00 52.05           O  \\nHETATM 1113  O   HOH A 202      30.290  37.315   2.097  1.00 50.90           O  \\nHETATM 1114  O   HOH A 203      36.649  53.205  15.444  1.00 50.94           O  \\nHETATM 1115  O   HOH A 204      39.838  37.684   1.374  1.00 55.90           O  \\nHETATM 1116  O   HOH A 205      38.677  22.618  10.243  1.00 55.54           O  \\nHETATM 1117  O   HOH A 206      35.313  21.009   9.026  1.00 67.16           O  \\nHETATM 1118  O   HOH A 207      46.674  25.557  10.445  1.00 57.98           O  \\nHETATM 1119  O   HOH A 208      52.371  31.422  25.856  1.00 52.46           O  \\nHETATM 1120  O   HOH A 209      48.032  27.106  40.293  1.00 43.30           O  \\nHETATM 1121  O   HOH A 210      56.608  40.738  35.434  1.00 54.13           O  \\nHETATM 1122  O   HOH A 211      33.205  26.406  35.788  1.00 63.54           O  \\nHETATM 1123  O   HOH A 212      29.234  47.657  32.231  1.00 41.22           O  \\nHETATM 1124  O   HOH A 213      46.802  44.695   8.975  1.00 48.32           O  \\nHETATM 1125  O   HOH A 214      53.596  49.218  16.249  1.00 73.45           O  \\nHETATM 1126  O   HOH A 215      32.346  24.399  27.898  1.00 40.20           O  \\nHETATM 1127  O   HOH A 216      41.164  56.842   5.360  1.00 44.94           O  \\nHETATM 1128  O   HOH A 217      47.408  34.053  10.598  1.00 51.62           O  \\nHETATM 1129  O   HOH A 218      44.979  32.067  42.084  1.00 52.74           O  \\nHETATM 1130  O   HOH A 219      27.532  40.972   6.997  1.00 63.43           O  \\nHETATM 1131  O   HOH A 220      35.738  28.722  38.494  1.00 43.37           O  \\nHETATM 1132  O   HOH A 221      25.386  39.507  30.001  1.00 54.29           O  \\nHETATM 1133  O   HOH A 222      34.311  27.464   3.780  1.00 44.60           O  \\nHETATM 1134  O   HOH A 223      50.613  33.594  21.911  1.00 38.89           O  \\nHETATM 1135  O   HOH A 224      39.789  34.054  38.678  1.00 44.91           O  \\nHETATM 1136  O   HOH A 225      39.373  36.275  35.797  1.00 40.70           O  \\nHETATM 1137  O   HOH A 226      24.449  30.637  24.318  1.00 49.23           O  \\nHETATM 1138  O   HOH A 227      36.385  31.881  39.673  1.00 46.21           O  \\nHETATM 1139  O   HOH A 228      22.724  32.719  25.222  1.00 63.16           O  \\nHETATM 1140  O   HOH A 229      28.016  27.288  11.824  1.00 26.02           O  \\nHETATM 1141  O   HOH A 230      35.986  51.649  18.787  1.00 56.77           O  \\nHETATM 1142  O   HOH A 231      47.921  36.396  13.846  1.00 58.72           O  \\nHETATM 1143  O   HOH A 232      35.793  51.622   5.105  1.00 74.45           O  \\nHETATM 1144  O   HOH A 233      47.283  29.645  16.652  1.00 38.97           O  \\nHETATM 1145  O   HOH A 234      50.606  28.923  14.105  1.00 68.81           O  \\nHETATM 1146  O   HOH A 235      40.743  20.028  12.770  1.00 49.94           O  \\nHETATM 1147  O   HOH A 236      40.974  30.394   6.052  1.00 28.38           O  \\nHETATM 1148  O   HOH A 237      37.422  30.358   3.256  1.00 38.28           O  \\nHETATM 1149  O   HOH A 238      24.619  37.527  13.027  1.00 17.78           O  \\nHETATM 1150  O   HOH A 239      36.019  22.147  28.080  1.00 33.75           O  \\nHETATM 1151  O   HOH A 240      30.422  26.031  14.322  1.00 70.01           O  \\nHETATM 1152  O   HOH A 241      47.806  54.316  10.948  1.00 29.81           O  \\nHETATM 1153  O   HOH A 242      35.610  48.903  33.703  1.00 46.20           O  \\nHETATM 1154  O   HOH A 243      48.198  36.379  20.430  1.00 72.71           O  \\nHETATM 1155  O   HOH A 244      46.009  39.902  21.612  1.00 62.02           O  \\nHETATM 1156  O   HOH A 245      35.934  45.940  35.267  1.00 44.04           O  \\nHETATM 1157  O   HOH A 246      34.148  44.122  34.308  1.00 40.52           O  \\nHETATM 1158  O   HOH A 247      36.685  44.061  36.384  1.00 74.76           O  \\nHETATM 1159  O   HOH A 248      33.772  41.949  39.092  1.00 70.07           O  \\nHETATM 1160  O   HOH A 249      47.689  41.322  22.332  1.00 34.09           O  \\nCONECT   53  988                                                                \\nCONECT  228  895                                                                \\nCONECT  510  623                                                                \\nCONECT  594  729                                                                \\nCONECT  623  510                                                                \\nCONECT  729  594                                                                \\nCONECT  895  228                                                                \\nCONECT  988   53                                                                \\nCONECT 1001 1002 1012 1025                                                      \\nCONECT 1002 1001 1003 1009                                                      \\nCONECT 1003 1002 1004 1010                                                      \\nCONECT 1004 1003 1005 1011                                                      \\nCONECT 1005 1004 1006 1012                                                      \\nCONECT 1006 1005 1013                                                           \\nCONECT 1007 1008 1009 1014                                                      \\nCONECT 1008 1007                                                                \\nCONECT 1009 1002 1007                                                           \\nCONECT 1010 1003                                                                \\nCONECT 1011 1004                                                                \\nCONECT 1012 1001 1005                                                           \\nCONECT 1013 1006                                                                \\nCONECT 1014 1007                                                                \\nCONECT 1015 1016 1026 1039                                                      \\nCONECT 1016 1015 1017 1023                                                      \\nCONECT 1017 1016 1018 1024                                                      \\nCONECT 1018 1017 1019 1025                                                      \\nCONECT 1019 1018 1020 1026                                                      \\nCONECT 1020 1019 1027                                                           \\nCONECT 1021 1022 1023 1028                                                      \\nCONECT 1022 1021                                                                \\nCONECT 1023 1016 1021                                                           \\nCONECT 1024 1017                                                                \\nCONECT 1025 1001 1018                                                           \\nCONECT 1026 1015 1019                                                           \\nCONECT 1027 1020                                                                \\nCONECT 1028 1021                                                                \\nCONECT 1029 1030 1037 1043                                                      \\nCONECT 1030 1029 1031 1042                                                      \\nCONECT 1031 1030 1032 1038                                                      \\nCONECT 1032 1031 1033 1039                                                      \\nCONECT 1033 1032 1034 1037                                                      \\nCONECT 1034 1033 1040                                                           \\nCONECT 1035 1036 1041 1042                                                      \\nCONECT 1036 1035                                                                \\nCONECT 1037 1029 1033                                                           \\nCONECT 1038 1031                                                                \\nCONECT 1039 1015 1032                                                           \\nCONECT 1040 1034                                                                \\nCONECT 1041 1035                                                                \\nCONECT 1042 1030 1035                                                           \\nCONECT 1043 1029                                                                \\nMASTER      330    0    3    8    2    0    8    6 1159    1   51   10          \\nEND                                                                             \\n\",\"pdb\");\n",
       "\tviewergrid_151451551001[0][1].setStyle({\"cartoon\": {\"color\": \"spectrum\"}});\n",
       "\tviewergrid_151451551001[0][1].setStyle({\"hetflag\": true},{\"stick\": {}});\n",
       "\tviewergrid_151451551001[0][1].zoomTo();\n",
       "\tviewergrid_151451551001[0][0].rotate(-100,\"y\");\n",
       "\tviewergrid_151451551001[0][1].rotate(-100,\"y\");\n",
       "\tviewergrid_151451551001[0][0].rotate(-20,\"x\");\n",
       "\tviewergrid_151451551001[0][1].rotate(-20,\"x\");\n",
       "viewergrid_151451551001[0][1].render();\n",
       "viewergrid_151451551001[0][0].render();\n",
       "});\n",
       "</script>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "view = py3Dmol.view(width=900, height=400, viewergrid=(1,2))\n",
    "with open('without_ligand.B99990001.pdb', 'r') as pdbfile:\n",
    "    view.addModel(pdbfile.read(), 'pdb', viewer=(0,0))\n",
    "    view.setStyle({'cartoon': {'color':'spectrum'}}, viewer=(0,0))\n",
    "    view.zoomTo(viewer=(0,0))\n",
    "    view.zoom(1.25, viewer=(0,0))\n",
    "with open('1lmp.pdb', 'r') as pdbfile:\n",
    "    view.addModel(pdbfile.read(), 'pdb', viewer=(0,1))\n",
    "    view.setStyle({'cartoon': {'color':'spectrum'}}, viewer=(0,1))\n",
    "    view.setStyle({'hetflag': True}, {'stick':{}}, viewer=(0,1))\n",
    "    view.zoomTo(viewer=(0,1))\n",
    "    \n",
    "view.rotate(-100,'y');\n",
    "view.rotate(-20,'x');\n",
    "view.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Для того, чтобы лиганд отображался и вместе с нашим белком, добавим три последних остатка в выравнивание "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "[Residue 130:A (type NAG), Residue 131:A (type NAG), Residue 132:A (type NDG)]\n"
     ]
    }
   ],
   "source": [
    "## Получить список остаков\n",
    "print(alignm[1].residues[129:132])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\r\n",
      ">P1;without_ligand\r\n",
      "sequence::     : :     : :::-1.00:-1.00\r\n",
      "MRSLLILVLCFLPLAAPGKVYGRCELAAAMKRMGLDNYRGYSLGNWVCAAKFESNFNTGATNRNTDGSTDYGILQ\r\n",
      "INSRWWCNDGRTPGSKNLCHIPCSALLSSDITASVNCAKKIVSDGNGMNAWVAWRKHCKGTDVNVWIRGCRL---*\r\n",
      "\r\n",
      ">P1;1lmp\r\n",
      "structureX:1lmp.pdb:   1 :A:+132 :A:MOL_ID  1; MOLECULE  LYSOZYME; CHAIN  A; SYNONYM  MUCOPEPTIDE N-ACETYLMURAMYLHYDROLASE; EC  3.2.1.17:MOL_ID  1; ORGANISM_SCIENTIFIC  ONCORHYNCHUS MYKISS; ORGANISM_COMMON  RAINBOW TROUT; ORGANISM_TAXID  8022; ORGAN  KIDNEY: 2.00: 0.16\r\n",
      "------------------KVYDRCELARALKASGMDGYAGNSLPNWVCLSKWESSYNTQATNRNTDGSTDYGIFQ\r\n",
      "INSRYWCDDGRTPGAKNVCGIRCSQLLTDDLTVAIRCAKRVVLDPNGIGAWVAWRLHCQNQDLRSYVAGCGV...*\r\n",
      "\r\n",
      ">P1;with_ligand\r\n",
      "sequence::1    : :+150 : :undefined:undefined:-1.00:-1.00\r\n",
      "MRSLLILVLCFLPLAAPGKVYGRCELAAAMKRMGLDNYRGYSLGNWVCAAKFESNFNTGATNRNTDGSTDYGILQ\r\n",
      "INSRWWCNDGRTPGSKNLCHIPCSALLSSDITASVNCAKKIVSDGNGMNAWVAWRKHCKGTDVNVWIRGCRL...*\r\n"
     ]
    }
   ],
   "source": [
    "seq_with_ligand = ''.join(i.code for i in alignm[0].residues) + '...'    # Припишем точки -- обозначение лиганда\n",
    "alignm.append_sequence(seq_with_ligand)                         # Добавим в объект выравнивание посл-ть из строки\n",
    "pdb = alignm[1]                                                 # Выбираем объекты для выравнивания \n",
    "s   = alignm[2]                                                   \n",
    "s.code = 'with_ligand'\n",
    "\n",
    "alignm.salign()\n",
    "alignm.write(file='all_in_one_ligand.ali', alignment_format='PIR')\n",
    "! cat 'all_in_one_ligand.ali'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "with_ligand 1lmp\n",
      "The following 1 residues contain 6-membered rings with poor geometries\n",
      "after transfer from templates. Rebuilding rings from internal coordinates:\n",
      "   <Residue 52 (type PHE)>\n",
      "43 atoms in HETATM/BLK residues constrained\n",
      "to protein atoms within 2.30 angstroms\n",
      "and protein CA atoms within 10.00 angstroms\n",
      "43 atoms in residues without defined topology\n",
      "constrained to be rigid bodies\n",
      "\n",
      ">> Summary of successfully produced models:\n",
      "Filename                          molpdf\n",
      "----------------------------------------\n",
      "with_ligand.B99990001.pdb      856.06525\n",
      "with_ligand.B99990002.pdb      853.56006\n",
      "\n"
     ]
    }
   ],
   "source": [
    "print(s.code, pdb.code)\n",
    "\n",
    "## Создаем объект automodel\n",
    "a2 = modeller.automodel.automodel(env, alnfile='all_in_one_ligand.ali', knowns= pdb.code , sequence = s.code )\n",
    "\n",
    "a2.name='mod' + s.code\n",
    "a2.starting_model = 1\n",
    "a2.ending_model   = 2\n",
    "a2.make()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div id=\"3dmolviewer_151451555764\"  style=\"position: relative; width: 900px; height: 400px\">\n",
       "<script>\n",
       "if(typeof $3Dmolpromise === 'undefined') $3Dmolpromise = $.when($.getScript('https://3dmol.csb.pitt.edu/build/3Dmol.js'))\n",
       "var viewer_151451555764 = null;\n",
       "$3Dmolpromise.done(function() {\n",
       "var viewergrid_151451555764 = null;\n",
       "viewergrid_151451555764 = $3Dmol.createViewerGrid($(\"#3dmolviewer_151451555764\"),{rows: 1, cols: 2, control_all: true},{backgroundColor:\"white\"});\n",
       "viewer_151451555764 = viewergrid_151451555764[0][0];\n",
       "\tviewergrid_151451555764[0][0].addModel(\"EXPDTA    THEORETICAL MODEL, MODELLER 9.19 2017/12/29 05:45:31\\nREMARK   6 MODELLER OBJECTIVE FUNCTION:       856.0652\\nREMARK   6 MODELLER BEST TEMPLATE % SEQ ID:  62.879\\nREMARK   6 SEQUENCE: with_ligand\\nREMARK   6 ALIGNMENT: all_in_one_ligand.ali\\nREMARK   6 TEMPLATE: 1lmp 1:A - 132:A MODELS 19: - 150: AT 60.6%\\nREMARK   6 MODELLER BLK RESIDUE  148:\\nREMARK   6 MODELLER BLK RESIDUE  149:\\nREMARK   6 MODELLER BLK RESIDUE  150:\\nSSBOND   1 CYS     24    CYS    145                          1555   1555  2.04\\nSSBOND   2 CYS     48    CYS    133                          1555   1555  2.02\\nSSBOND   3 CYS     82    CYS     98                          1555   1555  2.04\\nSSBOND   4 CYS     94    CYS    112                          1555   1555  2.03\\nATOM      1  N   MET     1      53.754  12.903  41.828  1.00 39.11           N\\nATOM      2  CA  MET     1      55.013  13.450  42.375  1.00 39.11           C\\nATOM      3  CB  MET     1      55.174  14.941  42.037  1.00 39.11           C\\nATOM      4  CG  MET     1      55.319  15.265  40.552  1.00 39.11           C\\nATOM      5  SD  MET     1      55.508  17.047  40.249  1.00 39.11           S\\nATOM      6  CE  MET     1      57.276  17.105  40.662  1.00 39.11           C\\nATOM      7  C   MET     1      55.058  13.331  43.862  1.00 39.11           C\\nATOM      8  O   MET     1      54.360  12.516  44.463  1.00 39.11           O\\nATOM      9  N   ARG     2      55.900  14.169  44.489  1.00240.59           N\\nATOM     10  CA  ARG     2      56.097  14.110  45.909  1.00240.59           C\\nATOM     11  CB  ARG     2      57.371  14.844  46.376  1.00240.59           C\\nATOM     12  CG  ARG     2      57.623  14.737  47.883  1.00240.59           C\\nATOM     13  CD  ARG     2      58.909  15.420  48.360  1.00240.59           C\\nATOM     14  NE  ARG     2      58.936  15.325  49.846  1.00240.59           N\\nATOM     15  CZ  ARG     2      59.421  14.201  50.447  1.00240.59           C\\nATOM     16  NH1 ARG     2      59.861  13.153  49.691  1.00240.59           N\\nATOM     17  NH2 ARG     2      59.459  14.130  51.810  1.00240.59           N\\nATOM     18  C   ARG     2      54.917  14.714  46.605  1.00240.59           C\\nATOM     19  O   ARG     2      54.270  15.627  46.093  1.00240.59           O\\nATOM     20  N   SER     3      54.598  14.190  47.809  1.00 67.77           N\\nATOM     21  CA  SER     3      53.481  14.718  48.535  1.00 67.77           C\\nATOM     22  CB  SER     3      53.120  13.922  49.810  1.00 67.77           C\\nATOM     23  OG  SER     3      54.149  14.010  50.781  1.00 67.77           O\\nATOM     24  C   SER     3      53.810  16.116  48.922  1.00 67.77           C\\nATOM     25  O   SER     3      53.001  17.026  48.748  1.00 67.77           O\\nATOM     26  N   LEU     4      55.026  16.328  49.453  1.00234.49           N\\nATOM     27  CA  LEU     4      55.376  17.665  49.806  1.00234.49           C\\nATOM     28  CB  LEU     4      56.603  17.766  50.727  1.00234.49           C\\nATOM     29  CG  LEU     4      56.400  17.062  52.079  1.00234.49           C\\nATOM     30  CD1 LEU     4      56.263  15.546  51.881  1.00234.49           C\\nATOM     31  CD2 LEU     4      57.495  17.435  53.090  1.00234.49           C\\nATOM     32  C   LEU     4      55.704  18.359  48.533  1.00234.49           C\\nATOM     33  O   LEU     4      56.277  17.770  47.618  1.00234.49           O\\nATOM     34  N   LEU     5      55.321  19.642  48.445  1.00190.23           N\\nATOM     35  CA  LEU     5      55.624  20.393  47.272  1.00190.23           C\\nATOM     36  CB  LEU     5      54.953  21.768  47.212  1.00190.23           C\\nATOM     37  CG  LEU     5      53.429  21.668  47.152  1.00190.23           C\\nATOM     38  CD1 LEU     5      52.788  23.040  46.891  1.00190.23           C\\nATOM     39  CD2 LEU     5      53.006  20.615  46.126  1.00190.23           C\\nATOM     40  C   LEU     5      57.087  20.631  47.283  1.00190.23           C\\nATOM     41  O   LEU     5      57.735  20.617  48.328  1.00190.23           O\\nATOM     42  N   ILE     6      57.658  20.832  46.086  1.00165.34           N\\nATOM     43  CA  ILE     6      59.058  21.063  46.022  1.00165.34           C\\nATOM     44  CB  ILE     6      59.748  20.143  45.051  1.00165.34           C\\nATOM     45  CG1 ILE     6      61.284  20.214  45.180  1.00165.34           C\\nATOM     46  CG2 ILE     6      59.198  20.433  43.644  1.00165.34           C\\nATOM     47  CD1 ILE     6      61.911  21.565  44.824  1.00165.34           C\\nATOM     48  C   ILE     6      59.219  22.473  45.578  1.00165.34           C\\nATOM     49  O   ILE     6      58.585  22.918  44.622  1.00165.34           O\\nATOM     50  N   LEU     7      60.066  23.223  46.305  1.00195.14           N\\nATOM     51  CA  LEU     7      60.274  24.589  45.954  1.00195.14           C\\nATOM     52  CB  LEU     7      60.373  25.493  47.205  1.00195.14           C\\nATOM     53  CG  LEU     7      60.473  27.013  46.970  1.00195.14           C\\nATOM     54  CD1 LEU     7      60.446  27.763  48.313  1.00195.14           C\\nATOM     55  CD2 LEU     7      61.707  27.401  46.148  1.00195.14           C\\nATOM     56  C   LEU     7      61.555  24.628  45.192  1.00195.14           C\\nATOM     57  O   LEU     7      62.641  24.511  45.759  1.00195.14           O\\nATOM     58  N   VAL     8      61.435  24.775  43.860  1.00118.05           N\\nATOM     59  CA  VAL     8      62.548  24.871  42.967  1.00118.05           C\\nATOM     60  CB  VAL     8      62.980  23.547  42.406  1.00118.05           C\\nATOM     61  CG1 VAL     8      61.829  22.973  41.562  1.00118.05           C\\nATOM     62  CG2 VAL     8      64.273  23.753  41.607  1.00118.05           C\\nATOM     63  C   VAL     8      62.046  25.695  41.828  1.00118.05           C\\nATOM     64  O   VAL     8      60.837  25.877  41.689  1.00118.05           O\\nATOM     65  N   LEU     9      62.946  26.239  40.990  1.00187.12           N\\nATOM     66  CA  LEU     9      62.443  27.019  39.900  1.00187.12           C\\nATOM     67  CB  LEU     9      63.280  28.283  39.632  1.00187.12           C\\nATOM     68  CG  LEU     9      62.646  29.337  38.689  1.00187.12           C\\nATOM     69  CD1 LEU     9      63.626  30.495  38.446  1.00187.12           C\\nATOM     70  CD2 LEU     9      62.126  28.749  37.366  1.00187.12           C\\nATOM     71  C   LEU     9      62.534  26.153  38.687  1.00187.12           C\\nATOM     72  O   LEU     9      63.610  25.968  38.119  1.00187.12           O\\nATOM     73  N   CYS    10      61.392  25.586  38.262  1.00116.23           N\\nATOM     74  CA  CYS    10      61.424  24.767  37.093  1.00116.23           C\\nATOM     75  CB  CYS    10      61.963  23.353  37.368  1.00116.23           C\\nATOM     76  SG  CYS    10      60.952  22.447  38.577  1.00116.23           S\\nATOM     77  C   CYS    10      60.022  24.654  36.593  1.00116.23           C\\nATOM     78  O   CYS    10      59.075  24.656  37.378  1.00116.23           O\\nATOM     79  N   PHE    11      59.853  24.552  35.261  1.00274.42           N\\nATOM     80  CA  PHE    11      58.524  24.459  34.736  1.00274.42           C\\nATOM     81  CB  PHE    11      58.118  25.695  33.912  1.00274.42           C\\nATOM     82  CG  PHE    11      56.727  25.519  33.407  1.00274.42           C\\nATOM     83  CD1 PHE    11      55.652  25.708  34.244  1.00274.42           C\\nATOM     84  CD2 PHE    11      56.500  25.183  32.091  1.00274.42           C\\nATOM     85  CE1 PHE    11      54.365  25.557  33.784  1.00274.42           C\\nATOM     86  CE2 PHE    11      55.216  25.031  31.625  1.00274.42           C\\nATOM     87  CZ  PHE    11      54.149  25.217  32.471  1.00274.42           C\\nATOM     88  C   PHE    11      58.476  23.275  33.834  1.00274.42           C\\nATOM     89  O   PHE    11      59.451  22.944  33.160  1.00274.42           O\\nATOM     90  N   LEU    12      57.327  22.577  33.823  1.00242.87           N\\nATOM     91  CA  LEU    12      57.197  21.454  32.943  1.00242.87           C\\nATOM     92  CB  LEU    12      56.743  20.176  33.678  1.00242.87           C\\nATOM     93  CG  LEU    12      56.927  18.858  32.900  1.00242.87           C\\nATOM     94  CD1 LEU    12      56.359  17.670  33.694  1.00242.87           C\\nATOM     95  CD2 LEU    12      56.387  18.932  31.465  1.00242.87           C\\nATOM     96  C   LEU    12      56.102  21.854  32.011  1.00242.87           C\\nATOM     97  O   LEU    12      55.098  22.411  32.452  1.00242.87           O\\nATOM     98  N   PRO    13      56.247  21.610  30.742  1.00174.96           N\\nATOM     99  CA  PRO    13      55.207  22.038  29.860  1.00174.96           C\\nATOM    100  CD  PRO    13      57.550  21.639  30.096  1.00174.96           C\\nATOM    101  CB  PRO    13      55.764  21.870  28.448  1.00174.96           C\\nATOM    102  CG  PRO    13      57.280  22.075  28.645  1.00174.96           C\\nATOM    103  C   PRO    13      53.964  21.278  30.150  1.00174.96           C\\nATOM    104  O   PRO    13      54.053  20.111  30.526  1.00174.96           O\\nATOM    105  N   LEU    14      52.796  21.932  30.029  1.00246.88           N\\nATOM    106  CA  LEU    14      51.584  21.238  30.319  1.00246.88           C\\nATOM    107  CB  LEU    14      50.840  21.831  31.530  1.00246.88           C\\nATOM    108  CG  LEU    14      49.626  21.031  32.050  1.00246.88           C\\nATOM    109  CD1 LEU    14      49.053  21.699  33.306  1.00246.88           C\\nATOM    110  CD2 LEU    14      48.531  20.834  30.986  1.00246.88           C\\nATOM    111  C   LEU    14      50.719  21.362  29.115  1.00246.88           C\\nATOM    112  O   LEU    14      50.582  22.436  28.531  1.00246.88           O\\nATOM    113  N   ALA    15      50.112  20.235  28.712  1.00275.87           N\\nATOM    114  CA  ALA    15      49.211  20.251  27.606  1.00275.87           C\\nATOM    115  CB  ALA    15      49.672  19.351  26.451  1.00275.87           C\\nATOM    116  C   ALA    15      47.930  19.706  28.139  1.00275.87           C\\nATOM    117  O   ALA    15      47.935  18.808  28.979  1.00275.87           O\\nATOM    118  N   ALA    16      46.789  20.254  27.683  1.00248.69           N\\nATOM    119  CA  ALA    16      45.538  19.784  28.193  1.00248.69           C\\nATOM    120  CB  ALA    16      44.727  20.860  28.932  1.00248.69           C\\nATOM    121  C   ALA    16      44.712  19.331  27.038  1.00248.69           C\\nATOM    122  O   ALA    16      44.832  19.804  25.909  1.00248.69           O\\nATOM    123  N   PRO    17      43.889  18.373  27.345  1.00174.17           N\\nATOM    124  CA  PRO    17      42.996  17.854  26.353  1.00174.17           C\\nATOM    125  CD  PRO    17      44.261  17.369  28.329  1.00174.17           C\\nATOM    126  CB  PRO    17      42.460  16.546  26.925  1.00174.17           C\\nATOM    127  CG  PRO    17      43.590  16.070  27.859  1.00174.17           C\\nATOM    128  C   PRO    17      41.947  18.883  26.076  1.00174.17           C\\nATOM    129  O   PRO    17      41.609  19.641  26.985  1.00174.17           O\\nATOM    130  N   GLY    18      41.427  18.947  24.836  1.00107.06           N\\nATOM    131  CA  GLY    18      40.427  19.937  24.549  1.00107.06           C\\nATOM    132  C   GLY    18      40.079  19.848  23.096  1.00107.06           C\\nATOM    133  O   GLY    18      40.835  19.287  22.305  1.00107.06           O\\nATOM    134  N   LYS    19      38.917  20.426  22.731  1.00192.43           N\\nATOM    135  CA  LYS    19      38.421  20.388  21.385  1.00192.43           C\\nATOM    136  CB  LYS    19      36.952  20.823  21.252  1.00192.43           C\\nATOM    137  CG  LYS    19      36.385  20.725  19.829  1.00192.43           C\\nATOM    138  CD  LYS    19      34.889  21.060  19.756  1.00192.43           C\\nATOM    139  CE  LYS    19      34.223  20.772  18.404  1.00192.43           C\\nATOM    140  NZ  LYS    19      32.763  21.044  18.466  1.00192.43           N\\nATOM    141  C   LYS    19      39.201  21.344  20.556  1.00192.43           C\\nATOM    142  O   LYS    19      39.432  22.487  20.950  1.00192.43           O\\nATOM    143  N   VAL    20      39.621  20.885  19.360  1.00 63.55           N\\nATOM    144  CA  VAL    20      40.288  21.767  18.456  1.00 63.55           C\\nATOM    145  CB  VAL    20      41.437  21.122  17.726  1.00 63.55           C\\nATOM    146  CG1 VAL    20      42.039  22.131  16.727  1.00 63.55           C\\nATOM    147  CG2 VAL    20      42.436  20.593  18.774  1.00 63.55           C\\nATOM    148  C   VAL    20      39.236  22.148  17.463  1.00 63.55           C\\nATOM    149  O   VAL    20      38.705  21.301  16.745  1.00 63.55           O\\nATOM    150  N   TYR    21      38.903  23.449  17.417  1.00 86.17           N\\nATOM    151  CA  TYR    21      37.867  23.963  16.565  1.00 86.17           C\\nATOM    152  CB  TYR    21      37.240  25.284  17.048  1.00 86.17           C\\nATOM    153  CG  TYR    21      36.209  24.982  18.080  1.00 86.17           C\\nATOM    154  CD1 TYR    21      36.511  24.747  19.404  1.00 86.17           C\\nATOM    155  CD2 TYR    21      34.892  24.940  17.692  1.00 86.17           C\\nATOM    156  CE1 TYR    21      35.504  24.474  20.307  1.00 86.17           C\\nATOM    157  CE2 TYR    21      33.889  24.668  18.593  1.00 86.17           C\\nATOM    158  CZ  TYR    21      34.187  24.432  19.911  1.00 86.17           C\\nATOM    159  OH  TYR    21      33.152  24.148  20.833  1.00 86.17           O\\nATOM    160  C   TYR    21      38.358  24.233  15.181  1.00 86.17           C\\nATOM    161  O   TYR    21      39.503  24.628  14.969  1.00 86.17           O\\nATOM    162  N   GLY    22      37.473  23.978  14.195  1.00 27.83           N\\nATOM    163  CA  GLY    22      37.756  24.336  12.837  1.00 27.83           C\\nATOM    164  C   GLY    22      37.512  25.813  12.767  1.00 27.83           C\\nATOM    165  O   GLY    22      36.765  26.362  13.576  1.00 27.83           O\\nATOM    166  N   ARG    23      38.111  26.502  11.778  1.00130.80           N\\nATOM    167  CA  ARG    23      38.011  27.934  11.711  1.00130.80           C\\nATOM    168  CB  ARG    23      38.805  28.505  10.518  1.00130.80           C\\nATOM    169  CG  ARG    23      38.664  30.019  10.326  1.00130.80           C\\nATOM    170  CD  ARG    23      39.529  30.559   9.180  1.00130.80           C\\nATOM    171  NE  ARG    23      39.271  29.696   7.993  1.00130.80           N\\nATOM    172  CZ  ARG    23      38.352  30.063   7.051  1.00130.80           C\\nATOM    173  NH1 ARG    23      37.796  31.309   7.077  1.00130.80           N\\nATOM    174  NH2 ARG    23      38.004  29.187   6.063  1.00130.80           N\\nATOM    175  C   ARG    23      36.588  28.377  11.571  1.00130.80           C\\nATOM    176  O   ARG    23      36.137  29.243  12.320  1.00130.80           O\\nATOM    177  N   CYS    24      35.840  27.803  10.606  1.00 53.04           N\\nATOM    178  CA  CYS    24      34.486  28.232  10.399  1.00 53.04           C\\nATOM    179  CB  CYS    24      33.869  27.831   9.049  1.00 53.04           C\\nATOM    180  SG  CYS    24      34.592  28.818   7.702  1.00 53.04           S\\nATOM    181  C   CYS    24      33.607  27.779  11.516  1.00 53.04           C\\nATOM    182  O   CYS    24      32.656  28.478  11.856  1.00 53.04           O\\nATOM    183  N   GLU    25      33.889  26.601  12.108  1.00 44.54           N\\nATOM    184  CA  GLU    25      33.043  26.114  13.163  1.00 44.54           C\\nATOM    185  CB  GLU    25      33.472  24.763  13.762  1.00 44.54           C\\nATOM    186  CG  GLU    25      32.509  24.344  14.874  1.00 44.54           C\\nATOM    187  CD  GLU    25      32.892  22.982  15.413  1.00 44.54           C\\nATOM    188  OE1 GLU    25      34.029  22.514  15.136  1.00 44.54           O\\nATOM    189  OE2 GLU    25      32.039  22.385  16.125  1.00 44.54           O\\nATOM    190  C   GLU    25      33.098  27.084  14.293  1.00 44.54           C\\nATOM    191  O   GLU    25      32.090  27.373  14.937  1.00 44.54           O\\nATOM    192  N   LEU    26      34.310  27.583  14.582  1.00118.55           N\\nATOM    193  CA  LEU    26      34.451  28.511  15.657  1.00118.55           C\\nATOM    194  CB  LEU    26      35.922  28.663  16.102  1.00118.55           C\\nATOM    195  CG  LEU    26      36.161  29.466  17.393  1.00118.55           C\\nATOM    196  CD1 LEU    26      37.553  29.160  17.955  1.00118.55           C\\nATOM    197  CD2 LEU    26      36.011  30.974  17.167  1.00118.55           C\\nATOM    198  C   LEU    26      33.775  29.798  15.283  1.00118.55           C\\nATOM    199  O   LEU    26      33.119  30.419  16.118  1.00118.55           O\\nATOM    200  N   ALA    27      33.862  30.206  13.998  1.00 42.04           N\\nATOM    201  CA  ALA    27      33.238  31.437  13.593  1.00 42.04           C\\nATOM    202  CB  ALA    27      33.429  31.769  12.104  1.00 42.04           C\\nATOM    203  C   ALA    27      31.761  31.344  13.856  1.00 42.04           C\\nATOM    204  O   ALA    27      31.154  32.297  14.341  1.00 42.04           O\\nATOM    205  N   ALA    28      31.148  30.183  13.550  1.00 32.71           N\\nATOM    206  CA  ALA    28      29.734  29.989  13.733  1.00 32.71           C\\nATOM    207  CB  ALA    28      29.270  28.604  13.248  1.00 32.71           C\\nATOM    208  C   ALA    28      29.370  30.080  15.190  1.00 32.71           C\\nATOM    209  O   ALA    28      28.379  30.714  15.544  1.00 32.71           O\\nATOM    210  N   ALA    29      30.164  29.451  16.075  1.00 32.64           N\\nATOM    211  CA  ALA    29      29.861  29.428  17.480  1.00 32.64           C\\nATOM    212  CB  ALA    29      30.867  28.588  18.291  1.00 32.64           C\\nATOM    213  C   ALA    29      29.903  30.827  18.021  1.00 32.64           C\\nATOM    214  O   ALA    29      29.079  31.207  18.853  1.00 32.64           O\\nATOM    215  N   MET    30      30.901  31.620  17.584  1.00 67.62           N\\nATOM    216  CA  MET    30      31.078  32.977  18.034  1.00 67.62           C\\nATOM    217  CB  MET    30      32.353  33.628  17.473  1.00 67.62           C\\nATOM    218  CG  MET    30      33.638  33.110  18.105  1.00 67.62           C\\nATOM    219  SD  MET    30      35.143  33.924  17.499  1.00 67.62           S\\nATOM    220  CE  MET    30      36.121  33.485  18.964  1.00 67.62           C\\nATOM    221  C   MET    30      29.939  33.832  17.587  1.00 67.62           C\\nATOM    222  O   MET    30      29.423  34.647  18.353  1.00 67.62           O\\nATOM    223  N   LYS    31      29.511  33.670  16.322  1.00 44.88           N\\nATOM    224  CA  LYS    31      28.463  34.507  15.825  1.00 44.88           C\\nATOM    225  CB  LYS    31      28.169  34.335  14.321  1.00 44.88           C\\nATOM    226  CG  LYS    31      27.144  35.365  13.835  1.00 44.88           C\\nATOM    227  CD  LYS    31      27.086  35.569  12.321  1.00 44.88           C\\nATOM    228  CE  LYS    31      26.200  36.752  11.919  1.00 44.88           C\\nATOM    229  NZ  LYS    31      26.291  36.991  10.461  1.00 44.88           N\\nATOM    230  C   LYS    31      27.208  34.225  16.587  1.00 44.88           C\\nATOM    231  O   LYS    31      26.465  35.145  16.921  1.00 44.88           O\\nATOM    232  N   ARG    32      26.932  32.945  16.892  1.00115.12           N\\nATOM    233  CA  ARG    32      25.722  32.616  17.594  1.00115.12           C\\nATOM    234  CB  ARG    32      25.485  31.106  17.745  1.00115.12           C\\nATOM    235  CG  ARG    32      25.054  30.454  16.428  1.00115.12           C\\nATOM    236  CD  ARG    32      24.805  28.949  16.512  1.00115.12           C\\nATOM    237  NE  ARG    32      23.430  28.737  17.040  1.00115.12           N\\nATOM    238  CZ  ARG    32      22.368  28.707  16.185  1.00115.12           C\\nATOM    239  NH1 ARG    32      22.550  28.943  14.852  1.00115.12           N\\nATOM    240  NH2 ARG    32      21.122  28.440  16.673  1.00115.12           N\\nATOM    241  C   ARG    32      25.741  33.221  18.968  1.00115.12           C\\nATOM    242  O   ARG    32      24.708  33.675  19.457  1.00115.12           O\\nATOM    243  N   MET    33      26.923  33.241  19.609  1.00178.99           N\\nATOM    244  CA  MET    33      27.157  33.698  20.955  1.00178.99           C\\nATOM    245  CB  MET    33      28.526  33.304  21.522  1.00178.99           C\\nATOM    246  CG  MET    33      28.693  31.792  21.733  1.00178.99           C\\nATOM    247  SD  MET    33      27.446  31.006  22.801  1.00178.99           S\\nATOM    248  CE  MET    33      28.060  31.609  24.402  1.00178.99           C\\nATOM    249  C   MET    33      26.995  35.189  21.102  1.00178.99           C\\nATOM    250  O   MET    33      26.921  35.678  22.228  1.00178.99           O\\nATOM    251  N   GLY    34      27.040  35.958  19.994  1.00 36.28           N\\nATOM    252  CA  GLY    34      26.825  37.379  20.100  1.00 36.28           C\\nATOM    253  C   GLY    34      28.136  38.100  20.109  1.00 36.28           C\\nATOM    254  O   GLY    34      28.212  39.262  20.508  1.00 36.28           O\\nATOM    255  N   LEU    35      29.211  37.406  19.688  1.00 67.55           N\\nATOM    256  CA  LEU    35      30.539  37.951  19.611  1.00 67.55           C\\nATOM    257  CB  LEU    35      31.636  36.878  19.410  1.00 67.55           C\\nATOM    258  CG  LEU    35      31.796  35.883  20.586  1.00 67.55           C\\nATOM    259  CD1 LEU    35      32.970  34.918  20.344  1.00 67.55           C\\nATOM    260  CD2 LEU    35      31.881  36.607  21.943  1.00 67.55           C\\nATOM    261  C   LEU    35      30.646  38.973  18.506  1.00 67.55           C\\nATOM    262  O   LEU    35      31.484  39.869  18.572  1.00 67.55           O\\nATOM    263  N   ASP    36      29.848  38.841  17.428  1.00 86.64           N\\nATOM    264  CA  ASP    36      29.859  39.787  16.338  1.00 86.64           C\\nATOM    265  CB  ASP    36      28.776  39.442  15.284  1.00 86.64           C\\nATOM    266  CG  ASP    36      28.661  40.457  14.137  1.00 86.64           C\\nATOM    267  OD1 ASP    36      29.383  41.486  14.154  1.00 86.64           O\\nATOM    268  OD2 ASP    36      27.825  40.205  13.227  1.00 86.64           O\\nATOM    269  C   ASP    36      29.517  41.144  16.894  1.00 86.64           C\\nATOM    270  O   ASP    36      28.404  41.369  17.366  1.00 86.64           O\\nATOM    271  N   ASN    37      30.480  42.087  16.806  1.00103.92           N\\nATOM    272  CA  ASN    37      30.402  43.468  17.216  1.00103.92           C\\nATOM    273  CB  ASN    37      29.295  44.273  16.496  1.00103.92           C\\nATOM    274  CG  ASN    37      29.651  45.756  16.571  1.00103.92           C\\nATOM    275  OD1 ASN    37      28.786  46.624  16.694  1.00103.92           O\\nATOM    276  ND2 ASN    37      30.974  46.050  16.466  1.00103.92           N\\nATOM    277  C   ASN    37      30.228  43.622  18.702  1.00103.92           C\\nATOM    278  O   ASN    37      29.681  44.629  19.148  1.00103.92           O\\nATOM    279  N   TYR    38      30.736  42.674  19.521  1.00125.86           N\\nATOM    280  CA  TYR    38      30.610  42.830  20.946  1.00125.86           C\\nATOM    281  CB  TYR    38      30.910  41.528  21.724  1.00125.86           C\\nATOM    282  CG  TYR    38      30.537  41.702  23.160  1.00125.86           C\\nATOM    283  CD1 TYR    38      31.437  42.206  24.069  1.00125.86           C\\nATOM    284  CD2 TYR    38      29.276  41.367  23.602  1.00125.86           C\\nATOM    285  CE1 TYR    38      31.090  42.362  25.390  1.00125.86           C\\nATOM    286  CE2 TYR    38      28.920  41.519  24.923  1.00125.86           C\\nATOM    287  CZ  TYR    38      29.831  42.017  25.822  1.00125.86           C\\nATOM    288  OH  TYR    38      29.466  42.171  27.178  1.00125.86           O\\nATOM    289  C   TYR    38      31.639  43.848  21.332  1.00125.86           C\\nATOM    290  O   TYR    38      32.818  43.698  21.012  1.00125.86           O\\nATOM    291  N   ARG    39      31.204  44.929  22.014  1.00115.07           N\\nATOM    292  CA  ARG    39      32.088  45.983  22.422  1.00115.07           C\\nATOM    293  CB  ARG    39      33.144  45.504  23.425  1.00115.07           C\\nATOM    294  CG  ARG    39      32.524  45.212  24.788  1.00115.07           C\\nATOM    295  CD  ARG    39      32.157  46.488  25.545  1.00115.07           C\\nATOM    296  NE  ARG    39      33.437  47.183  25.838  1.00115.07           N\\nATOM    297  CZ  ARG    39      33.449  48.366  26.516  1.00115.07           C\\nATOM    298  NH1 ARG    39      32.280  48.948  26.916  1.00115.07           N\\nATOM    299  NH2 ARG    39      34.651  48.949  26.792  1.00115.07           N\\nATOM    300  C   ARG    39      32.760  46.556  21.213  1.00115.07           C\\nATOM    301  O   ARG    39      33.843  47.136  21.303  1.00115.07           O\\nATOM    302  N   GLY    40      32.104  46.428  20.044  1.00 29.45           N\\nATOM    303  CA  GLY    40      32.595  47.036  18.840  1.00 29.45           C\\nATOM    304  C   GLY    40      33.646  46.203  18.165  1.00 29.45           C\\nATOM    305  O   GLY    40      34.399  46.731  17.349  1.00 29.45           O\\nATOM    306  N   TYR    41      33.738  44.889  18.458  1.00 60.03           N\\nATOM    307  CA  TYR    41      34.743  44.124  17.770  1.00 60.03           C\\nATOM    308  CB  TYR    41      35.610  43.238  18.681  1.00 60.03           C\\nATOM    309  CG  TYR    41      36.242  44.121  19.695  1.00 60.03           C\\nATOM    310  CD1 TYR    41      37.397  44.811  19.420  1.00 60.03           C\\nATOM    311  CD2 TYR    41      35.649  44.267  20.927  1.00 60.03           C\\nATOM    312  CE1 TYR    41      37.947  45.624  20.384  1.00 60.03           C\\nATOM    313  CE2 TYR    41      36.192  45.076  21.894  1.00 60.03           C\\nATOM    314  CZ  TYR    41      37.349  45.756  21.617  1.00 60.03           C\\nATOM    315  OH  TYR    41      37.922  46.595  22.596  1.00 60.03           O\\nATOM    316  C   TYR    41      34.037  43.173  16.854  1.00 60.03           C\\nATOM    317  O   TYR    41      33.246  42.342  17.294  1.00 60.03           O\\nATOM    318  N   SER    42      34.333  43.258  15.543  1.00 85.59           N\\nATOM    319  CA  SER    42      33.715  42.409  14.564  1.00 85.59           C\\nATOM    320  CB  SER    42      34.045  42.838  13.125  1.00 85.59           C\\nATOM    321  OG  SER    42      33.463  41.945  12.189  1.00 85.59           O\\nATOM    322  C   SER    42      34.236  41.014  14.761  1.00 85.59           C\\nATOM    323  O   SER    42      35.263  40.813  15.408  1.00 85.59           O\\nATOM    324  N   LEU    43      33.550  40.015  14.159  1.00192.26           N\\nATOM    325  CA  LEU    43      33.871  38.619  14.348  1.00192.26           C\\nATOM    326  CB  LEU    43      33.109  37.596  13.486  1.00192.26           C\\nATOM    327  CG  LEU    43      31.635  37.397  13.812  1.00192.26           C\\nATOM    328  CD1 LEU    43      31.438  37.074  15.298  1.00192.26           C\\nATOM    329  CD2 LEU    43      30.805  38.571  13.301  1.00192.26           C\\nATOM    330  C   LEU    43      35.268  38.306  13.936  1.00192.26           C\\nATOM    331  O   LEU    43      35.930  37.491  14.575  1.00192.26           O\\nATOM    332  N   GLY    44      35.745  38.919  12.843  1.00 41.83           N\\nATOM    333  CA  GLY    44      37.025  38.567  12.312  1.00 41.83           C\\nATOM    334  C   GLY    44      38.070  38.778  13.363  1.00 41.83           C\\nATOM    335  O   GLY    44      39.062  38.053  13.400  1.00 41.83           O\\nATOM    336  N   ASN    45      37.901  39.801  14.221  1.00 52.27           N\\nATOM    337  CA  ASN    45      38.865  40.097  15.247  1.00 52.27           C\\nATOM    338  CB  ASN    45      38.455  41.314  16.094  1.00 52.27           C\\nATOM    339  CG  ASN    45      38.494  42.542  15.204  1.00 52.27           C\\nATOM    340  OD1 ASN    45      39.534  42.889  14.645  1.00 52.27           O\\nATOM    341  ND2 ASN    45      37.321  43.214  15.062  1.00 52.27           N\\nATOM    342  C   ASN    45      38.981  38.926  16.183  1.00 52.27           C\\nATOM    343  O   ASN    45      40.081  38.521  16.562  1.00 52.27           O\\nATOM    344  N   TRP    46      37.826  38.364  16.578  1.00 78.25           N\\nATOM    345  CA  TRP    46      37.737  37.272  17.509  1.00 78.25           C\\nATOM    346  CB  TRP    46      36.283  36.966  17.934  1.00 78.25           C\\nATOM    347  CG  TRP    46      35.618  38.123  18.649  1.00 78.25           C\\nATOM    348  CD2 TRP    46      35.835  38.476  20.024  1.00 78.25           C\\nATOM    349  CD1 TRP    46      34.758  39.051  18.143  1.00 78.25           C\\nATOM    350  NE1 TRP    46      34.422  39.964  19.112  1.00 78.25           N\\nATOM    351  CE2 TRP    46      35.079  39.624  20.275  1.00 78.25           C\\nATOM    352  CE3 TRP    46      36.621  37.910  20.985  1.00 78.25           C\\nATOM    353  CZ2 TRP    46      35.103  40.229  21.498  1.00 78.25           C\\nATOM    354  CZ3 TRP    46      36.613  38.499  22.229  1.00 78.25           C\\nATOM    355  CH2 TRP    46      35.868  39.635  22.475  1.00 78.25           C\\nATOM    356  C   TRP    46      38.329  36.025  16.918  1.00 78.25           C\\nATOM    357  O   TRP    46      38.997  35.271  17.621  1.00 78.25           O\\nATOM    358  N   VAL    47      38.065  35.741  15.627  1.00 50.71           N\\nATOM    359  CA  VAL    47      38.601  34.549  15.028  1.00 50.71           C\\nATOM    360  CB  VAL    47      38.097  34.295  13.634  1.00 50.71           C\\nATOM    361  CG1 VAL    47      38.772  33.014  13.110  1.00 50.71           C\\nATOM    362  CG2 VAL    47      36.557  34.212  13.669  1.00 50.71           C\\nATOM    363  C   VAL    47      40.092  34.667  14.954  1.00 50.71           C\\nATOM    364  O   VAL    47      40.807  33.715  15.261  1.00 50.71           O\\nATOM    365  N   CYS    48      40.615  35.846  14.549  1.00107.43           N\\nATOM    366  CA  CYS    48      42.039  35.955  14.382  1.00107.43           C\\nATOM    367  CB  CYS    48      42.497  37.218  13.625  1.00107.43           C\\nATOM    368  SG  CYS    48      42.159  38.801  14.427  1.00107.43           S\\nATOM    369  C   CYS    48      42.773  35.814  15.685  1.00107.43           C\\nATOM    370  O   CYS    48      43.811  35.155  15.730  1.00107.43           O\\nATOM    371  N   ALA    49      42.275  36.410  16.782  1.00 42.57           N\\nATOM    372  CA  ALA    49      42.963  36.296  18.043  1.00 42.57           C\\nATOM    373  CB  ALA    49      42.331  37.150  19.153  1.00 42.57           C\\nATOM    374  C   ALA    49      42.974  34.868  18.519  1.00 42.57           C\\nATOM    375  O   ALA    49      43.966  34.406  19.085  1.00 42.57           O\\nATOM    376  N   ALA    50      41.863  34.129  18.327  1.00 41.78           N\\nATOM    377  CA  ALA    50      41.790  32.767  18.799  1.00 41.78           C\\nATOM    378  CB  ALA    50      40.418  32.099  18.575  1.00 41.78           C\\nATOM    379  C   ALA    50      42.817  31.952  18.084  1.00 41.78           C\\nATOM    380  O   ALA    50      43.474  31.100  18.680  1.00 41.78           O\\nATOM    381  N   LYS    51      42.983  32.199  16.771  1.00129.30           N\\nATOM    382  CA  LYS    51      43.904  31.449  15.975  1.00129.30           C\\nATOM    383  CB  LYS    51      43.815  31.868  14.497  1.00129.30           C\\nATOM    384  CG  LYS    51      44.487  30.879  13.549  1.00129.30           C\\nATOM    385  CD  LYS    51      45.993  30.752  13.754  1.00129.30           C\\nATOM    386  CE  LYS    51      46.630  29.684  12.871  1.00129.30           C\\nATOM    387  NZ  LYS    51      46.228  28.338  13.333  1.00129.30           N\\nATOM    388  C   LYS    51      45.316  31.649  16.467  1.00129.30           C\\nATOM    389  O   LYS    51      46.045  30.677  16.671  1.00129.30           O\\nATOM    390  N   PHE    52      45.750  32.915  16.668  1.00108.74           N\\nATOM    391  CA  PHE    52      47.111  33.169  17.066  1.00108.74           C\\nATOM    392  CB  PHE    52      47.546  34.642  17.048  1.00108.74           C\\nATOM    393  CG  PHE    52      49.004  34.589  17.362  1.00108.74           C\\nATOM    394  CD1 PHE    52      49.868  34.115  16.401  1.00108.74           C\\nATOM    395  CD2 PHE    52      49.517  34.995  18.571  1.00108.74           C\\nATOM    396  CE1 PHE    52      51.218  34.041  16.630  1.00108.74           C\\nATOM    397  CE2 PHE    52      50.870  34.928  18.812  1.00108.74           C\\nATOM    398  CZ  PHE    52      51.721  34.451  17.842  1.00108.74           C\\nATOM    399  C   PHE    52      47.354  32.721  18.464  1.00108.74           C\\nATOM    400  O   PHE    52      48.427  32.215  18.786  1.00108.74           O\\nATOM    401  N   GLU    53      46.376  32.976  19.341  1.00107.31           N\\nATOM    402  CA  GLU    53      46.531  32.674  20.730  1.00107.31           C\\nATOM    403  CB  GLU    53      45.426  33.321  21.581  1.00107.31           C\\nATOM    404  CG  GLU    53      45.439  34.855  21.550  1.00107.31           C\\nATOM    405  CD  GLU    53      46.506  35.371  22.508  1.00107.31           C\\nATOM    406  OE1 GLU    53      47.572  34.711  22.655  1.00107.31           O\\nATOM    407  OE2 GLU    53      46.260  36.451  23.107  1.00107.31           O\\nATOM    408  C   GLU    53      46.548  31.201  21.015  1.00107.31           C\\nATOM    409  O   GLU    53      47.378  30.736  21.794  1.00107.31           O\\nATOM    410  N   SER    54      45.649  30.407  20.400  1.00164.60           N\\nATOM    411  CA  SER    54      45.603  29.051  20.858  1.00164.60           C\\nATOM    412  CB  SER    54      44.396  28.854  21.765  1.00164.60           C\\nATOM    413  OG  SER    54      44.389  27.512  22.200  1.00164.60           O\\nATOM    414  C   SER    54      45.474  28.078  19.734  1.00164.60           C\\nATOM    415  O   SER    54      45.471  26.867  19.960  1.00164.60           O\\nATOM    416  N   ASN    55      45.414  28.562  18.482  1.00 74.61           N\\nATOM    417  CA  ASN    55      45.276  27.670  17.373  1.00 74.61           C\\nATOM    418  CB  ASN    55      46.433  26.672  17.290  1.00 74.61           C\\nATOM    419  CG  ASN    55      47.705  27.500  17.178  1.00 74.61           C\\nATOM    420  OD1 ASN    55      47.666  28.664  16.782  1.00 74.61           O\\nATOM    421  ND2 ASN    55      48.862  26.891  17.547  1.00 74.61           N\\nATOM    422  C   ASN    55      43.988  26.915  17.518  1.00 74.61           C\\nATOM    423  O   ASN    55      43.878  25.757  17.113  1.00 74.61           O\\nATOM    424  N   PHE    56      42.965  27.592  18.071  1.00 93.98           N\\nATOM    425  CA  PHE    56      41.624  27.094  18.227  1.00 93.98           C\\nATOM    426  CB  PHE    56      40.977  26.656  16.901  1.00 93.98           C\\nATOM    427  CG  PHE    56      40.953  27.846  16.015  1.00 93.98           C\\nATOM    428  CD1 PHE    56      39.988  28.820  16.139  1.00 93.98           C\\nATOM    429  CD2 PHE    56      41.918  27.980  15.047  1.00 93.98           C\\nATOM    430  CE1 PHE    56      39.998  29.914  15.304  1.00 93.98           C\\nATOM    431  CE2 PHE    56      41.934  29.070  14.209  1.00 93.98           C\\nATOM    432  CZ  PHE    56      40.971  30.039  14.341  1.00 93.98           C\\nATOM    433  C   PHE    56      41.533  25.904  19.135  1.00 93.98           C\\nATOM    434  O   PHE    56      40.594  25.120  19.015  1.00 93.98           O\\nATOM    435  N   ASN    57      42.466  25.755  20.091  1.00 66.69           N\\nATOM    436  CA  ASN    57      42.467  24.627  20.986  1.00 66.69           C\\nATOM    437  CB  ASN    57      43.912  24.180  21.263  1.00 66.69           C\\nATOM    438  CG  ASN    57      44.019  22.746  21.764  1.00 66.69           C\\nATOM    439  OD1 ASN    57      43.108  22.195  22.379  1.00 66.69           O\\nATOM    440  ND2 ASN    57      45.193  22.121  21.477  1.00 66.69           N\\nATOM    441  C   ASN    57      41.897  25.118  22.286  1.00 66.69           C\\nATOM    442  O   ASN    57      42.438  26.024  22.910  1.00 66.69           O\\nATOM    443  N   THR    58      40.770  24.551  22.738  1.00132.06           N\\nATOM    444  CA  THR    58      40.171  25.022  23.954  1.00132.06           C\\nATOM    445  CB  THR    58      38.797  24.496  24.136  1.00132.06           C\\nATOM    446  OG1 THR    58      38.063  24.663  22.933  1.00132.06           O\\nATOM    447  CG2 THR    58      38.163  25.398  25.200  1.00132.06           C\\nATOM    448  C   THR    58      41.037  24.607  25.108  1.00132.06           C\\nATOM    449  O   THR    58      41.022  25.216  26.176  1.00132.06           O\\nATOM    450  N   GLY    59      41.768  23.494  24.919  1.00 70.79           N\\nATOM    451  CA  GLY    59      42.650  22.830  25.847  1.00 70.79           C\\nATOM    452  C   GLY    59      43.921  23.573  26.152  1.00 70.79           C\\nATOM    453  O   GLY    59      44.587  23.262  27.139  1.00 70.79           O\\nATOM    454  N   ALA    60      44.357  24.489  25.267  1.00 54.07           N\\nATOM    455  CA  ALA    60      45.643  25.125  25.396  1.00 54.07           C\\nATOM    456  CB  ALA    60      45.922  26.152  24.282  1.00 54.07           C\\nATOM    457  C   ALA    60      45.856  25.818  26.715  1.00 54.07           C\\nATOM    458  O   ALA    60      44.992  26.530  27.227  1.00 54.07           O\\nATOM    459  N   THR    61      47.060  25.597  27.298  1.00 51.61           N\\nATOM    460  CA  THR    61      47.496  26.228  28.513  1.00 51.61           C\\nATOM    461  CB  THR    61      47.534  25.313  29.710  1.00 51.61           C\\nATOM    462  OG1 THR    61      48.385  24.203  29.451  1.00 51.61           O\\nATOM    463  CG2 THR    61      46.120  24.815  30.042  1.00 51.61           C\\nATOM    464  C   THR    61      48.912  26.665  28.289  1.00 51.61           C\\nATOM    465  O   THR    61      49.686  25.950  27.658  1.00 51.61           O\\nATOM    466  N   ASN    62      49.294  27.854  28.804  1.00 74.59           N\\nATOM    467  CA  ASN    62      50.641  28.345  28.655  1.00 74.59           C\\nATOM    468  CB  ASN    62      50.738  29.410  27.542  1.00 74.59           C\\nATOM    469  CG  ASN    62      52.152  29.965  27.426  1.00 74.59           C\\nATOM    470  OD1 ASN    62      53.010  29.419  26.733  1.00 74.59           O\\nATOM    471  ND2 ASN    62      52.382  31.115  28.111  1.00 74.59           N\\nATOM    472  C   ASN    62      51.033  28.948  29.973  1.00 74.59           C\\nATOM    473  O   ASN    62      50.292  29.749  30.539  1.00 74.59           O\\nATOM    474  N   ARG    63      52.198  28.547  30.525  1.00149.39           N\\nATOM    475  CA  ARG    63      52.627  29.074  31.793  1.00149.39           C\\nATOM    476  CB  ARG    63      53.534  28.117  32.587  1.00149.39           C\\nATOM    477  CG  ARG    63      53.932  28.628  33.977  1.00149.39           C\\nATOM    478  CD  ARG    63      52.793  28.641  35.004  1.00149.39           C\\nATOM    479  NE  ARG    63      52.893  27.405  35.838  1.00149.39           N\\nATOM    480  CZ  ARG    63      52.627  27.429  37.179  1.00149.39           C\\nATOM    481  NH1 ARG    63      52.261  28.588  37.803  1.00149.39           N\\nATOM    482  NH2 ARG    63      52.710  26.276  37.907  1.00149.39           N\\nATOM    483  C   ARG    63      53.419  30.320  31.543  1.00149.39           C\\nATOM    484  O   ARG    63      54.056  30.484  30.504  1.00149.39           O\\nATOM    485  N   ASN    64      53.393  31.251  32.509  1.00 77.66           N\\nATOM    486  CA  ASN    64      54.099  32.483  32.335  1.00 77.66           C\\nATOM    487  CB  ASN    64      53.205  33.705  32.513  1.00 77.66           C\\nATOM    488  CG  ASN    64      52.097  33.555  31.500  1.00 77.66           C\\nATOM    489  OD1 ASN    64      50.914  33.598  31.831  1.00 77.66           O\\nATOM    490  ND2 ASN    64      52.493  33.370  30.215  1.00 77.66           N\\nATOM    491  C   ASN    64      55.114  32.566  33.420  1.00 77.66           C\\nATOM    492  O   ASN    64      55.020  31.895  34.445  1.00 77.66           O\\nATOM    493  N   THR    65      56.117  33.423  33.205  1.00104.44           N\\nATOM    494  CA  THR    65      57.194  33.560  34.134  1.00104.44           C\\nATOM    495  CB  THR    65      58.309  34.405  33.589  1.00104.44           C\\nATOM    496  OG1 THR    65      59.377  34.420  34.514  1.00104.44           O\\nATOM    497  CG2 THR    65      57.828  35.835  33.302  1.00104.44           C\\nATOM    498  C   THR    65      56.688  34.103  35.443  1.00104.44           C\\nATOM    499  O   THR    65      57.159  33.690  36.500  1.00104.44           O\\nATOM    500  N   ASP    66      55.702  35.022  35.411  1.00 86.29           N\\nATOM    501  CA  ASP    66      55.147  35.666  36.583  1.00 86.29           C\\nATOM    502  CB  ASP    66      54.206  36.861  36.264  1.00 86.29           C\\nATOM    503  CG  ASP    66      53.030  36.433  35.398  1.00 86.29           C\\nATOM    504  OD1 ASP    66      53.228  35.522  34.553  1.00 86.29           O\\nATOM    505  OD2 ASP    66      51.923  37.012  35.553  1.00 86.29           O\\nATOM    506  C   ASP    66      54.408  34.677  37.428  1.00 86.29           C\\nATOM    507  O   ASP    66      53.992  34.987  38.543  1.00 86.29           O\\nATOM    508  N   GLY    67      54.136  33.475  36.896  1.00 35.95           N\\nATOM    509  CA  GLY    67      53.506  32.491  37.725  1.00 35.95           C\\nATOM    510  C   GLY    67      52.093  32.320  37.299  1.00 35.95           C\\nATOM    511  O   GLY    67      51.394  31.431  37.785  1.00 35.95           O\\nATOM    512  N   SER    68      51.617  33.182  36.384  1.00 55.79           N\\nATOM    513  CA  SER    68      50.270  33.026  35.936  1.00 55.79           C\\nATOM    514  CB  SER    68      49.574  34.350  35.560  1.00 55.79           C\\nATOM    515  OG  SER    68      50.209  34.951  34.442  1.00 55.79           O\\nATOM    516  C   SER    68      50.249  32.116  34.749  1.00 55.79           C\\nATOM    517  O   SER    68      51.278  31.776  34.167  1.00 55.79           O\\nATOM    518  N   THR    69      49.031  31.682  34.372  1.00 67.66           N\\nATOM    519  CA  THR    69      48.851  30.770  33.285  1.00 67.66           C\\nATOM    520  CB  THR    69      48.438  29.428  33.820  1.00 67.66           C\\nATOM    521  OG1 THR    69      49.394  28.983  34.771  1.00 67.66           O\\nATOM    522  CG2 THR    69      48.317  28.422  32.659  1.00 67.66           C\\nATOM    523  C   THR    69      47.748  31.306  32.406  1.00 67.66           C\\nATOM    524  O   THR    69      46.838  31.990  32.868  1.00 67.66           O\\nATOM    525  N   ASP    70      47.828  31.008  31.091  1.00 78.22           N\\nATOM    526  CA  ASP    70      46.877  31.440  30.089  1.00 78.22           C\\nATOM    527  CB  ASP    70      47.534  31.804  28.762  1.00 78.22           C\\nATOM    528  CG  ASP    70      48.507  32.919  29.066  1.00 78.22           C\\nATOM    529  OD1 ASP    70      48.176  33.794  29.908  1.00 78.22           O\\nATOM    530  OD2 ASP    70      49.617  32.892  28.473  1.00 78.22           O\\nATOM    531  C   ASP    70      46.019  30.238  29.794  1.00 78.22           C\\nATOM    532  O   ASP    70      46.539  29.134  29.627  1.00 78.22           O\\nATOM    533  N   TYR    71      44.675  30.409  29.728  1.00101.60           N\\nATOM    534  CA  TYR    71      43.844  29.248  29.530  1.00101.60           C\\nATOM    535  CB  TYR    71      42.973  28.888  30.750  1.00101.60           C\\nATOM    536  CG  TYR    71      43.831  28.458  31.894  1.00101.60           C\\nATOM    537  CD1 TYR    71      44.480  29.387  32.668  1.00101.60           C\\nATOM    538  CD2 TYR    71      43.971  27.124  32.216  1.00101.60           C\\nATOM    539  CE1 TYR    71      45.268  28.985  33.726  1.00101.60           C\\nATOM    540  CE2 TYR    71      44.757  26.715  33.270  1.00101.60           C\\nATOM    541  CZ  TYR    71      45.413  27.649  34.030  1.00101.60           C\\nATOM    542  OH  TYR    71      46.220  27.229  35.111  1.00101.60           O\\nATOM    543  C   TYR    71      42.853  29.402  28.408  1.00101.60           C\\nATOM    544  O   TYR    71      42.259  30.460  28.199  1.00101.60           O\\nATOM    545  N   GLY    72      42.656  28.293  27.657  1.00 44.27           N\\nATOM    546  CA  GLY    72      41.608  28.145  26.674  1.00 44.27           C\\nATOM    547  C   GLY    72      41.922  28.735  25.330  1.00 44.27           C\\nATOM    548  O   GLY    72      43.060  29.082  25.017  1.00 44.27           O\\nATOM    549  N   ILE    73      40.865  28.851  24.485  1.00137.30           N\\nATOM    550  CA  ILE    73      41.020  29.336  23.135  1.00137.30           C\\nATOM    551  CB  ILE    73      39.782  29.362  22.280  1.00137.30           C\\nATOM    552  CG1 ILE    73      39.284  27.952  21.960  1.00137.30           C\\nATOM    553  CG2 ILE    73      40.086  30.178  21.017  1.00137.30           C\\nATOM    554  CD1 ILE    73      38.212  27.970  20.876  1.00137.30           C\\nATOM    555  C   ILE    73      41.498  30.755  23.132  1.00137.30           C\\nATOM    556  O   ILE    73      42.302  31.146  22.288  1.00137.30           O\\nATOM    557  N   LEU    74      40.922  31.566  24.031  1.00110.03           N\\nATOM    558  CA  LEU    74      41.165  32.962  24.256  1.00110.03           C\\nATOM    559  CB  LEU    74      39.973  33.616  24.980  1.00110.03           C\\nATOM    560  CG  LEU    74      38.660  33.530  24.180  1.00110.03           C\\nATOM    561  CD1 LEU    74      37.490  34.169  24.933  1.00110.03           C\\nATOM    562  CD2 LEU    74      38.828  34.131  22.783  1.00110.03           C\\nATOM    563  C   LEU    74      42.437  33.201  25.040  1.00110.03           C\\nATOM    564  O   LEU    74      42.882  34.344  25.158  1.00110.03           O\\nATOM    565  N   GLN    75      43.005  32.157  25.680  1.00 90.25           N\\nATOM    566  CA  GLN    75      44.200  32.282  26.479  1.00 90.25           C\\nATOM    567  CB  GLN    75      45.478  32.707  25.716  1.00 90.25           C\\nATOM    568  CG  GLN    75      46.003  31.717  24.676  1.00 90.25           C\\nATOM    569  CD  GLN    75      46.529  30.472  25.376  1.00 90.25           C\\nATOM    570  OE1 GLN    75      47.635  30.452  25.913  1.00 90.25           O\\nATOM    571  NE2 GLN    75      45.706  29.394  25.362  1.00 90.25           N\\nATOM    572  C   GLN    75      43.989  33.341  27.522  1.00 90.25           C\\nATOM    573  O   GLN    75      44.789  34.273  27.622  1.00 90.25           O\\nATOM    574  N   ILE    76      42.888  33.239  28.311  1.00136.19           N\\nATOM    575  CA  ILE    76      42.641  34.189  29.371  1.00136.19           C\\nATOM    576  CB  ILE    76      41.222  34.179  29.925  1.00136.19           C\\nATOM    577  CG1 ILE    76      40.160  34.579  28.870  1.00136.19           C\\nATOM    578  CG2 ILE    76      41.199  35.098  31.164  1.00136.19           C\\nATOM    579  CD1 ILE    76      39.680  33.476  27.918  1.00136.19           C\\nATOM    580  C   ILE    76      43.599  33.921  30.524  1.00136.19           C\\nATOM    581  O   ILE    76      43.849  32.785  30.918  1.00136.19           O\\nATOM    582  N   ASN    77      44.195  35.001  31.072  1.00 85.84           N\\nATOM    583  CA  ASN    77      45.227  34.985  32.085  1.00 85.84           C\\nATOM    584  CB  ASN    77      46.133  36.229  32.022  1.00 85.84           C\\nATOM    585  CG  ASN    77      47.336  35.951  32.922  1.00 85.84           C\\nATOM    586  OD1 ASN    77      47.395  36.405  34.063  1.00 85.84           O\\nATOM    587  ND2 ASN    77      48.308  35.156  32.396  1.00 85.84           N\\nATOM    588  C   ASN    77      44.660  34.898  33.479  1.00 85.84           C\\nATOM    589  O   ASN    77      43.696  35.577  33.827  1.00 85.84           O\\nATOM    590  N   SER    78      45.304  34.056  34.318  1.00124.28           N\\nATOM    591  CA  SER    78      44.948  33.755  35.687  1.00124.28           C\\nATOM    592  CB  SER    78      45.655  32.490  36.191  1.00124.28           C\\nATOM    593  OG  SER    78      45.396  32.299  37.572  1.00124.28           O\\nATOM    594  C   SER    78      45.261  34.874  36.655  1.00124.28           C\\nATOM    595  O   SER    78      44.788  34.836  37.790  1.00124.28           O\\nATOM    596  N   ARG    79      46.114  35.862  36.311  1.00202.23           N\\nATOM    597  CA  ARG    79      46.344  36.851  37.333  1.00202.23           C\\nATOM    598  CB  ARG    79      47.505  37.834  37.074  1.00202.23           C\\nATOM    599  CG  ARG    79      47.398  38.681  35.814  1.00202.23           C\\nATOM    600  CD  ARG    79      48.465  39.779  35.754  1.00202.23           C\\nATOM    601  NE  ARG    79      49.597  39.380  36.627  1.00202.23           N\\nATOM    602  CZ  ARG    79      50.622  40.254  36.861  1.00202.23           C\\nATOM    603  NH1 ARG    79      50.563  41.525  36.372  1.00202.23           N\\nATOM    604  NH2 ARG    79      51.701  39.896  37.618  1.00202.23           N\\nATOM    605  C   ARG    79      45.082  37.621  37.600  1.00202.23           C\\nATOM    606  O   ARG    79      44.690  37.794  38.750  1.00202.23           O\\nATOM    607  N   TRP    80      44.443  38.183  36.557  1.00173.33           N\\nATOM    608  CA  TRP    80      43.193  38.896  36.704  1.00173.33           C\\nATOM    609  CB  TRP    80      43.030  40.091  35.736  1.00173.33           C\\nATOM    610  CG  TRP    80      43.481  41.397  36.342  1.00173.33           C\\nATOM    611  CD2 TRP    80      44.791  41.972  36.226  1.00173.33           C\\nATOM    612  CD1 TRP    80      42.746  42.253  37.111  1.00173.33           C\\nATOM    613  NE1 TRP    80      43.531  43.304  37.519  1.00173.33           N\\nATOM    614  CE2 TRP    80      44.792  43.148  36.971  1.00173.33           C\\nATOM    615  CE3 TRP    80      45.911  41.550  35.565  1.00173.33           C\\nATOM    616  CZ2 TRP    80      45.925  43.913  37.068  1.00173.33           C\\nATOM    617  CZ3 TRP    80      47.038  42.341  35.639  1.00173.33           C\\nATOM    618  CH2 TRP    80      47.049  43.500  36.381  1.00173.33           C\\nATOM    619  C   TRP    80      41.893  38.128  36.652  1.00173.33           C\\nATOM    620  O   TRP    80      40.988  38.371  37.447  1.00173.33           O\\nATOM    621  N   TRP    81      41.738  37.285  35.616  1.00150.05           N\\nATOM    622  CA  TRP    81      40.465  36.731  35.228  1.00150.05           C\\nATOM    623  CB  TRP    81      40.505  36.487  33.719  1.00150.05           C\\nATOM    624  CG  TRP    81      40.913  37.784  33.054  1.00150.05           C\\nATOM    625  CD2 TRP    81      40.139  38.988  33.125  1.00150.05           C\\nATOM    626  CD1 TRP    81      42.055  38.102  32.381  1.00150.05           C\\nATOM    627  NE1 TRP    81      42.035  39.425  32.015  1.00150.05           N\\nATOM    628  CE2 TRP    81      40.863  39.987  32.469  1.00150.05           C\\nATOM    629  CE3 TRP    81      38.936  39.247  33.712  1.00150.05           C\\nATOM    630  CZ2 TRP    81      40.388  41.263  32.385  1.00150.05           C\\nATOM    631  CZ3 TRP    81      38.451  40.530  33.600  1.00150.05           C\\nATOM    632  CH2 TRP    81      39.161  41.518  32.948  1.00150.05           C\\nATOM    633  C   TRP    81      39.900  35.524  35.933  1.00150.05           C\\nATOM    634  O   TRP    81      38.702  35.508  36.207  1.00150.05           O\\nATOM    635  N   CYS    82      40.691  34.465  36.213  1.00 68.47           N\\nATOM    636  CA  CYS    82      40.095  33.269  36.762  1.00 68.47           C\\nATOM    637  CB  CYS    82      39.974  32.131  35.728  1.00 68.47           C\\nATOM    638  SG  CYS    82      41.536  31.753  34.859  1.00 68.47           S\\nATOM    639  C   CYS    82      40.954  32.765  37.875  1.00 68.47           C\\nATOM    640  O   CYS    82      42.059  33.266  38.062  1.00 68.47           O\\nATOM    641  N   ASN    83      40.487  31.763  38.662  1.00127.63           N\\nATOM    642  CA  ASN    83      41.434  31.358  39.666  1.00127.63           C\\nATOM    643  CB  ASN    83      40.967  31.465  41.128  1.00127.63           C\\nATOM    644  CG  ASN    83      40.028  30.322  41.437  1.00127.63           C\\nATOM    645  OD1 ASN    83      40.461  29.249  41.851  1.00127.63           O\\nATOM    646  ND2 ASN    83      38.701  30.564  41.260  1.00127.63           N\\nATOM    647  C   ASN    83      41.883  29.944  39.421  1.00127.63           C\\nATOM    648  O   ASN    83      41.068  29.035  39.257  1.00127.63           O\\nATOM    649  N   ASP    84      43.219  29.778  39.266  1.00227.82           N\\nATOM    650  CA  ASP    84      43.962  28.548  39.149  1.00227.82           C\\nATOM    651  CB  ASP    84      45.471  28.682  38.843  1.00227.82           C\\nATOM    652  CG  ASP    84      45.905  29.433  37.607  1.00227.82           C\\nATOM    653  OD1 ASP    84      45.297  29.273  36.521  1.00227.82           O\\nATOM    654  OD2 ASP    84      46.914  30.173  37.754  1.00227.82           O\\nATOM    655  C   ASP    84      44.164  27.985  40.515  1.00227.82           C\\nATOM    656  O   ASP    84      44.262  26.776  40.685  1.00227.82           O\\nATOM    657  N   GLY    85      44.371  28.881  41.502  1.00 63.09           N\\nATOM    658  CA  GLY    85      44.715  28.529  42.854  1.00 63.09           C\\nATOM    659  C   GLY    85      46.213  28.636  43.015  1.00 63.09           C\\nATOM    660  O   GLY    85      46.724  28.726  44.133  1.00 63.09           O\\nATOM    661  N   ARG    86      46.942  28.521  41.883  1.00262.10           N\\nATOM    662  CA  ARG    86      48.375  28.591  41.726  1.00262.10           C\\nATOM    663  CB  ARG    86      48.857  27.840  40.460  1.00262.10           C\\nATOM    664  CG  ARG    86      48.239  26.447  40.278  1.00262.10           C\\nATOM    665  CD  ARG    86      48.912  25.558  39.222  1.00262.10           C\\nATOM    666  NE  ARG    86      48.992  26.284  37.922  1.00262.10           N\\nATOM    667  CZ  ARG    86      49.608  25.702  36.849  1.00262.10           C\\nATOM    668  NH1 ARG    86      49.994  24.391  36.886  1.00262.10           N\\nATOM    669  NH2 ARG    86      49.832  26.446  35.728  1.00262.10           N\\nATOM    670  C   ARG    86      48.914  30.002  41.611  1.00262.10           C\\nATOM    671  O   ARG    86      50.113  30.211  41.796  1.00262.10           O\\nATOM    672  N   THR    87      48.107  31.023  41.242  1.00165.66           N\\nATOM    673  CA  THR    87      48.849  32.211  40.894  1.00165.66           C\\nATOM    674  CB  THR    87      48.549  32.669  39.476  1.00165.66           C\\nATOM    675  OG1 THR    87      49.712  33.233  38.904  1.00165.66           O\\nATOM    676  CG2 THR    87      47.451  33.727  39.423  1.00165.66           C\\nATOM    677  C   THR    87      48.722  33.308  41.920  1.00165.66           C\\nATOM    678  O   THR    87      47.666  33.585  42.488  1.00165.66           O\\nATOM    679  N   PRO    88      49.847  33.907  42.209  1.00 87.28           N\\nATOM    680  CA  PRO    88      49.885  34.964  43.181  1.00 87.28           C\\nATOM    681  CD  PRO    88      51.112  33.197  42.137  1.00 87.28           C\\nATOM    682  CB  PRO    88      51.337  35.057  43.665  1.00 87.28           C\\nATOM    683  CG  PRO    88      52.134  34.220  42.647  1.00 87.28           C\\nATOM    684  C   PRO    88      49.322  36.256  42.667  1.00 87.28           C\\nATOM    685  O   PRO    88      49.535  36.584  41.501  1.00 87.28           O\\nATOM    686  N   GLY    89      48.614  37.010  43.536  1.00 38.73           N\\nATOM    687  CA  GLY    89      48.081  38.306  43.209  1.00 38.73           C\\nATOM    688  C   GLY    89      46.869  38.213  42.316  1.00 38.73           C\\nATOM    689  O   GLY    89      46.600  39.150  41.563  1.00 38.73           O\\nATOM    690  N   SER    90      46.109  37.095  42.387  1.00111.99           N\\nATOM    691  CA  SER    90      44.972  36.853  41.517  1.00111.99           C\\nATOM    692  CB  SER    90      44.502  35.390  41.491  1.00111.99           C\\nATOM    693  OG  SER    90      45.583  34.508  41.288  1.00111.99           O\\nATOM    694  C   SER    90      43.726  37.563  41.983  1.00111.99           C\\nATOM    695  O   SER    90      43.366  37.467  43.156  1.00111.99           O\\nATOM    696  N   LYS    91      43.065  38.318  41.065  1.00170.12           N\\nATOM    697  CA  LYS    91      41.788  38.977  41.264  1.00170.12           C\\nATOM    698  CB  LYS    91      41.638  40.267  40.444  1.00170.12           C\\nATOM    699  CG  LYS    91      42.727  41.303  40.730  1.00170.12           C\\nATOM    700  CD  LYS    91      42.862  41.671  42.208  1.00170.12           C\\nATOM    701  CE  LYS    91      43.774  42.869  42.473  1.00170.12           C\\nATOM    702  NZ  LYS    91      45.176  42.556  42.118  1.00170.12           N\\nATOM    703  C   LYS    91      40.546  38.134  40.996  1.00170.12           C\\nATOM    704  O   LYS    91      39.534  38.291  41.676  1.00170.12           O\\nATOM    705  N   ASN    92      40.568  37.238  39.977  1.00 76.17           N\\nATOM    706  CA  ASN    92      39.415  36.442  39.604  1.00 76.17           C\\nATOM    707  CB  ASN    92      39.045  35.405  40.681  1.00 76.17           C\\nATOM    708  CG  ASN    92      37.961  34.461  40.177  1.00 76.17           C\\nATOM    709  OD1 ASN    92      37.824  34.219  38.978  1.00 76.17           O\\nATOM    710  ND2 ASN    92      37.167  33.912  41.134  1.00 76.17           N\\nATOM    711  C   ASN    92      38.199  37.293  39.319  1.00 76.17           C\\nATOM    712  O   ASN    92      37.164  37.157  39.972  1.00 76.17           O\\nATOM    713  N   LEU    93      38.305  38.202  38.322  1.00146.97           N\\nATOM    714  CA  LEU    93      37.230  39.058  37.883  1.00146.97           C\\nATOM    715  CB  LEU    93      37.663  40.093  36.836  1.00146.97           C\\nATOM    716  CG  LEU    93      38.502  41.262  37.397  1.00146.97           C\\nATOM    717  CD1 LEU    93      39.012  42.173  36.268  1.00146.97           C\\nATOM    718  CD2 LEU    93      37.706  42.066  38.444  1.00146.97           C\\nATOM    719  C   LEU    93      36.101  38.276  37.256  1.00146.97           C\\nATOM    720  O   LEU    93      34.937  38.618  37.465  1.00146.97           O\\nATOM    721  N   CYS    94      36.394  37.231  36.446  1.00 92.14           N\\nATOM    722  CA  CYS    94      35.373  36.455  35.781  1.00 92.14           C\\nATOM    723  CB  CYS    94      35.849  35.359  34.778  1.00 92.14           C\\nATOM    724  SG  CYS    94      37.330  35.675  33.758  1.00 92.14           S\\nATOM    725  C   CYS    94      34.647  35.670  36.833  1.00 92.14           C\\nATOM    726  O   CYS    94      33.523  35.225  36.604  1.00 92.14           O\\nATOM    727  N   HIS    95      35.291  35.446  38.004  1.00128.45           N\\nATOM    728  CA  HIS    95      34.759  34.682  39.101  1.00128.45           C\\nATOM    729  ND1 HIS    95      33.547  35.202  42.098  1.00128.45           N\\nATOM    730  CG  HIS    95      33.040  34.697  40.923  1.00128.45           C\\nATOM    731  CB  HIS    95      33.414  35.223  39.581  1.00128.45           C\\nATOM    732  NE2 HIS    95      32.160  33.558  42.656  1.00128.45           N\\nATOM    733  CD2 HIS    95      32.195  33.692  41.280  1.00128.45           C\\nATOM    734  CE1 HIS    95      32.985  34.485  43.101  1.00128.45           C\\nATOM    735  C   HIS    95      34.548  33.253  38.701  1.00128.45           C\\nATOM    736  O   HIS    95      33.523  32.651  39.020  1.00128.45           O\\nATOM    737  N   ILE    96      35.527  32.661  37.994  1.00 74.95           N\\nATOM    738  CA  ILE    96      35.409  31.302  37.549  1.00 74.95           C\\nATOM    739  CB  ILE    96      35.163  31.226  36.071  1.00 74.95           C\\nATOM    740  CG1 ILE    96      36.301  31.939  35.318  1.00 74.95           C\\nATOM    741  CG2 ILE    96      33.767  31.813  35.792  1.00 74.95           C\\nATOM    742  CD1 ILE    96      36.235  31.823  33.794  1.00 74.95           C\\nATOM    743  C   ILE    96      36.690  30.577  37.826  1.00 74.95           C\\nATOM    744  O   ILE    96      37.724  31.188  38.105  1.00 74.95           O\\nATOM    745  N   PRO    97      36.613  29.267  37.847  1.00135.98           N\\nATOM    746  CA  PRO    97      37.808  28.473  37.936  1.00135.98           C\\nATOM    747  CD  PRO    97      35.459  28.575  38.391  1.00135.98           C\\nATOM    748  CB  PRO    97      37.379  27.096  38.446  1.00135.98           C\\nATOM    749  CG  PRO    97      35.845  27.090  38.295  1.00135.98           C\\nATOM    750  C   PRO    97      38.367  28.486  36.546  1.00135.98           C\\nATOM    751  O   PRO    97      37.577  28.519  35.604  1.00135.98           O\\nATOM    752  N   CYS    98      39.704  28.451  36.383  1.00 67.56           N\\nATOM    753  CA  CYS    98      40.308  28.538  35.081  1.00 67.56           C\\nATOM    754  CB  CYS    98      41.837  28.709  35.118  1.00 67.56           C\\nATOM    755  SG  CYS    98      42.379  30.245  35.941  1.00 67.56           S\\nATOM    756  C   CYS    98      39.979  27.297  34.305  1.00 67.56           C\\nATOM    757  O   CYS    98      40.005  27.282  33.073  1.00 67.56           O\\nATOM    758  N   SER    99      39.689  26.206  35.032  1.00 94.64           N\\nATOM    759  CA  SER    99      39.407  24.926  34.445  1.00 94.64           C\\nATOM    760  CB  SER    99      39.002  23.887  35.498  1.00 94.64           C\\nATOM    761  OG  SER    99      38.702  22.655  34.866  1.00 94.64           O\\nATOM    762  C   SER    99      38.238  25.032  33.517  1.00 94.64           C\\nATOM    763  O   SER    99      38.186  24.342  32.500  1.00 94.64           O\\nATOM    764  N   ALA   100      37.280  25.916  33.842  1.00 60.44           N\\nATOM    765  CA  ALA   100      36.063  26.109  33.101  1.00 60.44           C\\nATOM    766  CB  ALA   100      35.138  27.161  33.744  1.00 60.44           C\\nATOM    767  C   ALA   100      36.388  26.559  31.703  1.00 60.44           C\\nATOM    768  O   ALA   100      35.598  26.354  30.784  1.00 60.44           O\\nATOM    769  N   LEU   101      37.521  27.258  31.539  1.00104.69           N\\nATOM    770  CA  LEU   101      38.004  27.797  30.289  1.00104.69           C\\nATOM    771  CB  LEU   101      39.178  28.772  30.497  1.00104.69           C\\nATOM    772  CG  LEU   101      38.784  30.055  31.256  1.00104.69           C\\nATOM    773  CD1 LEU   101      39.997  30.979  31.476  1.00104.69           C\\nATOM    774  CD2 LEU   101      37.622  30.785  30.554  1.00104.69           C\\nATOM    775  C   LEU   101      38.451  26.718  29.317  1.00104.69           C\\nATOM    776  O   LEU   101      38.653  26.998  28.136  1.00104.69           O\\nATOM    777  N   LEU   102      38.783  25.519  29.831  1.00144.95           N\\nATOM    778  CA  LEU   102      39.288  24.360  29.121  1.00144.95           C\\nATOM    779  CB  LEU   102      39.975  23.360  30.073  1.00144.95           C\\nATOM    780  CG  LEU   102      41.272  23.878  30.726  1.00144.95           C\\nATOM    781  CD1 LEU   102      42.386  24.051  29.682  1.00144.95           C\\nATOM    782  CD2 LEU   102      41.032  25.140  31.569  1.00144.95           C\\nATOM    783  C   LEU   102      38.269  23.569  28.333  1.00144.95           C\\nATOM    784  O   LEU   102      38.642  22.775  27.470  1.00144.95           O\\nATOM    785  N   SER   103      36.971  23.671  28.669  1.00102.05           N\\nATOM    786  CA  SER   103      35.935  22.818  28.132  1.00102.05           C\\nATOM    787  CB  SER   103      34.595  23.066  28.835  1.00102.05           C\\nATOM    788  OG  SER   103      33.594  22.209  28.300  1.00102.05           O\\nATOM    789  C   SER   103      35.709  22.983  26.655  1.00102.05           C\\nATOM    790  O   SER   103      35.984  24.020  26.063  1.00102.05           O\\nATOM    791  N   SER   104      35.178  21.921  26.005  1.00 37.47           N\\nATOM    792  CA  SER   104      34.882  22.003  24.601  1.00 37.47           C\\nATOM    793  CB  SER   104      34.397  20.680  23.993  1.00 37.47           C\\nATOM    794  OG  SER   104      35.464  19.744  23.948  1.00 37.47           O\\nATOM    795  C   SER   104      33.805  23.021  24.436  1.00 37.47           C\\nATOM    796  O   SER   104      33.799  23.770  23.459  1.00 37.47           O\\nATOM    797  N   ASP   105      32.852  23.054  25.394  1.00 71.06           N\\nATOM    798  CA  ASP   105      31.784  24.009  25.384  1.00 71.06           C\\nATOM    799  CB  ASP   105      30.680  23.625  26.378  1.00 71.06           C\\nATOM    800  CG  ASP   105      29.531  24.605  26.257  1.00 71.06           C\\nATOM    801  OD1 ASP   105      29.475  25.357  25.248  1.00 71.06           O\\nATOM    802  OD2 ASP   105      28.690  24.607  27.194  1.00 71.06           O\\nATOM    803  C   ASP   105      32.345  25.366  25.742  1.00 71.06           C\\nATOM    804  O   ASP   105      32.974  25.552  26.782  1.00 71.06           O\\nATOM    805  N   ILE   106      32.110  26.333  24.831  1.00190.21           N\\nATOM    806  CA  ILE   106      32.549  27.707  24.731  1.00190.21           C\\nATOM    807  CB  ILE   106      32.307  28.217  23.335  1.00190.21           C\\nATOM    808  CG1 ILE   106      33.145  29.453  22.952  1.00190.21           C\\nATOM    809  CG2 ILE   106      30.797  28.475  23.244  1.00190.21           C\\nATOM    810  CD1 ILE   106      32.645  30.785  23.508  1.00190.21           C\\nATOM    811  C   ILE   106      31.905  28.648  25.722  1.00190.21           C\\nATOM    812  O   ILE   106      32.441  29.718  26.004  1.00190.21           O\\nATOM    813  N   THR   107      30.714  28.318  26.247  1.00 66.42           N\\nATOM    814  CA  THR   107      29.908  29.268  26.982  1.00 66.42           C\\nATOM    815  CB  THR   107      28.744  28.608  27.672  1.00 66.42           C\\nATOM    816  OG1 THR   107      27.905  27.950  26.731  1.00 66.42           O\\nATOM    817  CG2 THR   107      27.956  29.684  28.442  1.00 66.42           C\\nATOM    818  C   THR   107      30.653  30.037  28.050  1.00 66.42           C\\nATOM    819  O   THR   107      30.560  31.265  28.072  1.00 66.42           O\\nATOM    820  N   ALA   108      31.386  29.372  28.960  1.00 43.51           N\\nATOM    821  CA  ALA   108      32.065  30.067  30.026  1.00 43.51           C\\nATOM    822  CB  ALA   108      32.793  29.106  30.985  1.00 43.51           C\\nATOM    823  C   ALA   108      33.111  30.982  29.466  1.00 43.51           C\\nATOM    824  O   ALA   108      33.235  32.128  29.901  1.00 43.51           O\\nATOM    825  N   SER   109      33.883  30.497  28.471  1.00 85.78           N\\nATOM    826  CA  SER   109      34.972  31.249  27.912  1.00 85.78           C\\nATOM    827  CB  SER   109      35.713  30.525  26.764  1.00 85.78           C\\nATOM    828  OG  SER   109      36.486  29.442  27.259  1.00 85.78           O\\nATOM    829  C   SER   109      34.437  32.513  27.320  1.00 85.78           C\\nATOM    830  O   SER   109      34.995  33.590  27.525  1.00 85.78           O\\nATOM    831  N   VAL   110      33.327  32.403  26.568  1.00 88.52           N\\nATOM    832  CA  VAL   110      32.787  33.547  25.888  1.00 88.52           C\\nATOM    833  CB  VAL   110      31.629  33.228  24.974  1.00 88.52           C\\nATOM    834  CG1 VAL   110      30.355  32.966  25.790  1.00 88.52           C\\nATOM    835  CG2 VAL   110      31.488  34.370  23.957  1.00 88.52           C\\nATOM    836  C   VAL   110      32.333  34.567  26.885  1.00 88.52           C\\nATOM    837  O   VAL   110      32.535  35.765  26.695  1.00 88.52           O\\nATOM    838  N   ASN   111      31.703  34.121  27.982  1.00 66.73           N\\nATOM    839  CA  ASN   111      31.204  35.059  28.943  1.00 66.73           C\\nATOM    840  CB  ASN   111      30.459  34.386  30.110  1.00 66.73           C\\nATOM    841  CG  ASN   111      29.802  35.470  30.951  1.00 66.73           C\\nATOM    842  OD1 ASN   111      30.458  36.405  31.403  1.00 66.73           O\\nATOM    843  ND2 ASN   111      28.465  35.348  31.170  1.00 66.73           N\\nATOM    844  C   ASN   111      32.362  35.813  29.518  1.00 66.73           C\\nATOM    845  O   ASN   111      32.284  37.026  29.695  1.00 66.73           O\\nATOM    846  N   CYS   112      33.468  35.119  29.855  1.00 73.25           N\\nATOM    847  CA  CYS   112      34.555  35.858  30.432  1.00 73.25           C\\nATOM    848  CB  CYS   112      35.639  35.064  31.183  1.00 73.25           C\\nATOM    849  SG  CYS   112      36.753  36.308  31.913  1.00 73.25           S\\nATOM    850  C   CYS   112      35.224  36.750  29.418  1.00 73.25           C\\nATOM    851  O   CYS   112      35.634  37.858  29.759  1.00 73.25           O\\nATOM    852  N   ALA   113      35.370  36.322  28.144  1.00 48.20           N\\nATOM    853  CA  ALA   113      36.017  37.194  27.191  1.00 48.20           C\\nATOM    854  CB  ALA   113      36.090  36.615  25.774  1.00 48.20           C\\nATOM    855  C   ALA   113      35.208  38.460  27.086  1.00 48.20           C\\nATOM    856  O   ALA   113      35.757  39.552  26.937  1.00 48.20           O\\nATOM    857  N   LYS   114      33.867  38.355  27.149  1.00 59.70           N\\nATOM    858  CA  LYS   114      33.046  39.527  27.040  1.00 59.70           C\\nATOM    859  CB  LYS   114      31.527  39.241  27.078  1.00 59.70           C\\nATOM    860  CG  LYS   114      30.995  38.774  25.717  1.00 59.70           C\\nATOM    861  CD  LYS   114      29.575  38.197  25.723  1.00 59.70           C\\nATOM    862  CE  LYS   114      29.076  37.838  24.318  1.00 59.70           C\\nATOM    863  NZ  LYS   114      27.615  37.573  24.321  1.00 59.70           N\\nATOM    864  C   LYS   114      33.416  40.452  28.162  1.00 59.70           C\\nATOM    865  O   LYS   114      33.464  41.665  27.970  1.00 59.70           O\\nATOM    866  N   LYS   115      33.693  39.905  29.362  1.00111.31           N\\nATOM    867  CA  LYS   115      34.058  40.718  30.496  1.00111.31           C\\nATOM    868  CB  LYS   115      34.261  39.897  31.787  1.00111.31           C\\nATOM    869  CG  LYS   115      34.287  40.727  33.084  1.00111.31           C\\nATOM    870  CD  LYS   115      35.348  41.831  33.152  1.00111.31           C\\nATOM    871  CE  LYS   115      35.102  42.869  34.250  1.00111.31           C\\nATOM    872  NZ  LYS   115      36.060  43.987  34.104  1.00111.31           N\\nATOM    873  C   LYS   115      35.377  41.403  30.245  1.00111.31           C\\nATOM    874  O   LYS   115      35.529  42.597  30.503  1.00111.31           O\\nATOM    875  N   ILE   116      36.370  40.665  29.722  1.00151.98           N\\nATOM    876  CA  ILE   116      37.687  41.218  29.569  1.00151.98           C\\nATOM    877  CB  ILE   116      38.694  40.209  29.071  1.00151.98           C\\nATOM    878  CG1 ILE   116      40.134  40.688  29.345  1.00151.98           C\\nATOM    879  CG2 ILE   116      38.415  39.905  27.590  1.00151.98           C\\nATOM    880  CD1 ILE   116      40.561  41.949  28.595  1.00151.98           C\\nATOM    881  C   ILE   116      37.657  42.412  28.652  1.00151.98           C\\nATOM    882  O   ILE   116      38.289  43.424  28.947  1.00151.98           O\\nATOM    883  N   VAL   117      36.907  42.352  27.533  1.00 70.21           N\\nATOM    884  CA  VAL   117      36.886  43.391  26.526  1.00 70.21           C\\nATOM    885  CB  VAL   117      36.073  43.048  25.304  1.00 70.21           C\\nATOM    886  CG1 VAL   117      36.716  41.829  24.615  1.00 70.21           C\\nATOM    887  CG2 VAL   117      34.598  42.859  25.701  1.00 70.21           C\\nATOM    888  C   VAL   117      36.352  44.679  27.072  1.00 70.21           C\\nATOM    889  O   VAL   117      36.605  45.748  26.516  1.00 70.21           O\\nATOM    890  N   SER   118      35.533  44.600  28.133  1.00 81.57           N\\nATOM    891  CA  SER   118      34.886  45.727  28.746  1.00 81.57           C\\nATOM    892  CB  SER   118      33.921  45.247  29.848  1.00 81.57           C\\nATOM    893  OG  SER   118      33.278  46.355  30.457  1.00 81.57           O\\nATOM    894  C   SER   118      35.900  46.662  29.358  1.00 81.57           C\\nATOM    895  O   SER   118      35.621  47.847  29.537  1.00 81.57           O\\nATOM    896  N   ASP   119      37.111  46.176  29.687  1.00 51.10           N\\nATOM    897  CA  ASP   119      38.065  47.035  30.334  1.00 51.10           C\\nATOM    898  CB  ASP   119      39.295  46.313  30.880  1.00 51.10           C\\nATOM    899  CG  ASP   119      38.806  45.394  31.974  1.00 51.10           C\\nATOM    900  OD1 ASP   119      37.895  45.819  32.730  1.00 51.10           O\\nATOM    901  OD2 ASP   119      39.321  44.249  32.061  1.00 51.10           O\\nATOM    902  C   ASP   119      38.546  48.054  29.347  1.00 51.10           C\\nATOM    903  O   ASP   119      38.245  47.985  28.156  1.00 51.10           O\\nATOM    904  N   GLY   120      39.341  49.026  29.844  1.00 28.30           N\\nATOM    905  CA  GLY   120      39.782  50.150  29.065  1.00 28.30           C\\nATOM    906  C   GLY   120      40.549  49.718  27.854  1.00 28.30           C\\nATOM    907  O   GLY   120      40.377  50.268  26.765  1.00 28.30           O\\nATOM    908  N   ASN   121      41.422  48.716  28.017  1.00 99.69           N\\nATOM    909  CA  ASN   121      42.253  48.238  26.958  1.00 99.69           C\\nATOM    910  CB  ASN   121      43.292  47.221  27.472  1.00 99.69           C\\nATOM    911  CG  ASN   121      42.584  46.186  28.332  1.00 99.69           C\\nATOM    912  OD1 ASN   121      42.383  46.382  29.532  1.00 99.69           O\\nATOM    913  ND2 ASN   121      42.198  45.047  27.700  1.00 99.69           N\\nATOM    914  C   ASN   121      41.442  47.638  25.845  1.00 99.69           C\\nATOM    915  O   ASN   121      41.873  47.652  24.691  1.00 99.69           O\\nATOM    916  N   GLY   122      40.261  47.057  26.141  1.00 33.28           N\\nATOM    917  CA  GLY   122      39.485  46.497  25.067  1.00 33.28           C\\nATOM    918  C   GLY   122      40.182  45.240  24.632  1.00 33.28           C\\nATOM    919  O   GLY   122      40.759  44.506  25.434  1.00 33.28           O\\nATOM    920  N   MET   123      40.171  45.013  23.313  1.00182.73           N\\nATOM    921  CA  MET   123      40.704  43.872  22.627  1.00182.73           C\\nATOM    922  CB  MET   123      40.385  43.938  21.130  1.00182.73           C\\nATOM    923  CG  MET   123      41.147  45.040  20.383  1.00182.73           C\\nATOM    924  SD  MET   123      40.848  46.748  20.929  1.00182.73           S\\nATOM    925  CE  MET   123      42.019  47.450  19.732  1.00182.73           C\\nATOM    926  C   MET   123      42.189  43.826  22.778  1.00182.73           C\\nATOM    927  O   MET   123      42.809  42.776  22.613  1.00182.73           O\\nATOM    928  N   ASN   124      42.794  44.992  23.051  1.00109.45           N\\nATOM    929  CA  ASN   124      44.214  45.183  23.187  1.00109.45           C\\nATOM    930  CB  ASN   124      44.575  46.622  23.592  1.00109.45           C\\nATOM    931  CG  ASN   124      46.091  46.736  23.583  1.00109.45           C\\nATOM    932  OD1 ASN   124      46.730  46.746  24.633  1.00109.45           O\\nATOM    933  ND2 ASN   124      46.692  46.798  22.363  1.00109.45           N\\nATOM    934  C   ASN   124      44.738  44.287  24.286  1.00109.45           C\\nATOM    935  O   ASN   124      45.946  44.081  24.391  1.00109.45           O\\nATOM    936  N   ALA   125      43.850  43.764  25.159  1.00 53.93           N\\nATOM    937  CA  ALA   125      44.237  42.927  26.271  1.00 53.93           C\\nATOM    938  CB  ALA   125      43.041  42.392  27.077  1.00 53.93           C\\nATOM    939  C   ALA   125      44.964  41.730  25.730  1.00 53.93           C\\nATOM    940  O   ALA   125      45.811  41.145  26.409  1.00 53.93           O\\nATOM    941  N   TRP   126      44.612  41.288  24.509  1.00 86.85           N\\nATOM    942  CA  TRP   126      45.279  40.127  23.983  1.00 86.85           C\\nATOM    943  CB  TRP   126      44.415  39.287  23.052  1.00 86.85           C\\nATOM    944  CG  TRP   126      43.360  38.489  23.762  1.00 86.85           C\\nATOM    945  CD2 TRP   126      42.012  38.919  24.004  1.00 86.85           C\\nATOM    946  CD1 TRP   126      43.458  37.228  24.270  1.00 86.85           C\\nATOM    947  NE1 TRP   126      42.254  36.834  24.799  1.00 86.85           N\\nATOM    948  CE2 TRP   126      41.356  37.868  24.646  1.00 86.85           C\\nATOM    949  CE3 TRP   126      41.377  40.089  23.709  1.00 86.85           C\\nATOM    950  CZ2 TRP   126      40.046  37.965  25.009  1.00 86.85           C\\nATOM    951  CZ3 TRP   126      40.056  40.187  24.087  1.00 86.85           C\\nATOM    952  CH2 TRP   126      39.407  39.148  24.722  1.00 86.85           C\\nATOM    953  C   TRP   126      46.505  40.504  23.206  1.00 86.85           C\\nATOM    954  O   TRP   126      46.453  41.291  22.265  1.00 86.85           O\\nATOM    955  N   VAL   127      47.652  39.896  23.573  1.00 52.11           N\\nATOM    956  CA  VAL   127      48.919  40.223  22.982  1.00 52.11           C\\nATOM    957  CB  VAL   127      50.068  39.522  23.648  1.00 52.11           C\\nATOM    958  CG1 VAL   127      51.376  40.013  22.993  1.00 52.11           C\\nATOM    959  CG2 VAL   127      49.961  39.721  25.176  1.00 52.11           C\\nATOM    960  C   VAL   127      48.892  39.869  21.520  1.00 52.11           C\\nATOM    961  O   VAL   127      49.317  40.661  20.679  1.00 52.11           O\\nATOM    962  N   ALA   128      48.331  38.683  21.192  1.00 46.91           N\\nATOM    963  CA  ALA   128      48.263  38.129  19.862  1.00 46.91           C\\nATOM    964  CB  ALA   128      47.559  36.770  19.839  1.00 46.91           C\\nATOM    965  C   ALA   128      47.487  39.034  18.968  1.00 46.91           C\\nATOM    966  O   ALA   128      47.811  39.157  17.788  1.00 46.91           O\\nATOM    967  N   TRP   129      46.410  39.649  19.486  1.00 59.98           N\\nATOM    968  CA  TRP   129      45.627  40.517  18.657  1.00 59.98           C\\nATOM    969  CB  TRP   129      44.389  41.072  19.372  1.00 59.98           C\\nATOM    970  CG  TRP   129      43.452  41.804  18.447  1.00 59.98           C\\nATOM    971  CD2 TRP   129      43.493  43.210  18.171  1.00 59.98           C\\nATOM    972  CD1 TRP   129      42.420  41.295  17.715  1.00 59.98           C\\nATOM    973  NE1 TRP   129      41.821  42.292  16.989  1.00 59.98           N\\nATOM    974  CE2 TRP   129      42.468  43.477  17.263  1.00 59.98           C\\nATOM    975  CE3 TRP   129      44.311  44.198  18.638  1.00 59.98           C\\nATOM    976  CZ2 TRP   129      42.243  44.742  16.804  1.00 59.98           C\\nATOM    977  CZ3 TRP   129      44.079  45.471  18.169  1.00 59.98           C\\nATOM    978  CH2 TRP   129      43.068  45.737  17.272  1.00 59.98           C\\nATOM    979  C   TRP   129      46.472  41.692  18.269  1.00 59.98           C\\nATOM    980  O   TRP   129      46.499  42.091  17.103  1.00 59.98           O\\nATOM    981  N   ARG   130      47.202  42.262  19.248  1.00 65.44           N\\nATOM    982  CA  ARG   130      47.981  43.429  18.969  1.00 65.44           C\\nATOM    983  CB  ARG   130      48.840  43.906  20.159  1.00 65.44           C\\nATOM    984  CG  ARG   130      48.055  44.288  21.418  1.00 65.44           C\\nATOM    985  CD  ARG   130      48.903  44.962  22.503  1.00 65.44           C\\nATOM    986  NE  ARG   130      50.094  44.095  22.745  1.00 65.44           N\\nATOM    987  CZ  ARG   130      50.692  44.062  23.973  1.00 65.44           C\\nATOM    988  NH1 ARG   130      50.164  44.771  25.011  1.00 65.44           N\\nATOM    989  NH2 ARG   130      51.827  43.328  24.169  1.00 65.44           N\\nATOM    990  C   ARG   130      48.936  43.078  17.869  1.00 65.44           C\\nATOM    991  O   ARG   130      49.065  43.812  16.887  1.00 65.44           O\\nATOM    992  N   LYS   131      49.630  41.930  18.006  1.00101.84           N\\nATOM    993  CA  LYS   131      50.611  41.600  17.016  1.00101.84           C\\nATOM    994  CB  LYS   131      51.435  40.361  17.378  1.00101.84           C\\nATOM    995  CG  LYS   131      52.228  40.543  18.667  1.00101.84           C\\nATOM    996  CD  LYS   131      52.834  39.261  19.239  1.00101.84           C\\nATOM    997  CE  LYS   131      53.576  39.508  20.558  1.00101.84           C\\nATOM    998  NZ  LYS   131      54.156  38.249  21.073  1.00101.84           N\\nATOM    999  C   LYS   131      50.020  41.290  15.668  1.00101.84           C\\nATOM   1000  O   LYS   131      50.257  42.008  14.701  1.00101.84           O\\nATOM   1001  N   HIS   132      49.252  40.185  15.574  1.00110.78           N\\nATOM   1002  CA  HIS   132      48.758  39.688  14.312  1.00110.78           C\\nATOM   1003  ND1 HIS   132      50.686  37.656  15.603  1.00110.78           N\\nATOM   1004  CG  HIS   132      49.917  37.523  14.471  1.00110.78           C\\nATOM   1005  CB  HIS   132      48.574  38.166  14.333  1.00110.78           C\\nATOM   1006  NE2 HIS   132      51.880  36.459  14.163  1.00110.78           N\\nATOM   1007  CD2 HIS   132      50.659  36.787  13.599  1.00110.78           C\\nATOM   1008  CE1 HIS   132      51.849  37.003  15.367  1.00110.78           C\\nATOM   1009  C   HIS   132      47.508  40.318  13.748  1.00110.78           C\\nATOM   1010  O   HIS   132      47.357  40.388  12.533  1.00110.78           O\\nATOM   1011  N   CYS   133      46.515  40.645  14.592  1.00 92.76           N\\nATOM   1012  CA  CYS   133      45.233  41.141  14.147  1.00 92.76           C\\nATOM   1013  CB  CYS   133      44.131  40.901  15.193  1.00 92.76           C\\nATOM   1014  SG  CYS   133      43.855  39.135  15.477  1.00 92.76           S\\nATOM   1015  C   CYS   133      45.150  42.590  13.813  1.00 92.76           C\\nATOM   1016  O   CYS   133      44.546  42.973  12.813  1.00 92.76           O\\nATOM   1017  N   LYS   134      45.741  43.443  14.665  1.00106.09           N\\nATOM   1018  CA  LYS   134      45.520  44.852  14.564  1.00106.09           C\\nATOM   1019  CB  LYS   134      46.197  45.632  15.700  1.00106.09           C\\nATOM   1020  CG  LYS   134      45.729  47.080  15.816  1.00106.09           C\\nATOM   1021  CD  LYS   134      46.099  47.977  14.631  1.00106.09           C\\nATOM   1022  CE  LYS   134      45.433  49.354  14.705  1.00106.09           C\\nATOM   1023  NZ  LYS   134      46.156  50.324  13.854  1.00106.09           N\\nATOM   1024  C   LYS   134      46.042  45.362  13.263  1.00106.09           C\\nATOM   1025  O   LYS   134      47.140  45.015  12.833  1.00106.09           O\\nATOM   1026  N   GLY   135      45.214  46.182  12.585  1.00 31.81           N\\nATOM   1027  CA  GLY   135      45.615  46.836  11.376  1.00 31.81           C\\nATOM   1028  C   GLY   135      45.806  45.841  10.277  1.00 31.81           C\\nATOM   1029  O   GLY   135      46.551  46.111   9.337  1.00 31.81           O\\nATOM   1030  N   THR   136      45.136  44.675  10.328  1.00107.18           N\\nATOM   1031  CA  THR   136      45.416  43.743   9.273  1.00107.18           C\\nATOM   1032  CB  THR   136      45.964  42.428   9.745  1.00107.18           C\\nATOM   1033  OG1 THR   136      46.560  41.734   8.660  1.00107.18           O\\nATOM   1034  CG2 THR   136      44.814  41.582  10.314  1.00107.18           C\\nATOM   1035  C   THR   136      44.166  43.445   8.519  1.00107.18           C\\nATOM   1036  O   THR   136      43.086  43.931   8.851  1.00107.18           O\\nATOM   1037  N   ASP   137      44.311  42.641   7.444  1.00 61.79           N\\nATOM   1038  CA  ASP   137      43.190  42.267   6.639  1.00 61.79           C\\nATOM   1039  CB  ASP   137      43.548  42.026   5.159  1.00 61.79           C\\nATOM   1040  CG  ASP   137      42.260  42.069   4.345  1.00 61.79           C\\nATOM   1041  OD1 ASP   137      41.184  41.780   4.934  1.00 61.79           O\\nATOM   1042  OD2 ASP   137      42.327  42.396   3.130  1.00 61.79           O\\nATOM   1043  C   ASP   137      42.647  40.995   7.215  1.00 61.79           C\\nATOM   1044  O   ASP   137      43.207  39.914   7.044  1.00 61.79           O\\nATOM   1045  N   VAL   138      41.526  41.153   7.938  1.00 73.65           N\\nATOM   1046  CA  VAL   138      40.757  40.196   8.681  1.00 73.65           C\\nATOM   1047  CB  VAL   138      39.809  40.881   9.626  1.00 73.65           C\\nATOM   1048  CG1 VAL   138      38.966  39.820  10.356  1.00 73.65           C\\nATOM   1049  CG2 VAL   138      40.636  41.769  10.575  1.00 73.65           C\\nATOM   1050  C   VAL   138      39.953  39.266   7.813  1.00 73.65           C\\nATOM   1051  O   VAL   138      39.564  38.183   8.252  1.00 73.65           O\\nATOM   1052  N   ASN   139      39.676  39.653   6.559  1.00 63.89           N\\nATOM   1053  CA  ASN   139      38.713  38.956   5.750  1.00 63.89           C\\nATOM   1054  CB  ASN   139      38.641  39.494   4.319  1.00 63.89           C\\nATOM   1055  CG  ASN   139      37.945  40.833   4.431  1.00 63.89           C\\nATOM   1056  OD1 ASN   139      37.041  40.997   5.249  1.00 63.89           O\\nATOM   1057  ND2 ASN   139      38.370  41.816   3.595  1.00 63.89           N\\nATOM   1058  C   ASN   139      38.969  37.483   5.665  1.00 63.89           C\\nATOM   1059  O   ASN   139      38.023  36.696   5.694  1.00 63.89           O\\nATOM   1060  N   VAL   140      40.235  37.054   5.584  1.00103.58           N\\nATOM   1061  CA  VAL   140      40.524  35.660   5.402  1.00103.58           C\\nATOM   1062  CB  VAL   140      41.996  35.378   5.317  1.00103.58           C\\nATOM   1063  CG1 VAL   140      42.555  36.125   4.094  1.00103.58           C\\nATOM   1064  CG2 VAL   140      42.656  35.759   6.654  1.00103.58           C\\nATOM   1065  C   VAL   140      39.959  34.851   6.535  1.00103.58           C\\nATOM   1066  O   VAL   140      39.576  33.701   6.334  1.00103.58           O\\nATOM   1067  N   TRP   141      39.888  35.413   7.754  1.00123.73           N\\nATOM   1068  CA  TRP   141      39.452  34.662   8.900  1.00123.73           C\\nATOM   1069  CB  TRP   141      39.526  35.482  10.198  1.00123.73           C\\nATOM   1070  CG  TRP   141      40.932  35.532  10.738  1.00123.73           C\\nATOM   1071  CD2 TRP   141      41.995  36.350  10.224  1.00123.73           C\\nATOM   1072  CD1 TRP   141      41.473  34.775  11.734  1.00123.73           C\\nATOM   1073  NE1 TRP   141      42.809  35.057  11.866  1.00123.73           N\\nATOM   1074  CE2 TRP   141      43.147  36.026  10.948  1.00123.73           C\\nATOM   1075  CE3 TRP   141      42.017  37.290   9.235  1.00123.73           C\\nATOM   1076  CZ2 TRP   141      44.339  36.639  10.689  1.00123.73           C\\nATOM   1077  CZ3 TRP   141      43.221  37.906   8.976  1.00123.73           C\\nATOM   1078  CH2 TRP   141      44.357  37.585   9.689  1.00123.73           C\\nATOM   1079  C   TRP   141      38.060  34.109   8.754  1.00123.73           C\\nATOM   1080  O   TRP   141      37.806  33.002   9.225  1.00123.73           O\\nATOM   1081  N   ILE   142      37.116  34.916   8.230  1.00168.42           N\\nATOM   1082  CA  ILE   142      35.728  34.615   7.962  1.00168.42           C\\nATOM   1083  CB  ILE   142      34.907  35.868   7.861  1.00168.42           C\\nATOM   1084  CG1 ILE   142      33.409  35.557   7.934  1.00168.42           C\\nATOM   1085  CG2 ILE   142      35.306  36.581   6.560  1.00168.42           C\\nATOM   1086  CD1 ILE   142      32.550  36.819   7.997  1.00168.42           C\\nATOM   1087  C   ILE   142      35.493  33.850   6.683  1.00168.42           C\\nATOM   1088  O   ILE   142      34.531  33.095   6.574  1.00168.42           O\\nATOM   1089  N   ARG   143      36.319  34.080   5.646  1.00154.07           N\\nATOM   1090  CA  ARG   143      36.027  33.627   4.311  1.00154.07           C\\nATOM   1091  CB  ARG   143      37.187  33.860   3.330  1.00154.07           C\\nATOM   1092  CG  ARG   143      36.838  33.456   1.902  1.00154.07           C\\nATOM   1093  CD  ARG   143      37.909  33.830   0.883  1.00154.07           C\\nATOM   1094  NE  ARG   143      39.109  32.985   1.154  1.00154.07           N\\nATOM   1095  CZ  ARG   143      40.152  33.022   0.276  1.00154.07           C\\nATOM   1096  NH1 ARG   143      40.044  33.771  -0.858  1.00154.07           N\\nATOM   1097  NH2 ARG   143      41.283  32.295   0.500  1.00154.07           N\\nATOM   1098  C   ARG   143      35.643  32.181   4.244  1.00154.07           C\\nATOM   1099  O   ARG   143      36.309  31.308   4.799  1.00154.07           O\\nATOM   1100  N   GLY   144      34.508  31.927   3.551  1.00 28.38           N\\nATOM   1101  CA  GLY   144      34.015  30.615   3.251  1.00 28.38           C\\nATOM   1102  C   GLY   144      33.104  30.116   4.329  1.00 28.38           C\\nATOM   1103  O   GLY   144      32.503  29.053   4.190  1.00 28.38           O\\nATOM   1104  N   CYS   145      33.009  30.844   5.453  1.00 61.37           N\\nATOM   1105  CA  CYS   145      32.219  30.429   6.581  1.00 61.37           C\\nATOM   1106  CB  CYS   145      32.619  31.131   7.880  1.00 61.37           C\\nATOM   1107  SG  CYS   145      34.346  30.756   8.299  1.00 61.37           S\\nATOM   1108  C   CYS   145      30.752  30.613   6.353  1.00 61.37           C\\nATOM   1109  O   CYS   145      29.946  29.887   6.933  1.00 61.37           O\\nATOM   1110  N   ARG   146      30.380  31.606   5.522  1.00103.20           N\\nATOM   1111  CA  ARG   146      29.015  31.930   5.202  1.00103.20           C\\nATOM   1112  CB  ARG   146      28.250  30.729   4.617  1.00103.20           C\\nATOM   1113  CG  ARG   146      26.913  31.075   3.956  1.00103.20           C\\nATOM   1114  CD  ARG   146      25.683  30.645   4.756  1.00103.20           C\\nATOM   1115  NE  ARG   146      24.487  31.055   3.966  1.00103.20           N\\nATOM   1116  CZ  ARG   146      23.921  32.277   4.176  1.00103.20           C\\nATOM   1117  NH1 ARG   146      24.396  33.074   5.177  1.00103.20           N\\nATOM   1118  NH2 ARG   146      22.902  32.690   3.370  1.00103.20           N\\nATOM   1119  C   ARG   146      28.288  32.431   6.412  1.00103.20           C\\nATOM   1120  O   ARG   146      27.101  32.163   6.590  1.00103.20           O\\nATOM   1121  N   LEU   147      28.984  33.192   7.276  1.00 77.36           N\\nATOM   1122  CA  LEU   147      28.332  33.774   8.412  1.00 77.36           C\\nATOM   1123  CB  LEU   147      29.270  34.019   9.616  1.00 77.36           C\\nATOM   1124  CG  LEU   147      29.580  32.728  10.389  1.00 77.36           C\\nATOM   1125  CD1 LEU   147      30.170  31.671   9.451  1.00 77.36           C\\nATOM   1126  CD2 LEU   147      30.458  32.996  11.627  1.00 77.36           C\\nATOM   1127  C   LEU   147      27.736  35.101   7.967  1.00 77.36           C\\nATOM   1128  O   LEU   147      28.195  36.171   8.453  1.00 77.36           O\\nATOM   1129  OXT LEU   147      26.796  35.057   7.129  1.00 77.36           O\\nTER    1130      LEU   147\\nHETATM 1131  C1  NAG   148      46.113  43.839  32.590  1.00105.22           C\\nHETATM 1132  C2  NAG   148      46.589  45.338  32.718  1.00105.22           C\\nHETATM 1133  C3  NAG   148      45.880  46.070  33.836  1.00105.22           C\\nHETATM 1134  C4  NAG   148      44.298  45.826  33.884  1.00105.22           C\\nHETATM 1135  C5  NAG   148      44.049  44.318  33.799  1.00105.22           C\\nHETATM 1136  C6  NAG   148      42.648  43.981  33.591  1.00105.22           C\\nHETATM 1137  C7  NAG   148      48.245  45.917  31.540  1.00105.22           C\\nHETATM 1138  C8  NAG   148      49.697  46.160  31.993  1.00105.22           C\\nHETATM 1139  N2  NAG   148      47.751  45.383  32.672  1.00105.22           N\\nHETATM 1140  O3  NAG   148      45.860  47.512  33.602  1.00105.22           O\\nHETATM 1141  O4  NAG   148      43.699  46.534  34.979  1.00105.22           O\\nHETATM 1142  O5  NAG   148      44.700  43.706  32.666  1.00105.22           O\\nHETATM 1143  O6  NAG   148      42.014  44.720  32.605  1.00105.22           O\\nHETATM 1144  O7  NAG   148      47.873  46.266  30.396  1.00105.22           O\\nHETATM 1145  C1  NAG   149      47.338  39.674  29.366  1.00126.11           C\\nHETATM 1146  C2  NAG   149      45.798  39.839  29.676  1.00126.11           C\\nHETATM 1147  C3  NAG   149      45.537  41.263  30.176  1.00126.11           C\\nHETATM 1148  C4  NAG   149      46.595  41.797  31.243  1.00126.11           C\\nHETATM 1149  C5  NAG   149      48.011  41.446  30.853  1.00126.11           C\\nHETATM 1150  C6  NAG   149      48.981  41.646  31.948  1.00126.11           C\\nHETATM 1151  C7  NAG   149      44.200  38.305  29.159  1.00126.11           C\\nHETATM 1152  C8  NAG   149      43.562  38.119  27.783  1.00126.11           C\\nHETATM 1153  N2  NAG   149      45.004  39.382  29.017  1.00126.11           N\\nHETATM 1154  O3  NAG   149      44.296  41.453  30.857  1.00126.11           O\\nHETATM 1155  O4  NAG   149      46.376  43.232  31.283  1.00126.11           O\\nHETATM 1156  O5  NAG   149      48.069  40.018  30.610  1.00126.11           O\\nHETATM 1157  O6  NAG   149      48.624  41.136  33.210  1.00126.11           O\\nHETATM 1158  O7  NAG   149      43.857  37.458  30.002  1.00126.11           O\\nHETATM 1159  C1  NDG   150      50.201  35.922  27.602  1.00 75.54           C\\nHETATM 1160  C2  NDG   150      50.585  37.422  27.617  1.00 75.54           C\\nHETATM 1161  C3  NDG   150      49.685  38.189  28.597  1.00 75.54           C\\nHETATM 1162  C4  NDG   150      48.182  38.000  28.337  1.00 75.54           C\\nHETATM 1163  C5  NDG   150      47.713  36.593  27.911  1.00 75.54           C\\nHETATM 1164  C6  NDG   150      46.759  36.818  26.770  1.00 75.54           C\\nHETATM 1165  C7  NDG   150      52.833  38.011  28.221  1.00 75.54           C\\nHETATM 1166  C8  NDG   150      52.890  38.993  27.014  1.00 75.54           C\\nHETATM 1167  O   NDG   150      48.769  35.789  27.306  1.00 75.54           O\\nHETATM 1168  O3  NDG   150      50.050  39.597  28.752  1.00 75.54           O\\nHETATM 1169  O4  NDG   150      47.473  38.303  29.576  1.00 75.54           O\\nHETATM 1170  O6  NDG   150      47.276  37.684  25.719  1.00 75.54           O\\nHETATM 1171  O7  NDG   150      54.002  37.838  28.780  1.00 75.54           O\\nHETATM 1172  N2  NDG   150      51.690  37.382  28.714  1.00 75.54           N\\nHETATM 1173  O1L NDG   150      50.479  35.538  28.690  1.00 75.54           O\\nCONECT  180 1107\\nCONECT  368 1014\\nCONECT  638  755\\nCONECT  724  849\\nEND\\n\",\"pdb\");\n",
       "\tviewergrid_151451555764[0][0].setStyle({\"cartoon\": {\"color\": \"spectrum\"}});\n",
       "\tviewergrid_151451555764[0][0].setStyle({\"hetflag\": true},{\"stick\": {}});\n",
       "\tviewergrid_151451555764[0][0].zoomTo();\n",
       "\tviewergrid_151451555764[0][0].zoom(1.4);\n",
       "\tviewergrid_151451555764[0][1].addModel(\"HEADER    HYDROLASE (O-GLYCOSYL)                  25-OCT-94   1LMP              \\nTITLE     THE CRYSTAL STRUCTURES OF THREE COMPLEXES BETWEEN                     \\nTITLE    2 CHITOOLIGOSACCHARIDES AND LYSOZYME FROM THE RAINBOW TROUT            \\nCOMPND    MOL_ID: 1;                                                            \\nCOMPND   2 MOLECULE: LYSOZYME;                                                  \\nCOMPND   3 CHAIN: A;                                                            \\nCOMPND   4 SYNONYM: MUCOPEPTIDE N-ACETYLMURAMYLHYDROLASE;                       \\nCOMPND   5 EC: 3.2.1.17                                                         \\nSOURCE    MOL_ID: 1;                                                            \\nSOURCE   2 ORGANISM_SCIENTIFIC: ONCORHYNCHUS MYKISS;                            \\nSOURCE   3 ORGANISM_COMMON: RAINBOW TROUT;                                      \\nSOURCE   4 ORGANISM_TAXID: 8022;                                                \\nSOURCE   5 ORGAN: KIDNEY                                                        \\nKEYWDS    HYDROLASE (O-GLYCOSYL)                                                \\nEXPDTA    X-RAY DIFFRACTION                                                     \\nAUTHOR    S.KARLSEN,E.HOUGH                                                     \\nREVDAT   3   13-JUL-11 1LMP    1       VERSN                                    \\nREVDAT   2   24-FEB-09 1LMP    1       VERSN                                    \\nREVDAT   1   01-JAN-96 1LMP    0                                                \\nJRNL        AUTH   S.KARLSEN,E.HOUGH                                            \\nJRNL        TITL   CRYSTAL STRUCTURES OF THREE COMPLEXES BETWEEN                \\nJRNL        TITL 2 CHITO-OLIGOSACCHARIDES AND LYSOZYME FROM THE RAINBOW TROUT.  \\nJRNL        TITL 3 HOW DISTORTED IS THE NAG SUGAR IN SITE D?                    \\nJRNL        REF    ACTA CRYSTALLOGR.,SECT.D      V.  51   962 1995              \\nJRNL        REFN                   ISSN 0907-4449                               \\nJRNL        PMID   15299765                                                     \\nJRNL        DOI    10.1107/S0907444995005105                                    \\nREMARK   1                                                                      \\nREMARK   1 REFERENCE 1                                                          \\nREMARK   1  AUTH   S.KARLSEN,B.E.ELIASSEN,L.KR.HANSEN,R.L.LARSEN,B.W.RIISE,     \\nREMARK   1  AUTH 2 A.O.SMALAAS,E.HOUGH,B.GRINDE                                 \\nREMARK   1  TITL   THE REFINED CRYSTAL STRUCTURE OF LYSOZYME FROM RAINBOW TROUT \\nREMARK   1  TITL 2 (ONCORHYNCHUS MYKISS)                                        \\nREMARK   1  REF    TO BE PUBLISHED                                              \\nREMARK   1  REFN                                                                \\nREMARK   1 REFERENCE 2                                                          \\nREMARK   1  AUTH   B.GRINDE,J.JOLLES,P.JOLLES                                   \\nREMARK   1  TITL   PURIFICATION AND CHARACTERIZATION OF TWO LYSOZYMES FROM      \\nREMARK   1  TITL 2 RAINBOW TROUT (SALMO GAIRDNERI)                              \\nREMARK   1  REF    EUR.J.BIOCHEM.                V. 173   269 1988              \\nREMARK   1  REFN                   ISSN 0014-2956                               \\nREMARK   2                                                                      \\nREMARK   2 RESOLUTION.    2.00 ANGSTROMS.                                       \\nREMARK   3                                                                      \\nREMARK   3 REFINEMENT.                                                          \\nREMARK   3   PROGRAM     : PROLSQ                                               \\nREMARK   3   AUTHORS     : KONNERT,HENDRICKSON                                  \\nREMARK   3                                                                      \\nREMARK   3  DATA USED IN REFINEMENT.                                            \\nREMARK   3   RESOLUTION RANGE HIGH (ANGSTROMS) : 2.00                           \\nREMARK   3   RESOLUTION RANGE LOW  (ANGSTROMS) : 8.00                           \\nREMARK   3   DATA CUTOFF            (SIGMA(F)) : 3.000                          \\nREMARK   3   COMPLETENESS FOR RANGE        (%) : NULL                           \\nREMARK   3   NUMBER OF REFLECTIONS             : 12175                          \\nREMARK   3                                                                      \\nREMARK   3  FIT TO DATA USED IN REFINEMENT.                                     \\nREMARK   3   CROSS-VALIDATION METHOD          : NULL                            \\nREMARK   3   FREE R VALUE TEST SET SELECTION  : NULL                            \\nREMARK   3   R VALUE     (WORKING + TEST SET) : 0.159                           \\nREMARK   3   R VALUE            (WORKING SET) : NULL                            \\nREMARK   3   FREE R VALUE                     : NULL                            \\nREMARK   3   FREE R VALUE TEST SET SIZE   (%) : NULL                            \\nREMARK   3   FREE R VALUE TEST SET COUNT      : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  FIT/AGREEMENT OF MODEL WITH ALL DATA.                               \\nREMARK   3   R VALUE   (WORKING + TEST SET, NO CUTOFF) : NULL                   \\nREMARK   3   R VALUE          (WORKING SET, NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE                  (NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE TEST SET SIZE (%, NO CUTOFF) : NULL                   \\nREMARK   3   FREE R VALUE TEST SET COUNT   (NO CUTOFF) : NULL                   \\nREMARK   3   TOTAL NUMBER OF REFLECTIONS   (NO CUTOFF) : NULL                   \\nREMARK   3                                                                      \\nREMARK   3  NUMBER OF NON-HYDROGEN ATOMS USED IN REFINEMENT.                    \\nREMARK   3   PROTEIN ATOMS            : 999                                     \\nREMARK   3   NUCLEIC ACID ATOMS       : 0                                       \\nREMARK   3   HETEROGEN ATOMS          : 43                                      \\nREMARK   3   SOLVENT ATOMS            : 117                                     \\nREMARK   3                                                                      \\nREMARK   3  B VALUES.                                                           \\nREMARK   3   FROM WILSON PLOT           (A**2) : NULL                           \\nREMARK   3   MEAN B VALUE      (OVERALL, A**2) : NULL                           \\nREMARK   3   OVERALL ANISOTROPIC B VALUE.                                       \\nREMARK   3    B11 (A**2) : NULL                                                 \\nREMARK   3    B22 (A**2) : NULL                                                 \\nREMARK   3    B33 (A**2) : NULL                                                 \\nREMARK   3    B12 (A**2) : NULL                                                 \\nREMARK   3    B13 (A**2) : NULL                                                 \\nREMARK   3    B23 (A**2) : NULL                                                 \\nREMARK   3                                                                      \\nREMARK   3  ESTIMATED COORDINATE ERROR.                                         \\nREMARK   3   ESD FROM LUZZATI PLOT        (A) : NULL                            \\nREMARK   3   ESD FROM SIGMAA              (A) : NULL                            \\nREMARK   3   LOW RESOLUTION CUTOFF        (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  RMS DEVIATIONS FROM IDEAL VALUES.                                   \\nREMARK   3   DISTANCE RESTRAINTS.                    RMS    SIGMA               \\nREMARK   3    BOND LENGTH                     (A) : 0.013 ; 0.020               \\nREMARK   3    ANGLE DISTANCE                  (A) : 0.047 ; 0.040               \\nREMARK   3    INTRAPLANAR 1-4 DISTANCE        (A) : 0.075 ; 0.050               \\nREMARK   3    H-BOND OR METAL COORDINATION    (A) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3   PLANE RESTRAINT                  (A) : 0.013 ; 0.020               \\nREMARK   3   CHIRAL-CENTER RESTRAINT       (A**3) : 0.037 ; 0.060               \\nREMARK   3                                                                      \\nREMARK   3   NON-BONDED CONTACT RESTRAINTS.                                     \\nREMARK   3    SINGLE TORSION                  (A) : 0.183 ; 0.030               \\nREMARK   3    MULTIPLE TORSION                (A) : 0.185 ; 0.300               \\nREMARK   3    H-BOND (X...Y)                  (A) : NULL  ; NULL                \\nREMARK   3    H-BOND (X-H...Y)                (A) : 0.235 ; 0.300               \\nREMARK   3                                                                      \\nREMARK   3   CONFORMATIONAL TORSION ANGLE RESTRAINTS.                           \\nREMARK   3    SPECIFIED                 (DEGREES) : NULL  ; NULL                \\nREMARK   3    PLANAR                    (DEGREES) : 5.200 ; 3.000               \\nREMARK   3    STAGGERED                 (DEGREES) : 18.200; 15.000              \\nREMARK   3    TRANSVERSE                (DEGREES) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL FACTOR RESTRAINTS.    RMS    SIGMA                \\nREMARK   3   MAIN-CHAIN BOND               (A**2) : NULL  ; NULL                \\nREMARK   3   MAIN-CHAIN ANGLE              (A**2) : NULL  ; NULL                \\nREMARK   3   SIDE-CHAIN BOND               (A**2) : NULL  ; NULL                \\nREMARK   3   SIDE-CHAIN ANGLE              (A**2) : NULL  ; NULL                \\nREMARK   3                                                                      \\nREMARK   3  OTHER REFINEMENT REMARKS: NULL                                      \\nREMARK   4                                                                      \\nREMARK   4 1LMP COMPLIES WITH FORMAT V. 3.30, 13-JUL-11                         \\nREMARK 100                                                                      \\nREMARK 100 THIS ENTRY HAS BEEN PROCESSED BY BNL.                                \\nREMARK 200                                                                      \\nREMARK 200 EXPERIMENTAL DETAILS                                                 \\nREMARK 200  EXPERIMENT TYPE                : X-RAY DIFFRACTION                  \\nREMARK 200  DATE OF DATA COLLECTION        : AUG-93                             \\nREMARK 200  TEMPERATURE           (KELVIN) : NULL                               \\nREMARK 200  PH                             : NULL                               \\nREMARK 200  NUMBER OF CRYSTALS USED        : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  SYNCHROTRON              (Y/N) : N                                  \\nREMARK 200  RADIATION SOURCE               : NULL                               \\nREMARK 200  BEAMLINE                       : NULL                               \\nREMARK 200  X-RAY GENERATOR MODEL          : NULL                               \\nREMARK 200  MONOCHROMATIC OR LAUE    (M/L) : M                                  \\nREMARK 200  WAVELENGTH OR RANGE        (A) : 1.5418                             \\nREMARK 200  MONOCHROMATOR                  : NULL                               \\nREMARK 200  OPTICS                         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  DETECTOR TYPE                  : AREA DETECTOR                      \\nREMARK 200  DETECTOR MANUFACTURER          : ENRAF-NONIUS FAST                  \\nREMARK 200  INTENSITY-INTEGRATION SOFTWARE : MADNES                             \\nREMARK 200  DATA SCALING SOFTWARE          : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  NUMBER OF UNIQUE REFLECTIONS   : 12175                              \\nREMARK 200  RESOLUTION RANGE HIGH      (A) : NULL                               \\nREMARK 200  RESOLUTION RANGE LOW       (A) : NULL                               \\nREMARK 200  REJECTION CRITERIA  (SIGMA(I)) : 3.000                              \\nREMARK 200                                                                      \\nREMARK 200 OVERALL.                                                             \\nREMARK 200  COMPLETENESS FOR RANGE     (%) : 96.9                               \\nREMARK 200  DATA REDUNDANCY                : NULL                               \\nREMARK 200  R MERGE                    (I) : 0.03300                            \\nREMARK 200  R SYM                      (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR THE DATA SET  : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 IN THE HIGHEST RESOLUTION SHELL.                                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE HIGH (A) : NULL                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE LOW  (A) : NULL                     \\nREMARK 200  COMPLETENESS FOR SHELL     (%) : NULL                               \\nREMARK 200  DATA REDUNDANCY IN SHELL       : NULL                               \\nREMARK 200  R MERGE FOR SHELL          (I) : NULL                               \\nREMARK 200  R SYM FOR SHELL            (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR SHELL         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 DIFFRACTION PROTOCOL: NULL                                           \\nREMARK 200 METHOD USED TO DETERMINE THE STRUCTURE: NULL                         \\nREMARK 200 SOFTWARE USED: NULL                                                  \\nREMARK 200 STARTING MODEL: NULL                                                 \\nREMARK 200                                                                      \\nREMARK 200 REMARK: NULL                                                         \\nREMARK 280                                                                      \\nREMARK 280 CRYSTAL                                                              \\nREMARK 280 SOLVENT CONTENT, VS   (%): 61.55                                     \\nREMARK 280 MATTHEWS COEFFICIENT, VM (ANGSTROMS**3/DA): 3.20                     \\nREMARK 280                                                                      \\nREMARK 280 CRYSTALLIZATION CONDITIONS: NULL                                     \\nREMARK 285                                                                      \\nREMARK 285 THE ENTRY COORDINATES                                                \\nREMARK 285 ARE NOT PRESENTED IN THE STANDARD CRYSTAL FRAME.                     \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY                                            \\nREMARK 290 SYMMETRY OPERATORS FOR SPACE GROUP: P 31 2 1                         \\nREMARK 290                                                                      \\nREMARK 290      SYMOP   SYMMETRY                                                \\nREMARK 290     NNNMMM   OPERATOR                                                \\nREMARK 290       1555   X,Y,Z                                                   \\nREMARK 290       2555   -Y,X-Y,Z+1/3                                            \\nREMARK 290       3555   -X+Y,-X,Z+2/3                                           \\nREMARK 290       4555   Y,X,-Z                                                  \\nREMARK 290       5555   X-Y,-Y,-Z+2/3                                           \\nREMARK 290       6555   -X,-X+Y,-Z+1/3                                          \\nREMARK 290                                                                      \\nREMARK 290     WHERE NNN -> OPERATOR NUMBER                                     \\nREMARK 290           MMM -> TRANSLATION VECTOR                                  \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY TRANSFORMATIONS                            \\nREMARK 290 THE FOLLOWING TRANSFORMATIONS OPERATE ON THE ATOM/HETATM             \\nREMARK 290 RECORDS IN THIS ENTRY TO PRODUCE CRYSTALLOGRAPHICALLY                \\nREMARK 290 RELATED MOLECULES.                                                   \\nREMARK 290   SMTRY1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 290   SMTRY1   2 -0.500000 -0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   2  0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   2  0.000000  0.000000  1.000000       18.09627            \\nREMARK 290   SMTRY1   3 -0.500000  0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   3 -0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   3  0.000000  0.000000  1.000000       36.19254            \\nREMARK 290   SMTRY1   4  0.500000  0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   4  0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   4  0.000000  0.000000 -1.000000        0.00000            \\nREMARK 290   SMTRY1   5  0.500000 -0.866049  0.000000        0.00000            \\nREMARK 290   SMTRY2   5 -0.866002 -0.500000  0.000000        0.00000            \\nREMARK 290   SMTRY3   5  0.000000  0.000000 -1.000000       36.19254            \\nREMARK 290   SMTRY1   6 -1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   6  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   6  0.000000  0.000000 -1.000000       18.09627            \\nREMARK 290                                                                      \\nREMARK 290 REMARK: NULL                                                         \\nREMARK 300                                                                      \\nREMARK 300 BIOMOLECULE: 1                                                       \\nREMARK 300 SEE REMARK 350 FOR THE AUTHOR PROVIDED AND/OR PROGRAM                \\nREMARK 300 GENERATED ASSEMBLY INFORMATION FOR THE STRUCTURE IN                  \\nREMARK 300 THIS ENTRY. THE REMARK MAY ALSO PROVIDE INFORMATION ON               \\nREMARK 300 BURIED SURFACE AREA.                                                 \\nREMARK 350                                                                      \\nREMARK 350 COORDINATES FOR A COMPLETE MULTIMER REPRESENTING THE KNOWN           \\nREMARK 350 BIOLOGICALLY SIGNIFICANT OLIGOMERIZATION STATE OF THE                \\nREMARK 350 MOLECULE CAN BE GENERATED BY APPLYING BIOMT TRANSFORMATIONS          \\nREMARK 350 GIVEN BELOW.  BOTH NON-CRYSTALLOGRAPHIC AND                          \\nREMARK 350 CRYSTALLOGRAPHIC OPERATIONS ARE GIVEN.                               \\nREMARK 350                                                                      \\nREMARK 350 BIOMOLECULE: 1                                                       \\nREMARK 350 AUTHOR DETERMINED BIOLOGICAL UNIT: MONOMERIC                         \\nREMARK 350 APPLY THE FOLLOWING TO CHAINS: A                                     \\nREMARK 350   BIOMT1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 350   BIOMT2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 350   BIOMT3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS IN SAME ASYMMETRIC UNIT                     \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS ARE IN CLOSE CONTACT.                            \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI           DISTANCE          \\nREMARK 500   O5   NAG A   131     O4   NDG A   132              2.11            \\nREMARK 500   C1   NAG A   131     C4   NDG A   132              2.14            \\nREMARK 500   OE1  GLU A    35     O    HOH A   244              2.14            \\nREMARK 500   NH1  ARG A    45     NH2  ARG A    68              2.19            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS                                             \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS THAT ARE RELATED BY CRYSTALLOGRAPHIC             \\nREMARK 500 SYMMETRY ARE IN CLOSE CONTACT.  AN ATOM LOCATED WITHIN 0.15          \\nREMARK 500 ANGSTROMS OF A SYMMETRY RELATED ATOM IS ASSUMED TO BE ON A           \\nREMARK 500 SPECIAL POSITION AND IS, THEREFORE, LISTED IN REMARK 375             \\nREMARK 500 INSTEAD OF REMARK 500.  ATOMS WITH NON-BLANK ALTERNATE               \\nREMARK 500 LOCATION INDICATORS ARE NOT INCLUDED IN THE CALCULATIONS.            \\nREMARK 500                                                                      \\nREMARK 500 DISTANCE CUTOFF:                                                     \\nREMARK 500 2.2 ANGSTROMS FOR CONTACTS NOT INVOLVING HYDROGEN ATOMS              \\nREMARK 500 1.6 ANGSTROMS FOR CONTACTS INVOLVING HYDROGEN ATOMS                  \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI  SSYMOP   DISTANCE          \\nREMARK 500   O    HOH A   143     O    HOH A   143     4556     1.47            \\nREMARK 500   O    HOH A   170     O    HOH A   170     4556     1.51            \\nREMARK 500   O    SER A    81     O    HOH A   170     4556     2.01            \\nREMARK 500   O    HOH A   175     O    HOH A   235     4556     2.17            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: COVALENT BOND ANGLES                                       \\nREMARK 500                                                                      \\nREMARK 500 THE STEREOCHEMICAL PARAMETERS OF THE FOLLOWING RESIDUES              \\nREMARK 500 HAVE VALUES WHICH DEVIATE FROM EXPECTED VALUES BY MORE               \\nREMARK 500 THAN 6*RMSD (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN               \\nREMARK 500 IDENTIFIER; SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                 \\nREMARK 500                                                                      \\nREMARK 500 STANDARD TABLE:                                                      \\nREMARK 500 FORMAT: (10X,I3,1X,A3,1X,A1,I4,A1,3(1X,A4,2X),12X,F5.1)              \\nREMARK 500                                                                      \\nREMARK 500 EXPECTED VALUES PROTEIN: ENGH AND HUBER, 1999                        \\nREMARK 500 EXPECTED VALUES NUCLEIC ACID: CLOWNEY ET AL 1996                     \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI ATM1   ATM2   ATM3                                     \\nREMARK 500    ASP A   4   CB  -  CG  -  OD1 ANGL. DEV. =  -6.3 DEGREES          \\nREMARK 500    ASP A   4   CB  -  CG  -  OD2 ANGL. DEV. =   5.7 DEGREES          \\nREMARK 500    ARG A   5   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.1 DEGREES          \\nREMARK 500    ASP A  18   CB  -  CG  -  OD1 ANGL. DEV. =   6.0 DEGREES          \\nREMARK 500    ARG A  45   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.4 DEGREES          \\nREMARK 500    ASP A  48   CB  -  CG  -  OD1 ANGL. DEV. =   6.5 DEGREES          \\nREMARK 500    ASP A  48   CB  -  CG  -  OD2 ANGL. DEV. =  -5.9 DEGREES          \\nREMARK 500    ARG A  61   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.5 DEGREES          \\nREMARK 500    TYR A  62   CB  -  CG  -  CD2 ANGL. DEV. =  -4.7 DEGREES          \\nREMARK 500    ASP A  86   CB  -  CG  -  OD1 ANGL. DEV. =   9.2 DEGREES          \\nREMARK 500    ARG A  93   NE  -  CZ  -  NH2 ANGL. DEV. =  -3.3 DEGREES          \\nREMARK 500    ARG A  97   NE  -  CZ  -  NH1 ANGL. DEV. =   5.1 DEGREES          \\nREMARK 500    ARG A  97   NE  -  CZ  -  NH2 ANGL. DEV. =  -4.6 DEGREES          \\nREMARK 500    ARG A 121   CD  -  NE  -  CZ  ANGL. DEV. =  10.2 DEGREES          \\nREMARK 500    ARG A 121   NE  -  CZ  -  NH1 ANGL. DEV. =   5.9 DEGREES          \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: PLANAR GROUPS                                              \\nREMARK 500                                                                      \\nREMARK 500 PLANAR GROUPS IN THE FOLLOWING RESIDUES HAVE A TOTAL                 \\nREMARK 500 RMS DISTANCE OF ALL ATOMS FROM THE BEST-FIT PLANE                    \\nREMARK 500 BY MORE THAN AN EXPECTED VALUE OF 6*RMSD, WITH AN                    \\nREMARK 500 RMSD 0.02 ANGSTROMS, OR AT LEAST ONE ATOM HAS                        \\nREMARK 500 AN RMSD GREATER THAN THIS VALUE                                      \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        RMS     TYPE                                    \\nREMARK 500    ARG A  10         0.11    SIDE CHAIN                              \\nREMARK 500    ARG A  45         0.09    SIDE CHAIN                              \\nREMARK 500    ARG A  61         0.17    SIDE CHAIN                              \\nREMARK 500    ARG A  79         0.13    SIDE CHAIN                              \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 525                                                                      \\nREMARK 525 SOLVENT                                                              \\nREMARK 525                                                                      \\nREMARK 525 THE SOLVENT MOLECULES HAVE CHAIN IDENTIFIERS THAT                    \\nREMARK 525 INDICATE THE POLYMER CHAIN WITH WHICH THEY ARE MOST                  \\nREMARK 525 CLOSELY ASSOCIATED. THE REMARK LISTS ALL THE SOLVENT                 \\nREMARK 525 MOLECULES WHICH ARE MORE THAN 5A AWAY FROM THE                       \\nREMARK 525 NEAREST POLYMER CHAIN (M = MODEL NUMBER;                             \\nREMARK 525 RES=RESIDUE NAME; C=CHAIN IDENTIFIER; SSEQ=SEQUENCE                  \\nREMARK 525 NUMBER; I=INSERTION CODE):                                           \\nREMARK 525                                                                      \\nREMARK 525  M RES CSSEQI                                                        \\nREMARK 525    HOH A 214        DISTANCE =  8.17 ANGSTROMS                       \\nREMARK 800                                                                      \\nREMARK 800 SITE                                                                 \\nREMARK 800 SITE_IDENTIFIER: AC1                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NAG A 130                 \\nREMARK 800                                                                      \\nREMARK 800 SITE_IDENTIFIER: AC2                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NAG A 131                 \\nREMARK 800                                                                      \\nREMARK 800 SITE_IDENTIFIER: AC3                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE NDG A 132                 \\nDBREF  1LMP A    1   129  UNP    P11941   LYC2_ONCMY      16    144             \\nSEQADV 1LMP ASP A   86  UNP  P11941    ALA   101 CONFLICT                       \\nSEQRES   1 A  129  LYS VAL TYR ASP ARG CYS GLU LEU ALA ARG ALA LEU LYS          \\nSEQRES   2 A  129  ALA SER GLY MET ASP GLY TYR ALA GLY ASN SER LEU PRO          \\nSEQRES   3 A  129  ASN TRP VAL CYS LEU SER LYS TRP GLU SER SER TYR ASN          \\nSEQRES   4 A  129  THR GLN ALA THR ASN ARG ASN THR ASP GLY SER THR ASP          \\nSEQRES   5 A  129  TYR GLY ILE PHE GLN ILE ASN SER ARG TYR TRP CYS ASP          \\nSEQRES   6 A  129  ASP GLY ARG THR PRO GLY ALA LYS ASN VAL CYS GLY ILE          \\nSEQRES   7 A  129  ARG CYS SER GLN LEU LEU THR ASP ASP LEU THR VAL ALA          \\nSEQRES   8 A  129  ILE ARG CYS ALA LYS ARG VAL VAL LEU ASP PRO ASN GLY          \\nSEQRES   9 A  129  ILE GLY ALA TRP VAL ALA TRP ARG LEU HIS CYS GLN ASN          \\nSEQRES  10 A  129  GLN ASP LEU ARG SER TYR VAL ALA GLY CYS GLY VAL              \\nHET    NAG  A 130      14                                                       \\nHET    NAG  A 131      14                                                       \\nHET    NDG  A 132      15                                                       \\nHETNAM     NAG N-ACETYL-D-GLUCOSAMINE                                           \\nHETNAM     NDG 2-(ACETYLAMINO)-2-DEOXY-A-D-GLUCOPYRANOSE                        \\nFORMUL   2  NAG    2(C8 H15 N O6)                                               \\nFORMUL   2  NDG    C8 H15 N O6                                                  \\nFORMUL   3  HOH   *117(H2 O)                                                    \\nHELIX    1   1 ARG A    5  ALA A   14  1                                  10    \\nHELIX    2   2 TYR A   20  GLY A   22  5                                   3    \\nHELIX    3   3 LEU A   25  SER A   36  1                                  12    \\nHELIX    4   4 CYS A   80  LEU A   83  5                                   4    \\nHELIX    5   5 THR A   89  LEU A  100  1                                  12    \\nHELIX    6   6 GLY A  104  ALA A  107  5                                   4    \\nHELIX    7   7 VAL A  109  HIS A  114  1                                   6    \\nHELIX    8   8 ARG A  121  VAL A  124  1                                   4    \\nSHEET    1   A 2 THR A  43  ARG A  45  0                                        \\nSHEET    2   A 2 THR A  51  TYR A  53 -1  N  ASP A  52   O  ASN A  44           \\nSSBOND   1 CYS A    6    CYS A  127                          1555   1555  2.00  \\nSSBOND   2 CYS A   30    CYS A  115                          1555   1555  2.01  \\nSSBOND   3 CYS A   64    CYS A   80                          1555   1555  2.03  \\nSSBOND   4 CYS A   76    CYS A   94                          1555   1555  2.02  \\nLINK         C1  NAG A 130                 O4  NAG A 131     1555   1555  1.39  \\nLINK         C1  NAG A 131                 O4  NDG A 132     1555   1555  1.41  \\nSITE     1 AC1  7 TRP A  63  ASP A 101  ASN A 103  NAG A 131                    \\nSITE     2 AC1  7 HOH A 152  HOH A 242  HOH A 245                               \\nSITE     1 AC2  9 ILE A  58  ASN A  59  TYR A  62  TRP A  63                    \\nSITE     2 AC2  9 ALA A 107  TRP A 108  NAG A 130  NDG A 132                    \\nSITE     3 AC2  9 HOH A 151                                                     \\nSITE     1 AC3 11 GLU A  35  ASN A  46  ASP A  52  GLN A  57                    \\nSITE     2 AC3 11 ASN A  59  TRP A 108  VAL A 109  NAG A 131                    \\nSITE     3 AC3 11 HOH A 149  HOH A 244  HOH A 249                               \\nCRYST1   76.420   76.420   54.290  90.00  90.00 120.00 P 31 2 1      6          \\nORIGX1      1.000000  0.000000  0.000000        0.00000                         \\nORIGX2      0.000000  1.000000  0.000000        0.00000                         \\nORIGX3      0.000000  0.000000  1.000000        0.00000                         \\nSCALE1      0.015110  0.000000  0.000000        0.00000                         \\nSCALE2      0.007555  0.013086  0.000000        0.00000                         \\nSCALE3      0.000000  0.000000  0.018420        0.00000                         \\nATOM      1  N   LYS A   1      40.347  23.372  17.250  1.00 18.46           N  \\nATOM      2  CA  LYS A   1      40.073  23.407  15.807  1.00 15.65           C  \\nATOM      3  C   LYS A   1      40.596  24.629  15.115  1.00 17.93           C  \\nATOM      4  O   LYS A   1      40.458  25.714  15.693  1.00 14.83           O  \\nATOM      5  CB  LYS A   1      38.560  23.401  15.582  1.00 15.31           C  \\nATOM      6  CG  LYS A   1      38.032  23.710  14.177  1.00 19.38           C  \\nATOM      7  CD  LYS A   1      36.559  23.377  14.207  1.00 23.13           C  \\nATOM      8  CE  LYS A   1      35.670  23.601  13.032  1.00 26.45           C  \\nATOM      9  NZ  LYS A   1      36.120  22.779  11.894  1.00 23.20           N  \\nATOM     10  N   VAL A   2      41.125  24.494  13.923  1.00 15.30           N  \\nATOM     11  CA  VAL A   2      41.608  25.678  13.176  1.00 20.02           C  \\nATOM     12  C   VAL A   2      40.514  25.924  12.118  1.00 23.84           C  \\nATOM     13  O   VAL A   2      40.414  25.137  11.181  1.00 24.49           O  \\nATOM     14  CB  VAL A   2      43.013  25.575  12.573  1.00 20.68           C  \\nATOM     15  CG1 VAL A   2      43.281  26.867  11.826  1.00 19.15           C  \\nATOM     16  CG2 VAL A   2      44.049  25.168  13.622  1.00 10.67           C  \\nATOM     17  N   TYR A   3      39.710  26.949  12.315  1.00 23.36           N  \\nATOM     18  CA  TYR A   3      38.638  27.323  11.400  1.00 14.17           C  \\nATOM     19  C   TYR A   3      39.186  27.965  10.134  1.00 16.95           C  \\nATOM     20  O   TYR A   3      40.165  28.702  10.075  1.00 19.73           O  \\nATOM     21  CB  TYR A   3      37.632  28.347  11.995  1.00 12.31           C  \\nATOM     22  CG  TYR A   3      36.652  27.714  12.936  1.00 14.11           C  \\nATOM     23  CD1 TYR A   3      36.982  27.245  14.192  1.00 13.59           C  \\nATOM     24  CD2 TYR A   3      35.318  27.563  12.512  1.00 19.65           C  \\nATOM     25  CE1 TYR A   3      36.048  26.639  15.053  1.00 14.59           C  \\nATOM     26  CE2 TYR A   3      34.351  26.957  13.318  1.00 18.45           C  \\nATOM     27  CZ  TYR A   3      34.741  26.508  14.586  1.00 21.46           C  \\nATOM     28  OH  TYR A   3      33.842  25.916  15.417  1.00 22.23           O  \\nATOM     29  N   ASP A   4      38.472  27.746   9.078  1.00 20.20           N  \\nATOM     30  CA  ASP A   4      38.563  28.275   7.732  1.00 22.68           C  \\nATOM     31  C   ASP A   4      37.913  29.655   7.877  1.00 13.41           C  \\nATOM     32  O   ASP A   4      36.886  29.708   8.609  1.00 14.78           O  \\nATOM     33  CB  ASP A   4      37.881  27.335   6.714  1.00 22.82           C  \\nATOM     34  CG  ASP A   4      37.437  28.107   5.488  1.00 24.29           C  \\nATOM     35  OD1 ASP A   4      38.372  28.271   4.674  1.00 44.94           O  \\nATOM     36  OD2 ASP A   4      36.299  28.575   5.338  1.00 40.03           O  \\nATOM     37  N   ARG A   5      38.371  30.656   7.186  1.00 16.12           N  \\nATOM     38  CA  ARG A   5      37.790  31.993   7.264  1.00 22.57           C  \\nATOM     39  C   ARG A   5      36.286  32.052   7.017  1.00 27.39           C  \\nATOM     40  O   ARG A   5      35.604  32.681   7.857  1.00 18.92           O  \\nATOM     41  CB  ARG A   5      38.476  32.885   6.251  1.00 14.57           C  \\nATOM     42  CG  ARG A   5      37.915  34.299   6.177  1.00 21.83           C  \\nATOM     43  CD  ARG A   5      38.776  35.072   5.208  1.00 20.58           C  \\nATOM     44  NE  ARG A   5      38.632  34.614   3.827  1.00 26.09           N  \\nATOM     45  CZ  ARG A   5      37.680  34.895   2.939  1.00 24.62           C  \\nATOM     46  NH1 ARG A   5      36.677  35.715   3.197  1.00 22.32           N  \\nATOM     47  NH2 ARG A   5      37.762  34.300   1.752  1.00 23.40           N  \\nATOM     48  N   CYS A   6      35.764  31.444   5.964  1.00 22.68           N  \\nATOM     49  CA  CYS A   6      34.313  31.485   5.674  1.00 17.04           C  \\nATOM     50  C   CYS A   6      33.558  30.617   6.652  1.00 14.60           C  \\nATOM     51  O   CYS A   6      32.428  30.993   6.976  1.00 17.85           O  \\nATOM     52  CB  CYS A   6      34.031  31.115   4.209  1.00 20.63           C  \\nATOM     53  SG  CYS A   6      34.518  32.471   3.120  1.00 19.40           S  \\nATOM     54  N   GLU A   7      34.140  29.516   7.066  1.00 14.34           N  \\nATOM     55  CA  GLU A   7      33.509  28.647   8.067  1.00 15.91           C  \\nATOM     56  C   GLU A   7      33.279  29.378   9.374  1.00 13.36           C  \\nATOM     57  O   GLU A   7      32.186  29.245   9.998  1.00 13.77           O  \\nATOM     58  CB  GLU A   7      34.393  27.429   8.264  1.00 17.03           C  \\nATOM     59  CG  GLU A   7      33.909  26.462   9.310  1.00 14.95           C  \\nATOM     60  CD  GLU A   7      34.938  25.403   9.582  1.00 27.28           C  \\nATOM     61  OE1 GLU A   7      36.114  25.543   9.367  1.00 21.35           O  \\nATOM     62  OE2 GLU A   7      34.447  24.376  10.043  1.00 23.54           O  \\nATOM     63  N   LEU A   8      34.309  30.157   9.740  1.00 11.86           N  \\nATOM     64  CA  LEU A   8      34.180  31.000  10.946  1.00 11.28           C  \\nATOM     65  C   LEU A   8      33.104  32.053  10.689  1.00 12.97           C  \\nATOM     66  O   LEU A   8      32.245  32.277  11.530  1.00 16.68           O  \\nATOM     67  CB  LEU A   8      35.499  31.652  11.332  1.00 13.19           C  \\nATOM     68  CG  LEU A   8      35.466  32.531  12.586  1.00 19.14           C  \\nATOM     69  CD1 LEU A   8      35.149  31.692  13.809  1.00 17.13           C  \\nATOM     70  CD2 LEU A   8      36.834  33.255  12.661  1.00 15.84           C  \\nATOM     71  N   ALA A   9      33.162  32.719   9.530  1.00 14.21           N  \\nATOM     72  CA  ALA A   9      32.170  33.765   9.183  1.00 15.32           C  \\nATOM     73  C   ALA A   9      30.762  33.199   9.309  1.00 20.76           C  \\nATOM     74  O   ALA A   9      29.881  33.864   9.910  1.00 20.35           O  \\nATOM     75  CB  ALA A   9      32.493  34.365   7.812  1.00 12.21           C  \\nATOM     76  N   ARG A  10      30.481  32.006   8.808  1.00 13.12           N  \\nATOM     77  CA  ARG A  10      29.153  31.416   8.949  1.00  8.69           C  \\nATOM     78  C   ARG A  10      28.763  31.138  10.381  1.00 14.66           C  \\nATOM     79  O   ARG A  10      27.599  31.407  10.743  1.00 16.18           O  \\nATOM     80  CB  ARG A  10      29.136  30.134   8.077  1.00 11.95           C  \\nATOM     81  CG  ARG A  10      29.355  30.655   6.636  1.00 23.45           C  \\nATOM     82  CD  ARG A  10      28.976  29.728   5.541  1.00 44.55           C  \\nATOM     83  NE  ARG A  10      29.278  28.340   5.882  1.00 38.82           N  \\nATOM     84  CZ  ARG A  10      30.456  27.778   5.573  1.00 57.87           C  \\nATOM     85  NH1 ARG A  10      31.203  28.272   4.585  1.00 24.69           N  \\nATOM     86  NH2 ARG A  10      30.906  26.699   6.234  1.00 35.62           N  \\nATOM     87  N   ALA A  11      29.625  30.549  11.195  1.00 20.04           N  \\nATOM     88  CA  ALA A  11      29.349  30.250  12.599  1.00 15.30           C  \\nATOM     89  C   ALA A  11      29.102  31.554  13.370  1.00 20.91           C  \\nATOM     90  O   ALA A  11      28.197  31.569  14.233  1.00 16.15           O  \\nATOM     91  CB  ALA A  11      30.477  29.420  13.211  1.00 11.27           C  \\nATOM     92  N   LEU A  12      29.803  32.645  13.105  1.00 14.33           N  \\nATOM     93  CA  LEU A  12      29.576  33.923  13.793  1.00 17.22           C  \\nATOM     94  C   LEU A  12      28.223  34.539  13.409  1.00 12.82           C  \\nATOM     95  O   LEU A  12      27.460  35.053  14.245  1.00 17.90           O  \\nATOM     96  CB  LEU A  12      30.795  34.867  13.521  1.00  9.99           C  \\nATOM     97  CG  LEU A  12      32.162  34.437  14.075  1.00 19.97           C  \\nATOM     98  CD1 LEU A  12      33.254  35.426  13.707  1.00 19.86           C  \\nATOM     99  CD2 LEU A  12      31.992  34.260  15.594  1.00 16.73           C  \\nATOM    100  N   LYS A  13      27.986  34.515  12.104  1.00 13.83           N  \\nATOM    101  CA  LYS A  13      26.714  35.051  11.569  1.00 16.29           C  \\nATOM    102  C   LYS A  13      25.539  34.276  12.189  1.00 22.44           C  \\nATOM    103  O   LYS A  13      24.552  34.865  12.661  1.00 16.93           O  \\nATOM    104  CB  LYS A  13      26.691  35.014  10.060  1.00 23.15           C  \\nATOM    105  CG  LYS A  13      25.395  35.325   9.332  1.00 22.03           C  \\nATOM    106  CD  LYS A  13      24.829  36.685   9.661  1.00 36.34           C  \\nATOM    107  CE  LYS A  13      24.096  37.439   8.572  1.00 34.01           C  \\nATOM    108  NZ  LYS A  13      24.575  37.038   7.221  1.00 65.12           N  \\nATOM    109  N   ALA A  14      25.589  32.966  12.237  1.00 18.73           N  \\nATOM    110  CA  ALA A  14      24.597  32.046  12.784  1.00 23.65           C  \\nATOM    111  C   ALA A  14      24.386  32.312  14.258  1.00 17.69           C  \\nATOM    112  O   ALA A  14      23.274  32.069  14.748  1.00 23.46           O  \\nATOM    113  CB  ALA A  14      24.985  30.567  12.620  1.00 16.71           C  \\nATOM    114  N   SER A  15      25.385  32.787  14.978  1.00 18.66           N  \\nATOM    115  CA  SER A  15      25.349  33.048  16.428  1.00 19.35           C  \\nATOM    116  C   SER A  15      24.997  34.465  16.862  1.00 17.79           C  \\nATOM    117  O   SER A  15      25.132  34.714  18.068  1.00 25.00           O  \\nATOM    118  CB  SER A  15      26.716  32.737  17.060  1.00 24.47           C  \\nATOM    119  OG  SER A  15      26.830  31.324  17.030  1.00 37.07           O  \\nATOM    120  N   GLY A  16      24.613  35.294  15.937  1.00 19.45           N  \\nATOM    121  CA  GLY A  16      24.171  36.645  16.139  1.00 16.50           C  \\nATOM    122  C   GLY A  16      25.245  37.689  16.334  1.00 21.68           C  \\nATOM    123  O   GLY A  16      24.886  38.768  16.869  1.00 20.53           O  \\nATOM    124  N   MET A  17      26.450  37.345  15.882  1.00 21.90           N  \\nATOM    125  CA  MET A  17      27.580  38.317  16.009  1.00 13.23           C  \\nATOM    126  C   MET A  17      27.510  39.430  14.969  1.00 19.76           C  \\nATOM    127  O   MET A  17      28.146  40.472  15.200  1.00 21.08           O  \\nATOM    128  CB  MET A  17      28.972  37.683  15.921  1.00 10.50           C  \\nATOM    129  CG  MET A  17      29.098  36.642  17.044  1.00 17.31           C  \\nATOM    130  SD  MET A  17      29.255  37.555  18.582  1.00 30.13           S  \\nATOM    131  CE  MET A  17      31.007  37.771  18.782  1.00 29.67           C  \\nATOM    132  N   ASP A  18      26.786  39.296  13.862  1.00 22.04           N  \\nATOM    133  CA  ASP A  18      26.760  40.394  12.862  1.00 16.68           C  \\nATOM    134  C   ASP A  18      25.941  41.570  13.408  1.00 29.72           C  \\nATOM    135  O   ASP A  18      24.712  41.514  13.401  1.00 25.38           O  \\nATOM    136  CB  ASP A  18      26.312  39.826  11.519  1.00 18.74           C  \\nATOM    137  CG  ASP A  18      26.467  40.887  10.442  1.00 34.76           C  \\nATOM    138  OD1 ASP A  18      27.194  41.890  10.546  1.00 22.73           O  \\nATOM    139  OD2 ASP A  18      25.792  40.715   9.412  1.00 31.88           O  \\nATOM    140  N   GLY A  19      26.590  42.624  13.893  1.00 23.44           N  \\nATOM    141  CA  GLY A  19      25.904  43.794  14.434  1.00 20.18           C  \\nATOM    142  C   GLY A  19      25.820  43.776  15.950  1.00 19.60           C  \\nATOM    143  O   GLY A  19      25.195  44.714  16.480  1.00 26.69           O  \\nATOM    144  N   TYR A  20      26.417  42.782  16.613  1.00 16.96           N  \\nATOM    145  CA  TYR A  20      26.321  42.705  18.081  1.00 17.33           C  \\nATOM    146  C   TYR A  20      26.986  43.947  18.676  1.00 18.43           C  \\nATOM    147  O   TYR A  20      28.163  44.178  18.374  1.00 18.22           O  \\nATOM    148  CB  TYR A  20      26.917  41.397  18.650  1.00 12.58           C  \\nATOM    149  CG  TYR A  20      26.408  41.254  20.086  1.00 13.24           C  \\nATOM    150  CD1 TYR A  20      25.175  40.690  20.346  1.00 17.66           C  \\nATOM    151  CD2 TYR A  20      27.166  41.730  21.170  1.00 16.33           C  \\nATOM    152  CE1 TYR A  20      24.699  40.597  21.650  1.00 20.69           C  \\nATOM    153  CE2 TYR A  20      26.689  41.649  22.478  1.00 20.26           C  \\nATOM    154  CZ  TYR A  20      25.438  41.069  22.717  1.00 21.29           C  \\nATOM    155  OH  TYR A  20      24.950  40.954  23.982  1.00 27.09           O  \\nATOM    156  N   ALA A  21      26.261  44.702  19.474  1.00 21.02           N  \\nATOM    157  CA  ALA A  21      26.686  45.950  20.117  1.00 14.59           C  \\nATOM    158  C   ALA A  21      27.240  46.930  19.061  1.00 26.05           C  \\nATOM    159  O   ALA A  21      28.153  47.748  19.282  1.00 24.30           O  \\nATOM    160  CB  ALA A  21      27.671  45.637  21.231  1.00 20.86           C  \\nATOM    161  N   GLY A  22      26.662  46.842  17.862  1.00 19.35           N  \\nATOM    162  CA  GLY A  22      27.020  47.645  16.696  1.00 16.32           C  \\nATOM    163  C   GLY A  22      28.259  47.255  15.918  1.00 29.12           C  \\nATOM    164  O   GLY A  22      28.809  48.084  15.157  1.00 23.30           O  \\nATOM    165  N   ASN A  23      28.805  46.071  16.049  1.00 19.67           N  \\nATOM    166  CA  ASN A  23      30.014  45.558  15.400  1.00 19.85           C  \\nATOM    167  C   ASN A  23      29.665  44.587  14.284  1.00 18.50           C  \\nATOM    168  O   ASN A  23      29.251  43.444  14.598  1.00 20.81           O  \\nATOM    169  CB  ASN A  23      30.919  44.867  16.436  1.00 18.98           C  \\nATOM    170  CG  ASN A  23      31.326  45.880  17.500  1.00 23.62           C  \\nATOM    171  OD1 ASN A  23      30.956  45.831  18.674  1.00 24.10           O  \\nATOM    172  ND2 ASN A  23      32.050  46.845  17.011  1.00 18.56           N  \\nATOM    173  N   SER A  24      29.790  45.013  13.061  1.00 19.76           N  \\nATOM    174  CA  SER A  24      29.472  44.173  11.893  1.00 22.86           C  \\nATOM    175  C   SER A  24      30.412  42.971  11.865  1.00 17.74           C  \\nATOM    176  O   SER A  24      31.519  43.050  12.384  1.00 16.59           O  \\nATOM    177  CB  SER A  24      29.529  44.986  10.611  1.00 22.63           C  \\nATOM    178  OG  SER A  24      30.868  45.404  10.339  1.00 23.48           O  \\nATOM    179  N   LEU A  25      29.958  41.916  11.207  1.00 15.58           N  \\nATOM    180  CA  LEU A  25      30.677  40.656  11.075  1.00 15.40           C  \\nATOM    181  C   LEU A  25      32.137  40.746  10.685  1.00 15.36           C  \\nATOM    182  O   LEU A  25      32.948  40.026  11.316  1.00 15.67           O  \\nATOM    183  CB  LEU A  25      29.835  39.766  10.074  1.00 14.88           C  \\nATOM    184  CG  LEU A  25      30.298  38.309   9.963  1.00 18.70           C  \\nATOM    185  CD1 LEU A  25      30.115  37.578  11.292  1.00 15.67           C  \\nATOM    186  CD2 LEU A  25      29.516  37.603   8.847  1.00 17.13           C  \\nATOM    187  N   PRO A  26      32.489  41.532   9.691  1.00 21.37           N  \\nATOM    188  CA  PRO A  26      33.891  41.644   9.273  1.00 18.87           C  \\nATOM    189  C   PRO A  26      34.825  42.072  10.421  1.00 20.05           C  \\nATOM    190  O   PRO A  26      36.000  41.701  10.366  1.00 14.84           O  \\nATOM    191  CB  PRO A  26      33.918  42.587   8.067  1.00 22.73           C  \\nATOM    192  CG  PRO A  26      32.491  42.624   7.630  1.00 18.42           C  \\nATOM    193  CD  PRO A  26      31.637  42.406   8.871  1.00 16.61           C  \\nATOM    194  N   ASN A  27      34.361  42.789  11.425  1.00 17.22           N  \\nATOM    195  CA  ASN A  27      35.113  43.225  12.608  1.00 13.27           C  \\nATOM    196  C   ASN A  27      35.612  42.017  13.377  1.00 10.15           C  \\nATOM    197  O   ASN A  27      36.783  41.915  13.704  1.00 15.05           O  \\nATOM    198  CB  ASN A  27      34.267  44.154  13.516  1.00 13.80           C  \\nATOM    199  CG  ASN A  27      34.292  45.508  12.799  1.00 24.88           C  \\nATOM    200  OD1 ASN A  27      35.341  46.185  12.812  1.00 20.38           O  \\nATOM    201  ND2 ASN A  27      33.233  45.890  12.133  1.00 23.80           N  \\nATOM    202  N   TRP A  28      34.645  41.134  13.583  1.00 15.92           N  \\nATOM    203  CA  TRP A  28      34.826  39.856  14.319  1.00 13.94           C  \\nATOM    204  C   TRP A  28      35.707  38.864  13.572  1.00 15.40           C  \\nATOM    205  O   TRP A  28      36.507  38.214  14.259  1.00 14.86           O  \\nATOM    206  CB  TRP A  28      33.508  39.191  14.642  1.00 13.16           C  \\nATOM    207  CG  TRP A  28      32.568  40.049  15.428  1.00 16.33           C  \\nATOM    208  CD1 TRP A  28      31.427  40.678  15.018  1.00 14.77           C  \\nATOM    209  CD2 TRP A  28      32.716  40.356  16.822  1.00 17.90           C  \\nATOM    210  NE1 TRP A  28      30.871  41.370  16.063  1.00 19.67           N  \\nATOM    211  CE2 TRP A  28      31.627  41.183  17.179  1.00 23.79           C  \\nATOM    212  CE3 TRP A  28      33.694  40.011  17.775  1.00 16.35           C  \\nATOM    213  CZ2 TRP A  28      31.470  41.668  18.474  1.00 29.57           C  \\nATOM    214  CZ3 TRP A  28      33.534  40.490  19.078  1.00 18.00           C  \\nATOM    215  CH2 TRP A  28      32.440  41.298  19.402  1.00 15.42           C  \\nATOM    216  N   VAL A  29      35.602  38.711  12.277  1.00 18.40           N  \\nATOM    217  CA  VAL A  29      36.473  37.823  11.484  1.00 13.46           C  \\nATOM    218  C   VAL A  29      37.892  38.414  11.474  1.00 14.97           C  \\nATOM    219  O   VAL A  29      38.875  37.687  11.679  1.00 15.39           O  \\nATOM    220  CB  VAL A  29      35.959  37.565  10.059  1.00 13.48           C  \\nATOM    221  CG1 VAL A  29      36.933  36.695   9.265  1.00 12.84           C  \\nATOM    222  CG2 VAL A  29      34.572  36.988  10.064  1.00 14.46           C  \\nATOM    223  N   CYS A  30      38.046  39.718  11.277  1.00 16.14           N  \\nATOM    224  CA  CYS A  30      39.377  40.376  11.292  1.00 13.89           C  \\nATOM    225  C   CYS A  30      40.085  40.184  12.622  1.00 15.23           C  \\nATOM    226  O   CYS A  30      41.288  39.832  12.651  1.00 16.41           O  \\nATOM    227  CB  CYS A  30      39.242  41.866  10.918  1.00 13.86           C  \\nATOM    228  SG  CYS A  30      40.795  42.784  10.937  1.00 20.39           S  \\nATOM    229  N   LEU A  31      39.402  40.417  13.749  1.00 12.96           N  \\nATOM    230  CA  LEU A  31      40.128  40.282  15.041  1.00 21.55           C  \\nATOM    231  C   LEU A  31      40.475  38.819  15.310  1.00 13.97           C  \\nATOM    232  O   LEU A  31      41.505  38.618  15.958  1.00 17.80           O  \\nATOM    233  CB  LEU A  31      39.304  40.947  16.124  1.00 21.46           C  \\nATOM    234  CG  LEU A  31      38.278  40.339  17.013  1.00 22.89           C  \\nATOM    235  CD1 LEU A  31      38.722  39.323  18.065  1.00 18.01           C  \\nATOM    236  CD2 LEU A  31      37.651  41.536  17.793  1.00 21.95           C  \\nATOM    237  N   SER A  32      39.636  37.868  14.912  1.00 15.12           N  \\nATOM    238  CA  SER A  32      39.915  36.429  15.124  1.00 17.16           C  \\nATOM    239  C   SER A  32      41.193  36.016  14.356  1.00 17.69           C  \\nATOM    240  O   SER A  32      42.112  35.329  14.817  1.00 17.21           O  \\nATOM    241  CB  SER A  32      38.757  35.529  14.716  1.00 12.42           C  \\nATOM    242  OG  SER A  32      37.600  35.769  15.445  1.00 16.87           O  \\nATOM    243  N   LYS A  33      41.291  36.470  13.102  1.00 14.38           N  \\nATOM    244  CA  LYS A  33      42.453  36.248  12.248  1.00 14.46           C  \\nATOM    245  C   LYS A  33      43.766  36.775  12.869  1.00 20.46           C  \\nATOM    246  O   LYS A  33      44.753  36.017  12.934  1.00 17.19           O  \\nATOM    247  CB  LYS A  33      42.260  36.887  10.867  1.00 18.49           C  \\nATOM    248  CG  LYS A  33      43.344  36.335   9.919  1.00 24.81           C  \\nATOM    249  CD  LYS A  33      44.289  37.439   9.529  1.00 33.05           C  \\nATOM    250  CE  LYS A  33      45.099  36.975   8.318  1.00 57.02           C  \\nATOM    251  NZ  LYS A  33      46.537  37.178   8.664  1.00 45.77           N  \\nATOM    252  N   TRP A  34      43.782  38.025  13.337  1.00 14.53           N  \\nATOM    253  CA  TRP A  34      44.982  38.645  13.905  1.00 13.49           C  \\nATOM    254  C   TRP A  34      45.275  38.153  15.305  1.00 22.95           C  \\nATOM    255  O   TRP A  34      46.476  38.084  15.608  1.00 30.70           O  \\nATOM    256  CB  TRP A  34      44.866  40.177  13.897  1.00 16.57           C  \\nATOM    257  CG  TRP A  34      44.824  40.583  12.464  1.00 13.87           C  \\nATOM    258  CD1 TRP A  34      43.807  40.959  11.633  1.00 17.30           C  \\nATOM    259  CD2 TRP A  34      46.006  40.573  11.652  1.00 19.89           C  \\nATOM    260  NE1 TRP A  34      44.279  41.210  10.370  1.00 23.40           N  \\nATOM    261  CE2 TRP A  34      45.618  40.988  10.350  1.00 18.07           C  \\nATOM    262  CE3 TRP A  34      47.355  40.296  11.938  1.00 26.52           C  \\nATOM    263  CZ2 TRP A  34      46.583  41.111   9.356  1.00 37.31           C  \\nATOM    264  CZ3 TRP A  34      48.282  40.404  10.924  1.00 40.23           C  \\nATOM    265  CH2 TRP A  34      47.903  40.805   9.651  1.00 34.72           C  \\nATOM    266  N   GLU A  35      44.254  37.863  16.083  1.00 17.64           N  \\nATOM    267  CA  GLU A  35      44.448  37.386  17.454  1.00 18.73           C  \\nATOM    268  C   GLU A  35      44.900  35.935  17.527  1.00 18.86           C  \\nATOM    269  O   GLU A  35      45.832  35.632  18.288  1.00 17.23           O  \\nATOM    270  CB  GLU A  35      43.166  37.507  18.299  1.00 13.16           C  \\nATOM    271  CG  GLU A  35      42.684  38.876  18.761  1.00 15.09           C  \\nATOM    272  CD  GLU A  35      43.588  39.517  19.796  1.00 22.23           C  \\nATOM    273  OE1 GLU A  35      44.603  39.018  20.255  1.00 20.04           O  \\nATOM    274  OE2 GLU A  35      43.200  40.623  20.176  1.00 20.77           O  \\nATOM    275  N   SER A  36      44.294  35.013  16.812  1.00 17.58           N  \\nATOM    276  CA  SER A  36      44.642  33.607  16.930  1.00 17.66           C  \\nATOM    277  C   SER A  36      44.899  32.835  15.659  1.00 19.50           C  \\nATOM    278  O   SER A  36      45.165  31.628  15.792  1.00 18.49           O  \\nATOM    279  CB  SER A  36      43.423  32.949  17.624  1.00 15.60           C  \\nATOM    280  OG  SER A  36      42.374  33.081  16.675  1.00 13.21           O  \\nATOM    281  N   SER A  37      44.785  33.468  14.515  1.00 16.77           N  \\nATOM    282  CA  SER A  37      44.898  32.801  13.212  1.00 15.41           C  \\nATOM    283  C   SER A  37      43.795  31.755  13.111  1.00 20.35           C  \\nATOM    284  O   SER A  37      44.009  30.659  12.572  1.00 18.87           O  \\nATOM    285  CB  SER A  37      46.230  32.113  12.958  1.00 32.23           C  \\nATOM    286  OG  SER A  37      47.257  32.995  13.284  1.00 29.24           O  \\nATOM    287  N   TYR A  38      42.663  32.076  13.724  1.00 17.05           N  \\nATOM    288  CA  TYR A  38      41.504  31.191  13.727  1.00 18.35           C  \\nATOM    289  C   TYR A  38      41.620  29.864  14.475  1.00 18.07           C  \\nATOM    290  O   TYR A  38      40.879  28.907  14.193  1.00 12.36           O  \\nATOM    291  CB  TYR A  38      41.182  30.857  12.263  1.00 16.26           C  \\nATOM    292  CG  TYR A  38      40.986  32.038  11.360  1.00 15.65           C  \\nATOM    293  CD1 TYR A  38      40.052  33.024  11.624  1.00 23.28           C  \\nATOM    294  CD2 TYR A  38      41.761  32.157  10.202  1.00 19.32           C  \\nATOM    295  CE1 TYR A  38      39.872  34.117  10.769  1.00 14.60           C  \\nATOM    296  CE2 TYR A  38      41.556  33.211   9.318  1.00 24.47           C  \\nATOM    297  CZ  TYR A  38      40.616  34.187   9.599  1.00 22.07           C  \\nATOM    298  OH  TYR A  38      40.411  35.217   8.725  1.00 24.28           O  \\nATOM    299  N   ASN A  39      42.532  29.801  15.413  1.00 15.97           N  \\nATOM    300  CA  ASN A  39      42.740  28.550  16.162  1.00 13.21           C  \\nATOM    301  C   ASN A  39      42.063  28.674  17.523  1.00 14.83           C  \\nATOM    302  O   ASN A  39      42.483  29.550  18.309  1.00 14.96           O  \\nATOM    303  CB  ASN A  39      44.261  28.256  16.158  1.00 15.35           C  \\nATOM    304  CG  ASN A  39      44.628  26.954  16.890  1.00 12.41           C  \\nATOM    305  OD1 ASN A  39      43.892  26.058  17.247  1.00 18.02           O  \\nATOM    306  ND2 ASN A  39      45.929  26.806  17.158  1.00 15.84           N  \\nATOM    307  N   THR A  40      41.074  27.844  17.810  1.00 14.00           N  \\nATOM    308  CA  THR A  40      40.384  27.810  19.108  1.00 18.17           C  \\nATOM    309  C   THR A  40      41.318  27.410  20.244  1.00 15.60           C  \\nATOM    310  O   THR A  40      41.082  27.776  21.398  1.00 15.54           O  \\nATOM    311  CB  THR A  40      39.113  26.863  19.084  1.00 17.38           C  \\nATOM    312  OG1 THR A  40      39.595  25.495  18.994  1.00 13.72           O  \\nATOM    313  CG2 THR A  40      38.161  27.266  17.955  1.00 12.13           C  \\nATOM    314  N   GLN A  41      42.425  26.721  19.985  1.00 17.45           N  \\nATOM    315  CA  GLN A  41      43.386  26.265  20.968  1.00 13.17           C  \\nATOM    316  C   GLN A  41      44.540  27.213  21.234  1.00 22.87           C  \\nATOM    317  O   GLN A  41      45.482  26.823  21.961  1.00 24.42           O  \\nATOM    318  CB  GLN A  41      44.010  24.905  20.541  1.00 12.53           C  \\nATOM    319  CG  GLN A  41      42.898  23.865  20.441  1.00 17.23           C  \\nATOM    320  CD  GLN A  41      43.367  22.421  20.495  1.00 13.61           C  \\nATOM    321  OE1 GLN A  41      43.458  21.752  19.461  1.00 22.26           O  \\nATOM    322  NE2 GLN A  41      43.696  22.001  21.710  1.00 16.79           N  \\nATOM    323  N   ALA A  42      44.487  28.381  20.640  1.00 14.34           N  \\nATOM    324  CA  ALA A  42      45.597  29.312  20.879  1.00 18.27           C  \\nATOM    325  C   ALA A  42      45.657  29.805  22.325  1.00 22.28           C  \\nATOM    326  O   ALA A  42      44.649  30.163  22.947  1.00 15.13           O  \\nATOM    327  CB  ALA A  42      45.490  30.492  19.914  1.00 17.94           C  \\nATOM    328  N   THR A  43      46.872  29.867  22.870  1.00 17.78           N  \\nATOM    329  CA  THR A  43      47.132  30.407  24.214  1.00 26.75           C  \\nATOM    330  C   THR A  43      48.398  31.281  24.131  1.00 22.42           C  \\nATOM    331  O   THR A  43      49.319  31.066  23.358  1.00 23.75           O  \\nATOM    332  CB  THR A  43      47.229  29.363  25.388  1.00 25.09           C  \\nATOM    333  OG1 THR A  43      48.343  28.493  25.035  1.00 21.09           O  \\nATOM    334  CG2 THR A  43      45.931  28.597  25.626  1.00 11.74           C  \\nATOM    335  N   ASN A  44      48.417  32.336  24.899  1.00 15.73           N  \\nATOM    336  CA  ASN A  44      49.524  33.298  24.959  1.00 17.41           C  \\nATOM    337  C   ASN A  44      49.635  33.837  26.382  1.00 22.79           C  \\nATOM    338  O   ASN A  44      48.708  34.479  26.902  1.00 19.97           O  \\nATOM    339  CB  ASN A  44      49.320  34.372  23.887  1.00 23.51           C  \\nATOM    340  CG  ASN A  44      50.396  35.452  23.938  1.00 47.13           C  \\nATOM    341  OD1 ASN A  44      51.524  35.245  23.437  1.00 53.30           O  \\nATOM    342  ND2 ASN A  44      50.077  36.597  24.559  1.00 46.80           N  \\nATOM    343  N   ARG A  45      50.748  33.557  27.024  1.00 18.97           N  \\nATOM    344  CA  ARG A  45      50.983  34.022  28.397  1.00 15.52           C  \\nATOM    345  C   ARG A  45      51.507  35.442  28.411  1.00 26.35           C  \\nATOM    346  O   ARG A  45      52.357  35.790  27.568  1.00 28.65           O  \\nATOM    347  CB  ARG A  45      51.958  33.079  29.109  1.00 24.05           C  \\nATOM    348  CG  ARG A  45      52.139  33.583  30.535  1.00 43.45           C  \\nATOM    349  CD  ARG A  45      51.436  32.875  31.615  1.00 34.96           C  \\nATOM    350  NE  ARG A  45      52.263  31.752  32.079  1.00 73.13           N  \\nATOM    351  CZ  ARG A  45      52.319  30.619  31.355  1.00 79.93           C  \\nATOM    352  NH1 ARG A  45      51.394  30.364  30.416  1.00 58.80           N  \\nATOM    353  NH2 ARG A  45      53.327  29.787  31.613  1.00 53.52           N  \\nATOM    354  N   ASN A  46      51.039  36.257  29.335  1.00 28.72           N  \\nATOM    355  CA  ASN A  46      51.522  37.653  29.431  1.00 31.17           C  \\nATOM    356  C   ASN A  46      52.478  37.797  30.621  1.00 34.85           C  \\nATOM    357  O   ASN A  46      52.546  36.929  31.508  1.00 30.02           O  \\nATOM    358  CB  ASN A  46      50.344  38.607  29.500  1.00 20.09           C  \\nATOM    359  CG  ASN A  46      49.591  38.619  28.175  1.00 23.38           C  \\nATOM    360  OD1 ASN A  46      48.408  38.263  28.170  1.00 36.10           O  \\nATOM    361  ND2 ASN A  46      50.177  38.963  27.043  1.00 33.99           N  \\nATOM    362  N   THR A  47      53.164  38.919  30.590  1.00 36.86           N  \\nATOM    363  CA  THR A  47      54.153  39.356  31.579  1.00 37.27           C  \\nATOM    364  C   THR A  47      53.601  39.489  32.991  1.00 33.48           C  \\nATOM    365  O   THR A  47      54.243  39.229  34.004  1.00 46.09           O  \\nATOM    366  CB  THR A  47      54.804  40.756  31.230  1.00 52.01           C  \\nATOM    367  OG1 THR A  47      53.721  41.711  31.514  1.00 69.50           O  \\nATOM    368  CG2 THR A  47      55.362  40.834  29.816  1.00 39.44           C  \\nATOM    369  N   ASP A  48      52.360  39.919  33.004  1.00 29.16           N  \\nATOM    370  CA  ASP A  48      51.535  40.122  34.209  1.00 29.86           C  \\nATOM    371  C   ASP A  48      50.944  38.851  34.842  1.00 32.96           C  \\nATOM    372  O   ASP A  48      50.176  38.986  35.837  1.00 34.15           O  \\nATOM    373  CB  ASP A  48      50.436  41.146  33.837  1.00 26.05           C  \\nATOM    374  CG  ASP A  48      49.319  40.537  33.009  1.00 47.30           C  \\nATOM    375  OD1 ASP A  48      49.355  39.402  32.489  1.00 32.41           O  \\nATOM    376  OD2 ASP A  48      48.322  41.290  32.925  1.00 58.64           O  \\nATOM    377  N   GLY A  49      51.226  37.670  34.308  1.00 22.78           N  \\nATOM    378  CA  GLY A  49      50.720  36.424  34.892  1.00 30.15           C  \\nATOM    379  C   GLY A  49      49.424  35.938  34.256  1.00 20.20           C  \\nATOM    380  O   GLY A  49      49.012  34.791  34.547  1.00 25.53           O  \\nATOM    381  N   SER A  50      48.861  36.800  33.431  1.00 21.62           N  \\nATOM    382  CA  SER A  50      47.602  36.385  32.763  1.00 21.86           C  \\nATOM    383  C   SER A  50      47.954  35.684  31.436  1.00 19.00           C  \\nATOM    384  O   SER A  50      49.070  35.702  30.931  1.00 19.44           O  \\nATOM    385  CB  SER A  50      46.643  37.538  32.551  1.00 14.68           C  \\nATOM    386  OG  SER A  50      47.225  38.400  31.584  1.00 18.76           O  \\nATOM    387  N   THR A  51      46.914  35.020  30.926  1.00 19.33           N  \\nATOM    388  CA  THR A  51      46.971  34.274  29.669  1.00 16.55           C  \\nATOM    389  C   THR A  51      45.771  34.623  28.807  1.00 16.93           C  \\nATOM    390  O   THR A  51      44.697  34.813  29.414  1.00 15.79           O  \\nATOM    391  CB  THR A  51      47.110  32.719  29.952  1.00 18.65           C  \\nATOM    392  OG1 THR A  51      48.310  32.615  30.799  1.00 22.61           O  \\nATOM    393  CG2 THR A  51      47.191  31.792  28.724  1.00 11.90           C  \\nATOM    394  N   ASP A  52      45.988  34.678  27.502  1.00 17.35           N  \\nATOM    395  CA  ASP A  52      44.945  34.918  26.490  1.00 20.57           C  \\nATOM    396  C   ASP A  52      44.541  33.540  25.940  1.00 17.31           C  \\nATOM    397  O   ASP A  52      45.384  32.712  25.653  1.00 18.51           O  \\nATOM    398  CB  ASP A  52      45.354  35.888  25.391  1.00 17.67           C  \\nATOM    399  CG  ASP A  52      45.777  37.237  25.989  1.00 25.71           C  \\nATOM    400  OD1 ASP A  52      45.196  37.738  26.966  1.00 21.10           O  \\nATOM    401  OD2 ASP A  52      46.720  37.793  25.423  1.00 25.65           O  \\nATOM    402  N   TYR A  53      43.221  33.325  25.829  1.00 12.97           N  \\nATOM    403  CA  TYR A  53      42.615  32.057  25.428  1.00 16.88           C  \\nATOM    404  C   TYR A  53      41.650  32.046  24.260  1.00 15.87           C  \\nATOM    405  O   TYR A  53      40.691  32.832  24.229  1.00 15.49           O  \\nATOM    406  CB  TYR A  53      41.788  31.462  26.620  1.00 13.26           C  \\nATOM    407  CG  TYR A  53      42.659  31.119  27.812  1.00 17.67           C  \\nATOM    408  CD1 TYR A  53      42.975  32.051  28.803  1.00 13.92           C  \\nATOM    409  CD2 TYR A  53      43.176  29.822  27.926  1.00 24.83           C  \\nATOM    410  CE1 TYR A  53      43.766  31.706  29.893  1.00 10.61           C  \\nATOM    411  CE2 TYR A  53      43.968  29.449  29.013  1.00 21.03           C  \\nATOM    412  CZ  TYR A  53      44.277  30.423  29.990  1.00 21.61           C  \\nATOM    413  OH  TYR A  53      45.084  30.097  31.042  1.00 17.14           O  \\nATOM    414  N   GLY A  54      41.899  31.077  23.380  1.00 11.91           N  \\nATOM    415  CA  GLY A  54      41.025  30.803  22.269  1.00 12.37           C  \\nATOM    416  C   GLY A  54      41.092  31.669  21.049  1.00 18.38           C  \\nATOM    417  O   GLY A  54      42.036  32.428  20.856  1.00 12.89           O  \\nATOM    418  N   ILE A  55      40.067  31.483  20.228  1.00 17.64           N  \\nATOM    419  CA  ILE A  55      39.973  32.201  18.939  1.00 14.29           C  \\nATOM    420  C   ILE A  55      39.994  33.722  19.101  1.00 21.77           C  \\nATOM    421  O   ILE A  55      40.509  34.406  18.225  1.00 18.01           O  \\nATOM    422  CB  ILE A  55      38.725  31.630  18.132  1.00 13.85           C  \\nATOM    423  CG1 ILE A  55      39.064  31.779  16.634  1.00 14.21           C  \\nATOM    424  CG2 ILE A  55      37.368  32.271  18.514  1.00 10.77           C  \\nATOM    425  CD1 ILE A  55      38.253  30.831  15.682  1.00 15.40           C  \\nATOM    426  N   PHE A  56      39.391  34.258  20.144  1.00 14.78           N  \\nATOM    427  CA  PHE A  56      39.284  35.685  20.475  1.00 18.37           C  \\nATOM    428  C   PHE A  56      40.338  36.136  21.500  1.00 21.80           C  \\nATOM    429  O   PHE A  56      40.342  37.310  21.917  1.00 19.12           O  \\nATOM    430  CB  PHE A  56      37.890  36.066  21.024  1.00 12.10           C  \\nATOM    431  CG  PHE A  56      36.745  35.656  20.148  1.00 22.21           C  \\nATOM    432  CD1 PHE A  56      36.714  36.045  18.795  1.00 24.31           C  \\nATOM    433  CD2 PHE A  56      35.737  34.878  20.687  1.00 15.11           C  \\nATOM    434  CE1 PHE A  56      35.628  35.649  17.987  1.00 22.11           C  \\nATOM    435  CE2 PHE A  56      34.648  34.473  19.891  1.00 18.01           C  \\nATOM    436  CZ  PHE A  56      34.606  34.852  18.558  1.00 15.95           C  \\nATOM    437  N   GLN A  57      41.185  35.198  21.917  1.00 12.00           N  \\nATOM    438  CA  GLN A  57      42.249  35.500  22.872  1.00 18.97           C  \\nATOM    439  C   GLN A  57      41.713  36.303  24.058  1.00 19.57           C  \\nATOM    440  O   GLN A  57      42.237  37.390  24.353  1.00 18.20           O  \\nATOM    441  CB  GLN A  57      43.430  36.212  22.161  1.00 13.60           C  \\nATOM    442  CG  GLN A  57      44.125  35.302  21.156  1.00  9.93           C  \\nATOM    443  CD  GLN A  57      45.008  34.347  21.916  1.00 15.19           C  \\nATOM    444  OE1 GLN A  57      46.023  34.727  22.432  1.00 15.17           O  \\nATOM    445  NE2 GLN A  57      44.558  33.107  22.033  1.00 17.43           N  \\nATOM    446  N   ILE A  58      40.686  35.751  24.700  1.00 13.37           N  \\nATOM    447  CA  ILE A  58      40.144  36.411  25.920  1.00 14.37           C  \\nATOM    448  C   ILE A  58      41.105  36.257  27.096  1.00 14.99           C  \\nATOM    449  O   ILE A  58      41.641  35.190  27.428  1.00 12.78           O  \\nATOM    450  CB  ILE A  58      38.691  35.875  26.119  1.00 19.24           C  \\nATOM    451  CG1 ILE A  58      37.841  36.509  24.972  1.00 22.89           C  \\nATOM    452  CG2 ILE A  58      38.183  36.134  27.563  1.00 13.90           C  \\nATOM    453  CD1 ILE A  58      36.476  35.836  24.753  1.00 23.01           C  \\nATOM    454  N   ASN A  59      41.363  37.350  27.818  1.00 17.25           N  \\nATOM    455  CA  ASN A  59      42.310  37.460  28.933  1.00 17.24           C  \\nATOM    456  C   ASN A  59      41.790  36.983  30.277  1.00 14.54           C  \\nATOM    457  O   ASN A  59      40.668  37.301  30.690  1.00 16.35           O  \\nATOM    458  CB  ASN A  59      42.757  38.929  28.982  1.00 22.14           C  \\nATOM    459  CG  ASN A  59      43.899  39.067  29.987  1.00 25.20           C  \\nATOM    460  OD1 ASN A  59      43.684  39.424  31.168  1.00 23.44           O  \\nATOM    461  ND2 ASN A  59      45.082  38.754  29.464  1.00 16.47           N  \\nATOM    462  N   SER A  60      42.639  36.226  30.992  1.00 15.55           N  \\nATOM    463  CA  SER A  60      42.308  35.610  32.294  1.00 16.24           C  \\nATOM    464  C   SER A  60      42.332  36.537  33.513  1.00 17.55           C  \\nATOM    465  O   SER A  60      41.913  36.094  34.591  1.00 18.30           O  \\nATOM    466  CB  SER A  60      43.243  34.442  32.609  1.00 12.14           C  \\nATOM    467  OG  SER A  60      44.609  34.782  32.675  1.00 15.60           O  \\nATOM    468  N   ARG A  61      42.804  37.766  33.334  1.00 25.85           N  \\nATOM    469  CA  ARG A  61      42.773  38.704  34.457  1.00 25.69           C  \\nATOM    470  C   ARG A  61      41.364  39.194  34.786  1.00 22.93           C  \\nATOM    471  O   ARG A  61      40.991  39.448  35.945  1.00 24.66           O  \\nATOM    472  CB  ARG A  61      43.632  39.927  34.174  1.00 27.65           C  \\nATOM    473  CG  ARG A  61      43.685  40.644  35.544  1.00 31.27           C  \\nATOM    474  CD  ARG A  61      45.128  41.010  35.711  1.00 49.54           C  \\nATOM    475  NE  ARG A  61      45.200  42.466  35.733  1.00 59.79           N  \\nATOM    476  CZ  ARG A  61      44.922  43.171  36.845  1.00 81.11           C  \\nATOM    477  NH1 ARG A  61      43.993  42.792  37.726  1.00 76.32           N  \\nATOM    478  NH2 ARG A  61      45.639  44.284  37.049  1.00 79.91           N  \\nATOM    479  N   TYR A  62      40.551  39.343  33.728  1.00 22.63           N  \\nATOM    480  CA  TYR A  62      39.170  39.797  33.914  1.00 24.66           C  \\nATOM    481  C   TYR A  62      38.033  38.870  33.554  1.00 18.51           C  \\nATOM    482  O   TYR A  62      36.947  38.969  34.188  1.00 19.76           O  \\nATOM    483  CB  TYR A  62      38.874  41.062  33.035  1.00 25.26           C  \\nATOM    484  CG  TYR A  62      39.816  42.174  33.438  1.00 34.67           C  \\nATOM    485  CD1 TYR A  62      39.602  43.023  34.517  1.00 40.78           C  \\nATOM    486  CD2 TYR A  62      40.986  42.306  32.675  1.00 32.42           C  \\nATOM    487  CE1 TYR A  62      40.548  44.005  34.851  1.00 40.18           C  \\nATOM    488  CE2 TYR A  62      41.923  43.288  33.008  1.00 46.53           C  \\nATOM    489  CZ  TYR A  62      41.706  44.146  34.093  1.00 41.63           C  \\nATOM    490  OH  TYR A  62      42.657  45.116  34.369  1.00 72.23           O  \\nATOM    491  N   TRP A  63      38.248  38.046  32.522  1.00 17.37           N  \\nATOM    492  CA  TRP A  63      37.065  37.302  32.025  1.00 14.97           C  \\nATOM    493  C   TRP A  63      36.910  35.852  32.362  1.00 17.83           C  \\nATOM    494  O   TRP A  63      35.720  35.480  32.312  1.00 13.57           O  \\nATOM    495  CB  TRP A  63      37.081  37.498  30.458  1.00 12.63           C  \\nATOM    496  CG  TRP A  63      37.269  38.942  30.049  1.00 18.40           C  \\nATOM    497  CD1 TRP A  63      38.348  39.582  29.515  1.00 14.00           C  \\nATOM    498  CD2 TRP A  63      36.232  39.937  30.189  1.00 13.65           C  \\nATOM    499  NE1 TRP A  63      38.047  40.907  29.322  1.00 14.56           N  \\nATOM    500  CE2 TRP A  63      36.760  41.150  29.724  1.00 14.69           C  \\nATOM    501  CE3 TRP A  63      34.919  39.912  30.687  1.00 21.13           C  \\nATOM    502  CZ2 TRP A  63      36.014  42.331  29.733  1.00 16.09           C  \\nATOM    503  CZ3 TRP A  63      34.187  41.080  30.677  1.00 20.95           C  \\nATOM    504  CH2 TRP A  63      34.714  42.280  30.200  1.00 13.33           C  \\nATOM    505  N   CYS A  64      37.937  35.078  32.614  1.00 17.33           N  \\nATOM    506  CA  CYS A  64      37.707  33.638  32.860  1.00 18.36           C  \\nATOM    507  C   CYS A  64      38.643  33.203  33.975  1.00 15.69           C  \\nATOM    508  O   CYS A  64      39.633  33.915  34.229  1.00 17.52           O  \\nATOM    509  CB  CYS A  64      37.893  32.873  31.548  1.00 12.23           C  \\nATOM    510  SG  CYS A  64      39.569  33.010  30.792  1.00 15.40           S  \\nATOM    511  N   ASP A  65      38.341  32.069  34.579  1.00 13.86           N  \\nATOM    512  CA  ASP A  65      39.238  31.570  35.641  1.00 16.52           C  \\nATOM    513  C   ASP A  65      40.240  30.537  35.161  1.00 14.55           C  \\nATOM    514  O   ASP A  65      39.777  29.498  34.636  1.00 16.81           O  \\nATOM    515  CB  ASP A  65      38.254  31.020  36.660  1.00 19.55           C  \\nATOM    516  CG  ASP A  65      39.056  30.332  37.771  1.00 39.16           C  \\nATOM    517  OD1 ASP A  65      40.143  30.861  38.120  1.00 33.03           O  \\nATOM    518  OD2 ASP A  65      38.561  29.290  38.227  1.00 43.60           O  \\nATOM    519  N   ASP A  66      41.533  30.714  35.237  1.00 14.68           N  \\nATOM    520  CA  ASP A  66      42.490  29.664  34.800  1.00 18.54           C  \\nATOM    521  C   ASP A  66      43.285  29.145  36.030  1.00 21.82           C  \\nATOM    522  O   ASP A  66      44.214  28.353  35.835  1.00 21.01           O  \\nATOM    523  CB  ASP A  66      43.401  30.105  33.688  1.00 14.01           C  \\nATOM    524  CG  ASP A  66      44.449  31.117  34.071  1.00 17.63           C  \\nATOM    525  OD1 ASP A  66      44.498  31.571  35.229  1.00 18.50           O  \\nATOM    526  OD2 ASP A  66      45.282  31.477  33.171  1.00 21.35           O  \\nATOM    527  N   GLY A  67      42.907  29.581  37.205  1.00 19.91           N  \\nATOM    528  CA  GLY A  67      43.476  29.240  38.466  1.00 17.84           C  \\nATOM    529  C   GLY A  67      44.897  29.629  38.766  1.00 21.63           C  \\nATOM    530  O   GLY A  67      45.424  29.194  39.811  1.00 25.31           O  \\nATOM    531  N   ARG A  68      45.535  30.429  37.955  1.00 18.98           N  \\nATOM    532  CA  ARG A  68      46.925  30.855  38.193  1.00 22.39           C  \\nATOM    533  C   ARG A  68      47.192  32.328  37.884  1.00 26.40           C  \\nATOM    534  O   ARG A  68      48.349  32.801  37.731  1.00 29.50           O  \\nATOM    535  CB  ARG A  68      47.869  29.967  37.371  1.00 22.87           C  \\nATOM    536  CG  ARG A  68      47.655  30.073  35.887  1.00 17.07           C  \\nATOM    537  CD  ARG A  68      48.873  29.623  35.179  1.00 20.83           C  \\nATOM    538  NE  ARG A  68      48.897  30.169  33.822  1.00 26.31           N  \\nATOM    539  CZ  ARG A  68      49.537  29.559  32.818  1.00 49.80           C  \\nATOM    540  NH1 ARG A  68      50.222  28.429  33.043  1.00 26.63           N  \\nATOM    541  NH2 ARG A  68      49.558  30.037  31.562  1.00 21.96           N  \\nATOM    542  N   THR A  69      46.054  33.050  37.795  1.00 20.06           N  \\nATOM    543  CA  THR A  69      46.161  34.474  37.509  1.00 22.37           C  \\nATOM    544  C   THR A  69      45.868  35.301  38.775  1.00 18.89           C  \\nATOM    545  O   THR A  69      44.771  35.215  39.315  1.00 29.15           O  \\nATOM    546  CB  THR A  69      45.249  35.044  36.349  1.00 23.00           C  \\nATOM    547  OG1 THR A  69      45.511  34.126  35.269  1.00 15.08           O  \\nATOM    548  CG2 THR A  69      45.528  36.493  35.957  1.00 17.64           C  \\nATOM    549  N   PRO A  70      46.898  36.088  39.096  1.00 38.62           N  \\nATOM    550  CA  PRO A  70      46.831  37.059  40.183  1.00 36.92           C  \\nATOM    551  C   PRO A  70      45.840  38.190  39.888  1.00 21.03           C  \\nATOM    552  O   PRO A  70      45.882  38.862  38.818  1.00 38.15           O  \\nATOM    553  CB  PRO A  70      48.274  37.535  40.368  1.00 57.26           C  \\nATOM    554  CG  PRO A  70      48.975  37.298  39.072  1.00 46.04           C  \\nATOM    555  CD  PRO A  70      48.194  36.179  38.389  1.00 40.03           C  \\nATOM    556  N   GLY A  71      44.909  38.379  40.818  1.00 26.51           N  \\nATOM    557  CA  GLY A  71      43.876  39.404  40.765  1.00 37.61           C  \\nATOM    558  C   GLY A  71      42.778  39.217  39.737  1.00 31.96           C  \\nATOM    559  O   GLY A  71      42.288  40.233  39.199  1.00 39.20           O  \\nATOM    560  N   ALA A  72      42.399  37.974  39.510  1.00 24.83           N  \\nATOM    561  CA  ALA A  72      41.412  37.624  38.506  1.00 31.81           C  \\nATOM    562  C   ALA A  72      39.993  37.827  39.010  1.00 38.51           C  \\nATOM    563  O   ALA A  72      39.705  37.478  40.154  1.00 34.08           O  \\nATOM    564  CB  ALA A  72      41.652  36.181  38.080  1.00 27.44           C  \\nATOM    565  N   LYS A  73      39.179  38.322  38.081  1.00 30.14           N  \\nATOM    566  CA  LYS A  73      37.767  38.604  38.376  1.00 26.24           C  \\nATOM    567  C   LYS A  73      36.761  37.683  37.705  1.00 35.69           C  \\nATOM    568  O   LYS A  73      35.587  37.673  38.192  1.00 39.50           O  \\nATOM    569  CB  LYS A  73      37.420  40.047  37.983  1.00 24.79           C  \\nATOM    570  CG  LYS A  73      38.539  41.039  38.297  1.00 41.30           C  \\nATOM    571  CD  LYS A  73      38.023  42.212  39.114  1.00 75.00           C  \\nATOM    572  CE  LYS A  73      37.966  41.868  40.590  1.00 73.38           C  \\nATOM    573  NZ  LYS A  73      39.251  42.194  41.268  1.00 70.15           N  \\nATOM    574  N   ASN A  74      37.123  36.933  36.700  1.00 15.91           N  \\nATOM    575  CA  ASN A  74      36.096  35.997  36.081  1.00 15.63           C  \\nATOM    576  C   ASN A  74      34.669  36.522  35.889  1.00 17.55           C  \\nATOM    577  O   ASN A  74      33.674  35.992  36.408  1.00 18.43           O  \\nATOM    578  CB  ASN A  74      36.032  34.686  36.882  1.00 15.16           C  \\nATOM    579  CG  ASN A  74      35.411  33.576  36.071  1.00 18.17           C  \\nATOM    580  OD1 ASN A  74      35.097  33.714  34.863  1.00 18.06           O  \\nATOM    581  ND2 ASN A  74      35.196  32.469  36.786  1.00 23.58           N  \\nATOM    582  N   VAL A  75      34.617  37.554  35.058  1.00 21.60           N  \\nATOM    583  CA  VAL A  75      33.335  38.206  34.703  1.00 16.52           C  \\nATOM    584  C   VAL A  75      32.495  37.284  33.829  1.00 20.44           C  \\nATOM    585  O   VAL A  75      31.256  37.300  33.983  1.00 22.78           O  \\nATOM    586  CB  VAL A  75      33.682  39.583  34.114  1.00 19.29           C  \\nATOM    587  CG1 VAL A  75      32.533  40.216  33.366  1.00 29.00           C  \\nATOM    588  CG2 VAL A  75      34.195  40.497  35.214  1.00 19.92           C  \\nATOM    589  N   CYS A  76      33.043  36.469  32.948  1.00 16.20           N  \\nATOM    590  CA  CYS A  76      32.196  35.576  32.138  1.00 12.00           C  \\nATOM    591  C   CYS A  76      31.777  34.398  32.995  1.00 14.64           C  \\nATOM    592  O   CYS A  76      30.896  33.677  32.505  1.00 17.41           O  \\nATOM    593  CB  CYS A  76      32.836  35.049  30.861  1.00  9.87           C  \\nATOM    594  SG  CYS A  76      33.054  36.453  29.681  1.00 18.35           S  \\nATOM    595  N   GLY A  77      32.384  34.226  34.141  1.00 18.64           N  \\nATOM    596  CA  GLY A  77      31.963  33.109  35.020  1.00 18.26           C  \\nATOM    597  C   GLY A  77      32.272  31.757  34.425  1.00 18.13           C  \\nATOM    598  O   GLY A  77      31.422  30.859  34.526  1.00 20.18           O  \\nATOM    599  N   ILE A  78      33.453  31.630  33.828  1.00 29.20           N  \\nATOM    600  CA  ILE A  78      33.811  30.366  33.191  1.00 21.25           C  \\nATOM    601  C   ILE A  78      35.254  30.000  33.522  1.00 16.76           C  \\nATOM    602  O   ILE A  78      36.001  30.853  34.021  1.00 21.81           O  \\nATOM    603  CB  ILE A  78      33.590  30.440  31.630  1.00 15.20           C  \\nATOM    604  CG1 ILE A  78      34.312  31.715  31.117  1.00 13.92           C  \\nATOM    605  CG2 ILE A  78      32.108  30.390  31.212  1.00 19.90           C  \\nATOM    606  CD1 ILE A  78      34.469  31.764  29.589  1.00 15.43           C  \\nATOM    607  N   ARG A  79      35.542  28.769  33.158  1.00 15.88           N  \\nATOM    608  CA  ARG A  79      36.917  28.266  33.255  1.00 18.00           C  \\nATOM    609  C   ARG A  79      37.542  28.693  31.914  1.00 20.50           C  \\nATOM    610  O   ARG A  79      36.773  28.503  30.932  1.00 13.97           O  \\nATOM    611  CB  ARG A  79      37.091  26.787  33.428  1.00 21.11           C  \\nATOM    612  CG  ARG A  79      36.322  26.223  34.632  1.00 21.94           C  \\nATOM    613  CD  ARG A  79      37.172  26.532  35.823  1.00 30.78           C  \\nATOM    614  NE  ARG A  79      37.012  25.419  36.771  1.00 60.65           N  \\nATOM    615  CZ  ARG A  79      37.388  25.475  38.058  1.00 74.21           C  \\nATOM    616  NH1 ARG A  79      38.366  26.302  38.455  1.00 62.60           N  \\nATOM    617  NH2 ARG A  79      36.769  24.690  38.963  1.00 50.54           N  \\nATOM    618  N   CYS A  80      38.783  29.157  31.857  1.00 15.00           N  \\nATOM    619  CA  CYS A  80      39.378  29.545  30.573  1.00  9.53           C  \\nATOM    620  C   CYS A  80      39.463  28.385  29.568  1.00 16.33           C  \\nATOM    621  O   CYS A  80      39.456  28.596  28.342  1.00 15.34           O  \\nATOM    622  CB  CYS A  80      40.728  30.146  30.863  1.00 10.23           C  \\nATOM    623  SG  CYS A  80      40.713  31.674  31.799  1.00 16.76           S  \\nATOM    624  N   SER A  81      39.562  27.174  30.060  1.00 17.11           N  \\nATOM    625  CA  SER A  81      39.583  25.909  29.298  1.00 27.76           C  \\nATOM    626  C   SER A  81      38.387  25.747  28.347  1.00 19.17           C  \\nATOM    627  O   SER A  81      38.523  25.158  27.244  1.00 15.68           O  \\nATOM    628  CB  SER A  81      39.699  24.773  30.307  1.00 18.26           C  \\nATOM    629  OG  SER A  81      38.622  24.665  31.223  1.00 18.96           O  \\nATOM    630  N   GLN A  82      37.208  26.275  28.715  1.00 12.61           N  \\nATOM    631  CA  GLN A  82      35.998  26.278  27.903  1.00 14.47           C  \\nATOM    632  C   GLN A  82      36.102  27.181  26.661  1.00 16.25           C  \\nATOM    633  O   GLN A  82      35.252  27.041  25.776  1.00 18.52           O  \\nATOM    634  CB  GLN A  82      34.781  26.744  28.685  1.00 18.12           C  \\nATOM    635  CG  GLN A  82      34.561  25.870  29.915  1.00 21.03           C  \\nATOM    636  CD  GLN A  82      33.345  26.329  30.701  1.00 33.40           C  \\nATOM    637  OE1 GLN A  82      33.426  26.905  31.784  1.00 30.92           O  \\nATOM    638  NE2 GLN A  82      32.176  26.062  30.130  1.00 28.66           N  \\nATOM    639  N   LEU A  83      37.105  28.053  26.662  1.00 12.53           N  \\nATOM    640  CA  LEU A  83      37.379  28.945  25.565  1.00 17.44           C  \\nATOM    641  C   LEU A  83      38.254  28.240  24.523  1.00 20.26           C  \\nATOM    642  O   LEU A  83      38.543  28.910  23.518  1.00 19.47           O  \\nATOM    643  CB  LEU A  83      38.055  30.259  26.051  1.00 11.30           C  \\nATOM    644  CG  LEU A  83      37.243  31.103  27.013  1.00 13.36           C  \\nATOM    645  CD1 LEU A  83      37.996  32.353  27.389  1.00 15.63           C  \\nATOM    646  CD2 LEU A  83      35.913  31.450  26.325  1.00 11.21           C  \\nATOM    647  N   LEU A  84      38.663  27.001  24.747  1.00 15.58           N  \\nATOM    648  CA  LEU A  84      39.562  26.348  23.785  1.00 18.37           C  \\nATOM    649  C   LEU A  84      38.919  25.231  22.972  1.00 19.62           C  \\nATOM    650  O   LEU A  84      39.648  24.560  22.241  1.00 19.93           O  \\nATOM    651  CB  LEU A  84      40.789  25.803  24.554  1.00 15.48           C  \\nATOM    652  CG  LEU A  84      41.555  26.832  25.368  1.00 25.14           C  \\nATOM    653  CD1 LEU A  84      42.662  26.144  26.151  1.00 28.13           C  \\nATOM    654  CD2 LEU A  84      42.223  27.893  24.491  1.00 15.35           C  \\nATOM    655  N   THR A  85      37.646  25.036  23.134  1.00 19.69           N  \\nATOM    656  CA  THR A  85      36.900  23.970  22.445  1.00 13.86           C  \\nATOM    657  C   THR A  85      36.622  24.308  20.984  1.00 26.75           C  \\nATOM    658  O   THR A  85      36.574  25.455  20.521  1.00 22.46           O  \\nATOM    659  CB  THR A  85      35.625  23.658  23.308  1.00 17.99           C  \\nATOM    660  OG1 THR A  85      34.770  24.841  23.283  1.00 17.16           O  \\nATOM    661  CG2 THR A  85      35.888  23.278  24.776  1.00 19.95           C  \\nATOM    662  N   ASP A  86      36.391  23.269  20.182  1.00 21.54           N  \\nATOM    663  CA  ASP A  86      36.108  23.434  18.730  1.00 19.67           C  \\nATOM    664  C   ASP A  86      34.776  24.154  18.624  1.00 14.42           C  \\nATOM    665  O   ASP A  86      34.551  24.958  17.728  1.00 19.13           O  \\nATOM    666  CB  ASP A  86      36.260  22.079  18.071  1.00 21.50           C  \\nATOM    667  CG  ASP A  86      37.582  21.332  18.252  1.00 76.88           C  \\nATOM    668  OD1 ASP A  86      38.708  21.823  18.550  1.00 34.80           O  \\nATOM    669  OD2 ASP A  86      37.562  20.083  18.057  1.00 37.31           O  \\nATOM    670  N   ASP A  87      33.868  23.857  19.522  1.00 19.06           N  \\nATOM    671  CA  ASP A  87      32.561  24.470  19.680  1.00 17.34           C  \\nATOM    672  C   ASP A  87      32.748  25.885  20.235  1.00 17.82           C  \\nATOM    673  O   ASP A  87      33.355  26.043  21.339  1.00 17.69           O  \\nATOM    674  CB  ASP A  87      31.723  23.637  20.624  1.00 15.32           C  \\nATOM    675  CG  ASP A  87      30.312  24.207  20.661  1.00 25.26           C  \\nATOM    676  OD1 ASP A  87      29.633  24.042  19.655  1.00 37.21           O  \\nATOM    677  OD2 ASP A  87      29.903  24.810  21.635  1.00 33.96           O  \\nATOM    678  N   LEU A  88      32.256  26.855  19.508  1.00 15.61           N  \\nATOM    679  CA  LEU A  88      32.434  28.292  19.817  1.00 18.42           C  \\nATOM    680  C   LEU A  88      31.381  28.887  20.781  1.00 23.52           C  \\nATOM    681  O   LEU A  88      31.463  30.055  21.162  1.00 17.99           O  \\nATOM    682  CB  LEU A  88      32.266  29.143  18.551  1.00 20.15           C  \\nATOM    683  CG  LEU A  88      33.485  29.171  17.624  1.00 35.63           C  \\nATOM    684  CD1 LEU A  88      33.834  27.798  17.053  1.00 20.00           C  \\nATOM    685  CD2 LEU A  88      33.280  30.084  16.405  1.00 20.00           C  \\nATOM    686  N   THR A  89      30.325  28.069  21.167  1.00 17.61           N  \\nATOM    687  CA  THR A  89      29.272  28.630  22.010  1.00 14.12           C  \\nATOM    688  C   THR A  89      29.705  29.458  23.218  1.00 17.75           C  \\nATOM    689  O   THR A  89      29.159  30.571  23.361  1.00 17.45           O  \\nATOM    690  CB  THR A  89      28.360  27.423  22.451  1.00 17.59           C  \\nATOM    691  OG1 THR A  89      27.923  26.853  21.185  1.00 24.55           O  \\nATOM    692  CG2 THR A  89      27.261  27.902  23.400  1.00 21.48           C  \\nATOM    693  N   VAL A  90      30.572  28.938  24.073  1.00 18.21           N  \\nATOM    694  CA  VAL A  90      30.980  29.610  25.294  1.00 17.12           C  \\nATOM    695  C   VAL A  90      31.868  30.804  24.926  1.00 16.76           C  \\nATOM    696  O   VAL A  90      31.675  31.846  25.567  1.00 17.90           O  \\nATOM    697  CB  VAL A  90      31.667  28.667  26.291  1.00 14.60           C  \\nATOM    698  CG1 VAL A  90      32.332  29.359  27.469  1.00 14.54           C  \\nATOM    699  CG2 VAL A  90      30.657  27.672  26.786  1.00 19.10           C  \\nATOM    700  N   ALA A  91      32.754  30.635  23.970  1.00 10.75           N  \\nATOM    701  CA  ALA A  91      33.638  31.742  23.543  1.00 12.26           C  \\nATOM    702  C   ALA A  91      32.780  32.897  23.050  1.00 16.95           C  \\nATOM    703  O   ALA A  91      33.063  34.036  23.432  1.00 16.20           O  \\nATOM    704  CB  ALA A  91      34.629  31.293  22.478  1.00  9.95           C  \\nATOM    705  N   ILE A  92      31.788  32.578  22.225  1.00 14.01           N  \\nATOM    706  CA  ILE A  92      30.906  33.642  21.685  1.00 20.50           C  \\nATOM    707  C   ILE A  92      30.134  34.337  22.823  1.00 17.47           C  \\nATOM    708  O   ILE A  92      30.034  35.575  22.837  1.00 15.67           O  \\nATOM    709  CB  ILE A  92      29.984  33.106  20.538  1.00 20.56           C  \\nATOM    710  CG1 ILE A  92      30.885  32.859  19.284  1.00 14.53           C  \\nATOM    711  CG2 ILE A  92      28.780  34.025  20.218  1.00 12.81           C  \\nATOM    712  CD1 ILE A  92      30.054  31.995  18.292  1.00 16.95           C  \\nATOM    713  N   ARG A  93      29.556  33.567  23.736  1.00 14.49           N  \\nATOM    714  CA  ARG A  93      28.794  34.168  24.828  1.00 18.76           C  \\nATOM    715  C   ARG A  93      29.711  35.064  25.649  1.00 17.16           C  \\nATOM    716  O   ARG A  93      29.324  36.166  26.049  1.00 16.42           O  \\nATOM    717  CB  ARG A  93      28.145  33.032  25.592  1.00 17.75           C  \\nATOM    718  CG  ARG A  93      27.242  33.508  26.716  1.00 35.41           C  \\nATOM    719  CD  ARG A  93      26.922  32.320  27.573  1.00 45.93           C  \\nATOM    720  NE  ARG A  93      26.362  31.336  26.645  1.00 46.10           N  \\nATOM    721  CZ  ARG A  93      26.471  30.022  26.817  1.00 76.63           C  \\nATOM    722  NH1 ARG A  93      27.322  29.481  27.685  1.00 54.12           N  \\nATOM    723  NH2 ARG A  93      25.670  29.245  26.082  1.00 62.87           N  \\nATOM    724  N   CYS A  94      30.946  34.683  25.880  1.00 15.49           N  \\nATOM    725  CA  CYS A  94      31.893  35.528  26.659  1.00 20.88           C  \\nATOM    726  C   CYS A  94      32.330  36.727  25.783  1.00 17.36           C  \\nATOM    727  O   CYS A  94      32.335  37.840  26.375  1.00 18.30           O  \\nATOM    728  CB  CYS A  94      33.016  34.662  27.256  1.00 13.87           C  \\nATOM    729  SG  CYS A  94      34.183  35.643  28.222  1.00 15.28           S  \\nATOM    730  N   ALA A  95      32.655  36.606  24.492  1.00 15.48           N  \\nATOM    731  CA  ALA A  95      33.016  37.783  23.675  1.00 17.66           C  \\nATOM    732  C   ALA A  95      31.865  38.798  23.642  1.00 20.76           C  \\nATOM    733  O   ALA A  95      32.019  40.020  23.619  1.00 14.72           O  \\nATOM    734  CB  ALA A  95      33.424  37.365  22.281  1.00 12.91           C  \\nATOM    735  N   LYS A  96      30.605  38.346  23.619  1.00 14.30           N  \\nATOM    736  CA  LYS A  96      29.419  39.206  23.666  1.00 17.13           C  \\nATOM    737  C   LYS A  96      29.428  40.003  24.986  1.00 17.20           C  \\nATOM    738  O   LYS A  96      29.018  41.183  24.985  1.00 17.01           O  \\nATOM    739  CB  LYS A  96      28.100  38.457  23.541  1.00  8.06           C  \\nATOM    740  CG  LYS A  96      27.947  38.011  22.097  1.00 18.44           C  \\nATOM    741  CD  LYS A  96      26.604  37.293  21.950  1.00 21.53           C  \\nATOM    742  CE  LYS A  96      26.380  36.802  20.523  1.00 24.84           C  \\nATOM    743  NZ  LYS A  96      25.188  35.905  20.535  1.00 20.54           N  \\nATOM    744  N   ARG A  97      29.825  39.369  26.083  1.00 13.83           N  \\nATOM    745  CA  ARG A  97      29.907  40.040  27.381  1.00 17.41           C  \\nATOM    746  C   ARG A  97      31.055  41.087  27.372  1.00 19.69           C  \\nATOM    747  O   ARG A  97      30.916  42.254  27.822  1.00 15.34           O  \\nATOM    748  CB  ARG A  97      30.080  39.057  28.530  1.00 16.69           C  \\nATOM    749  CG  ARG A  97      30.450  39.720  29.857  1.00 17.78           C  \\nATOM    750  CD  ARG A  97      29.401  40.677  30.301  1.00 25.17           C  \\nATOM    751  NE  ARG A  97      29.717  41.496  31.444  1.00 18.76           N  \\nATOM    752  CZ  ARG A  97      30.365  42.651  31.411  1.00 13.49           C  \\nATOM    753  NH1 ARG A  97      30.780  43.264  30.320  1.00 12.96           N  \\nATOM    754  NH2 ARG A  97      30.565  43.230  32.583  1.00 19.37           N  \\nATOM    755  N   VAL A  98      32.222  40.728  26.873  1.00 15.71           N  \\nATOM    756  CA  VAL A  98      33.373  41.606  26.768  1.00 18.30           C  \\nATOM    757  C   VAL A  98      32.986  42.889  26.004  1.00 17.21           C  \\nATOM    758  O   VAL A  98      33.398  43.946  26.547  1.00 17.38           O  \\nATOM    759  CB  VAL A  98      34.584  40.915  26.098  1.00 16.56           C  \\nATOM    760  CG1 VAL A  98      35.717  41.920  25.863  1.00 14.33           C  \\nATOM    761  CG2 VAL A  98      35.079  39.679  26.832  1.00 10.64           C  \\nATOM    762  N   VAL A  99      32.319  42.821  24.853  1.00 13.39           N  \\nATOM    763  CA  VAL A  99      32.018  44.020  24.083  1.00 14.82           C  \\nATOM    764  C   VAL A  99      31.002  45.000  24.714  1.00 17.40           C  \\nATOM    765  O   VAL A  99      30.894  46.131  24.187  1.00 17.99           O  \\nATOM    766  CB  VAL A  99      31.431  43.859  22.632  1.00 24.56           C  \\nATOM    767  CG1 VAL A  99      32.662  43.864  21.750  1.00 23.77           C  \\nATOM    768  CG2 VAL A  99      30.443  42.748  22.502  1.00 15.81           C  \\nATOM    769  N   LEU A 100      30.323  44.532  25.726  1.00 17.67           N  \\nATOM    770  CA  LEU A 100      29.349  45.395  26.404  1.00 21.97           C  \\nATOM    771  C   LEU A 100      30.083  46.361  27.342  1.00 20.83           C  \\nATOM    772  O   LEU A 100      29.358  47.280  27.727  1.00 26.62           O  \\nATOM    773  CB  LEU A 100      28.302  44.535  27.108  1.00 15.25           C  \\nATOM    774  CG  LEU A 100      27.471  43.650  26.219  1.00 17.44           C  \\nATOM    775  CD1 LEU A 100      26.531  42.842  27.118  1.00 31.28           C  \\nATOM    776  CD2 LEU A 100      26.686  44.489  25.222  1.00 17.72           C  \\nATOM    777  N   ASP A 101      31.333  46.128  27.694  1.00 13.05           N  \\nATOM    778  CA  ASP A 101      31.988  47.087  28.564  1.00 16.95           C  \\nATOM    779  C   ASP A 101      32.228  48.341  27.707  1.00 22.07           C  \\nATOM    780  O   ASP A 101      32.169  48.304  26.479  1.00 21.47           O  \\nATOM    781  CB  ASP A 101      33.282  46.590  29.213  1.00 18.53           C  \\nATOM    782  CG  ASP A 101      33.044  45.995  30.590  1.00 17.30           C  \\nATOM    783  OD1 ASP A 101      31.874  45.780  30.979  1.00 26.27           O  \\nATOM    784  OD2 ASP A 101      34.060  45.721  31.245  1.00 22.85           O  \\nATOM    785  N   PRO A 102      32.499  49.413  28.436  1.00 21.39           N  \\nATOM    786  CA  PRO A 102      32.779  50.736  27.892  1.00 25.90           C  \\nATOM    787  C   PRO A 102      33.700  50.814  26.694  1.00 18.82           C  \\nATOM    788  O   PRO A 102      33.318  51.517  25.731  1.00 24.76           O  \\nATOM    789  CB  PRO A 102      33.385  51.460  29.109  1.00 29.27           C  \\nATOM    790  CG  PRO A 102      32.486  50.920  30.212  1.00 24.89           C  \\nATOM    791  CD  PRO A 102      32.568  49.435  29.920  1.00 23.84           C  \\nATOM    792  N   ASN A 103      34.764  50.039  26.726  1.00 23.60           N  \\nATOM    793  CA  ASN A 103      35.755  50.081  25.634  1.00 19.04           C  \\nATOM    794  C   ASN A 103      35.274  49.362  24.350  1.00 26.12           C  \\nATOM    795  O   ASN A 103      35.910  49.450  23.294  1.00 20.00           O  \\nATOM    796  CB  ASN A 103      37.068  49.457  26.094  1.00 20.77           C  \\nATOM    797  CG  ASN A 103      37.877  50.402  26.984  1.00 33.46           C  \\nATOM    798  OD1 ASN A 103      37.473  51.549  27.186  1.00 30.23           O  \\nATOM    799  ND2 ASN A 103      39.001  49.990  27.538  1.00 20.00           N  \\nATOM    800  N   GLY A 104      34.127  48.626  24.412  1.00 17.55           N  \\nATOM    801  CA  GLY A 104      33.616  47.925  23.243  1.00 18.44           C  \\nATOM    802  C   GLY A 104      34.701  47.013  22.665  1.00 15.00           C  \\nATOM    803  O   GLY A 104      35.494  46.395  23.387  1.00 16.48           O  \\nATOM    804  N   ILE A 105      34.713  46.948  21.358  1.00 16.97           N  \\nATOM    805  CA  ILE A 105      35.646  46.062  20.629  1.00 21.90           C  \\nATOM    806  C   ILE A 105      37.087  46.525  20.745  1.00 16.33           C  \\nATOM    807  O   ILE A 105      37.959  45.712  20.373  1.00 17.78           O  \\nATOM    808  CB  ILE A 105      35.054  45.889  19.172  1.00 20.57           C  \\nATOM    809  CG1 ILE A 105      35.574  44.581  18.532  1.00 13.63           C  \\nATOM    810  CG2 ILE A 105      35.326  47.181  18.371  1.00 20.85           C  \\nATOM    811  CD1 ILE A 105      34.898  44.235  17.204  1.00 14.68           C  \\nATOM    812  N   GLY A 106      37.261  47.705  21.309  1.00 15.13           N  \\nATOM    813  CA  GLY A 106      38.620  48.245  21.517  1.00 12.14           C  \\nATOM    814  C   GLY A 106      39.312  47.460  22.610  1.00 19.51           C  \\nATOM    815  O   GLY A 106      40.470  47.686  22.916  1.00 19.10           O  \\nATOM    816  N   ALA A 107      38.652  46.513  23.251  1.00 17.59           N  \\nATOM    817  CA  ALA A 107      39.173  45.619  24.293  1.00 15.03           C  \\nATOM    818  C   ALA A 107      40.253  44.710  23.697  1.00 15.02           C  \\nATOM    819  O   ALA A 107      41.168  44.201  24.344  1.00 18.31           O  \\nATOM    820  CB  ALA A 107      38.120  44.734  24.928  1.00 18.12           C  \\nATOM    821  N   TRP A 108      40.102  44.455  22.407  1.00 16.04           N  \\nATOM    822  CA  TRP A 108      41.024  43.604  21.666  1.00 16.09           C  \\nATOM    823  C   TRP A 108      42.185  44.390  21.050  1.00 19.70           C  \\nATOM    824  O   TRP A 108      41.940  45.192  20.125  1.00 19.09           O  \\nATOM    825  CB  TRP A 108      40.250  42.838  20.565  1.00 17.83           C  \\nATOM    826  CG  TRP A 108      39.508  41.661  21.114  1.00 13.49           C  \\nATOM    827  CD1 TRP A 108      39.997  40.402  21.369  1.00 14.20           C  \\nATOM    828  CD2 TRP A 108      38.133  41.659  21.526  1.00 12.99           C  \\nATOM    829  NE1 TRP A 108      38.977  39.640  21.907  1.00 15.50           N  \\nATOM    830  CE2 TRP A 108      37.816  40.352  22.006  1.00 11.62           C  \\nATOM    831  CE3 TRP A 108      37.128  42.621  21.504  1.00 14.87           C  \\nATOM    832  CZ2 TRP A 108      36.552  39.982  22.465  1.00 12.52           C  \\nATOM    833  CZ3 TRP A 108      35.854  42.259  21.957  1.00 14.43           C  \\nATOM    834  CH2 TRP A 108      35.567  40.965  22.438  1.00 15.49           C  \\nATOM    835  N   VAL A 109      43.393  44.138  21.490  1.00 15.29           N  \\nATOM    836  CA  VAL A 109      44.564  44.819  20.925  1.00 21.54           C  \\nATOM    837  C   VAL A 109      44.623  44.610  19.404  1.00 23.06           C  \\nATOM    838  O   VAL A 109      44.864  45.605  18.677  1.00 19.01           O  \\nATOM    839  CB  VAL A 109      45.872  44.374  21.633  1.00 20.10           C  \\nATOM    840  CG1 VAL A 109      47.055  45.224  21.119  1.00 22.23           C  \\nATOM    841  CG2 VAL A 109      45.761  44.380  23.126  1.00 27.58           C  \\nATOM    842  N   ALA A 110      44.457  43.394  18.900  1.00 20.17           N  \\nATOM    843  CA  ALA A 110      44.567  43.107  17.463  1.00 19.37           C  \\nATOM    844  C   ALA A 110      43.513  43.877  16.682  1.00 17.18           C  \\nATOM    845  O   ALA A 110      43.932  44.231  15.553  1.00 18.73           O  \\nATOM    846  CB  ALA A 110      44.478  41.621  17.114  1.00 20.58           C  \\nATOM    847  N   TRP A 111      42.320  44.088  17.232  1.00 16.19           N  \\nATOM    848  CA  TRP A 111      41.333  44.872  16.460  1.00 12.35           C  \\nATOM    849  C   TRP A 111      41.857  46.331  16.297  1.00 19.29           C  \\nATOM    850  O   TRP A 111      41.792  46.927  15.207  1.00 18.58           O  \\nATOM    851  CB  TRP A 111      39.935  44.789  17.078  1.00 13.53           C  \\nATOM    852  CG  TRP A 111      38.914  45.576  16.308  1.00 14.55           C  \\nATOM    853  CD1 TRP A 111      38.112  45.145  15.268  1.00 14.98           C  \\nATOM    854  CD2 TRP A 111      38.592  46.964  16.537  1.00 15.96           C  \\nATOM    855  NE1 TRP A 111      37.324  46.174  14.853  1.00 14.19           N  \\nATOM    856  CE2 TRP A 111      37.604  47.304  15.588  1.00 20.11           C  \\nATOM    857  CE3 TRP A 111      39.073  47.910  17.449  1.00 16.50           C  \\nATOM    858  CZ2 TRP A 111      37.076  48.596  15.486  1.00 15.26           C  \\nATOM    859  CZ3 TRP A 111      38.523  49.182  17.375  1.00 18.55           C  \\nATOM    860  CH2 TRP A 111      37.544  49.508  16.436  1.00 18.44           C  \\nATOM    861  N   ARG A 112      42.300  46.939  17.385  1.00 16.92           N  \\nATOM    862  CA  ARG A 112      42.818  48.318  17.434  1.00 20.82           C  \\nATOM    863  C   ARG A 112      43.910  48.533  16.407  1.00 20.44           C  \\nATOM    864  O   ARG A 112      43.925  49.504  15.648  1.00 17.20           O  \\nATOM    865  CB  ARG A 112      43.357  48.710  18.841  1.00 12.95           C  \\nATOM    866  CG  ARG A 112      42.133  48.857  19.772  1.00 14.66           C  \\nATOM    867  CD  ARG A 112      42.330  49.813  20.906  1.00 18.96           C  \\nATOM    868  NE  ARG A 112      43.618  49.681  21.519  1.00 26.26           N  \\nATOM    869  CZ  ARG A 112      44.054  48.817  22.412  1.00 31.02           C  \\nATOM    870  NH1 ARG A 112      43.236  47.941  22.992  1.00 21.48           N  \\nATOM    871  NH2 ARG A 112      45.313  48.780  22.803  1.00 23.55           N  \\nATOM    872  N   LEU A 113      44.749  47.501  16.374  1.00 18.45           N  \\nATOM    873  CA  LEU A 113      45.939  47.519  15.550  1.00 25.99           C  \\nATOM    874  C   LEU A 113      45.681  47.231  14.056  1.00 31.44           C  \\nATOM    875  O   LEU A 113      46.098  48.003  13.184  1.00 23.75           O  \\nATOM    876  CB  LEU A 113      46.946  46.510  16.071  1.00 19.39           C  \\nATOM    877  CG  LEU A 113      48.346  47.099  16.060  1.00 47.96           C  \\nATOM    878  CD1 LEU A 113      48.435  48.440  16.796  1.00 20.00           C  \\nATOM    879  CD2 LEU A 113      49.385  46.195  16.705  1.00 20.00           C  \\nATOM    880  N   HIS A 114      45.093  46.098  13.698  1.00 22.13           N  \\nATOM    881  CA  HIS A 114      44.837  45.724  12.308  1.00 19.41           C  \\nATOM    882  C   HIS A 114      43.452  45.871  11.693  1.00 17.65           C  \\nATOM    883  O   HIS A 114      43.413  45.674  10.463  1.00 27.42           O  \\nATOM    884  CB  HIS A 114      45.136  44.209  12.140  1.00 15.20           C  \\nATOM    885  CG  HIS A 114      46.534  43.960  12.577  1.00 20.23           C  \\nATOM    886  ND1 HIS A 114      46.758  43.358  13.805  1.00 31.86           N  \\nATOM    887  CD2 HIS A 114      47.727  44.166  11.966  1.00 21.43           C  \\nATOM    888  CE1 HIS A 114      48.061  43.211  13.969  1.00 21.45           C  \\nATOM    889  NE2 HIS A 114      48.634  43.673  12.864  1.00 25.18           N  \\nATOM    890  N   CYS A 115      42.426  46.200  12.433  1.00 20.67           N  \\nATOM    891  CA  CYS A 115      41.107  46.283  11.869  1.00 19.68           C  \\nATOM    892  C   CYS A 115      40.453  47.636  11.967  1.00 15.99           C  \\nATOM    893  O   CYS A 115      39.652  47.912  11.049  1.00 21.86           O  \\nATOM    894  CB  CYS A 115      40.171  45.279  12.605  1.00 18.67           C  \\nATOM    895  SG  CYS A 115      40.931  43.617  12.760  1.00 19.60           S  \\nATOM    896  N   GLN A 116      40.704  48.332  13.061  1.00 15.01           N  \\nATOM    897  CA  GLN A 116      40.067  49.652  13.248  1.00 23.86           C  \\nATOM    898  C   GLN A 116      40.348  50.586  12.064  1.00 27.48           C  \\nATOM    899  O   GLN A 116      41.511  50.661  11.615  1.00 24.50           O  \\nATOM    900  CB  GLN A 116      40.582  50.271  14.524  1.00 13.47           C  \\nATOM    901  CG  GLN A 116      40.094  51.679  14.755  1.00 16.62           C  \\nATOM    902  CD  GLN A 116      40.350  52.150  16.168  1.00 22.39           C  \\nATOM    903  OE1 GLN A 116      39.545  52.906  16.707  1.00 29.30           O  \\nATOM    904  NE2 GLN A 116      41.443  51.741  16.817  1.00 16.00           N  \\nATOM    905  N   ASN A 117      39.326  51.255  11.551  1.00 28.23           N  \\nATOM    906  CA  ASN A 117      39.531  52.191  10.415  1.00 42.50           C  \\nATOM    907  C   ASN A 117      40.001  51.571   9.097  1.00 61.43           C  \\nATOM    908  O   ASN A 117      40.420  52.304   8.171  1.00 42.87           O  \\nATOM    909  CB  ASN A 117      40.541  53.291  10.825  1.00 33.32           C  \\nATOM    910  CG  ASN A 117      40.120  54.182  11.976  1.00 31.33           C  \\nATOM    911  OD1 ASN A 117      38.926  54.497  12.184  1.00 37.02           O  \\nATOM    912  ND2 ASN A 117      41.117  54.596  12.771  1.00 33.22           N  \\nATOM    913  N   GLN A 118      39.985  50.273   8.938  1.00 35.07           N  \\nATOM    914  CA  GLN A 118      40.392  49.535   7.749  1.00 29.48           C  \\nATOM    915  C   GLN A 118      39.224  49.101   6.861  1.00 33.01           C  \\nATOM    916  O   GLN A 118      38.065  49.114   7.297  1.00 27.85           O  \\nATOM    917  CB  GLN A 118      41.121  48.198   8.037  1.00 30.27           C  \\nATOM    918  CG  GLN A 118      42.384  48.563   8.815  1.00 36.63           C  \\nATOM    919  CD  GLN A 118      43.433  48.995   7.814  1.00 75.43           C  \\nATOM    920  OE1 GLN A 118      43.138  49.281   6.653  1.00 76.43           O  \\nATOM    921  NE2 GLN A 118      44.634  48.968   8.379  1.00 73.90           N  \\nATOM    922  N   ASP A 119      39.638  48.675   5.669  1.00 33.91           N  \\nATOM    923  CA  ASP A 119      38.556  48.161   4.772  1.00 39.09           C  \\nATOM    924  C   ASP A 119      38.547  46.656   5.106  1.00 21.68           C  \\nATOM    925  O   ASP A 119      39.526  45.900   4.908  1.00 31.47           O  \\nATOM    926  CB  ASP A 119      38.741  48.595   3.324  1.00 44.22           C  \\nATOM    927  CG  ASP A 119      37.453  48.269   2.550  1.00 81.11           C  \\nATOM    928  OD1 ASP A 119      36.477  49.055   2.549  1.00 69.69           O  \\nATOM    929  OD2 ASP A 119      37.407  47.179   1.952  1.00 71.31           O  \\nATOM    930  N   LEU A 120      37.431  46.230   5.692  1.00 30.47           N  \\nATOM    931  CA  LEU A 120      37.331  44.802   6.116  1.00 24.47           C  \\nATOM    932  C   LEU A 120      36.547  43.896   5.179  1.00 35.50           C  \\nATOM    933  O   LEU A 120      36.230  42.733   5.510  1.00 23.43           O  \\nATOM    934  CB  LEU A 120      36.761  44.902   7.537  1.00 19.87           C  \\nATOM    935  CG  LEU A 120      37.462  45.716   8.594  1.00 18.37           C  \\nATOM    936  CD1 LEU A 120      36.864  45.446   9.968  1.00 23.47           C  \\nATOM    937  CD2 LEU A 120      38.935  45.350   8.701  1.00 16.15           C  \\nATOM    938  N   ARG A 121      36.239  44.406   3.994  1.00 26.13           N  \\nATOM    939  CA  ARG A 121      35.463  43.694   2.969  1.00 43.70           C  \\nATOM    940  C   ARG A 121      36.054  42.321   2.669  1.00 36.20           C  \\nATOM    941  O   ARG A 121      35.344  41.307   2.522  1.00 31.75           O  \\nATOM    942  CB  ARG A 121      35.345  44.522   1.675  1.00 35.99           C  \\nATOM    943  CG  ARG A 121      33.936  45.100   1.507  1.00 63.53           C  \\nATOM    944  CD  ARG A 121      32.852  44.064   1.547  1.00 76.01           C  \\nATOM    945  NE  ARG A 121      31.605  44.323   0.849  1.00 81.11           N  \\nATOM    946  CZ  ARG A 121      31.249  44.324  -0.436  1.00 81.11           C  \\nATOM    947  NH1 ARG A 121      32.080  44.339  -1.486  1.00 76.93           N  \\nATOM    948  NH2 ARG A 121      29.937  44.310  -0.730  1.00 78.66           N  \\nATOM    949  N   SER A 122      37.368  42.334   2.567  1.00 19.19           N  \\nATOM    950  CA  SER A 122      38.094  41.110   2.292  1.00 22.31           C  \\nATOM    951  C   SER A 122      37.878  39.995   3.315  1.00 38.34           C  \\nATOM    952  O   SER A 122      38.062  38.817   2.910  1.00 25.91           O  \\nATOM    953  CB  SER A 122      39.584  41.424   2.244  1.00 33.09           C  \\nATOM    954  OG  SER A 122      39.929  42.127   3.430  1.00 60.31           O  \\nATOM    955  N   TYR A 123      37.575  40.310   4.563  1.00 33.97           N  \\nATOM    956  CA  TYR A 123      37.428  39.223   5.561  1.00 26.12           C  \\nATOM    957  C   TYR A 123      36.200  38.357   5.300  1.00 14.78           C  \\nATOM    958  O   TYR A 123      36.275  37.207   5.768  1.00 22.61           O  \\nATOM    959  CB  TYR A 123      37.444  39.773   7.013  1.00 17.69           C  \\nATOM    960  CG  TYR A 123      38.846  40.281   7.282  1.00 20.04           C  \\nATOM    961  CD1 TYR A 123      39.858  39.432   7.688  1.00 15.21           C  \\nATOM    962  CD2 TYR A 123      39.164  41.627   7.071  1.00 25.16           C  \\nATOM    963  CE1 TYR A 123      41.160  39.905   7.923  1.00 15.03           C  \\nATOM    964  CE2 TYR A 123      40.433  42.109   7.327  1.00 17.95           C  \\nATOM    965  CZ  TYR A 123      41.449  41.250   7.741  1.00 16.94           C  \\nATOM    966  OH  TYR A 123      42.737  41.675   7.993  1.00 19.62           O  \\nATOM    967  N   VAL A 124      35.192  38.853   4.629  1.00 18.45           N  \\nATOM    968  CA  VAL A 124      33.978  38.018   4.369  1.00 21.35           C  \\nATOM    969  C   VAL A 124      33.731  37.751   2.882  1.00 20.96           C  \\nATOM    970  O   VAL A 124      32.794  37.067   2.504  1.00 22.36           O  \\nATOM    971  CB  VAL A 124      32.799  38.683   5.078  1.00 23.47           C  \\nATOM    972  CG1 VAL A 124      33.059  38.598   6.571  1.00 26.40           C  \\nATOM    973  CG2 VAL A 124      32.560  40.101   4.601  1.00 30.60           C  \\nATOM    974  N   ALA A 125      34.618  38.214   2.027  1.00 25.88           N  \\nATOM    975  CA  ALA A 125      34.575  38.033   0.592  1.00 32.41           C  \\nATOM    976  C   ALA A 125      34.616  36.536   0.269  1.00 21.27           C  \\nATOM    977  O   ALA A 125      35.465  35.760   0.722  1.00 27.19           O  \\nATOM    978  CB  ALA A 125      35.733  38.705  -0.120  1.00 38.08           C  \\nATOM    979  N   GLY A 126      33.628  36.229  -0.558  1.00 29.73           N  \\nATOM    980  CA  GLY A 126      33.422  34.859  -1.048  1.00 16.76           C  \\nATOM    981  C   GLY A 126      32.706  33.952  -0.036  1.00 18.63           C  \\nATOM    982  O   GLY A 126      32.705  32.762  -0.383  1.00 24.95           O  \\nATOM    983  N   CYS A 127      32.195  34.442   1.085  1.00 23.65           N  \\nATOM    984  CA  CYS A 127      31.633  33.532   2.092  1.00 15.47           C  \\nATOM    985  C   CYS A 127      30.155  33.267   1.882  1.00 15.28           C  \\nATOM    986  O   CYS A 127      29.662  32.307   2.475  1.00 23.63           O  \\nATOM    987  CB  CYS A 127      31.942  34.102   3.494  1.00 19.93           C  \\nATOM    988  SG  CYS A 127      33.718  34.150   3.855  1.00 22.03           S  \\nATOM    989  N   GLY A 128      29.575  34.150   1.101  1.00 23.38           N  \\nATOM    990  CA  GLY A 128      28.150  34.117   0.760  1.00 18.57           C  \\nATOM    991  C   GLY A 128      27.265  34.369   1.962  1.00 22.84           C  \\nATOM    992  O   GLY A 128      26.203  33.765   2.081  1.00 28.45           O  \\nATOM    993  N   VAL A 129      27.607  35.188   2.912  1.00 25.27           N  \\nATOM    994  CA  VAL A 129      26.915  35.579   4.143  1.00 23.88           C  \\nATOM    995  C   VAL A 129      27.122  37.129   4.234  1.00 37.06           C  \\nATOM    996  O   VAL A 129      26.036  37.695   4.510  1.00 43.88           O  \\nATOM    997  CB  VAL A 129      27.347  34.847   5.420  1.00 30.64           C  \\nATOM    998  CG1 VAL A 129      27.275  33.331   5.355  1.00 34.41           C  \\nATOM    999  CG2 VAL A 129      28.771  35.215   5.868  1.00 30.19           C  \\nTER    1000      VAL A 129                                                      \\nHETATM 1001  C1  NAG A 130      40.573  45.941  30.725  1.00 16.35           C  \\nHETATM 1002  C2  NAG A 130      40.599  47.461  31.105  1.00 49.86           C  \\nHETATM 1003  C3  NAG A 130      39.697  47.780  32.309  1.00 29.37           C  \\nHETATM 1004  C4  NAG A 130      38.249  47.104  32.228  1.00 20.77           C  \\nHETATM 1005  C5  NAG A 130      38.436  45.626  31.880  1.00 22.06           C  \\nHETATM 1006  C6  NAG A 130      37.186  44.958  31.539  1.00 18.57           C  \\nHETATM 1007  C7  NAG A 130      42.034  48.701  30.178  1.00 25.62           C  \\nHETATM 1008  C8  NAG A 130      43.346  49.262  30.759  1.00 42.60           C  \\nHETATM 1009  N2  NAG A 130      41.695  47.858  31.171  1.00 42.79           N  \\nHETATM 1010  O3  NAG A 130      39.266  49.181  32.311  1.00 46.30           O  \\nHETATM 1011  O4  NAG A 130      37.469  47.416  33.391  1.00 26.43           O  \\nHETATM 1012  O5  NAG A 130      39.246  45.423  30.710  1.00 20.34           O  \\nHETATM 1013  O6  NAG A 130      36.383  45.653  30.651  1.00 21.58           O  \\nHETATM 1014  O7  NAG A 130      41.594  49.122  29.081  1.00 58.35           O  \\nHETATM 1015  C1  NAG A 131      43.023  42.938  27.078  1.00 24.56           C  \\nHETATM 1016  C2  NAG A 131      41.492  42.604  27.308  1.00 30.33           C  \\nHETATM 1017  C3  NAG A 131      40.822  43.798  27.982  1.00 13.79           C  \\nHETATM 1018  C4  NAG A 131      41.639  44.440  29.207  1.00 16.75           C  \\nHETATM 1019  C5  NAG A 131      43.116  44.565  28.850  1.00 32.65           C  \\nHETATM 1020  C6  NAG A 131      43.971  44.853  30.023  1.00 38.78           C  \\nHETATM 1021  C7  NAG A 131      40.423  40.786  26.468  1.00 12.52           C  \\nHETATM 1022  C8  NAG A 131      39.899  40.642  25.035  1.00 12.39           C  \\nHETATM 1023  N2  NAG A 131      40.892  42.050  26.534  1.00 17.85           N  \\nHETATM 1024  O3  NAG A 131      39.563  43.515  28.603  1.00 15.77           O  \\nHETATM 1025  O4  NAG A 131      41.024  45.731  29.426  1.00 17.85           O  \\nHETATM 1026  O5  NAG A 131      43.596  43.274  28.397  1.00 20.51           O  \\nHETATM 1027  O6  NAG A 131      43.753  44.063  31.167  1.00 56.49           O  \\nHETATM 1028  O7  NAG A 131      40.336  39.746  27.152  1.00 16.98           O  \\nHETATM 1029  C1  NDG A 132      46.881  40.478  24.981  1.00 29.15           C  \\nHETATM 1030  C2  NDG A 132      46.805  41.995  25.238  1.00 28.47           C  \\nHETATM 1031  C3  NDG A 132      45.696  42.310  26.245  1.00 33.80           C  \\nHETATM 1032  C4  NDG A 132      44.322  41.736  25.871  1.00 33.06           C  \\nHETATM 1033  C5  NDG A 132      44.299  40.337  25.216  1.00 33.05           C  \\nHETATM 1034  C6  NDG A 132      43.345  40.460  24.056  1.00 28.22           C  \\nHETATM 1035  C7  NDG A 132      48.758  43.117  26.079  1.00 34.25           C  \\nHETATM 1036  C8  NDG A 132      48.543  44.254  25.032  1.00 34.25           C  \\nHETATM 1037  O   NDG A 132      45.558  39.988  24.562  1.00 34.25           O  \\nHETATM 1038  O3  NDG A 132      45.624  43.701  26.666  1.00 32.94           O  \\nHETATM 1039  O4  NDG A 132      43.524  41.622  27.086  1.00 26.50           O  \\nHETATM 1040  O6  NDG A 132      43.599  41.602  23.184  1.00 25.99           O  \\nHETATM 1041  O7  NDG A 132      49.919  43.191  26.673  1.00 34.25           O  \\nHETATM 1042  N2  NDG A 132      47.855  42.106  26.370  1.00 34.25           N  \\nHETATM 1043  O1L NDG A 132      47.236  40.018  26.007  1.00 20.00           O  \\nHETATM 1044  O   HOH A 133      26.246  29.807  19.762  1.00 44.26           O  \\nHETATM 1045  O   HOH A 134      42.457  45.513   5.433  1.00 44.45           O  \\nHETATM 1046  O   HOH A 135      43.129  44.697   8.039  1.00 42.75           O  \\nHETATM 1047  O   HOH A 136      30.676  48.082  12.515  1.00 30.11           O  \\nHETATM 1048  O   HOH A 137      45.397  33.460   9.278  1.00 46.64           O  \\nHETATM 1049  O   HOH A 138      42.270  28.973   8.488  1.00 30.46           O  \\nHETATM 1050  O   HOH A 139      44.881  29.870  10.111  1.00 36.19           O  \\nHETATM 1051  O   HOH A 140      36.813  19.961  21.449  1.00 37.55           O  \\nHETATM 1052  O   HOH A 141      33.911  21.046  21.228  1.00 29.57           O  \\nHETATM 1053  O   HOH A 142      47.163  37.425  22.811  1.00 35.20           O  \\nHETATM 1054  O   HOH A 143      50.688  29.260  26.410  1.00 35.88           O  \\nHETATM 1055  O   HOH A 144      37.814  30.027  21.259  1.00 18.60           O  \\nHETATM 1056  O   HOH A 145      35.987  28.037  21.407  1.00 18.50           O  \\nHETATM 1057  O   HOH A 146      33.941  27.839  23.332  1.00 18.21           O  \\nHETATM 1058  O   HOH A 147      31.233  25.903  23.973  1.00 26.37           O  \\nHETATM 1059  O   HOH A 148      33.222  25.029  25.620  1.00 24.59           O  \\nHETATM 1060  O   HOH A 149      48.054  41.415  29.146  1.00 38.25           O  \\nHETATM 1061  O   HOH A 150      45.653  41.509  31.621  1.00 30.84           O  \\nHETATM 1062  O   HOH A 151      39.549  47.453  27.372  1.00 28.50           O  \\nHETATM 1063  O   HOH A 152      37.121  46.082  28.281  1.00 23.29           O  \\nHETATM 1064  O   HOH A 153      35.737  48.800  29.148  1.00 19.80           O  \\nHETATM 1065  O   HOH A 154      35.327  46.041  26.364  1.00 17.44           O  \\nHETATM 1066  O   HOH A 155      47.450  39.756  36.686  1.00 42.57           O  \\nHETATM 1067  O   HOH A 156      43.181  32.844  38.573  1.00 26.40           O  \\nHETATM 1068  O   HOH A 157      42.102  33.428  36.234  1.00 25.04           O  \\nHETATM 1069  O   HOH A 158      50.872  31.929  34.885  1.00 34.74           O  \\nHETATM 1070  O   HOH A 159      51.336  27.000  35.357  1.00 59.34           O  \\nHETATM 1071  O   HOH A 160      46.953  28.097  31.061  1.00 18.96           O  \\nHETATM 1072  O   HOH A 161      47.577  32.509  33.301  1.00 16.49           O  \\nHETATM 1073  O   HOH A 162      30.297  30.120   3.054  1.00 32.01           O  \\nHETATM 1074  O   HOH A 163      30.253  43.810   4.175  1.00 73.43           O  \\nHETATM 1075  O   HOH A 164      54.291  42.638  35.300  1.00 60.64           O  \\nHETATM 1076  O   HOH A 165      38.180  32.868  22.674  1.00 14.52           O  \\nHETATM 1077  O   HOH A 166      41.909  25.652  37.234  1.00 16.68           O  \\nHETATM 1078  O   HOH A 167      39.176  23.335  33.549  1.00 20.31           O  \\nHETATM 1079  O   HOH A 168      33.991  29.402  36.749  1.00 37.46           O  \\nHETATM 1080  O   HOH A 169      36.366  22.717  30.508  1.00 38.87           O  \\nHETATM 1081  O   HOH A 170      39.688  22.174  27.546  1.00 42.71           O  \\nHETATM 1082  O   HOH A 171      29.454  33.811  29.657  1.00 36.48           O  \\nHETATM 1083  O   HOH A 172      30.286  32.010  28.140  1.00 34.07           O  \\nHETATM 1084  O   HOH A 173      26.854  37.106  26.832  1.00 35.29           O  \\nHETATM 1085  O   HOH A 174      25.482  39.410  26.251  1.00 45.08           O  \\nHETATM 1086  O   HOH A 175      39.875  25.136  41.397  1.00 30.77           O  \\nHETATM 1087  O   HOH A 176      40.998  27.364  39.063  1.00 27.69           O  \\nHETATM 1088  O   HOH A 177      26.908  31.409  21.981  1.00 25.68           O  \\nHETATM 1089  O   HOH A 178      25.643  33.900  22.469  1.00 33.30           O  \\nHETATM 1090  O   HOH A 179      28.495  28.102  18.315  1.00 48.60           O  \\nHETATM 1091  O   HOH A 180      31.692  24.972  11.145  1.00 57.62           O  \\nHETATM 1092  O   HOH A 181      26.885  25.969   5.922  1.00 31.19           O  \\nHETATM 1093  O   HOH A 182      28.060  29.349  15.898  1.00 45.01           O  \\nHETATM 1094  O   HOH A 183      30.711  26.321  17.129  1.00 32.36           O  \\nHETATM 1095  O   HOH A 184      28.775  30.503  29.497  1.00 42.21           O  \\nHETATM 1096  O   HOH A 185      29.237  27.866  30.561  1.00 45.76           O  \\nHETATM 1097  O   HOH A 186      32.165  48.286  20.008  1.00 26.08           O  \\nHETATM 1098  O   HOH A 187      27.507  50.974  28.469  1.00 31.43           O  \\nHETATM 1099  O   HOH A 188      29.852  48.567  21.547  1.00 37.20           O  \\nHETATM 1100  O   HOH A 189      29.179  50.481  26.452  1.00 61.06           O  \\nHETATM 1101  O   HOH A 190      40.900  50.004  24.515  1.00 51.70           O  \\nHETATM 1102  O   HOH A 191      36.829  51.179  12.906  1.00 43.76           O  \\nHETATM 1103  O   HOH A 192      36.534  48.596  11.404  1.00 41.14           O  \\nHETATM 1104  O   HOH A 193      39.856  57.612  14.660  1.00 59.55           O  \\nHETATM 1105  O   HOH A 194      38.704  51.290  20.772  1.00 37.82           O  \\nHETATM 1106  O   HOH A 195      48.941  50.913  11.287  1.00 51.27           O  \\nHETATM 1107  O   HOH A 196      41.365  54.071   6.463  1.00 43.07           O  \\nHETATM 1108  O   HOH A 197      30.534  36.988  -1.181  1.00 49.70           O  \\nHETATM 1109  O   HOH A 198      28.760  32.799  -2.317  1.00 45.69           O  \\nHETATM 1110  O   HOH A 199      30.545  31.312  -1.471  1.00 52.26           O  \\nHETATM 1111  O   HOH A 200      35.181  29.738   1.305  1.00 70.41           O  \\nHETATM 1112  O   HOH A 201      41.204  32.816   2.283  1.00 52.05           O  \\nHETATM 1113  O   HOH A 202      30.290  37.315   2.097  1.00 50.90           O  \\nHETATM 1114  O   HOH A 203      36.649  53.205  15.444  1.00 50.94           O  \\nHETATM 1115  O   HOH A 204      39.838  37.684   1.374  1.00 55.90           O  \\nHETATM 1116  O   HOH A 205      38.677  22.618  10.243  1.00 55.54           O  \\nHETATM 1117  O   HOH A 206      35.313  21.009   9.026  1.00 67.16           O  \\nHETATM 1118  O   HOH A 207      46.674  25.557  10.445  1.00 57.98           O  \\nHETATM 1119  O   HOH A 208      52.371  31.422  25.856  1.00 52.46           O  \\nHETATM 1120  O   HOH A 209      48.032  27.106  40.293  1.00 43.30           O  \\nHETATM 1121  O   HOH A 210      56.608  40.738  35.434  1.00 54.13           O  \\nHETATM 1122  O   HOH A 211      33.205  26.406  35.788  1.00 63.54           O  \\nHETATM 1123  O   HOH A 212      29.234  47.657  32.231  1.00 41.22           O  \\nHETATM 1124  O   HOH A 213      46.802  44.695   8.975  1.00 48.32           O  \\nHETATM 1125  O   HOH A 214      53.596  49.218  16.249  1.00 73.45           O  \\nHETATM 1126  O   HOH A 215      32.346  24.399  27.898  1.00 40.20           O  \\nHETATM 1127  O   HOH A 216      41.164  56.842   5.360  1.00 44.94           O  \\nHETATM 1128  O   HOH A 217      47.408  34.053  10.598  1.00 51.62           O  \\nHETATM 1129  O   HOH A 218      44.979  32.067  42.084  1.00 52.74           O  \\nHETATM 1130  O   HOH A 219      27.532  40.972   6.997  1.00 63.43           O  \\nHETATM 1131  O   HOH A 220      35.738  28.722  38.494  1.00 43.37           O  \\nHETATM 1132  O   HOH A 221      25.386  39.507  30.001  1.00 54.29           O  \\nHETATM 1133  O   HOH A 222      34.311  27.464   3.780  1.00 44.60           O  \\nHETATM 1134  O   HOH A 223      50.613  33.594  21.911  1.00 38.89           O  \\nHETATM 1135  O   HOH A 224      39.789  34.054  38.678  1.00 44.91           O  \\nHETATM 1136  O   HOH A 225      39.373  36.275  35.797  1.00 40.70           O  \\nHETATM 1137  O   HOH A 226      24.449  30.637  24.318  1.00 49.23           O  \\nHETATM 1138  O   HOH A 227      36.385  31.881  39.673  1.00 46.21           O  \\nHETATM 1139  O   HOH A 228      22.724  32.719  25.222  1.00 63.16           O  \\nHETATM 1140  O   HOH A 229      28.016  27.288  11.824  1.00 26.02           O  \\nHETATM 1141  O   HOH A 230      35.986  51.649  18.787  1.00 56.77           O  \\nHETATM 1142  O   HOH A 231      47.921  36.396  13.846  1.00 58.72           O  \\nHETATM 1143  O   HOH A 232      35.793  51.622   5.105  1.00 74.45           O  \\nHETATM 1144  O   HOH A 233      47.283  29.645  16.652  1.00 38.97           O  \\nHETATM 1145  O   HOH A 234      50.606  28.923  14.105  1.00 68.81           O  \\nHETATM 1146  O   HOH A 235      40.743  20.028  12.770  1.00 49.94           O  \\nHETATM 1147  O   HOH A 236      40.974  30.394   6.052  1.00 28.38           O  \\nHETATM 1148  O   HOH A 237      37.422  30.358   3.256  1.00 38.28           O  \\nHETATM 1149  O   HOH A 238      24.619  37.527  13.027  1.00 17.78           O  \\nHETATM 1150  O   HOH A 239      36.019  22.147  28.080  1.00 33.75           O  \\nHETATM 1151  O   HOH A 240      30.422  26.031  14.322  1.00 70.01           O  \\nHETATM 1152  O   HOH A 241      47.806  54.316  10.948  1.00 29.81           O  \\nHETATM 1153  O   HOH A 242      35.610  48.903  33.703  1.00 46.20           O  \\nHETATM 1154  O   HOH A 243      48.198  36.379  20.430  1.00 72.71           O  \\nHETATM 1155  O   HOH A 244      46.009  39.902  21.612  1.00 62.02           O  \\nHETATM 1156  O   HOH A 245      35.934  45.940  35.267  1.00 44.04           O  \\nHETATM 1157  O   HOH A 246      34.148  44.122  34.308  1.00 40.52           O  \\nHETATM 1158  O   HOH A 247      36.685  44.061  36.384  1.00 74.76           O  \\nHETATM 1159  O   HOH A 248      33.772  41.949  39.092  1.00 70.07           O  \\nHETATM 1160  O   HOH A 249      47.689  41.322  22.332  1.00 34.09           O  \\nCONECT   53  988                                                                \\nCONECT  228  895                                                                \\nCONECT  510  623                                                                \\nCONECT  594  729                                                                \\nCONECT  623  510                                                                \\nCONECT  729  594                                                                \\nCONECT  895  228                                                                \\nCONECT  988   53                                                                \\nCONECT 1001 1002 1012 1025                                                      \\nCONECT 1002 1001 1003 1009                                                      \\nCONECT 1003 1002 1004 1010                                                      \\nCONECT 1004 1003 1005 1011                                                      \\nCONECT 1005 1004 1006 1012                                                      \\nCONECT 1006 1005 1013                                                           \\nCONECT 1007 1008 1009 1014                                                      \\nCONECT 1008 1007                                                                \\nCONECT 1009 1002 1007                                                           \\nCONECT 1010 1003                                                                \\nCONECT 1011 1004                                                                \\nCONECT 1012 1001 1005                                                           \\nCONECT 1013 1006                                                                \\nCONECT 1014 1007                                                                \\nCONECT 1015 1016 1026 1039                                                      \\nCONECT 1016 1015 1017 1023                                                      \\nCONECT 1017 1016 1018 1024                                                      \\nCONECT 1018 1017 1019 1025                                                      \\nCONECT 1019 1018 1020 1026                                                      \\nCONECT 1020 1019 1027                                                           \\nCONECT 1021 1022 1023 1028                                                      \\nCONECT 1022 1021                                                                \\nCONECT 1023 1016 1021                                                           \\nCONECT 1024 1017                                                                \\nCONECT 1025 1001 1018                                                           \\nCONECT 1026 1015 1019                                                           \\nCONECT 1027 1020                                                                \\nCONECT 1028 1021                                                                \\nCONECT 1029 1030 1037 1043                                                      \\nCONECT 1030 1029 1031 1042                                                      \\nCONECT 1031 1030 1032 1038                                                      \\nCONECT 1032 1031 1033 1039                                                      \\nCONECT 1033 1032 1034 1037                                                      \\nCONECT 1034 1033 1040                                                           \\nCONECT 1035 1036 1041 1042                                                      \\nCONECT 1036 1035                                                                \\nCONECT 1037 1029 1033                                                           \\nCONECT 1038 1031                                                                \\nCONECT 1039 1015 1032                                                           \\nCONECT 1040 1034                                                                \\nCONECT 1041 1035                                                                \\nCONECT 1042 1030 1035                                                           \\nCONECT 1043 1029                                                                \\nMASTER      330    0    3    8    2    0    8    6 1159    1   51   10          \\nEND                                                                             \\n\",\"pdb\");\n",
       "\tviewergrid_151451555764[0][1].setStyle({\"cartoon\": {\"color\": \"spectrum\"}});\n",
       "\tviewergrid_151451555764[0][1].setStyle({\"hetflag\": true},{\"stick\": {}});\n",
       "\tviewergrid_151451555764[0][1].zoomTo();\n",
       "\tviewergrid_151451555764[0][0].zoom(0.9);\n",
       "\tviewergrid_151451555764[0][0].rotate(-100,\"y\");\n",
       "\tviewergrid_151451555764[0][1].rotate(-100,\"y\");\n",
       "\tviewergrid_151451555764[0][0].rotate(-20,\"x\");\n",
       "\tviewergrid_151451555764[0][1].rotate(-20,\"x\");\n",
       "viewergrid_151451555764[0][1].render();\n",
       "viewergrid_151451555764[0][0].render();\n",
       "});\n",
       "</script>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "view = py3Dmol.view(width=900, height=400, viewergrid=(1,2))\n",
    "with open('with_ligand.B99990001.pdb', 'r') as pdbfile:\n",
    "    view.addModel(pdbfile.read(), 'pdb', viewer=(0,0))\n",
    "    view.setStyle({'cartoon': {'color':'spectrum'}}, viewer=(0,0))\n",
    "    view.setStyle({'hetflag': True}, {'stick':{}}, viewer=(0,0))\n",
    "    view.zoomTo(viewer=(0,0))\n",
    "    view.zoom(1.4, viewer=(0,0))\n",
    "with open('1lmp.pdb', 'r') as pdbfile:\n",
    "    view.addModel(pdbfile.read(), 'pdb', viewer=(0,1))\n",
    "    view.setStyle({'cartoon': {'color':'spectrum'}}, viewer=(0,1))\n",
    "    view.setStyle({'hetflag': True}, {'stick':{}}, viewer=(0,1))\n",
    "    view.zoomTo(viewer=(0,1))\n",
    "    view.zoom(0.9, viewer=(0,0))\n",
    "    \n",
    "    \n",
    "view.rotate(-100,'y');\n",
    "view.rotate(-20,'x');\n",
    "view.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Вывод:** несмотря на то, что идентичность белков по аминокислотным остаткам составляет лишь 55%, согласно проведенному моделированию они обладают схожей пространственной структурой. Белок лизоцима фазана обладает дополнительным \"хвостом\" по сравнению с белком форели, что обусловлено его большей на 18 аминокислот длиной."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Источники\n",
    "\n",
    "1. [Документация 3Dmol.js](http://3dmol.csb.pitt.edu/doc/$3Dmol.GLViewer.html)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "hse-py27",
   "language": "python",
   "name": "hse"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.14"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
